#! /bin/sh
### BEGIN INIT INFO
# Provides:          checkfs
# Required-Start:    checkroot
# Required-Stop:
# Should-Start:      mtab cryptdisks
# Should-stop:
# Default-Start:     S
# Default-Stop:
# Short-Description: Check /rw2 filesystems.
### END INIT INFO

# Include /usr/bin in path to find on_ac_power if /usr/ is on the root
# partition.
PATH='/lib/init:/sbin:/bin:/usr/bin'
FSCK_LOGFILE='/rw2/var/fsck_rw2_usb'
FSCK_TMPLOG='/rw/checkfs.tmp'

. /lib/init/vars.sh
. /lib/lsb/init-functions
. /lib/init/mount-functions.sh
. /lib/init/splash-functions-base



do_start() {

  KERNEL="$(uname -s)"
  MACHINE="$(uname -m)"
  FSCK_CODE="0"

  #
  # Read /etc/fstab, looking for:
  # 1) The /rw2 filesystem, resolving LABEL=*|UUID=* entries to the
  #   device node,
  # 2) Swap that is on a md device or a file that may be on a md
  #   device,
  # 3) The mount parameters for a devfs filesystem.
  #

  rw2_fstab="none"
  rw2_dev="none"
  rw2_type="none"
  rw2_opts="defaults"
  rw2_mode="rw"
  rw2_check="no"
  swap_on_lv="no"
  swap_on_file="no"
  devfs=""

  exec 9<&0 </etc/fstab

  while read DEV MTPT FSTYPE OPTS DUMP PASS JUNK; do

    case "$DEV" in
              ""|\#*) continue ;;
       /dev/mapper/*) [ "$FSTYPE" = "swap" ] && swap_on_lv="yes" ;;
                  /*) [ "$FSTYPE" = "swap" ] && swap_on_file="yes" ;;
      LABEL=*|UUID=*) [ "$MTPT" = "/rw2" ] && [ "$(which findfs)" ] && DEV="$(findfs "$DEV")" ;;
    esac

    if [ "$MTPT" == "/rw2" ]; then

      rw2_dev="$DEV"
      rw2_fstab="$DEV"
      rw2_opts="$OPTS"
      rw2_type="$FSTYPE"

      [ "$PASS" -ne "0" ] && rw2_check="yes"
      [ "$FSTYPE" == "nfs" ] || [ "$FSTYPE" == "nfs4" ] && rw2_check="no"

      case "$OPTS" in
        ro|ro,*|*,ro|*,ro,*) rw2_mode="ro" ;;
      esac
    fi

  done

  exec 0<&9 9<&-

  [ -f "/fastboot" ] || [ "$rw2_check" == "yes" ] && echo "checkfs: Start..."

  #
  # See if we want to check the root file system.
  #

  [ -f "/fastboot" ] && [ "$rw2_check" == "yes" ] && rw2_check="no" && log_warning_msg "Fast boot enabled, so skipping file system check."

  if [ "$rw2_check" == "yes" ]; then

    case "$TERM" in
      dumb|network|unknown|"") spinner="" ;;
                            *) spinner="-C" ;;
    esac

    # This Linux/s390 special case should go away.
    [ "${KERNEL}:${MACHINE}" == "Linux:s390" ] && spinner=""

    [ -f "/forcefsck" ] && force="-f" || force=""

    # FSCKFIX is always - yes
    fix="-y"

    splash_start_indefinite
      if [ "$VERBOSE" == "no" ]; then
        log_action_begin_msg "Checking rw2 file system"
        logsave -s $FSCK_TMPLOG fsck $spinner $force $fix -t $rw2_type $rw2_dev
        FSCK_CODE="$?"
        [ "$FSCK_CODE" -eq "0" ] && log_action_msg "Done" || log_action_msg "code $FSCK_CODE"
      else
        log_daemon_msg "Will now check rw2 file system"
        logsave -s $FSCK_TMPLOG fsck $spinner $force $fix -V -t $rw2_type $rw2_dev
        FSCK_CODE="$?"
        log_end_msg $FSCK_CODE
      fi
    splash_stop_indefinite

    # write logs to rw2
    if [ -f "$FSCK_TMPLOG" ]; then
      grep -w "\/rw2" /etc/fstab | while read RW2_DEV RW2_MNPT RW2_TYPE RW2_UNUSE; do
        mount -t $RW2_TYPE $RW2_DEV $RW2_MNPT
        [ "$?" -eq "0" ] && mv $FSCK_TMPLOG $FSCK_LOGFILE && umount /rw2 2> /dev/null
      done
    fi
  fi

  #
  # If there was a failure, that error message.
  #
  # NOTE: "failure" is defined as exiting with a return code of
  # 4 or larger. A return code of 1 indicates that file system
  # errors were corrected but that the boot may proceed. A return
  # code of 2 or 3 indicates that the system should immediately reboot.
  #

  if [ "$FSCK_CODE" -gt "1" ] && [ "$FSCK_CODE" -lt "4" ]; then
    # Surprise! FS is broken. Need manual fsck or run it again from /etc/fsbat
    # does not work because the root is currently read-only.
    log_daemon_msg "An automatic file system check (fsck) of the rw2 filesystem finished.
    The system will be restarted."
    sleep 3

    # Remove recovery flag to avoid infinity loop
    mount -o remount,rw /
      grep -E " / |/rw2|/boot" /etc/fstab|awk '{print $1}'|sed -e 's/\/dev\///'|while read line; do
        sed -i "/$line/s/1$/0/g" /etc/fstab
      done

    [ "$VERBOSE" != "no" ] && log_action_msg "Will now restart"
    sync && reboot -f
  elif [ "$FSCK_CODE" -gt "3" ]; then
    # Not block operations. Just error message
    log_failure_msg "An automatic file system check (fsck) of the rw2 filesystem failed." && sleep 3
  fi

  # Check USB drive
  if [ -f "/forcefsck" ]; then
    log_action_begin_msg "Check USB flash drive disk(s)"
    ls -lrt -d -1 /dev/disk/by-id/{*,.*}|grep -E "usb.*part"|grep -Eo "[sh]d[a-z][1-9]$"|sort|while read line; do
      logsave -s $FSCK_TMPLOG fsck -yf /dev/$line
    done
  fi

   # write logs to rw2 for USB
  if [ -f "$FSCK_TMPLOG" ]; then
    grep -w "\/rw2" /etc/fstab | while read RW2_DEV RW2_MNPT RW2_TYPE RW2_UNUSE; do
      mount -t $RW2_TYPE $RW2_DEV $RW2_MNPT
      [ "$?" -eq "0" ] && cat $FSCK_TMPLOG >> $FSCK_LOGFILE && rm -f $FSCK_TMPLOG && umount /rw2 2> /dev/null
    done
  fi

  # Clean up
  mount -o remount,rw /
    grep -E " / |/rw2|/boot" /etc/fstab|awk '{print $1}'|sed -e 's/\/dev\///'|while read line; do
      sed -i "/$line/s/1$/0/g" /etc/fstab
    done
  rm -f /fastboot /forcefsck 2>/dev/null
}

case "$1" in
  start|"")
    do_start
  ;;
  restart|reload|force-reload)
    echo "Error: argument '$1' not supported" >&2
    exit 3
  ;;
  stop)
    # No-op
  ;;
  *)
    echo "Usage: checkroot.sh [start|stop]" >&2
    exit 3
  ;;
esac
