#! /bin/sh
### BEGIN INIT INFO
# Provides:          checkroot
# Required-Start:    mountdevsubfs hostname
# Required-Stop:
# Should-Start:      keymap hwclockfirst hdparm bootlogd
# Should-stop:
# Default-Start:     S
# Default-Stop:
# Short-Description: Check to root file system.
### END INIT INFO

# Include /usr/bin in path to find on_ac_power if /usr/ is on the root
# partition.
PATH='/lib/init:/sbin:/bin:/usr/bin'
FSCK_LOGFILE='/rw2/var/fsck_root'
FSCK_TMPLOG='/rw/checkroot.tmp'

. /lib/init/vars.sh
. /lib/lsb/init-functions
. /lib/init/mount-functions.sh
. /lib/init/splash-functions-base


do_start() {

  KERNEL="$(uname -s)"
  MACHINE="$(uname -m)"
  FSCK_CODE="0"

  root_fstab="/dev/root"
  root_dev="none"
  root_type="none"
  root_opts="defaults"
  root_mode="rw"
  root_check="no"
  swap_on_lv="no"
  swap_on_file="no"
  devfs=""

  exec 9<&0 </etc/fstab

  while read DEV MTPT FSTYPE OPTS DUMP PASS JUNK; do
      case "$DEV" in
                ""|\#*) continue ;;
         /dev/mapper/*) [ "$FSTYPE" = "swap" ] && swap_on_lv="yes" ;;
                    /*) [ "$FSTYPE" = "swap" ] && swap_on_file="yes" ;;
        LABEL=*|UUID=*) [ "$MTPT" = "/" ] && [ "$(which findfs)" ] && DEV="$(findfs "$DEV")" ;;
                     *) [ "$FSTYPE" = "devfs" ] && [ "$MTPT" = "/dev" ] && mountpoint -q /dev && DEV="$(findfs "$DEV")" ;;
      esac

      if [ "$MTPT" == "/" ]; then

        root_dev="$DEV"
        root_fstab="$DEV"
        root_opts="$OPTS"
        root_type="$FSTYPE"

        [ "$PASS" -ne "0" ] && root_check="yes"
        [ "$FSTYPE" == "nfs" ] || [ "$FSTYPE" == "nfs4" ] && root_check="no"

        case "$OPTS" in
          ro|ro,*|*,ro|*,ro,*) root_mode="ro" ;;
        esac
      fi
  done

  exec 0<&9 9<&-

  [ "$root_check" == "yes" ] && echo "checkroot: Start..."

  #
  # Does the root device in /etc/fstab match with the actual device ?
  # If not we try to use the /dev/root alias device, and if that
  # fails we create a temporary node in /lib/init/rw.
  #

  if [ "$root_check" == "yes" ]; then
    ddev="$(mountpoint -qx $root_dev)"
    rdev="$(mountpoint -d /)"

    if [ "$ddev" != "$rdev" ] && [ "$ddev" != "4:0" ]; then
      if [ "$(mountpoint -qx /dev/root)" == "4:0" ]; then
        root_dev="/dev/root"
      else
        rm -f /lib/init/rw/root_dev && mknod -m 600 /lib/init/rw/root_dev b ${rdev%:*} ${rdev#*:} && [ -e "/lib/init/rw/root_dev" ] && root_dev="/lib/init/rw/root_dev" || root_fatal="yes"
      fi
    fi
  fi

  #
  # Bother, said Pooh.
  #

  if [ "$root_fatal" == "yes" ]; then
    log_failure_msg "The device node $root_dev for the root filesystem is missing or incorrect
    or there is no entry for the root filesystem listed in /etc/fstab.
    The system is also unable to create a temporary node in /lib/init/rw.
    This means you have to fix the problem manually."
    sleep 5
    [ "$VERBOSE" != "no" ] && log_action_msg "Will now restart"
    sync && reboot -f
  fi

  #
  # See if we want to check the root file system.
  #

  [ -f "/fastboot" ] && [ "$root_check" == "yes" ] && root_check="no" && log_warning_msg "Fast boot enabled, so skipping file system check."

  #
  # The actual checking is done here.
  #

  if [ "$root_check" == "yes" ]; then
    #
    # Ensure that root is quiescent and read-only before fsck'ing.
    #
    # mount -n -o remount,ro / would be the correct syntax but
    # mount can get confused when there is a "bind" mount defined
    # in fstab that bind-mounts "/" somewhere else.
    #
    # So we use mount -n -o remount,ro $root_dev / but that can
    # fail on older kernels on sparc64/alpha architectures due
    # to a bug in sys_mount().
    #
    # As a compromise we try both.
    #
    if \
      ! mount    -n -o remount,ro              $root_dev /              \
      && ! mount -n -o remount,ro -t dummytype $root_dev /  2>/dev/null \
      && ! mount -n -o remount,ro                       /  2>/dev/null
      then
      log_failure_msg "Cannot check root file system because it is not mounted read-only."
      root_check="no"
    fi

    case "$TERM" in
      dumb|network|unknown|"") spinner="" ;;
                            *) spinner="-C" ;;
    esac

    # This Linux/s390 special case should go away.
    [ "${KERNEL}:${MACHINE}" == "Linux:s390" ] && spinner=""

    [ -f "/forcefsck" ] && force="-f" || force=""

    # FSCKFIX is always - yes
    fix="-y"

    splash_start_indefinite
      if [ "$VERBOSE" == "no" ]; then
        log_action_begin_msg "Checking root file system"
        logsave -s $FSCK_TMPLOG fsck $spinner $force $fix -t $root_type $root_dev
        FSCK_CODE="$?"
        [ "$FSCK_CODE" -eq "0" ] && log_action_msg "Done" || log_action_msg "code $FSCK_CODE"
      else
        log_daemon_msg "Will now check root file system"
        logsave -s $FSCK_TMPLOG fsck $spinner $force $fix -V -t $root_type $root_dev
        FSCK_CODE="$?"
        log_end_msg $FSCK_CODE
      fi
    splash_stop_indefinite

    # write logs to rw2
    if [ -f "$FSCK_TMPLOG" ]; then
      grep -w "\/rw2" /etc/fstab | while read RW2_DEV RW2_MNPT RW2_TYPE RW2_UNUSE; do
        mount -t $RW2_TYPE $RW2_DEV $RW2_MNPT
        [ "$?" -eq "0" ] && mv $FSCK_TMPLOG $FSCK_LOGFILE && umount /rw2 2> /dev/null
      done
    fi
  fi

  #
  # If there was a failure, that error message.
  #
  # NOTE: "failure" is defined as exiting with a return code of
  # 4 or larger. A return code of 1 indicates that file system
  # errors were corrected but that the boot may proceed. A return
  # code of 2 or 3 indicates that the system should immediately reboot.
  #

  if [ "$FSCK_CODE" -gt "1" ] && [ "$FSCK_CODE" -lt "4" ]; then
    # Surprise! FS is broken. Need manual fsck or run it again from /etc/fsbat
    # does not work because the root is currently read-only.
    log_daemon_msg "An automatic file system check (fsck) of the root filesystem finished.
    The system should be restarted in 3 seconds."
    sleep 3

    # Remove recovery flag to avoid infinity loop
    mount -o remount,rw /
      grep -E " / " /etc/fstab|awk '{print $1}'|sed -e 's/\/dev\///'|while read line; do
        sed -i "/$line/s/1$/0/g" /etc/fstab
      done

    [ "$VERBOSE" != "no" ] && log_action_msg "Will now restart"
    sync && reboot -f
  elif [ "$FSCK_CODE" -gt "3" ]; then
    # Not block operations. Just error message
    log_failure_msg "An automatic file system check (fsck) of the rw2 filesystem failed." && sleep 3
  fi

  #
  # Remount root to final mode (rw or ro).
  #
  # See the comments above at the previous "mount -o remount"
  # for an explanation why we try this twice.
  #

  mount -n -o remount,$root_opts $root_fstab / 2>/dev/null || mount -n -o remount,$root_opts /

  #
  # We only create/modify /etc/mtab if the location where it is
  # stored is writable. If /etc/mtab is a symlink into /proc/
  # then it is not writable.
  #

  INIT_MTAB_FILE="no"
  MTAB_PATH="$(readlink -f /etc/mtab || :)"

  case "$MTAB_PATH" in
    /*) touch "$MTAB_PATH" &>/dev/null && rm -f ${MTAB_PATH}~ && INIT_MTAB_FILE="yes" ;;
    "")
      [ -L "/etc/mtab" ] && MTAB_PATH="$(readlink /etc/mtab)"
      [ "$MTAB_PATH" ] && log_failure_msg "Cannot initialize ${MTAB_PATH}." || log_failure_msg "Cannot initialize /etc/mtab."
    ;;
     *) log_failure_msg "Illegal mtab location '${MTAB_PATH}'." ;;
  esac

  if [ "$INIT_MTAB_FILE" == "yes" ]; then
    [ "$root_type" != "none" ] && mount -f -o $root_opts -t $root_type $root_fstab
    [ "$devfs" ] && mount -f $devfs
  fi

  #
  # Remove /lib/init/rw/root_dev if we created it.
  #

  rm -f /lib/init/rw/root_dev
}

case "$1" in
  start|"")
    do_start
  ;;
  restart|reload|force-reload)
    echo "Error: argument '$1' not supported" >&2
    exit 3
  ;;
  stop)
    # No-op
  ;;
  *)
    echo "Usage: checkroot.sh [start|stop]" >&2
    exit 3
  ;;
esac