#!/bin/bash

[ "$(whoami)" = "root" ] && SUDO="sudo -u wms" || SUDO=""

function log () {
        logger -i -t wms_msmtp $1
}

# make a check before starting envelope a letter
res=$(free 2>/dev/null | grep -o '[0-9]\+' | awk 'FNR == 6 {print}')
if [ $res -le 10240 ]; then

	# write to syslog
	log "No space left for mails"
	exit 1
fi

# get company id
if [ -z "$1" -a -z "$com_id" ]; then
	com_id=0
elif [ -n "$1" ]; then
	com_id=$1
fi

TMPDIR=/tmp/mail
QUEUEDIR=/var/spool/mail/$com_id

# Set secure permissions on created directories and files
umask 002

# Change to temp directory (create it if necessary)
if [ ! -d "$TMPDIR" ]; then
	$SUDO mkdir -p "$TMPDIR" || exit 1
fi
sudo chown wms.wms -R $TMPDIR
sudo chmod 775 $TMPDIR
cd "$TMPDIR" || exit 1

# Create new unique filenames of the form
# MAILFILE:  ccyy-mm-dd-hh.mm.ss[-x].mail
# where x is a consecutive number only appended if you send more than one
# mail per second.
BASE="`date +%Y-%m-%d-%H.%M.%S`-$RANDOM"

if [ -f "$BASE.mail" ]; then
	TMP="$BASE"
	i=1
	while [ -f "$TMP-$i.mail" ]; do
		i=`expr $i + 1`
	done
	BASE="$BASE-$i"
fi
MAILFILE="$BASE.mail"

cat | $SUDO tee "$MAILFILE" >/dev/null || exit 1

# Write the mail to $MAILFILE

# check attach in mails to get cases
# - voicemail, recording - wav
# - faxes - tiff
# - feedback, text - non the both

if [ `grep "Content-Type.*image/tiff" "$MAILFILE" -i -c` -ne 0 ]; then
	# tiff, faxing
	P="fax"
elif [ `grep "Content-Type.*audio/x-wav" "$MAILFILE" -i -c` -ne 0 ]; then
	# recording or voi44cemail
	P="wav"
else
	# just a text
	P="txt"
fi

NBASE=$(echo "$@" | sed -ne 's/@/[at]/g;s/\s/~/g;s/.*--\~\(.*\)/\1/p;')

$SUDO mv {${BASE},${P}_${NBASE}_${BASE}}.mail

sudo chown wms.wms *mail

# Move to queue directory (create it if necessary)
if [ ! -d "$QUEUEDIR" ]; then
	$SUDO mkdir -p "$QUEUEDIR" || exit 1
fi
sudo chown wms.wms -R $QUEUEDIR
sudo chmod 775 $QUEUEDIR

$SUDO mv * $QUEUEDIR

exit 0
