#!/bin/bash

QUEUEDIR=/var/spool/mail
SPOOL=/var/spool/callweaver/monitor

# write messages to syslog
function log () {
	logger -i -t wms_msmtp $1
}

# mail send function for forking
send(){
                $SUDO msmtp --syslog --file=/etc/companies.d/$com_id/msmtprc -t < $1 1>/dev/null 2>&1
                ret=$?
                SUBJ=$(cat $MAILFILE  | sed -n /Subject/p)
                if [ $ret -eq 0 ]; then
                        rm "$1"
                        log "INFO: $1 sent successfully. With $SUBJ"
                elif [ $ret -eq 68 ]; then
                        log "INFO: Host name unknown. $1 With $SUBJ not sent. Try later"
                elif [ $ret -eq 75 ]; then
                        log "INFO: Temp failure; user is invited to retry. $1 With $SUBJ not sent."
                elif [ $ret -ne 0 ]; then
                        log "ERROR: File $1 is wrong! Server return error: $ret. $1 not send. Removed mail with $SUBJ"
                        rm "$1"
                fi
}

# fork limit detect function
queue(){
	mem=`grep MemTotal /proc/meminfo  | awk '{print $2}'`
	[ $mem -le 1048576 ] && limit='10'
	[ $mem -gt 1048576 ] && limit='20'
}

# do not execute second copy if one already running
[ `ps aux | grep -c [r]unqueue` -gt 2 ] && exit 1

# switch to wms
[ "$(whoami)" = "root" ] && SUDO="sudo -u wms" || SUDO=""

for com_id in `ls $QUEUEDIR | awk '/^[0-9]$/ {print$0}'`; do
	# change into $QUEUEDIR
	[ -d "$QUEUEDIR/$com_id" ] && cd "$QUEUEDIR/$com_id" || continue;

# call limit detect function
queue

# process all mails based on fork limit
for MAILFILE in `find . -type f -name "*.mail" -printf "%T@ %p\n" | sort -n | awk '{print $2}' | head -n $limit`; do
	log "INFO: Sending $MAILFILE..."
	send $MAILFILE &
done

done
exit 0
