#!/usr/bin/php
<?php

/** @var \Logger\Log $logger */

require_once '/var/www/init.php';

use Wildix\Colleagues\Colleague;

$avatarFileTemplate = '/mnt/cticonnect/uploads/user_avatar_:uid.png';

$diContainer = new \Wildix\DependencyInjection\Container();
$logger      = $diContainer->get(\Logger\Log::class);

$colleagueRepository = $diContainer->get(\Wildix\Colleagues\Colleagues::class);

$currentPbx = \Wildix\PBXes\PBXes::getInstance()->getPBXBySerial(\Models\PBX::getInstance()->getSerial());

$pbxs = WMS_Ldap::getInstance()->getEntries(WMS_Ldap::PBX, '', ['dn', 'pbxDomain']);
if (count($pbxs) < 2) {
    $logger->info(__LINE__, '[AvatarCleaner] Single PBX. No need clear remote avatars.');
    die();
}


$deleted = 0;
foreach ($pbxs as $pbx) {
    $dn = $pbx[\Wildix\PBXes\PBX::DN];
    if ($dn === $currentPbx->getDn()) {
        continue;
    }
    $logger->info(__LINE__, sprintf('[AvatarCleaner] Find users from pbxDn: %s', $dn));

    $fields = [
        Colleague::ID,
        Colleague::EXTENSION,
    ];
    $filter = [
        Colleague::PBX_DN => $dn
    ];

    $records = $colleagueRepository->getUsers($filter);
    foreach ($records as $record) {
        $data = $record->getAsArray($fields);

        $path = str_replace(':uid', $data[Colleague::ID], $avatarFileTemplate);
        if (file_exists($path)) {
            $logger->info(__LINE__, sprintf('[AvatarCleaner] Remove avatar for userId: %s from pbxDn: %s', $data[Colleague::ID], $dn));
            unlink($path);
            $deleted++;
        }
    }
}
$logger->info(__LINE__, sprintf('[AvatarCleaner] Was deleted remote avatars: %s', $deleted));

