#!/bin/bash
set -e
TMP_DIR="/tmp"

check_free_space(){
	local no_space=0
	local res=$(df -B 1 $1 2>/dev/null | awk '/\//{printf($4)}')
	local free_limit=$2
	[ -n "$res" ] &&
	if [ $res -le $free_limit ]; then
		no_space=1
	else
		no_space=0
	fi
	echo $no_space
}

check_diff(){
	local new=$(zcat "$TMP_DIR/$2.dmp.gz" |md5sum -b -)
	local old=''
	[ -f "$1/$2.dmp.gz" ] && old=$(zcat "$1/$2.dmp.gz" | md5sum -b -)

	if [ "x$new" != "x$old" ]; then
		mv "$TMP_DIR/$2.dmp.gz" "$1/$2.dmp.gz.tmp"
		mv "$1/$2.dmp.gz.tmp" "$1/$2.dmp.gz"
	fi
	[ -f "$TMP_DIR/$2.dmp.gz" ] && rm -f "$TMP_DIR/$2.dmp.gz"
	return 0
}

backup_sqlite(){
	can_backup=$(echo 'pragma integrity_check;' | sqlite3 "$1/$2" 2>/dev/null)
	filesize=$(stat -c%s "$1/$2")
	ret=1

	if [ "$can_backup" = "ok" -a $(check_free_space $1 $filesize ) -eq 0 -a $(check_free_space $TMP_DIR $filesize ) -eq 0 ]; then
		sqlite3 $1/$2 .dump | gzip > $TMP_DIR/$2.dmp.gz
		check_diff $1 $2
		ret=0
	fi
}

backup_cticonnect(){
	backup_sqlite /mnt/cticonnect cticonnectdb
	if [ "$can_backup" = "ok" -a $ret -eq 1 ]; then
#		row_count=$(echo "select count(*) from cti_contacts;" | sqlite3 /mnt/cticonnect/cticonnectdb)
#		filesize=$(stat -c%s /mnt/cticonnect/cticonnectdb)
#		dump_size=$((filesize-row_count*200))
		dump_size=512000
		if [ -f /tmp/cticonnectdb.dmp ]; then
            rm -f /tmp/cticonnectdb.dmp
        fi
		if [ $(check_free_space /mnt/cticonnect $dump_size) -eq 0 -a $(check_free_space "$TMP_DIR" $dump_size) -eq 0 ]; then
			for table in $(echo ".tables"|sqlite3 /mnt/cticonnect/cticonnectdb); do
				if [[ $table != "cti_phonebooks" && $table != cti_contacts* ]]; then
					echo ".dump $table"|sqlite3 /mnt/cticonnect/cticonnectdb >>/tmp/cticonnectdb.dmp
				fi
			done
			echo '.schema "cti_contacts%"'|sqlite3 /mnt/cticonnect/cticonnectdb >>/tmp/cticonnectdb.dmp
			echo '.schema cti_phonebooks'|sqlite3 /mnt/cticonnect/cticonnectdb >>/tmp/cticonnectdb.dmp
			gzip /tmp/cticonnectdb.dmp
			check_diff /mnt/cticonnect cticonnectdb
		fi
	fi
}

backup_sqlite /rw2/var/lib/wmsdb.d wmsdb
backup_sqlite /rw2/var/lib/wmsdb.d devdb
backup_cticonnect