#!/bin/bash

if [ -s '/usr/sbin/ldapcmd' ]; then
  source /usr/sbin/ldapcmd
else
  echo "ERROR: /usr/sbin/ldapcmd was not found" && exit 1
fi

if [ "$(pidof -x "${0##*/}" | wc -w)" -gt 2 ]; then
  __LOG "err" "Process already running." && exit 1
elif [ "${WMS_MODE}" != "client" ]; then
  __LOG "err" "ERROR: PBX in ${WMS_MODE} mode. Exiting." && exit 1
fi

LDAP_SYNC_OUT='/tmp/ldap_client_sync.out'
START_TIME="$(date +'%s')"
NEXT_UPDATE_MASTER='100'
MASTER_CONNECT_FAIL='0'


__START(){

  ## prepare to replication
  __IN_MEMORY 'in'
  __SERVICES 'restart' 'ldap' 'slapd'
  __LDAP_MODIFY "olcDatabase={1}mdb,cn=config" "replace" "olcDbNoSync" "TRUE"

}


__STOP() {

  __LDAP_MODIFY "olcDatabase={1}mdb,cn=config" "replace" "olcDbNoSync" "FALSE"
  __IN_MEMORY 'out'
  __SERVICES 'start'
  __LOG "info" "Replication completed."
  echo "state:completed;objects_expected:${MASTER_DB_ENTRIES};objects_actual:${MY_DB_ENTRIES};" > $LDAP_SYNC_OUT

}


__LOG "info" "LDAP Replication started at: $(date -d "@${START_TIME}")."
echo "state:in progress;objects_expected:0;objects_actual:0;" > $LDAP_SYNC_OUT
## go to replication (god give me a power)
__START
while true; do

  sleep 5

  CURR_TIME="$(date +'%s')"
  ((NEXT_UPDATE_MASTER++))

  ## exit if replication lasts 6 hours
  if [ "$(($CURR_TIME - $START_TIME))" -gt "$((6 * 60 * 60 * 1))" ]; then
    __LOG "err" "Replication timeout 6 hours reached and exiting."
    __STOP
  fi

  ## once per 1 minute we're updating data from master
  if [ "${NEXT_UPDATE_MASTER}" -ge '12' ]; then
    MASTER_CSN="$(__LDAP_GET "contextCSN" "dc=wildix" "ldaps://${LDAP_MASTER}" "${LDAP_ADMIN}" "${LDAP_ADMIN_PASSWORD}" | awk '$1 == "contextCSN:" {print $2}')"
    MASTER_DB_ENTRIES="$(__LDAP_GET "olmMDBEntries" "cn=Database 1,cn=Databases,cn=Monitor" "ldaps://${LDAP_MASTER}" "${LDAP_ADMIN}" "${LDAP_ADMIN_PASSWORD}" | awk '$1 == "olmMDBEntries:" {print $2}')"
    [ "${MASTER_CSN}" ] && NEXT_UPDATE_MASTER='0'
  fi

  ## exit if master unavailable 5 times
  if [ -z "${MASTER_CSN}" ]; then
    ((MASTER_CONNECT_FAIL++))
    __LOG "warn" "Failed to read from master. Retrying # ${MASTER_CONNECT_FAIL}."
    if [ "${MASTER_CONNECT_FAIL}" -ge '5' ]; then
      __LOG "err" "Failed to read from master. Exiting."
      __STOP
      break
    fi
  ## get data from local ldap for statistics
  else
    MY_CSN="$(__LDAP_GET "contextCSN" "dc=wildix" | awk '$1 == "contextCSN:" {print $2}')"
    MY_DB_ENTRIES="$(__LDAP_GET "olmMDBEntries" "cn=Database 1,cn=Databases,cn=Monitor" | awk '$1 == "olmMDBEntries:" {print $2}')"
    __LOG "info" "Entries count: ${MY_DB_ENTRIES}"
    echo "state:in progress;objects_expected:${MASTER_DB_ENTRIES};objects_actual:${MY_DB_ENTRIES};" > $LDAP_SYNC_OUT

    if [ "${MASTER_CSN}" == "${MY_CSN}" ]; then
      __LOG "info" "Replication stopped with 100% match and exiting."
      __STOP
      break
    fi
  fi

done
