#!/bin/bash

CONFIG_DIR='/etc/cron.random'


__LOG() {

	local msg="${1:-'empty'}"
	local tag="${2:-'cronrandom'}"

	echo -e "$msg" | logger -t "$tag"

}


__SET_VALUES() {

	FROM_HOUR="${FROM_HOUR:-'0'}"
	TO_HOUR="${TO_HOUR:-'5'}"
	NEXT_RUN_DATE_FOLDER="${NEXT_RUN_DATE_FOLDER:-'/rw2/var/spool/RandomCronTasks'}"
	NEXT_RUN_DATE_FILE="$NEXT_RUN_DATE_FOLDER/$TASK_NAME"
	LOCKFILE="/var/lock/$TASK_NAME.lock"

	if [ "$FROM_HOUR" -gt "$TO_HOUR" ]; then
		__LOG "ERROR ($TASK_NAME): value FROM_HOUR bigger than TO_HOUR"
		FROM_HOUR='0'
		TO_HOUR='5'
	fi

}


__LOAD_NEXT_RUN_FILE() {

	[ ! -d "$NEXT_RUN_DATE_FOLDER" ] && mkdir -m 0777 -p "$NEXT_RUN_DATE_FOLDER"
	[ ! -f "$NEXT_RUN_DATE_FILE" ] && touch "$NEXT_RUN_DATE_FILE"
	chmod 0666 "$NEXT_RUN_DATE_FILE"
	[ -s "$NEXT_RUN_DATE_FILE" ] && . "$NEXT_RUN_DATE_FILE" || NEXT_RUN_DATE='0'

}


__SET_NEXT_RUN_DATE() {

	local now_time_unix="$(date +%s)"
	local to_unix=$(($TO_HOUR * 60 * 60))
	local from_unix=$(($FROM_HOUR * 60 * 60))
	local random_unix="$(shuf -i $from_unix-$to_unix -n1)"

	local now_day_unix="$(date -d "$(date +"%Y/%m/%d")" "+%s")"
	local tomorow_day_unix="$(date -d "$(date --date="next day" +"%Y/%m/%d")" "+%s")"
	local remaining_unix="$(($tomorow_day_unix-$now_time_unix))"
	local next_run_date="$(($now_time_unix + $remaining_unix + $random_unix))"
	local now_run_date="$(($now_day_unix + $random_unix))"


	if [ "$now_time_unix" -lt "$(($now_day_unix + $from_unix))" ]; then
		NEXT_RUN_DATE="$now_run_date"
		echo "NEXT_RUN_DATE=$now_run_date" > "$NEXT_RUN_DATE_FILE"
	else
		NEXT_RUN_DATE="$next_run_date"
		echo "NEXT_RUN_DATE=$next_run_date" > "$NEXT_RUN_DATE_FILE"
	fi

}


__IS_NEED_RUN() {

	local now_time_unix="$(date +%s)"
	local time_delta="$(($now_time_unix - $NEXT_RUN_DATE))"

	[ "$time_delta" -gt "3600" ] && __SET_NEXT_RUN_DATE

	if [ "$now_time_unix" -ge "$NEXT_RUN_DATE" ]; then
		__SET_NEXT_RUN_DATE
		echo "true"
	else
		echo "false"
	fi

}


for TASK_NAME in $(ls $CONFIG_DIR); do
	[ -s "$CONFIG_DIR/$TASK_NAME" ] && . "$CONFIG_DIR/$TASK_NAME"

	__SET_VALUES
	__LOAD_NEXT_RUN_FILE

	if [ "$(__IS_NEED_RUN)" == 'true' ]; then
		if [ ! -f "$LOCKFILE" ]; then
			touch "$LOCKFILE"
			__LOG "Run task: \"$TASK_NAME\""
			/bin/bash -c "$COMMAND"
			rm -rf "$LOCKFILE"
		else
			__LOG "\"$TASK_NAME\" - is already started!"
		fi
	fi
done