#!/usr/bin/php
<?php

require_once '/var/www/api/init.php';

use Wildix\Sms\SmsViaGsmService;
use Wildix\Sms\Factory\SmsViaGsmDtoFactory;

function showHelp() {
    echo 'Send sms script.' . PHP_EOL;
    echo 'Usage: /usr/sbin/send_sms.php --fromNumber="007" --message="message text" --number="+12345" --gsm="012345ABCDEF" --notHeaderMessage' . PHP_EOL;
    echo 'Options:' . PHP_EOL
        . '   --fromNumber       Sender number.' . PHP_EOL
        . '   --number           Recipient number.' . PHP_EOL
        . '   --message          Message text.' . PHP_EOL
        . '   --message64        Message text encoded with base64. Replace "message" option. Don\'t use both. Optional' . PHP_EOL
        . '   --postpone         DateTime string formatted as "d/m/Y H:i" for postpone send. Optional.' . PHP_EOL
        . '   --gsm              GSM gateway MAC address. Optional.' . PHP_EOL
        . '   --notHeaderMessage Disable header message. Optional.' . PHP_EOL;
}

$availableOptions = [
    'fromNumber:',
    'number:',
    'message::',
    'message64::',
    'postpone::',
    'gsm::',
    'notHeaderMessage',
];

$definedOptions = getopt('', $availableOptions);

// missed options?
if (! isset($definedOptions['fromNumber'], $definedOptions['number']) || ! (isset($definedOptions['message']) xor isset($definedOptions['message64']))) {
    showHelp();
    exit(1);
}

if (isset($definedOptions['notHeaderMessage'])) {
    $definedOptions['notHeaderMessage'] = true;
}

try {
    $diContainer         = new \Wildix\DependencyInjection\Container();
    $smsViaGsmService    = $diContainer->get(SmsViaGsmService::class);
    $smsViaGsmDtoFactory = $diContainer->get(SmsViaGsmDtoFactory::class);
    $smsViaGsmDto        = $smsViaGsmDtoFactory->createFromOptions($definedOptions);
    $smsViaGsmService->sendSms($smsViaGsmDto);

    echo 'Success' . PHP_EOL;
} catch (Throwable $e) {
    echo sprintf("Error occurred: %s\n", $e->getMessage());
    die(1);
}

die(0);
