#!/bin/bash

CONF_FILE='/rw2/etc/pbx/trunk_notification.conf'
CALLWEAVER_PID='/var/run/callweaver/callweaver.pid'


__LOG(){

  local name message xargs

  name="${0##*/}"
  message="${2}"
  xargs="${3}"

  case "${1}" in
    warn) severity='warning' ;;
    err) severity='err' ;;
    *) severity='info' ;;
  esac

  if [ "${message}" ]; then
    echo ${xargs} "${message}" | tee >(systemd-cat -t "${name}" -p "${severity}")
  else
    systemd-cat -t "${name}" -p "${severity}"
  fi

}


__SEND_MAIL(){

  local mail_config mail_from mail_admin pbx_name mailbody subject_status sip_status arr

    ## include script for ldap
  if [ -s '/usr/sbin/ldapcmd' ]; then
    source /usr/sbin/ldapcmd
  else
    __LOG "err" "ERROR($FUNCNAME): /usr/sbin/ldapcmd was not found." && return 1
  fi

  declare -n arr=${1}
  mail_config='/etc/companies.d/0/msmtprc'
  mail_from="$(awk '/from/{print $2}' ${mail_config})"
  mail_admin="$(__LDAP_GET "(&(objectClass=wPerson)(cn=admin)(userKind=admin)) mail||mail" "dc=wildix" | awk '{print $2}')"
  pbx_name="$(cat /etc/hostname)"

    # check mail password and admin mail
  [ -z "${mail_admin}" ] || [ -z "$(awk '/password/{print $2}' ${mail_config})" ] && \
    __LOG "err" "ERROR($FUNCNAME): not set password or admin email" && return 1

    # check from
  [ -z "${mail_from}" ] && mail_from="no-reply@wildix.com"

    # select a subject
  [ "${arr['status']}" == 'up' ] && subject_status="Notification" || subject_status="Warning"

    # send email
  mailbody="SIP: ${arr['domain']} (${pbx_name})\nTIME: $(date)\nSTATUS: ${arr['status']}"

  /usr/sbin/sendemail.php \
    --type="default" \
    --body="$(echo -e ${mailbody})" \
    --subject="${subject_status} ${pbx_name}: ${arr['domain']} (${arr['account']}) is ${arr['status']}!" \
    --to=${mail_admin}

  [ "${?}" -eq "0" ] && __LOG "info" "Notification has been sent to ${mail_admin}." || \
    __LOG "err" "ERROR($FUNCNAME): Notification hasn't been delivered due to an error to ${mail_admin}."

}


__FLAG(){

  local status_file arr max_attempts attempts

  declare -n arr=${1}
  max_attempts='2'
  status_file="/tmp/sip_trunk_$(md5sum <<< "${arr['name']}_${arr['domain']}_${arr['account']}" | awk '{print $1}').lock"

  [ -s "${status_file}" ] && source ${status_file} 2>/dev/null # load array for counters

  if [ "${#attempts[@]}" -eq '2' ]; then
      # checking correct data
    for i in ${!attempts[@]}; do
      [[ ! "${attempts[${i}]}" =~ ^[0-9]{1,2}$ ]] && attempts[${i}]=0
    done
  else
      # declare a new array for counters
    [ -f "${status_file}" ] && rm -f ${status_file}
    declare -A attempts=(
      ['up']=0
      ['down']=0
      )
  fi

  case "${arr['status']}" in
    up)
      if [ "${attempts['down']}" -ge "${max_attempts}" ]; then

        if [ "${attempts['up']}" -le "10" ]; then
          ((attempts['up']++))
          declare -p attempts > ${status_file}
        fi
        if [ "${attempts['up']}" -eq "${max_attempts}" ]; then
          rm -f ${status_file}
          echo "up"
        fi

      fi
    ;;
    down)
      if [ "${attempts['down']}" -le "10" ]; then
        ((attempts['down']++))
        declare -p attempts > ${status_file}
      fi
      [ "${attempts['down']}" -eq "${max_attempts}" ] && echo "down"
    ;;
  esac

}


  ## check conf file
if [ ! -f "${CONF_FILE}" ]; then
  cat << 'EOF' > ${CONF_FILE}
[general]
start=0
EOF
fi

[ "$(awk -F '=' '/start=/{print $2}' ${CONF_FILE})" == "0" ] && exit  ## exit if start is 0
[ ! -f "${CALLWEAVER_PID}" ] || [ "$(( $(date +%s) - $(stat -c %Y ${CALLWEAVER_PID}) ))" -le '120' ] && exit ## exit if file pid is less than 120 seconds after creation


/usr/sbin/callweaver -rx 'sip show registry' | sed 's/Request Sent/Request_Sent/g;s/ws2sip.wildix.com/kite-connection/g' | awk '/Registered|Request_Sent/{print $1" "$3" "$4" "$5" "$6" "$7"_"$8"_"$9"_"$10"_"$11}' |\
while read DOMAIN ACCOUNT NAME REFRESH STATUS LAST_REGISTRATION; do

  declare -A SIP=(
    ['name']="${NAME}"
    ['domain']="${DOMAIN}"
    ['account']="${ACCOUNT}"
    ['refresh']="${REFRESH}"
    ['status']="$([ "${STATUS}" == 'Registered' ] && echo "up" || echo "down")"
    ['last_registration']="${LAST_REGISTRATION}"
    )

  case "$(__FLAG SIP)" in
    up) __SEND_MAIL SIP ;;
    down) __SEND_MAIL SIP ;;
  esac

done
