<?php

use Session\Session;
use Wildix\Core\Notification;
use Wildix\License;
use Wildix\Services\GlobalConfig;

(file_exists('auth.php')) ? require 'auth.php' : require '../auth.php';

if (!\User::getInstance()->isAdministrator()) {
    die('Access denied');
}

if (!isset($diContainer) || !($diContainer instanceof \Wildix\DependencyInjection\Container)) {
    $diContainer = new \Wildix\DependencyInjection\Container();
}

$_REQUEST['newclass'] = 'aclpbx';
require_once 'classes/aclpbx/aclpbx.class.php';
require_once 'features/features.functions.php';

$aclpbx_class     = new aclpbx();
$phonebooks_class = new phonebook();

ini_set("memory_limit", "-1");

if (isset($_GET['export_users_csv']) && $_GET['export_users_csv'] == '1' && WMS_Permissions::getInstance()->is_root()) {
    $filename = 'export_users.csv';
    // fix for IE catching or PHP bug issue
    header("Pragma: public");
    header("Expires: 0");
// set expiration time
    header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
    // browser must download file from server instead of cache
    // force download dialog
    header("Content-Type: application/x-download");
    header("Content-Disposition: attachment; filename=\"" . $filename . "\"");
    header("Content-Transfer-Encoding: binary");

    echo '"Id","SourceId","Type","Name","Login","Phone","Fax","OfficePhone","Email","Mobile","Dialplan","FaxDialplan","Lang","Group","Department","ImageUrl","Password","SipPassword","LicenseType"' . "\n";
    foreach ($aclpbx_class->get_users_csv_arr() as $user_arr) {
        echo '"' . implode('","', $user_arr) . '"' . "\n";
    }
    die();
}

if (isset($_GET['download_all_sync_users_log']) && $_GET['download_all_sync_users_log'] == '1') {
    $filename = 'users_sync.log';
    ini_set('memory_limit', '-1');
    // fix for IE catching or PHP bug issue
    header("Pragma: public");
    header("Expires: 0");
// set expiration time
    header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
    // browser must download file from server instead of cache
    // force download dialog
    header("Content-Type: application/x-download");
    header("Content-Disposition: attachment; filename=\"" . $filename . "\"");
    header("Content-Transfer-Encoding: binary");

    passthru('sudo /usr/sbin/syslog_grep \'userssync #\'');

    die();
}

$logger = null;

function getLog() {
    global $logger;
    if ($logger === null) {
        $writer    = new Logger\Writer\SysLog('wms');
        $formatter = new Logger\Formatter\MultiLine();
        $context   = new Logger\Context(array());
        $logger    = new Logger\Log($writer, $formatter, $context);
    }

    return $logger;
}

$kite = null;

function getKite() {
    global $kite;
    if ($kite === null) {
        $kite = new \Wildix\Services\Kite();
    }

    return $kite;
}

function getZohoClient() {
    return new Wildix\Import\ZohoClient\ZohoClient(getLog(), getKite(), env('ZOHO_CLIENT_AUTH_URI'));
}

function users_sync_save() {
    global $aclpbx_class;
    header("Content-Type: application/json\n");
    $_POST['settings'] = json_decode($_POST['settings'], true);
    if (WMS_Permissions::getInstance()->is_root()) {
        die(json_encode($aclpbx_class->set_sync_settings_n_map($_POST['settings'])));
    }
    die(json_encode($aclpbx_class->get_sync_settings_n_map()));
}

function users_sync() {
    if (isset($_POST['u_s_backend_csv_params'])) {
        // if $_FILES is empty than php raise max_upload_filesize error...
        if (sizeof($_FILES) == 0) {
            $upload_max_filesize = min(let_to_num(ini_get('post_max_size')), let_to_num(ini_get('upload_max_filesize')));
            die(json_encode(array('u_s_backend_csv_fileid' => _t('errors.selectedFileMustBeLessThan', $upload_max_filesize / 1024 / 1024))));
        }

        $_POST['settings'] = json_decode($_POST['u_s_backend_csv_params'], true);
        if (isset($_FILES['u_s_backend_csv_filename'])) {
            $t_fname    = $_FILES['u_s_backend_csv_filename']['tmp_name'];
            $t_new_name = dirname($t_fname) . '/users_sync_' . basename($t_fname);
            if (!move_uploaded_file($t_fname, $t_new_name)) {
                die(json_encode(array('u_s_backend_csv_fileid' => _t('errors.fileIsNotUploadedNotEnoughSpace'))));
            }
            $_POST['settings']['settings']['filename'] = $t_new_name;
        }

        // start sync job
        exec('nohup /usr/sbin/wms_users_sync ' . escapeshellarg(base64_encode(json_encode($_POST['settings']))) . ' >/dev/null 2>&1 &');
        die('true');
    }
    header("Content-Type: application/json\n");
    $_POST['settings']            = json_decode($_POST['settings'], true);
    $_POST['settings']['dry_run'] = $_POST['dry_run'];
    $_POST['settings']['verbose'] = $_POST['verbose'];
    $_POST['settings']['syncid']  = $_POST['syncid'];
    // start sync job
    exec('nohup /usr/sbin/wms_users_sync ' . escapeshellarg(base64_encode(json_encode($_POST['settings']))) . ' >/dev/null 2>&1 &');
    die(json_encode(array()));
}

function phonebook_sync_save() {
    global $phonebooks_class;
    header("Content-Type: application/json\n");
    $_POST['settings'] = json_decode($_POST['settings'], true);
    if (WMS_Permissions::getInstance()->is_allowed('page', 'users__phonebooks3'/*.$t_number*/)) {
        $phonebooks_class->set_sync_settings_n_map($_POST['pbook_id'], $_POST['settings']);
    }
    die(json_encode($phonebooks_class->get_sync_settings_n_map($_POST['pbook_id'], 'pbook_id')));
}

function phonebook_sync() {
    if (isset($_POST['p_s_backend_csv_params'])) {
        // if $_FILES is empty than php raise max_upload_filesize error...
        if (sizeof($_FILES) == 0) {
            $upload_max_filesize = min(let_to_num(ini_get('post_max_size')), let_to_num(ini_get('upload_max_filesize')));
            die(json_encode(array('p_s_backend_csv_fileid' => _t('errors.selectedFileMustBeLessThan', $upload_max_filesize / 1024 / 1024))));
        }
        $_POST['settings'] = json_decode($_POST['p_s_backend_csv_params'], true);
        if (isset($_FILES['p_s_backend_csv_filename'])) {
            $t_fname    = $_FILES['p_s_backend_csv_filename']['tmp_name'];
            $t_new_name = dirname($t_fname) . '/users_sync_' . basename($t_fname);
            if (!move_uploaded_file($t_fname, $t_new_name)) {
                die(json_encode(array('p_s_backend_csv_fileid' => _t('errors.fileIsNotUploadedNotEnoughSpace'))));
            }
            $_POST['settings']['settings']['filename'] = $t_new_name;
        }
        // start sync job
        // $_POST['settings']['pbook_version'] = 3;
        exec('nohup /usr/sbin/wms_phonebook_sync ' . escapeshellarg($_POST['settings']['pbook_id']) . ' ' . escapeshellarg(base64_encode(json_encode($_POST['settings']))) . ' >/dev/null 2>&1 &');
        die('true');
    }

    header("Content-Type: application/json\n");
    $_POST['settings']             = json_decode($_POST['settings'], true);
    $_POST['settings']['dry_run']  = $_POST['dry_run'];
    $_POST['settings']['verbose']  = $_POST['verbose'];
    $_POST['settings']['syncid']   = $_POST['syncid'];
    $_POST['settings']['pbook_id'] = $_POST['pbook_id'];

    exec('nohup /usr/sbin/wms_phonebook_sync ' . escapeshellarg($_POST['pbook_id']) . ' ' . escapeshellarg(base64_encode(json_encode($_POST['settings']))) . ' >/dev/null 2>&1 &');
    die(json_encode(array()));
}

function remove_pbx() {
    $oldPbx = $_POST['old_pbx'] ?? '';
    $newPbx = $_POST['new_pbx'] ?? '';

    // WMS-5801 Moving a large number of users can take more than a minute. Running this process in background.
    exec('nohup php /usr/sbin/wms_network_remove_pbx --oldpbx ' . escapeshellarg($oldPbx) . ' --newpbx ' . escapeshellarg($newPbx) . ' >/dev/null &');

    die('OK');
}

function sendWelcomeEmail() {
    include_once 'classes/network/network.class.php';
    $network = new network();
    $log     = getLog();

    $domain = \Models\PBX::getInstance()->getDomain();

    // get custom secure port
    $port       = '';
    $securePort = \Models\PBX::getInstance()->getCustomHttpsPort();
    if (!empty($securePort) && $securePort !== 443) {
        $port = ':' . $securePort;
    }

    $urls = '<li><a target="_blank" href="https://' . $domain . $port . '/">' . $domain . '</a></li>';

    $userids = explode('|', trim($_REQUEST['userid']));

    $filter = '';
    foreach ($userids as $id) {
        $filter .= '(uid=' . $id . ')';
    }
    if ($filter != '') {
        $filter = '(|' . $filter . ')';
    }

    $userLdapData = WMS_Ldap::getInstance()->getEntries(WMS_Ldap::PERSONS, $filter, array('dn', 'cn', 'userPrincipalName', 'userPassword', 'mail', LDAP_EXTEN_NUMBER, 'facsimileTelephoneNumber', LDAP_OFFICE_NUMBER, 'mobile'));
    $tpl          = $_POST['template'];

    foreach ($userLdapData as $user) {
        $logInfo = sprintf('UserDn: %s;', $user['dn']);
        if (!empty($user['mail']) && !empty($user[LDAP_EXTEN_NUMBER])) {
            $user['userPassword'] = \Wildix\Generator\StringGenerator::random();

            $currentUser = \Wildix\Colleagues\Colleagues::getInstance()->getUserByExtension($user[LDAP_EXTEN_NUMBER]);
            $currentUser->setPassword(\User::getInstance()->cryptPassword($user['userPassword']));
            $currentUser->setUserPIN(\User::getInstance()->makeUserPinFromPassword($user['userPassword']));

            $updateData = array(
                // 'NAME' => $user['cn'],
                                'LOGIN' => ($user['userPrincipalName'] ? $user['userPrincipalName'] : $user[LDAP_EXTEN_NUMBER]),
                                'PASSWORD' => $user['userPassword'],
                                'EXTENSION' => $user[LDAP_EXTEN_NUMBER],
                                'MOBILE' => $user['mobile'],
                                'OFFICE' => $user[LDAP_OFFICE_NUMBER],
                                'FAX' => $user['facsimileTelephoneNumber'],
                                'URLS' => $urls
            );
            $mailBody   = replaceVariablesInTemplate($tpl, $updateData);

            // prepare parameters
            $params = array(
                'type' => 'welcome',
                'subject' => _t('aclpbx.WelcomeSubject'),
                'to' => $user['mail'],
                'body' => $mailBody,
            );
            // send email
            Notification::sendEmail($params);
            $log->info(__LINE__, 'Welcome message sended. ' . $logInfo);
        } else {
            $log->info(__LINE__, 'Welcome message not sended. ' . $logInfo);
        }
    }
    die('OK');
}

function sendWelcomeEmailXbees() {
    $log     = getLog();
    $license = $GLOBALS['diContainer']->get(License::class);

    if (!$license->haveLicense($license::TYPE_XBEES)) {
        $log->info(__LINE__, 'Invite message x-bees not sended. Doesn\'t have a license x-bees.');
        die('OK');
    }

    $domain = \Models\PBX::getInstance()->getDomain();

    $securePort = \Models\PBX::getInstance()->getCustomHttpsPort();
    $port       = !empty($securePort) && $securePort !== 443 ? '&port=' . $securePort : '';

    $userids = explode('|', trim($_REQUEST['userid']));

    $filter = '';
    foreach ($userids as $id) {
        $filter .= '(uid=' . ldap_escape($id, "", LDAP_ESCAPE_FILTER) . ')';
    }
    if ($filter !== '') {
        $filter = '(|' . $filter . ')';
    }

    $userLdapData = WMS_Ldap::getInstance()->getEntries(WMS_Ldap::PERSONS, $filter, array('dn', 'userPrincipalName', 'cn', 'mail', LDAP_EXTEN_NUMBER));
    $xBeesConfig  = $GLOBALS['diContainer']->get(GlobalConfig::class)->getConfig(GlobalConfig::TYPE_CONFIG)['xBees'];

    $language = Language::getInstance()->getLanguageNameByCode($_GET['lang']);
    $dictionary = \Api\Translation\Factory\TranslationFactory::getByLang($language);

    $mailTemplate = file_get_contents('../data/templates/WelcomeMailTemplateXbees.html');

    foreach ($userLdapData as $user) {
        $logInfo = sprintf('UserDn: %s;', $user['dn']);
        if (!empty($user['mail']) && !empty($user[LDAP_EXTEN_NUMBER])) {
            $data = [
                'GREETING'    => $dictionary->t('aclpbx.welcomeEmailGreeting'),
                'WELCOME'     => $dictionary->t('aclpbx.welcomeEmailWelcome'),
                'HAPPY'       => $dictionary->t('aclpbx.welcomeEmailHappy'),
                'JOIN'        => $dictionary->t('aclpbx.welcomeEmailJoin'),
                'REGISTER'    => $dictionary->t('aclpbx.welcomeEmailRegister'),
                'GET'         => $dictionary->t('aclpbx.welcomeEmailGetApp'),
                'LOGIN'       => $user['cn'] ?? $user['mail'] ?? $user['userPrincipalName'],
                'URL'         => $xBeesConfig['joinUrl'] . '?pbx=' . $domain . '&email=' . urlencode($user['mail']) . $port,
                'IOSLINK'     => $xBeesConfig['applications'][0]['url'],
                'ANDROIDLINK' => $xBeesConfig['applications'][1]['url'],
                'IOSICON'     => $xBeesConfig['applications'][0]['icon'],
                'ANDROIDICON' => $xBeesConfig['applications'][1]['icon'],
            ];

            // send email
            Notification::sendEmail(
                [
                'type'    => 'welcome',
                'subject' => _t('aclpbx.InviteXbeesSubject'),
                'to'      => $user['mail'],
                'body'    => replaceVariablesInTemplate($mailTemplate, $data),
                ]
            );
            $log->info(__LINE__, 'Invite message x-bees sended. ' . $logInfo);
        } else {
            $log->info(__LINE__, 'Invite message x-bees not sended. ' . $logInfo);
        }
    }
    die('OK');
}

function replaceVariablesInTemplate($template, array $variables) {
        return preg_replace_callback(
            '#{_(.*?)_}#',
            function ($match) use ($variables) {
                $match[1] = trim($match[1], '$');
                return $variables[$match[1]];
            },
            ' ' . $template . ' '
        );
}

function moveUsers() {
    global $aclpbx_class;
    $wms_ldap = WMS_Ldap::getInstance();
    $userids  = explode('|', trim($_REQUEST['userid']));

    $filter = '';
    foreach ($userids as $id) {
        $filter .= '(uid=' . $id . ')';
    }
    if ($filter != '') {
        $filter = '(|' . $filter . ')';
    }

    $userLdapData = $wms_ldap->getEntries(WMS_Ldap::PERSONS, $filter, array('dn', 'pbxowner', 'uid', LDAP_EXTEN_NUMBER));

    // get dn of new PBX
    $new_pbx_dn = $wms_ldap->getEntry(WMS_Ldap::PBX, '(pbxSerial=' . $_POST['new_pbx'] . ')', array('dn'));
    if (empty($new_pbx_dn) || empty($new_pbx_dn['dn'])) {
        die(_t('multipbx.pbxNotFound', $_POST['new_pbx']));
    }
    $new_pbx_dn = $new_pbx_dn['dn'];

    $curr_pbx = $aclpbx_class->get_current_pbx_ldap_searchObj();

    $targetPbxService = getPbxService($new_pbx_dn);

    foreach ($userLdapData as $user) {
        if ($user['pbxowner'] !== $new_pbx_dn) {
            $log     = getLog();
            $logInfo = sprintf('UserDn: %s; CurrentPbxDn: %s; NewPbxDn: %s', $user['dn'], $curr_pbx['dn'], $new_pbx_dn);

            try {
                // move user from remote PBX to local
                if ($new_pbx_dn === $curr_pbx['dn']) {
                    $res = multipbx::moveUserSettings($user, $user['pbxowner'], $curr_pbx);
                    if ($res !== true) {
                        $log->error(__LINE__, 'Failed to move user settings. ' . $logInfo);
                    }

                    $sourcePbxService = getPbxService($user['pbxowner']);
                    // clear sip peer cache on remote PBX
                    $sourcePbxService->sipPeerPrune($user[LDAP_EXTEN_NUMBER]);
                }

                $res = $wms_ldap->moveUser($user['dn'], $user['pbxowner'], $new_pbx_dn);
                if ($res !== true) {
                    $log->error(__LINE__, 'Failed to move user to ldap. ' . $logInfo);
                    die(_t('multipbx.errorMoveUser', $res));
                }

                // clear local sip peer cache
                \Wildix\CallweaverManager::getInstance()->sipPeerPrune($user[LDAP_EXTEN_NUMBER]);

                // move user from local PBX to remote
                if ($new_pbx_dn !== $curr_pbx['dn']) {
                    // clear sip peer cache on remote PBX
                    $targetPbxService->sipPeerPrune($user[LDAP_EXTEN_NUMBER]);
                }
            } catch (\Exception $e) {
                $log->error(__LINE__, sprintf('Failed to move user. Error: %s; %s', $e->getMessage(), $logInfo));
            }
        }
    }

    // clear users avatar cache
    exec('exec /usr/sbin/cleanup_avatar_cache.php > /dev/null &');

    die('OK');
}

/**
 * Create PBX service by pbx DN
 *
 * @param  string $pbxDn
 * @return \Wildix\Services\PBX
 */
function getPbxService(string $pbxDn) {
    $pbx = \Wildix\PBXes\PBXes::getInstance()->getPBXByDN($pbxDn);

    return new \Wildix\Services\PBX($pbx);
}

function getGooglePhonebooks($token) {
    $googleApi = GoogleAPI::getInstance();

    if ($googleApi->setToken($token) != GoogleAPI::TOKEN_VALID) {
        return array('error_code' => '', 'error' => 'Invalid Token');
    }

    $phonebooks = $googleApi->getPhonebooks(1000);
    if (!empty($phonebooks['error'])) {
        return array(
                'error' => array(
                        'code' => $phonebooks['error']['code'],
                        'message' => $phonebooks['error']['message'],

                )

        );
    }
    if (!empty($phonebooks['entry'])) {
        return array('phonebooks' => $phonebooks['entry'], 'token' => $googleApi->getToken());
    }
}

function fetchGoogleAuthUrl($type) {
    $scopes           = array(
        'phonebooks' => array(
            'email',
            'profile',
            'https://www.googleapis.com/auth/contacts.readonly',
        ),
        'users' => array(
            'email',
            'profile',
            'https://www.googleapis.com/auth/admin.directory.user.readonly',
        ),
    );
    $basicCallbackUrl = ((!empty($_SERVER['HTTPS'])) ? 'https' : 'http') . '://' . $_SERVER['HTTP_HOST'] . '/aclpbx/google_callback.php?callback=callbackFunction';
    $callbacks        = array(
        'phonebooks' => $basicCallbackUrl . 'Phonebooks',
        'users' => $basicCallbackUrl . 'Users',
    );

    if (array_key_exists($type, $scopes) && array_key_exists($type, $callbacks)) {
        return array('url' => GoogleAPI::getInstance()->getAuthUrl(join(' ', $scopes[$type]), $callbacks[$type]));
    } else {
        throw new \Exception('Unknown Google Auth url type');
    }
}

function getGoogleDomainUsers($token, $try) {
    $googleApi     = GoogleAPI::getInstance();
    $users         = array('users' => array(), 'token' => $token);
    $nextPageToken = '';

    if ($googleApi->setToken($token) != GoogleAPI::TOKEN_VALID) {
        throw new \Exception('Invalid token');
    }

    do {
        $data = $googleApi->getDomainUsers($nextPageToken, $try);

        if (!empty($data['error'])) {
            throw new \Exception($data['error']['message'], $data['error']['code']);
        }

        $users['users'] = array_merge($users['users'], $data['users']);

        $nextPageToken = isset($data['nextPageToken']) ? $data['nextPageToken'] : '';
    } while (!empty($nextPageToken));

    return $users;
}

function fetchOffice365AuthUrl($type, $directory = false) {
    $scopes           = array(
            'phonebooks' => array(
                    'openid',
                    'offline_access',
                    'profile',
                    'https://graph.microsoft.com/Contacts.Read' . (($directory == 'yes') ? ' https://graph.microsoft.com/Directory.Read.All' : ''),
            ),
            'users' => array(
                    'openid',
                    'offline_access',
                    'profile',
                    'https://graph.microsoft.com/User.Read.All',
            )
    );
    $basicCallbackUrl = ((!empty($_SERVER['HTTPS'])) ? 'https' : 'http') . '://' . $_SERVER['HTTP_HOST'] . '/api/Microsoft/Callback/?callback=callbackOffice365FunctionContacts';
    $url              = \Microsoft\Office365::getInstance()->getAuthUrl(join(' ', $scopes[$type]), $basicCallbackUrl, 'online');
    return array('url' => $url);
}

function fetchZohoCrmAuthUrl($type) {
    $zohoCrm = getZohoClient();

    $basicCallbackUrl = ((!empty($_SERVER['HTTPS'])) ? 'https' : 'http') . '://' . $_SERVER['HTTP_HOST'] . '/api/ZohoCrm/Callback/?callback=callbackZohoCrmFunctionContacts';

    $url = $zohoCrm->getAuthUrl($type, $basicCallbackUrl);

    return array('url' => $url);
}

function getOffice365Phonebooks($token) {
    if (\Microsoft\Office365::getInstance()->setToken($token) != \Microsoft\Office365::TOKEN_VALID) {
        return array('error_code' => '', 'error' => 'Invalid Token');
    }

    $phonebooks = \Microsoft\Office365::getInstance()->getPhonebooks(0, 1000);
    if (!empty($phonebooks['error'])) {
        return array(
                'error' => array(
                        'code' => $phonebooks['error']['code'],
                        'message' => $phonebooks['error']['message'],

                )

        );
    }
    if (!empty($phonebooks)) {
        return array('phonebooks' => $phonebooks, 'token' => \Microsoft\Office365::getInstance()->getToken());
    }
}

function getUsersBadDialplan() {
    global $aclpbx_class;
    $wms_ldap = WMS_Ldap::getInstance();

    $filter1 = '';
    $filter2 = '';

    $goodDialplans = get_contextnames();

    foreach ($goodDialplans as $dplan => $v) {
        $filter1 .= '(!(userDialplan=' . $dplan . '))';
        $filter2 .= '(!(userFaxDialplan=' . $dplan . '))';
    }

    $curPbx = $aclpbx_class->get_current_pbx_ldap_searchObj();
    $filter = '';
    if ($filter1 != '') {
        $filter = '(&(|(&' . $filter1 . ')(&' . $filter2 . '))(pbxowner=' . $curPbx['dn'] . '))';
    }

    $userLdapData = $wms_ldap->getEntries(WMS_Ldap::PERSONS, $filter, array( 'cn', LDAP_EXTEN_NUMBER));

    return (($userLdapData && is_array($userLdapData)) ? $userLdapData : array());
}

function get_google_phonebooks() {
    if (!empty($_POST['token'])) {
        header("Content-Type: application/json\n");
        $phonebooks = getGooglePhonebooks(json_decode($_POST['token'], true));
        die(json_encode($phonebooks));
    }
}

function get_exchange_phonebooks() {
    if (!empty($_POST['params'])) {
        header("Content-Type: application/json\n");
        try {
            $params     = json_decode($_POST['params'], true);
            $server     = new \Microsoft\ExchangeServer($params['host'], $params['user'], $params['password']);
            $phonebooks = $server->getPhonebooks();
        } catch (\Exception $e) {
            $error = array(
                'error' => array(
                    'code' => $e->getCode(),
                    'message' => $e->getMessage(),
                )
            );
            die(json_encode($error));
        }

        die(json_encode(array('phonebooks' => $phonebooks)));
    }
}
function get_office365_phonebooks() {
    if (!empty($_POST['token'])) {
        header("Content-Type: application/json\n");
        $phonebooks = getOffice365Phonebooks(json_decode($_POST['token'], true));
        die(json_encode($phonebooks));
    }
}


function get_office365_auth_url() {
    try {
        $authUrl = fetchOffice365AuthUrl($_POST['type'], $_POST['directory']);
    } catch (\Exception $e) {
        $authUrl = array(
            'error' => array(
                'code' => $e->getCode(),
                'message' => $e->getMessage(),
            )
        );
        header($_SERVER['SERVER_PROTOCOL'] . ' 503 Service Temporarily Unavailable');
    }

    header("Content-Type: application/json\n");
    die(json_encode($authUrl));
}

function get_zohoCrm_auth_url() {
    try {
        $authUrl = fetchZohoCrmAuthUrl($_POST['type']);
    } catch (\Exception $e) {
        $authUrl = array(
            'error' => array(
                'code' => $e->getCode(),
                'message' => $e->getMessage(),
            )
        );
        header($_SERVER['SERVER_PROTOCOL'] . ' 503 Service Temporarily Unavailable');
    }

    header("Content-Type: application/json\n");
    die(json_encode($authUrl));
}

function zohoCrm_revoke_token() {
    $refresh_token = $_POST['refresh_token'];
    $api_domain    = $_POST['api_domain'];

    $zohoCrm = getZohoClient();

    $result = $zohoCrm->revokeToken($api_domain, $refresh_token);

    die(json_encode(array('stutus' => $result)));
}

function fetch_google_auth_url() {
    try {
        if (empty($_POST['type'])) {
            throw new \Exception('Please provide type of auth url');
        }
        $authUrl = fetchGoogleAuthUrl($_POST['type']);
    } catch (\Exception $e) {
        $authUrl = array(
            'error' => array(
                'code' => $e->getCode(),
                'message' => $e->getMessage(),
            )
        );
        header($_SERVER['SERVER_PROTOCOL'] . ' 503 Service Temporarily Unavailable');
    }

    header("Content-Type: application/json\n");
    die(json_encode($authUrl));
}

function get_google_domainusers($try = false) {
    try {
        if (empty($_POST['token'])) {
            throw new \Exception('Invalid token');
        }
        $users = getGoogleDomainUsers(json_decode($_POST['token'], true), $try);
    } catch (\Exception $e) {
        $users = array(
            'error' => array(
                'code' => $e->getCode(),
                'message' => $e->getMessage(),
            )
        );
        header($_SERVER['SERVER_PROTOCOL'] . ' 503 Service Temporarily Unavailable');
    }

    header("Content-Type: application/json\n");
    die(json_encode($users));
}

function saveFailover() {
    $wms_ldap = WMS_Ldap::getInstance();
    // check if failover already present in ldap
    $failover = $wms_ldap->getEntry(WMS_Ldap::FAILOVER, '(pbxowner=' . $_POST['pbxowner'] . ')', array('dn'));
    if (!empty($failover)) {
        $wms_ldap->deleteEntryByDn($failover['dn']);
    }

    if ($_POST['pbxFailover'] == 'none') {
        die('OK');
    }

    $params = array(
        'pbxowner' => $_POST['pbxowner'],
        'pbxFailover' => $_POST['pbxFailover'],
        'priority' => $_POST['priority'],
        'enabled' => $_POST['enabled']
    );

    $wms_ldap->addFailover($params);
    die('OK');
}

function getFailoverByDn() {
    $failover = \Wildix\Failovers\Failovers::getInstance()->getFailoverByDn($_POST['pbxowner']);
    header("Content-Type: application/json\n");
    die(json_encode($failover));
}

function getLicenseUsageStatus() {
    $license = $GLOBALS['diContainer']->get(License::class);

    if ($license->isLicenseLimitExceeded()) {
        die($license->getLimitExceededMessage());
    }

    die('OK');
}

if (isset($_POST['action'])) {
    if (isset($_POST[Session::CSRF_TOKEN_HEADER]) ? !Session::isValidCsrfToken($_POST[Session::CSRF_TOKEN_HEADER]) : !Session::isValidCsrfToken()) {
        die('Access denied');
    }

    switch ($_POST['action']) {
        case 'users_sync_save':
            users_sync_save();
           break;
        case 'users_sync':
            users_sync();
            break;
        case 'phonebook_sync_save':
            phonebook_sync_save();
           break;
        case 'phonebook_sync':
            phonebook_sync();
           break;
        case 'remove_pbx':
            remove_pbx();
           break;
        case 'sendWelcomeEmail':
            sendWelcomeEmail();
           break;
        case 'sendWelcomeEmailXbees':
            sendWelcomeEmailXbees();
           break;
        case 'moveUsers':
            moveUsers();
            break;
        case 'fetch_google_auth_url':
            fetch_google_auth_url();
           break;
        case 'get_google_phonebooks':
            get_google_phonebooks();
           break;
        case 'get_google_domainusers':
            get_google_domainusers();
           break;
        case 'try_google_domainusers':
            get_google_domainusers(true);
           break;
        case 'get_exchange_phonebooks':
            get_exchange_phonebooks(true);
           break;
        case 'get_office365_auth_url':
            get_office365_auth_url();
           break;
        case 'get_zohoCrm_auth_url':
            get_zohoCrm_auth_url();
           break;
        case 'zohoCrm_revoke_token':
            zohoCrm_revoke_token();
           break;
        case 'get_office365_phonebooks':
            get_office365_phonebooks();
           break;
        case 'saveFailover':
            saveFailover();
           break;
        case 'getFailoverByDn':
            getFailoverByDn();
           break;
        case 'getLicenseUsageStatus':
            getLicenseUsageStatus();
           break;
    }
}

if (isset($_GET['download_all_sync_phonbook_log']) && $_GET['download_all_sync_phonbook_log'] == '1') {
    $rid = isset($_GET['rid']) && is_numeric($_GET['rid']) ? (int)$_GET['rid'] : 0;
    if ($rid > 0) {
        $filename = 'phonebook_sync_' . $rid . '.log';
        ini_set('memory_limit', '-1');
        // fix for IE catching or PHP bug issue
        header("Pragma: public");
        header("Expires: 0");
// set expiration time
        header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
        // browser must download file from server instead of cache
        // force download dialog
        header("Content-Type: application/x-download");
        header("Content-Disposition: attachment; filename=\"" . $filename . "\"");
        header("Content-Transfer-Encoding: binary");

        passthru('sudo /usr/sbin/syslog_grep \'phonebook_' . $rid . '_sync3 #\'');
    }
    die();
}

$multipbx_class = new multipbx();
$pbx_net_mode   = $multipbx_class->get_mode();

$curPbx = $aclpbx_class->get_current_pbx_ldap_searchObj();

$_REQUEST['pbxid'] = $curPbx['pbxSerial'];
$proxy->setObject($aclpbx_class);
$proxy->mode = 'self';

$proxy->action = 'getGroups';
$proxy->processing();
$jsongroups = $proxy->toJSON;

$proxy->action = 'getPBXes';
$proxy->processing();
$jsonpbxes = $proxy->toJSON;

$proxy->action = 'getPhonebooks';
$proxy->processing();
$jsonphonebooks = $proxy->toJSON;
// print_r($jsonphonebooks); die;
$feature_names       = array();
$feature_names_tmp   = feature_names();
$feature_names_tmp[] = 'FKEYS';
foreach ($feature_names_tmp as $feat_name) {
    $feature_names[$feat_name] = _t('features.' . $feat_name);
}
$service_names_tmp = array('STIME','3SWITCH','SWITCH');
foreach ($service_names_tmp as $serv_name) {
    $feature_names[$serv_name] = _t('services.' . $serv_name);
}
$feature_names['PHONEBOOK']       = _t('features.PHONEBOOK');
$feature_names['P_INFO']          = _t('acl.P_INFO');
$feature_names['ADVANCED_STATUS'] = _t('acl.ADVANCED_STATUS');
$feature_names['FAXSERVERSET']    = _t('acl.FAXSERVERSET');
$feature_names['EMAILMCN']        = _t('features.EMAILMCN');
$feature_names['SMSMCN']          = _t('features.SMSMCN');
$feature_names['RING']            = _t('features.RING');
$feature_names['all']             = _t('features.all');
// }
$acl_callclasses        = get_call_classes_no_assoc();
$acl_callclasses['all'] = _t('features.all');

if (isset($_POST['action']) && $_POST['action'] == 'validate') {
    header("Content-Type: application/json\n");
    // ob_start("ob_gzhandler");
    $errors = validateValues(json_decode($_POST['elms'], true), $_GET['tab']);
    die(json_encode(($errors === true) ? array() : $errors));
}

$pbxdn = getPbxDn();

function getPbxDn() {
    global $aclpbx_class;

    return $aclpbx_class->get_current_pbx_ldap_dn();
}

function validateValues($values, $tab) {
    $errors = array();
    // form validate
    if (! function_exists($validate_function = "validate_{$tab}")) {
        return $errors;
    }
    array_walk($values, 'trim');
    array_walk($values, 'strip_tags');
    // logger('Validator',__FUNCTION__,__LINE__);
    return 0 == sizeof($errors = $validate_function($values)) ? true : $errors;
}

function validate_phonebooks($values) {
    global $aclpbx_class;
    $errors = array();
    if (!preg_match('/^[a-z0-9]{1,}[a-z0-9\-_ ]*$/i', $values['edit_name'])) {
        $errors['edit_name'] = _t('strings.Error');
    }

    foreach ($aclpbx_class->get_phonebooks() as $phonebook) {
        if (trim($values['edit_name']) == $phonebook['name']) {
            $errors['edit_name'] = _t('strings.AlreadyPresent');
            return $errors;
        }
    }

    return $errors;
}

$mount          = new \Wildix\System\Mount();
$t_samba_mounts = $mount->getMountsByType('cifs');
unset($mount);

// remove call generation share
if (isset($t_samba_mounts['/dev/shm/var/spool/callweaver/outgoing'])) {
    unset($t_samba_mounts['/dev/shm/var/spool/callweaver/outgoing']);
}
$samba_mounts = array();
foreach ($t_samba_mounts as $t_mpoint => $t_vals) {
    $samba_mounts[$t_mpoint] = _t('devices.' . $t_mpoint);
}

$is_userdir_present = get_users_settings_dir() !== false;

if (!$is_userdir_present) {
    $wmsErr->_set('', 'notification', _t('strings.UserdirIsNotMounted'));
}
