<?php
namespace Controllers;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Slim\Psr7\UploadedFile;
use Wildix\Error;
use Wildix\InvalidDataException;
use Wildix\System\ADSingleSignOnService;
use Wildix\Validator;

class ADSingleSignOnController extends Controller {

    public function getSettings(Request $request, Response $response) {
        $result = $this->service()->getSettings();

        return $this->result($result, $response);
    }

    public function setSettings(Request $request, Response $response) {
        $params = $request->getParsedBody();

        $data      = [
            'enabled' => $params['enabled'] ?? 'false',
            'keyTab' => $this->service()->getKeyTabPath(),
            'fqdn' => $params['fqdn'],
            'uploadData' => null
        ];
        $validator = new Validator($data);

        if (!empty($request->getUploadedFiles()['keyTab']) && $request->getUploadedFiles()['keyTab'] instanceof UploadedFile) {
            $data['uploadData'] = $request->getUploadedFiles()['keyTab'];
        }

        // check if file is uploaded before enable SSO
        if (Validator::isTrue($data['enabled']) && empty($data['keyTab']) && empty($data['uploadData'])) {
            throw new \InvalidArgumentException('AD Single SignOn can not be enabled without keyTab file. Please upload it first');
        }

        if ($data['fqdn']) {
            $validator->rule('AdFqdn', 'fqdn')->message(Error::AdFqdn);
        }

        if ($data['uploadData']) {
            $validator->rule('AdKeyTab', 'keyTab.name')->message(Error::AdKeyTab);
        }

        if (!$validator->validate()) {
            throw new InvalidDataException(Error::getMessage(Error::VALIDATION_ERROR), $validator->errors());
        }

        $result = $this->service()->setSettings($data);

        if (!$result) {
            throw new \InvalidArgumentException('Error while saving data');
        }

        return $this->result($result, $response);
    }

    public function deleteKeyTab(Request $request, Response $response) {
        $result = $this->service()->deleteKeyTab();

        return $this->result($result, $response);
    }

    private function service(): ADSingleSignOnService {
        return $this->getContainer()->get(ADSingleSignOnService::class);
    }
}
