<?php

namespace Controllers\CRM;

use Controllers\Controller;
use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Slim\Views\PhpRenderer;

class ZohoCrm extends Controller {

    public function callback(Request $request, Response $response) {
        $renderer = new PhpRenderer(__DIR__ . '/../../templates');

        return $renderer->render($response, 'ZohoCallback.php');
    }

    public function getStatus(Request $request, Response $response) {
        $result = [
            'isEnabled'  => $this->getZohoCrm()->isEnabled(),
            'apiVersion' => $this->getZohoCrm()->getApiVersion(),
        ];

        return $this->result($result, $response);
    }

    public function enable(Request $request, Response $response) {
        if ($this->getPbx()->isSlave()) {
            return $this->confirm($request, $response);
        }

        $params = $request->getParsedBody();
        $result = $this->getPhoneBridgeService()->enable(
            \Wildix\Services\PhoneBridge::SERVICE_ID_ZOHO_CRM,
            (string)($params['location'] ?? '')
        );

        if (!is_string($result)) {
            return $this->error('Failed enable Zoho Products integration on PhoneBridge.', $response, 502);
        }

        return $this->result(['accessRequest' => $result], $response);
    }

    public function disable(Request $request, Response $response) {
        if (!$this->getPbx()->isSlave()) {
            $phoneBridge = $this->getPhoneBridgeService();

            if ($phoneBridge->disable(\Wildix\Services\PhoneBridge::SERVICE_ID_ZOHO_CRM) === false) {
                return $this->error('Failed disable Zoho Products integration on PhoneBridge.', $response, 502);
            }
        }

        $this->getZohoCrm()->disable();

        $this->configureEjabberdLuaWorkers();

        return $this->success($response);
    }

    public function confirm(Request $request, Response $response) {
        $this->getZohoCrm()->enable();

        $this->configureEjabberdLuaWorkers();

        if (!$this->getPbx()->isSlave()) {
            exec('nohup php /usr/sbin/phonebridge_sync_users ' . \Wildix\Services\PhoneBridge::SERVICE_ID_ZOHO_CRM . '> /dev/null &');
        }

        return $this->success($response);
    }

    /**
     * Returns PBX model class.
     *
     * @return \Models\PBX
     */
    private function getPbx(): \Models\PBX {
        return $this->getContainer()->get(\Models\PBX::class);
    }

    /**
     * Returns ZohoCrm class.
     *
     * @return \Wildix\Integration\ZohoCrm
     */
    private function getZohoCrm(): \Wildix\Integration\ZohoCrm {
        return $this->getContainer()->get(\Wildix\Integration\ZohoCrm::class);
    }

    /**
     * Configure ejabberd  lua workers.
     *
     * @return void
     */
    private function configureEjabberdLuaWorkers(): void {
        $this->getContainer()->get(\Wildix\EjabberdMod\Astman::class)->configureLuaWorkers();
    }

    /**
     * Returns PhoneBridge service.
     *
     * @return \Wildix\Services\PhoneBridge
     */
    private function getPhoneBridgeService(): \Wildix\Services\PhoneBridge {
        return $this->getContainer()->get(\Wildix\Services\PhoneBridge::class);
    }
}
