<?php

namespace Controllers;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Wildix\Validator;

class CrmSettings extends Controller {

    public function setSettings(Request $request, Response $response, array $args): Response {
        $settings = $request->getParsedBody();

        if (!$settings) {
            return $this->error('settings are empty', $response);
        }

        if (isset($settings[\Wildix\Integration\CrmSettings::CRM_VERIFY_CERTIFICATE])
            && Validator::isTrue($settings[\Wildix\Integration\CrmSettings::CRM_VERIFY_CERTIFICATE])
        ) {
            $settings[\Wildix\Integration\CrmSettings::CRM_VERIFY_CERTIFICATE] = true;
        } else {
            $settings[\Wildix\Integration\CrmSettings::CRM_VERIFY_CERTIFICATE] = false;
        }

        $result = $this->getSettingsModel()->setSettings($settings);

        $this->getContainer()->get(\Wildix\EjabberdMod\Astman::class)->configureLuaWorkers();

        return $this->result($result, $response);
    }

    public function getSettings(Request $request, Response $response, array $args): Response {
        $params = $request->getQueryParams();

        $force  = $params['force'] ?? false;
        $result = $this->getSettingsModel()->getSettings($force);

        return $this->result($result, $response);
    }

    private function getSettingsModel(): \Wildix\Integration\CrmSettings {
        return $this->getContainer()->get(\Wildix\Integration\CrmSettings::class);
    }
}
