<?php

namespace Controllers\Dialplans;

use Api\Network\Exception\ForbiddenException;
use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Wildix\Core\AbstractCrudController;
use Wildix\Dialplan\CallGroups\CallGroupsService;
use Wildix\Error;

class CallGroupsController extends AbstractCrudController {

    protected $_service = CallGroupsService::class;

    /**
     * Getting call group statistic by id group
     *
     * @param Request  $request  Request.
     * @param Response $response Response.
     * @param array    $args     Arguments.
     *
     * @return Response
     *
     * @throws ForbiddenException Exception AccessError
     */
    public function getInfoByItem(Request $request, Response $response, array $args): Response {
        $user     = $this->getUser();
        $settings = $user->getSettings();
        if (!$settings->isAllowedCallGroup($args['id'])) {
            throw new ForbiddenException(Error::LimitCallGroupIds, 403);
        }
        $result = $this->_service()->getAgentsAvailabilityInfo($args['id']);
        return $this->result($result, $response);
    }
}
