<?php
declare(strict_types=1);

namespace Controllers\Dialplans;

use Controllers\Controller;
use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Wildix\Dialplan\CallGroups\CallGroupsQueueService;
use Wildix\Exception;

class CallGroupsQueueController extends Controller {

    public function getItems(Request $request, Response $response, array $args): Response {
        $records = [];
        $items   = $this->service()->getItems();
        foreach ($items as $item) {
            $records[] = $this->service()->buildItem($item);
        }

        return $this->resultList($records, $response);
    }

    public function getItem(Request $request, Response $response, array $args): Response {
        $result = $this->service()->getItem((int)$args['id'], true);

        return $this->result($result, $response);
    }

    public function addMember(Request $request, Response $response, array $args): Response {
        $request = $request->getParsedBody();

        $penalty = isset($request['penalty']) ? (int)$request['penalty'] : 1;
        $paused  = isset($request['paused']) && $request['paused'] ? 1 : 0;

        if (empty($request['member'])) {
            return $this->error('Member is empty', $response, 400);
        }
        if (!$this->_checkMemberFormat($request['member'])) {
            return $this->error('Not allowed member format', $response, 400);
        }

        $result = $this->service()->addMember((int)$args['id'], $request['member'], $penalty, $paused);
        $this->_checkResponse($result);

        return $this->result($result, $response);
    }

    public function deleteMember(Request $request, Response $response, array $args): Response {
        $id     = (int)$args['id'];
        $member = $args['member'];

        $result = $this->service()->deleteMember($id, $member);
        $this->_checkResponse($result);

        return $this->result($result, $response);
    }

    private function _checkMemberFormat(string $member): bool {
        return (preg_match('/^Local\/\S+@\S+$/', $member) || preg_match('/^SIP\/\S+$/', $member));
    }

    private function _checkResponse(array $result): void {
        if (mb_strtolower($result['Response']) !== 'success') {
            throw new Exception($result['Message'], 400);
        }
    }

    private function service(): CallGroupsQueueService {
        return $this->getContainer()->get(CallGroupsQueueService::class);
    }
}
