<?php

namespace Controllers\Dialplans;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Wildix\Core\AbstractCrudController;
use Wildix\Dialplan\Ivr\IvrService;
use Wildix\Dialplan\Ivr\IvrValidator;

class IvrController extends AbstractCrudController {

    protected $_service = IvrService::class;

    /**
     * Create IVR
     *
     * @param Request  $request  Request.
     * @param Response $response Response.
     *
     * @return Response
     */
    public function create(Request $request, Response $response): Response {
        $this->_service()->setValidator($this->_ivrValidator());
        return parent::create($request, $response);
    }

    /**
     * Update IVR
     *
     * @param Request  $request  Request.
     * @param Response $response Response.
     * @param array    $args     Arguments.
     *
     * @return Response
     */
    public function update(Request $request, Response $response, array $args): Response {
        $this->_service()->setValidator($this->_ivrValidator());
        return parent::update($request, $response, $args);
    }

    /**
     * Get Ivr Validator
     *
     * @return IvrValidator
     */
    private function _ivrValidator(): IvrValidator {
        return $this->getContainer()->get(IvrValidator::class);
    }
}
