<?php
namespace Controllers;

use Api\Dictionary\Enum\DictionaryTypeEnum;
use Api\Dictionary\Objects\ListItemsObject;
use Api\Dictionary\Response\DictionaryResponse;
use Api\Dictionary\Services\DictionaryService;
use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Wildix\License;

class Dictionaries extends Controller {

    /**
     * Get dialplan specifications
     *
     * @param Request  $request  Request.
     * @param Response $response Response.
     *
     * @throws \Exception Error.
     *
     * @return Response
     */
    public function getSettings(Request $request, Response $response): Response {
        $dictionaryService = $this->getDictionaryService();
        $params            = $request->getQueryParams();
        $types             = $params['items'] ?? DictionaryTypeEnum::getEnumKeys();
        $result            = new DictionaryResponse();
        foreach ($types as $type) {
            if ($type === DictionaryTypeEnum::SERVICE && !$this->serviceLicence()->haveLicense(License::TYPE_XBEES)) {
                continue;
            }
            $method = DictionaryTypeEnum::getValueById($type);
            if (method_exists($dictionaryService, $method)) {
                $resultMethod = $dictionaryService->$method();
                $resultData   = is_array($resultMethod) ? $resultMethod : $resultMethod->toArray();
                $listItems    = new ListItemsObject($type, $resultData);
                $result->addResponse($listItems->toArray());
            }
        }
        return $this->resultList($result->getResponse(), $response);
    }

    private function getDictionaryService(): DictionaryService {
        return $this->getContainer()->get(DictionaryService::class);
    }

    private function serviceLicence(): License {
        return $this->getContainer()->get(License::class);
    }
}
