<?php

namespace Controllers;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;

/**
 * REST API Controller for Fax/SMS profiles
 */
class FaxSmsProfiles extends Controller {

    private function getFaxSmsProfilesObject() {
        return $this->getContainer()->get(\Wildix\Faxes\FaxSmsProfiles::class);
    }

    public function getProfiles(Request $request, Response $response, array $args) {
        $profiles = $this->getFaxSmsProfilesObject()->getProfiles();

        $profiles['contexts'] = $this->getFaxSmsProfilesObject()->getContexts()->getNames();
        return $this->result($profiles, $response);
    }

    public function createProfile(Request $request, Response $response, array $args) {
        $datastore = $request->getParsedBody();

        $datastore['profileId'] = 'new';

        $result = $this->getFaxSmsProfilesObject()->saveProfile($datastore);

        return $this->result($result, $response);
    }

    public function updateProfile(Request $request, Response $response, array $args) {
        $datastore = $request->getParsedBody();

        $datastore['profileId'] = $args['profileId'];

        $result = $this->getFaxSmsProfilesObject()->saveProfile($datastore);

        return $this->result($result, $response);
    }

    public function removeProfiles(Request $request, Response $response, array $args) {
        $profileIds = $args['profileIds'];
        if (!isset($profileIds)) {
            return $this->error('params are empty', $response);
        }

        $profileIds = array_map('intval', explode(',', $profileIds));

        $this->getFaxSmsProfilesObject()->removeProfiles($profileIds);

        return $this->success($response);
    }

    public function runFetchmailTest(Request $request, Response $response, array $args) {
        $profileId = $args['profileId'];
        $result    = $this->getFaxSmsProfilesObject()->runFetchmailTest($profileId);

        return $this->result($result, $response);
    }

    public function getFetchmailTestStatus(Request $request, Response $response, array $args) {
        $profileId = $args['profileId'];
        $result    = $this->getFaxSmsProfilesObject()->getFetchmailTestStatus($profileId);

        return $this->result($result, $response);
    }
}
