<?php
namespace Controllers;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Wildix\Error;
use Wildix\InvalidDataException;
use Wildix\Validator;

class HttpProxy extends Controller {

    public function setSettings(Request $request, Response $response, array $args): Response {
        $form = new Validator(
            $request->getParsedBody(),
            [
                'enable',
                'host',
                'port',
                'auth_method',
                'login',
                'password',
            ]
        );

        $httpProxy = $this->service();

        $form->rules(
            ['boolean' => 'enable']
        );

        if (!$form->validate()) {
            throw new InvalidDataException(Error::BadRequest, $form->errors());
        }

        $enable = $form->data()['enable'] ?? false;

        if (!$enable) {
            $httpProxy->disable();
            $this->_restartRemoteSupportIfEnabled();

            return $this->result(true, $response);
        }

        $form->rule('required', ['host', 'port']);
        $form->rule('min', 'port', 1);
        $form->rule('max', 'port', 65535);
        $form->rule('numeric', 'port');

        $form->rule('DomainOrIp', 'host');

        $form->rule('optional', ['auth_method', 'login', 'password']);

        $form->rule('in', 'auth_method', ['none', 'basic', 'ntlm']);


        if (!$form->validate()) {
            throw new InvalidDataException(Error::BadRequest, $form->errors());
        }

        $httpProxy->validateSupport($form->data());
        $httpProxy->setSettings($form->data());

        $this->_restartRemoteSupportIfEnabled();

        return $this->result(true, $response);
    }

    public function getSettings(Request $request, Response $response, array $args): Response {
        return $this->result($this->service()->getSettings(), $response);
    }

    private function _restartRemoteSupportIfEnabled() {
        $remoteSupport = $this->getContainer()->get(\Wildix\System\RemoteSupport::class);

        if ($remoteSupport->getState() === 0) {
            $remoteSupport->initOperation(\Wildix\System\RemoteSupport::OPERATION_RESTART);
        }
    }

    private function service(): \Wildix\System\HttpProxy {
        return $this->getContainer()->get(\Wildix\System\HttpProxy::class);
    }
}
