<?php

namespace Controllers;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Wildix\Error;
use Wildix\InvalidDataException;
use Wildix\Validator;

/**
 * LdapRadius is a controller working with LDAP/Radius Server
 */
class LdapRadius extends Controller {
    const PASSWORD_MIN_LENGTH = 6;

    public function setSettings(Request $request, Response $response, array $args): Response {
        $options = $request->getParsedBody()['data'] ?? [];

        $form = new Validator($options);

        $form->rule(
            'required',
            [
                'connection_enable',
                'connection_pass',
            ]
        );
        $form->rule('LengthMin', 'connection_pass', self::PASSWORD_MIN_LENGTH);

        if (!$form->validate()) {
            throw new InvalidDataException(Error::BadRequest, $form->errors());
        }

        try {
            $this->service()->setOptions($options);
        } catch (\Exception $e) {
            throw new InvalidDataException($e->getMessage());
        }

        return $this->success($response);
    }

    public function getSettings(Request $request, Response $response, array $args): Response {
        $result = $this->service()->getOptions();

        return $this->result($result, $response);
    }

    private function service(): \Wildix\System\LdapRadius {
        return $this->getContainer()->get(\Wildix\System\LdapRadius::class);
    }
}
