<?php
namespace Controllers;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Wildix\Exception;
use Wildix\License;
use Wildix\Services\Portal;

class LicenseController extends Controller {

    public function get(Request $request, Response $response, array $args): Response {
        $service     = $this->service();
        $limitations = $service->getLimitations();

        foreach (['token', 'pbxKey'] as $keyToHide) {
            if (array_key_exists($keyToHide, $limitations)) {
                unset($limitations[$keyToHide]);
            }
        }

        return $this->result(
            [
                'limitations' => $limitations,
                'licenseUsage' => $service->getUserLicenseUsage(),
                'activated' => $service->isActivated(),
                'hwserial' => $this->servicePbx()->getEth0Serial(),
                'swserial' => $this->servicePbx()->getSerial(),
                'domain' => $this->servicePbx()->getDomain(),
                'processor' => $this->servicePbx()->getCpuModel(),
                'memory' => $this->servicePbx()->getTotalMemory()
            ],
            $response
        );
    }

    public function refresh(Request $request, Response $response, array $args): Response {
        $this->service()->reloadLicense();

        return $this->success($response);
    }

    public function deactivate(Request $request, Response $response, array $args): Response {
        $this->service()->deactivateLicense();

        return $this->success($response);
    }

    public function activate(Request $request, Response $response, array $args): Response {
        $params = $request->getParsedBody();
        $key    = (string)($params['key'] ?? '');

        $this->service()->activateByKey($key);

        return $this->success($response);
    }

    public function downloadLogo(Request $request, Response $response, array $args): Response {
        $filename = '';
        $logo     = $this->servicePortal()->getPartnerCustomLogo();

        if (!empty($logo)) {
            $filename = $this->servicePbx()->getLogoPath();
            file_put_contents($filename, $logo);
        }


        return $this->result(
            ['logo' => str_replace(BASEPATH, '', $filename)],
            $response
        );
    }

    public function deleteLogo(Request $request, Response $response, array $args): Response {
        $filename = $this->servicePbx()->getLogoPath();

        if (file_exists($filename)) {
            if (!unlink($filename)) {
                return $this->error('cannot remove', $response);
            }
        }

        return $this->success($response);
    }

    private function service(): License {
        return $this->getContainer()->get(License::class);
    }

    private function servicePbx(): \Models\PBX {
        return $this->getContainer()->get(\Models\PBX::class);
    }

    private function servicePortal(): Portal {
        return $this->getContainer()->get(Portal::class);
    }
}
