<?php
namespace Controllers;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Slim\Views\PhpRenderer;

class Microsoft extends Controller {

    public function singleSignOn(Request $request, Response $response) {
        $params    = $request->getQueryParams();
        $callback  = (string)($params['callback'] ?? '');
        $isMsTeams = (int)($params['msTeams'] ?? 0);
        $scopes    = [
                         'openid',
                         'profile',
                         'https://outlook.office.com/Contacts.Read',
                    ];

        $basicCallbackUrl = ((!empty($_SERVER['HTTPS'])) ? 'https' : 'http') . '://' . $_SERVER['HTTP_HOST'] . '/api/Microsoft/Callback/?msTeams=' . $isMsTeams . '&callback=' . $callback;

        $url = $this->serviceOffice365()->getAuthUrl(join(' ', $scopes), urlencode($basicCallbackUrl), 'online');

        return $response->withHeader('Location', $url)->withStatus(302);
    }

    public function callback(Request $request, Response $response) {
        $renderer = new PhpRenderer(__DIR__ . '/../templates');

        return $renderer->render($response, 'MicrosoftCallback.php');
    }

    private function serviceOffice365(): \Microsoft\Office365 {
        return $this->getContainer()->get(\Microsoft\Office365::class);
    }
}
