<?php

namespace Controllers\Network;

use Api\Network\Interfaces\NetworkServiceInterface;
use Api\Network\Request\DeleteRequest;
use Api\Network\Request\UpdateRequest;
use Controllers\Controller;
use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;

class NetworkPbxesController extends Controller {
    public function getItems(Request $request, Response $response, array $args): Response {
        return $this->result($this->service()->getItems()->toArray(), $response);
    }

    public function update(Request $request, Response $response, array $args): Response {
        $request = new UpdateRequest(
            [
                'serial' => $args['serial'],
                'data' => $request->getParsedBody()
            ]
        );

        $this->service()->update($request);

        return $this->success($response);
    }

    public function delete(Request $request, Response $response, array $args): Response {
        $request = new DeleteRequest(
            [
                'serial' => $args['serial'],
                'migrateToSerial' => $request->getQueryParams()['migrateTo'] ?? $this->service()->getMasterSerial()
            ]
        );

        $this->service()->delete($request);

        return $this->success($response);
    }

    private function service(): NetworkServiceInterface {
        return $this->getContainer()->get(NetworkServiceInterface::class);
    }
}
