<?php

namespace Controllers;

use Microsoft\Office365 as Office365Client;
use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Slim\Views\PhpRenderer;
use Wildix\Microsoft\Office365Service;

class Office365 extends Controller {

    public function callback(Request $request, Response $response) {
        $params   = $request->getQueryParams();
        $callback = (string)($params['callback'] ?? '');
        if ($callback === '') {
            return $this->error('Undefined callback.', $response, 400);
        }

        $data = [];
        // TODO weird... need better error resolving.
        if (isset($params['admin_consent']) || isset($params['tenant'])) {
            $data['admin_consent'] = $params['admin_consent'];
            $data['tenant']        = $params['tenant'];
            $data['modules']       = (array)$params['modules'];
            if (isset($params['error']) || isset($params['error_description'])) {
                $data['error']             = $params['error'];
                $data['error_description'] = $params['error_description'];
            }
        } else {
            $data = [
                'error' => 'lack_of_provider_data',
                'error_description' => 'Tenant of Admin consent is not granted',
            ];
        }

        $renderer = new PhpRenderer(__DIR__ . '/../templates');

        return $renderer->render($response, 'Office365Callback.php', compact(['callback', 'data']));
    }

    public function getStatus(Request $request, Response $response) {
        $result = [
            'isEnabled'  => $this->_getOfficeService()->isEnabledCalendarIntegration() || $this->_getOfficeService()->isEnabledPhonebookIntegration(),
            'modules'  => $this->_getOfficeService()->enabledModules(),
        ];

        return $this->result($result, $response);
    }

    public function adminConsentUrl(Request $request, Response $response) {
        $params   = $request->getQueryParams();
        $callback = (string)($params['callbackName'] ?? '');
        $modules  = (array)($params['modules'] ?? []);
        if ($callback === '') {
            return $this->error('Undefined callback.', $response, 400);
        }

        if (empty($modules)) {
            return $this->error('Undefined module.', $response, 400);
        }

        // now: copy-paste / route generator should be used instead!
        $basicCallbackUrl = ((!empty($_SERVER['HTTPS'])) ? 'https' : 'http') . '://' . $_SERVER['HTTP_HOST'] . '/api/Office365/Callback/?callback=' . $callback;

        $basicCallbackUrl .= '&' . http_build_query(['modules' => $modules]);

        $url = $this->office365Client()->getAdminConsentUrl($basicCallbackUrl);

        return $this->result(['url' => $url], $response);
    }

    public function enable(Request $request, Response $response) {
        $params = $request->getParsedBody();
        $tenant = (string)($params['tenant'] ?? '');
        if ($tenant === '') {
            return $this->error('Undefined tenant', $response, 400);
        }

        $modules = (array)($params['modules'] ?? []);
        if (empty($modules)) {
            return $this->error('Undefined module', $response, 400);
        }

        $officeService = $this->_getOfficeService();
        $officeService->enableIntegration($tenant, $modules);

        return $this->success($response);
    }

    public function disable(Request $request, Response $response) {
        $officeService = $this->_getOfficeService();
        $officeService->disableIntegration();
        return $this->success($response);
    }

    private function _getOfficeService(): Office365Service {
        return $this->getContainer()->get(Office365Service::class);
    }

    private function office365Client(): Office365Client {
        return $this->getContainer()->get(Office365Client::class);
    }
}
