<?php
namespace Controllers;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Wildix\Calendar\CalendarService;
use Wildix\Calendar\Events;
use Wildix\Calendar\Settings;

class OutlookCalendar extends Controller {

    public function updateCalendar(Request $request, Response $response) {
        $calendarService = $this->_getCalendarService();
        $eventDtoCollection = $calendarService->createEventsFromRequest($request);
        $userEvents         = $this->getEvents()->getUserEvents($this->getUser());
        // wiservice integration send whole batch of events
        // if some of ids are missed => event will be removed from DB
        $result = $calendarService->updateEvents($userEvents, $eventDtoCollection, $this->getUser());

        return $this->result(['id' => $result], $response);
    }

    public function getCalendar(Request $request, Response $response) {
        $params = $request->getQueryParams();
        $filter = (array)($params['filter'] ?? []);

        $calendarSettings = $this->getUser()->getSettings()->getCalendar();
        if ($calendarSettings['OUTLOOK']['working_hours']['enable'] != 1) {
            $filter['type'] = Events::EVENT_TYPE_CALENDAR;
        }

        $search       = (string)($params['search'] ?? '');
        $searchFields = (string)($params['searchFields'] ?? '');
        if ($searchFields) {
            $searchFields = explode(',', $searchFields);
        }

        $start = (int)($params['start'] ?? 0);
        $count = (int)($params['count'] ?? 100);
        $sort  = $params['sort'] ?? null;
        $dir   = $params['dir'] ?? null;

        $total  = $this->getEvents()->getCount($filter, $search, $searchFields, $this->getUser());
        $events = [];
        if ($total > 0) {
            $events = $this->getEvents()->getEvents($filter, $search, $searchFields, $start, $count, $sort, $dir, $this->getUser());
        }

        return $this->result(
            [
                'total'   => $total,
                'records' => $events,
            ],
            $response
        );
    }

    public function updateSettings(Request $request, Response $response) {
        $params   = $request->getParsedBody();
        $settings = (array)($params['data'] ?? []);
        if (empty($settings['workHoursStart'])) {
            return $this->error('The work hours start cannot be empty', $response);
        }

        if (empty($settings['workHoursEnd'])) {
            return $this->error('The work hours end cannot be empty', $response);
        }


        $calendarService = $this->_getCalendarService();
        $storedSettings  = $this->getSettings()->getOutlookSettings($this->getUser());
        $result          = $calendarService->updateSettings($storedSettings, $settings, $this->getUser(), Settings::SETTINGS_APP_OUTLOOK);

        $eventDtoCollection     = $calendarService->generateWorkHoursEvents($settings);
        $userWorkingHoursEvents = $this->getEvents()->getUserEvents($this->getUser(), true);
        $calendarService->updateEvents($userWorkingHoursEvents, $eventDtoCollection, $this->getUser());


        return $this->result(['id' => $result], $response);
    }

    private function _getCalendarService():CalendarService {
        return $this->getContainer()->get(CalendarService::class);
    }

    private function getEvents(): Events {
        return $this->getContainer()->get(Events::class);
    }

    private function getSettings(): Settings {
        return $this->getContainer()->get(Settings::class);
    }
}
