<?php
namespace Controllers;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Wildix\Phonebooks\Phonebook;
use Wildix\Phonebooks\Phonebooks;

class PhonebooksController extends Controller {

    public function getItems(Request $request, Response $response, array $args): Response {
        $params = $request->getQueryParams();

        $result = [];

        $filter = $params['filter'] ?? [];
        if (!is_array($filter)) {
            $filter = [];
        }

        $search       = $params['search'] ?? null;
        $searchFields = $params['searchFields'] ?? null;
        if ($searchFields) {
            $searchFields = explode(',', $searchFields);
        }
        $start  = $params['start'] ?? null;
        $count  = $params['count'] ?? null;
        $sort   = $params['sort'] ?? null;
        $dir    = $params['dir'] ?? null;
        $fields = $params['fields'] ?? null;
        if ($fields) {
            $fields = explode(',', $fields);
        }
        $total = $this->service()->getCount($filter, $search, $searchFields, $this->getUser());

        if ($total > 0) {
            $phonebooks = $this->service()->getPhonebooks(
                $filter,
                $search,
                $searchFields,
                $start,
                $count,
                $sort,
                $dir,
                $this->getUser()
            );
            foreach ($phonebooks as $phonebook) {
                $tmp = $phonebook->getAsArray($fields);
                if (!$this->getUser()->isAdministrator()) {
                    unset($tmp[Phonebook::SYNC_PARAMS]);
                }
                $result[] = $tmp;
            }
        }

        return $this->result(
            [
                'total'   => $total,
                'records' => $result
            ],
            $response
        );
    }

    public function getItem(Request $request, Response $response, array $args) {
        $phonebookId = $args['id'];
        $params      = $request->getQueryParams();

        $fields = $params['fields'] ?? '';
        if ($fields) {
            $fields = explode(',', $fields);
        }

        $phonebook = $this->service()->getByID((int)$phonebookId, $this->getUser());

        $tmp = $phonebook->getAsArray($fields);
        if (!$this->getUser()->isAdministrator()) {
            unset($tmp[Phonebook::SYNC_PARAMS]);
        }

        return $this->result($tmp, $response);
    }

    public function create(Request $request, Response $response, array $args): Response {
        $params = $request->getParsedBody();

        $data = $params['data'] ?? [];
        if (empty($data)) {
            return $this->error('Phone book data cannot be empty', $response, 400);
        }
        $result = $this->service()->addPhonebook($data, $this->getUser());

        return $this->result(['id' => $result], $response);
    }

    public function update(Request $request, Response $response, array $args): Response {
        $phonebookId = $args['id'] ?? null;

        $params = $request->getParsedBody();
        $data   = $params['data'] ?? [];

        if (empty($data)) {
            return $this->error('Phonebook data cannot be empty', $response, 400);
        }

        $filter = [];
        if ($phonebookId !== null) {
            $filter[Phonebook::ID] = (int)$phonebookId;
        } else {
            $filter = $params['filter'] ?? [];
            if (!is_array($filter)) {
                $filter = [];
            }
        }

        $search       = $params['search'] ?? null;
        $searchFields = $params['searchFields'] ?? null;
        if ($searchFields) {
            $searchFields = explode(',', $searchFields);
        }

        $result = $this->service()->updatePhonebooks($data, $filter, $search, $searchFields, $this->getUser());

        if (is_numeric($result)) {
            $result = ['changed' => $result];
        }

        return $this->result($result, $response);
    }

    public function remove(Request $request, Response $response, array $args): Response {
        $phonebookId = (int)$args['id'];

        $filter = [];

        $filter[Phonebook::ID] = $phonebookId;

        $search       = $params['search'] ?? null;
        $searchFields = $params['searchFields'] ?? null;
        if ($searchFields) {
            $searchFields = explode(',', $searchFields);
        }

        $result = $this->service()->deletePhonebooks($filter, $search, $searchFields, $this->getUser());
        if (is_numeric($result)) {
            $result = ['count' => $result];
        }

        return $this->result($result, $response);
    }

    private function service(): Phonebooks {
        return $this->getContainer()->get(Phonebooks::class);
    }
}
