<?php

namespace Controllers;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Wildix\Settings\RsyslogLogging;
use Wildix\System\RemoteSyslogSettings\Factory;
use Wildix\System\RemoteSyslogSettings\Repository;

class RemoteSyslog extends Controller {

    public function getSettings(Request $request, Response $response, array $args): Response {
        $settings = $this->_getRemoteSyslogSettingsRepository()->find();
        $stdClass = new \stdClass();

        return $this->result(
            (isset($settings) ? $settings->toArray() : $stdClass),
            $response
        );
    }

    public function setSettings(Request $request, Response $response, array $args): Response {
        $newRemoteSyslogSettingsData            = $request->getParsedBody();
        $newRemoteSyslogSettingsData['enabled'] = !empty($newRemoteSyslogSettingsData['enabled']);

        if (empty($newRemoteSyslogSettingsData['port'])) {
            unset($newRemoteSyslogSettingsData['port']);
        }

        $newRemoteSyslogSettings = $this->_getRemoteSyslogSettingsFactory()->create($newRemoteSyslogSettingsData);
        $this->_getRemoteSyslogSettingsRepository()->save($newRemoteSyslogSettings);

        $newRemoteSyslogSettings->apply($this->_getSettingsRsyslogLogging());

        return $this->result($newRemoteSyslogSettings->toArray(), $response);
    }

    private function _getRemoteSyslogSettingsFactory(): Factory {
        return $this->getContainer()->get(Factory::class);
    }

    private function _getRemoteSyslogSettingsRepository(): Repository {
        return $this->getContainer()->get(Repository::class);
    }

    private function _getSettingsRsyslogLogging(): RsyslogLogging {
        return $this->getContainer()->get(RsyslogLogging::class);
    }
}
