<?php

namespace Controllers;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Wildix\Error;

class SSLCertificate extends Controller {
    public function renew(Request $request, Response $response, array $args): Response {
        $params = $request->getParsedBody();

        if (!$this->serviceLicense()->isActivated()) {
            return $this->error(Error::WMSIsNotActivated, $response, 403);
        }

        $sslCertificate = $this->service();

        if ($sslCertificate->isBackgroundRenewRunning()) {
            return $this->error(Error::ProcessIsRunning, $response, 403);
        }

        $forced          = $params['forced'] ?? false;
        $attemptsCount   = $params['attemptsCount'] ?? $sslCertificate::DEFAULT_ATTEMPTS_COUNT;
        $requestInterval = $params['requestInterval'] ?? $sslCertificate::DEFAULT_REQUEST_INTERVAL;

        $sslCertificate::runBackgroundRenew($forced, $attemptsCount, $requestInterval, true);

        return $this->result(['status' => 'Success'], $response);
    }

    public function checkBackgroundRenewState(Request $request, Response $response, array $args): Response {
        $sslCertificate = $this->service();
        $isRunning      = $sslCertificate->isBackgroundRenewRunning();

        $result['processRunning'] = $isRunning;

        if ($isRunning === false) {
            $result['errors'] = $sslCertificate->getSavedErrors();
        }

        return $this->result($result, $response);
    }

    private function service(): \Wildix\Certificate\SSLCertificate {
        return $this->getContainer()->get(\Wildix\Certificate\SSLCertificate::class);
    }

    private function serviceLicense(): \Wildix\License {
        return $this->getContainer()->get(\Wildix\License::class);
    }
}
