<?php
namespace Controllers;

use Models\PBX;
use Models\VNC;
use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Wildix\Ejabberd;

class ScreenSharing extends Controller {

    public function create(Request $request, Response $response, array $args): Response {
        $params = $request->getParsedBody();

        $data['jid'] = $params['jid'] ?? '';

        if (empty($data['jid'])) {
            return $this->error('User not found', $response, 404);
        }

        $data['serial']  = $this->servicePbx()->getSerial();
        $data['version'] = $this->servicePbx()->getVersion();
        $data['vpnIP']   = $this->servicePbx()->getVpnIP();

        if (empty($data['serial'])) {
            return $this->error('Empty PBX serial or extension', $response);
        }
        $roomId = md5($data['jid'] . '|' . $data['serial']);
        $room   = $this->serviceVnc()->createRoom($roomId, $data);

        if (empty($room)) {
            return $this->error('Error get room', $response);
        }

        return $this->result($room, $response);
    }

    public function getItem(Request $request, Response $response, array $args): Response {
        $roomId = $args['roomId'] ?? '';

        $room = $this->serviceVnc()->getRoom($roomId);

        if (empty($room)) {
            return $this->error('Room not found', $response, 404);
        }

        return $this->result($room, $response);
    }

    public function remove(Request $request, Response $response, array $args): Response {
        $roomId = $args['roomId'] ?? '';

        $result = $this->serviceVnc()->removeRoom($roomId);

        if (!$result) {
            return $this->error('Error remove room', $response);
        }

        return $this->result($result, $response);
    }


    public function onReceiveEvent(Request $request, Response $response, array $args): Response {
        $event  = $args['event'];
        $params = $request->getParsedBody();

        $result = [
            'status' => 'success'
        ];

        if ($event == 'NewViewer' || $event == 'LostViewer' || $event == 'FreeRoom') {
            $data = [
                'room' => $params['room'],
                'room-id' => $params['session'],
                'info' => $params['info'],
                'viewerInfo' => $params['viewerInfo']
            ];

            if (!empty($data['room']) && !empty($data['room-id']) && !empty($data['info'])) {
                // @codingStandardsIgnoreStart
                $message  = '<event xmlns="urn:wildix:screen-sharing">';
                $message .= '<items>';
                $message .= '<item type=' . $event . '>';
                $message .= '<room>' . $data['room'] . '</room>';
                $message .= '<room-id>' . $data['room-id'] . '</room-id>';
                if (($event == 'NewViewer' || $event == 'LostViewer') && !empty($data['viewerInfo'])) {
                    $message .= '<viewer-info>';
                    $message .= '<jid>' . $data['viewerInfo']['jid'] . '</jid>';
                    $message .= '<name>' . $data['viewerInfo']['name'] . '</name>';
                    $message .= '<number>' . $data['viewerInfo']['number'] . '</number>';
                    $message .= '</viewer-info>';
                }
                $message .= '</item>';
                $message .= '</items>';
                $message .= '</event>';
                // @codingStandardsIgnoreEnd
                try {
                    $this->serviceEjabberd()->sendCustomMessage($data['info']['jid'], $data['info']['jid'], 'jabber:client', 'headline', $message);
                } catch (\Exception $e) {
                    $result['warning'] = $e->getMessage();
                }
            } else {
                $result['warning'] = 'room or room-id or info empty';
            }
        } else {
            $result['warning'] = 'Unknown event';
        }

        return $this->result($result, $response);
    }

    private function serviceVnc(): VNC {
        return $this->getContainer()->get(VNC::class);
    }

    private function servicePbx(): PBX {
        return $this->getContainer()->get(PBX::class);
    }

    private function serviceEjabberd(): Ejabberd {
        return $this->getContainer()->get(Ejabberd::class);
    }
}
