<?php

namespace Controllers;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Services\Helpers;

/**
 * Snmp is a controller working with SNMP Server
 */
class Snmp extends Controller {

    public function setSettings(Request $request, Response $response, array $args): Response {
        $params = $request->getParsedBody();
        $result = false;

        $data = [
            'enable' => (bool)($params['enable'] ?? false),
            'port' => (int)($params['port'] ?? 161),
            'community' => $params['community'],
            'trustedAddr' => $params['trustedAddr'],
        ];

        $data['enable'] = Helpers::formatBoolean($data['enable'], ['off', 'on']);

        $snmp = $this->_getSnmpService();
        if ($snmp->setOptions($data)) {
            $result = $this->_formatResponse($snmp->getOptions());
        }

        return $this->result($result, $response);
    }

    public function getSettings(Request $request, Response $response, array $args): Response {
        return $this->result($this->_formatResponse($this->_getSnmpService()->getOptions()), $response);
    }

    /**
     * Format response.
     *
     * @param array $data Input data.
     *
     * @return array
     */
    private function _formatResponse(array $data): array {
        $data['enable'] = \Wildix\Validator::isTrue($data['enable']);

        return $data;
    }

    /**
     * Get SNMP service.
     *
     * @return \Wildix\System\Snmp
     */
    private function _getSnmpService(): \Wildix\System\Snmp {
        return $this->getContainer()->get(\Wildix\System\Snmp::class);
    }
}
