<?php
declare(strict_types=1);

namespace Controllers\Trunks;

use Api\Trunks\Fxo\Interfaces\FxoTrunkServiceInterface;
use Controllers\Controller;
use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;

class FxoTrunksController extends Controller {

    /**
     * Get all FXO trunks
     *
     * @param Request  $request  Request.
     * @param Response $response Response.
     *
     * @return Response
     */
    public function getItems(Request $request, Response $response): Response {
        $this->getLogger()->info(__LINE__, sprintf('Get items in %s', get_class($this)));
        return $this->resultListObject($this->getService()->getItems(), $response);
    }

    /**
     * Remove FXO trunk
     *
     * @param Request  $request  Request.
     * @param Response $response Response.
     * @param array    $args     Arguments.
     *
     * @return Response
     */
    public function remove(Request $request, Response $response, array $args): Response {
        $this->getLogger()->info(__LINE__, sprintf('Delete in class %s with id = %d', get_class($this), $args['id']));
        $this->getService()->remove((int)$args['id']);

        return $this->success($response);
    }

    /**
     * Update FXO trunk
     *
     * @param Request  $request  Request.
     * @param Response $response Response.
     * @param array    $args     Arguments.
     *
     * @return Response
     */
    public function update(Request $request, Response $response, array $args): Response {
        $params = $request->getParsedBody();

        $this->getLogger()->info(
            __LINE__,
            sprintf(
                'Update in class %s with id = %d and params %s',
                get_class($this),
                $args['id'],
                json_encode($params)
            )
        );

        $this->getService()->update((int)$args['id'], $params);

        return $this->success($response);
    }

    private function getService(): FxoTrunkServiceInterface {
        return $this->getContainer()->get(FxoTrunkServiceInterface::class);
    }
}
