<?php

namespace Controllers\Trunks;

use Api\Trunks\PriceList\Interfaces\PriceListServiceInterface;
use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Wildix\Core\AbstractCrudController;

class PriceListController extends AbstractCrudController {

    protected $_service = PriceListServiceInterface::class;

    /**
     * Get price lists
     *
     * @param Request  $request  Request.
     * @param Response $response Response.
     *
     * @return Response
     */
    public function getItems(Request $request, Response $response): Response {
        $items = $this->_service()->getItems();
        return $this->resultList($items->toArray(), $response);
    }

    /**
     * Create a new price list
     *
     * @param Request  $request  Request.
     * @param Response $response Response.
     *
     * @return Response
     */
    public function create(Request $request, Response $response): Response {
        $this->getLogger()->info(__LINE__, sprintf('Create item in class %s', get_class($this)));
        $data   = array_merge($request->getUploadedFiles(), (array)$request->getParsedBody());
        $result = $this->_service()->create($data);

        return $this->result($result->toArray(), $response);
    }

    /**
     * Update a price list
     *
     * @param Request  $request  Request.
     * @param Response $response Response.
     * @param array    $args     Arguments.
     *
     * @return Response
     */
    public function update(Request $request, Response $response, array $args): Response {
        $this->getLogger()->info(__LINE__, sprintf('Update item %s in class %s', $args['id'], get_class($this)));
        $data   = array_merge($request->getUploadedFiles(), (array)$request->getParsedBody());
        $result = $this->_service()->update($args['id'], $data);

        return $this->result($result->toArray(), $response);
    }

    /**
     * Export price lists
     *
     * @param Request  $request  Request.
     * @param Response $response Response.
     * @param array    $args     Arguments.
     *
     * @return Response
     */
    public function export(Request $request, Response $response, array $args): Response {
        $this->_service()->export($args['id']);

        return $response->withHeader('Pragma', 'public')
            ->withHeader('Expires', '0')
            ->withHeader('Cache-Control', 'must-revalidate, post-check=0, pre-check=0')
            ->withHeader('Content-Type', 'application/x-download')
            ->withHeader('Content-Disposition', sprintf('attachment; filename="%s"', 'pricelist_' . $args['id'] . '.csv'))
            ->withHeader('Content-Transfer-Encoding', 'binary');
    }
}
