<?php

declare(strict_types=1);

namespace Controllers\Trunks;

use Api\Trunks\Sip\Interfaces\SipTrunkServiceInterface;
use Controllers\Controller;
use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Wildix\Dialplan\DialplanService;

class SipTrunksController extends Controller {

    public function getItems(Request $request, Response $response): Response {
        $this->getLogger()->info(__LINE__, sprintf('Get items in %s', get_class($this)));
        return $this->resultListObject($this->getService()->getItems(), $response);
    }

    /**
     * Get sip service
     *
     * @return SipTrunkServiceInterface
     */
    private function getService(): SipTrunkServiceInterface {
        return $this->getContainer()->get(SipTrunkServiceInterface::class);
    }

    private function getDialPlanService():DialplanService {
        return $this->getContainer()->get(DialplanService::class);
    }

    /**
     * Create sip trunk
     *
     * @param Request  $request  Request.
     * @param Response $response Response.
     *
     * @return Response
     */
    public function create(Request $request, Response $response): Response {
        $params = $request->getParsedBody();
        $this->getLogger()->info(__LINE__, sprintf('Create in class %s with params %s', get_class($this), json_encode($params)));
        $this->getService()->create($params);

        return $this->success($response);
    }

    /**
     * Update sip trunk
     *
     * @param Request  $request  Request.
     * @param Response $response Response.
     * @param array    $args     Arguments.
     *
     * @return Response
     */
    public function update(Request $request, Response $response, array $args): Response {
        $id     = (int)$args['id'] ?? 0;
        $params = $request->getParsedBody();
        $this->getLogger()->info(__LINE__, sprintf('Update in class %s with id = %d and params %s', get_class($this), $args['id'], json_encode($params)));
        $this->getService()->update($id, $request->getParsedBody());

        return $this->success($response);
    }

    /**
     * Remove sip trunk
     *
     * @param Request  $request  Request.
     * @param Response $response Response.
     * @param array    $args     Arguments.
     *
     * @return Response
     */
    public function remove(Request $request, Response $response, array $args): Response {
        $id = (int)$args['id'] ?? 0;
        $this->getLogger()->info(__LINE__, sprintf('Remove in class %s with id = %d', get_class($this), $args['id']));
        $this->isUseTrunk($id);
        $this->getService()->remove($id);

        return $this->success($response);
    }

    private function isUseTrunk(int $id): void {
        $dialPlanTrunk = $this->getDialPlanService()->getDialplanTrunkUse();
        $this->getService()->isUseTrunk($dialPlanTrunk, $id);
    }
}
