<?php

namespace Controllers;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Wildix\System\Upgrade\Checker;
use Wildix\System\Upgrade\ManuallyUpgrade;
use Wildix\System\Upgrade\UpgradeSettings;

class Upgrade extends Controller {

    private $_allowedSection = [
        UpgradeSettings::SECTION_WMS_RELEASE,
        UpgradeSettings::SECTION_CUSTOM_FIRMWARE,
    ];

    public function getSettings(Request $request, Response $response, array $args): Response {
        return $this->result(array_intersect_key($this->service()->getSettings(), array_flip($this->_allowedSection)), $response);
    }

    public function setSettings(Request $request, Response $response, array $args): Response {
        $data = $request->getParsedBody();
        $data = array_intersect_key($data, array_flip($this->_allowedSection));

        $result = $this->service()->updateSettings($this->service()->buildDataFromRequestParams($data));

        return $this->result($result, $response);
    }

    public function runCheckUpgrade(Request $request, Response $response, array $args): Response {
        return $this->result($this->serviceChecker()->runCheckerScript(), $response);
    }

    public function getCheckerStatus(Request $request, Response $response, array $args): Response {
        return $this->result($this->serviceChecker()->getCheckerStatus(), $response);
    }

    public function runUpgrade(Request $request, Response $response, array $args): Response {
        $result = $this->serviceManuallyUpgrade()->runUpgradeScript();

        return $this->result(['status' => $result], $response);
    }

    public function getUpgradeStatus(Request $request, Response $response, array $args): Response {
        return $this->result($this->serviceManuallyUpgrade()->getUpgradeStatus(), $response);
    }

    private function service(): UpgradeSettings {
        return $this->getContainer()->get(UpgradeSettings::class);
    }

    private function serviceManuallyUpgrade(): ManuallyUpgrade {
        return $this->getContainer()->get(ManuallyUpgrade::class);
    }

    private function serviceChecker(): Checker {
        return $this->getContainer()->get(Checker::class);
    }
}
