<?php
namespace Models;

use Wildix\Devices\Device;
use Wildix\Exception;

/**
 * Class Astman - service or repository / not a model
 */
class Astman extends \Singleton {

    const SMS_PATH = '/tmp/sms/';

    public const SMS_MAX_LENGTH = 300;

    /**
     * Send SMS Method
     *
     * @param string       $fromNumber Number from.
     * @param string|array $toNumber   Number1[,number2].
     * @param string       $message    SMS Message.
     * @param \DateTime    $postpone   Postpone delivery.
     * @param Device|null  $device     Device to send.
     *
     * @return boolean|array
     *
     * @throws Exception Error Msg.
     */
    public function sendSMS($fromNumber, $toNumber, $message, $postpone, Device $device = null) {
        if (!is_dir(self::SMS_PATH)) {
            mkdir(self::SMS_PATH);
        }

        if (!$postpone) {
            $postpone = new \DateTime();
        }

        if (empty($fromNumber)) {
            throw new Exception('Extension number is empty');
        }

        if (empty($message)) {
            throw new Exception('Message should not be empty');
        }

        if (mb_strlen($message, 'UTF-8') > self::SMS_MAX_LENGTH) {
            throw new Exception(sprintf('Message longer than %s characters', self::SMS_MAX_LENGTH));
        }

        if (!is_array($toNumber)) {
            $toNumber = explode(',', $toNumber);
        }

        $toNumbers = array();
        foreach ($toNumber as $value) {
            $value = trim($value);
            if (preg_match('/^\+*[#*0-9]{3,}+$/', $value)) {
                $toNumbers[] = $value;
            } else {
                if (empty($value)) {
                    throw new Exception('Number should not be empty');
                }

                throw new Exception('Number is not valid "' . $value . '". Number shall consist of (+,#,*,0-9)');
            }
        }

        $filename[] = trim($fromNumber);
        $filename[] = '';
        if ($device) {
            $filename[] = 'gw' . $device->getMac();
        }
        $filename[] = time();
        $filename[] = rand(0, 99999);

        $warning = array();
        foreach ($toNumbers as $key => $number) {
            $filename[1] = $number;
            $filePath    = self::SMS_PATH . implode('_', $filename) . '.sms';
            if (file_put_contents($filePath, escapeshellcmd($message)) !== false) {
                if (!touch($filePath, $postpone->getTimestamp())) {
                    $warning[] = $number;
                }
            } else {
                $warning[] = $number;
            }
        }
        if (!empty($warning)) {
            return $warning;
        }
        return true;
    }
}
