<?php
namespace Models;

use Wildix\Databases\CDRDB;

class Notes extends \Singleton
{

    public function getNoteByID($id) {
        return $this->getNoteByProperty(Note::NOTE_ID, $id);
    }

    public function getNotes($filter, $limit=100, $order="ASC") {
        $notes = [];
        if(CDRDB::getInstance()->isEnabled() && CDRDB::getInstance()->isExistTable(CDRDB::getInstance()->getNotesTableName())){
            $where = array();
            if($filter && !empty($filter)){
                if(!empty($filter['dateFrom'])){

                    if (CDRDB::getInstance()->isMsSql()) {
                        $where[] = '['.Note::NOTE_TIME.'] < :dateFrom';
                    }else{
                        $where[] = '`'.Note::NOTE_TIME.'` < :dateFrom';
                    }
                }

                if(count($where)>0){
                    $where = 'WHERE '.join(' AND ', $where);
                }
            }else{
                $where = '';
            }

            $query = '';
            if (CDRDB::getInstance()->isMsSql()) {
                $query = 'SELECT TOP '.$limit.' ['.join('], [', Note::getUserFields()).'] FROM ['.CDRDB::getInstance()->getNotesTableName().'] '.$where.' ORDER BY [time] '.$order.';';
            } else {
                $query = 'SELECT `'.join('`, `', Note::getUserFields()).'` FROM `'.CDRDB::getInstance()->getNotesTableName().'` '.$where.' ORDER BY time '.$order.' LIMIT '.$limit.'';
            }

            $items = CDRDB::getInstance()->getItems($query, $filter);

            foreach ($items as $item) {
                $notes[] = new Note($item);
            }
        }

        return $notes;
    }

    public function getLastNotesByContactID($id, $limit=100, $order="ASC") {
        $res = [];
        if(CDRDB::getInstance()->isEnabled() && CDRDB::getInstance()->isExistTable(CDRDB::getInstance()->getNotesTableName())){
            $res = $this->getNotesByProperty(Note::NOTE_CONTACT_ID, $id, $limit, $order);
        }
        return $res;

    }

    private function getNoteByProperty($name, $value) {

        $query = '';
        if (CDRDB::getInstance()->isMsSql()) {
            $query = 'SELECT TOP 1 ['.join('], [', Note::getUserFields()).'] FROM ['.CDRDB::getInstance()->getNotesTableName().'] WHERE ['.$name.'] = :property;';
        } else {
            $query = 'SELECT `'.join('`, `', Note::getUserFields()).'` FROM `'.CDRDB::getInstance()->getNotesTableName().'` WHERE `'.$name.'` = :property LIMIT 1;';
        }
        if(CDRDB::getInstance()->isEnabled() && CDRDB::getInstance()->isExistTable(CDRDB::getInstance()->getNotesTableName())) {
            $items = CDRDB::getInstance()->getItems($query, ['property' => $value]);
            if (!empty($items)) {
                return new Note($items[0]);
            }
        }
        return null;
    }


    private function getNotesByProperty($name, $value, $limit = 100, $order = 'ASC') {
        $notes = array();

        $query = '';
        if (CDRDB::getInstance()->isMsSql()) {
            $query = 'SELECT TOP '.$limit.' ['.join('], [', Note::getUserFields()).'] FROM ['.CDRDB::getInstance()->getNotesTableName().'] WHERE ['.$name.'] = :property ORDER BY [time] '.$order.';';
        }else{
            $query = 'SELECT `'.join('`, `', Note::getUserFields()).'` FROM `'.CDRDB::getInstance()->getNotesTableName().'` WHERE `'.$name.'` = :property ORDER BY time '.$order.' LIMIT '.$limit.';';
        }

        $items = CDRDB::getInstance()->getItems($query, array('property'=>$value));

        foreach ($items as $item) {
            $notes[] = new Note($item);
        }

        return $notes;
    }




    public function saveNote(\Models\Note &$note){
        $res = false;
        if ($note->getID() !== null && $note->getID() !== 0) {
            // UPDATE
        }else{
            // INSERT
            $query = '';
            if(CDRDB::getInstance()->isMsSql()){
                $query = 'INSERT INTO ['.CDRDB::getInstance()->getNotesTableName().']
                    (['.Note::NOTE_CONTACT_ID.'], ['.Note::NOTE_OWNER.'], ['.Note::NOTE_BODY.'], ['.Note::NOTE_TIME.'])
                    VALUES( :'.Note::NOTE_CONTACT_ID.', :'.Note::NOTE_OWNER.', :'.Note::NOTE_BODY.', :'.Note::NOTE_TIME.')';
            }else{
                $query = 'INSERT INTO `'.CDRDB::getInstance()->getNotesTableName().'`
                    (`'.Note::NOTE_CONTACT_ID.'`, `'.Note::NOTE_OWNER.'`, `'.Note::NOTE_BODY.'`, `'.Note::NOTE_TIME.'`)
                    VALUES( :'.Note::NOTE_CONTACT_ID.', :'.Note::NOTE_OWNER.', :'.Note::NOTE_BODY.', :'.Note::NOTE_TIME.');';
            }

            $arrNote = $note->getAsArray();
            unset($arrNote['id']);
            $result = CDRDB::getInstance()->prepare($query);
            $res    = $result->execute($arrNote);
            $note->setID(CDRDB::getInstance()->lastInsertId());
        }

        return $res;
    }

    public function deleteNote(\Models\Note &$note){
        $res = false;
        if ($note->getID() !== null && $note->getID() !== 0) {
            // DELETE

            $query = '';
            if(CDRDB::getInstance()->isMsSql()){
                $query = 'DELETE FROM ['.CDRDB::getInstance()->getNotesTableName().']
                    WHERE ['.Note::NOTE_ID.'] = :id;';
            }else{
                $query = 'DELETE FROM `'.CDRDB::getInstance()->getNotesTableName().'`
                    WHERE `'.Note::NOTE_ID.'` = :id;';
            }

            $result = CDRDB::getInstance()->prepare($query);
            $res    = $result->execute(['id' => $note->getID()]);
            if ($res) {
                $note->setID(null);
            }
        }

        return $res;
    }
}
