<?php
namespace Models;

use Services\LuaService;
use Wildix\Databases\WMSDB;
use Wildix\PBXes\PBXes;

class PBX extends \Singleton {
    const TPROXY_CONF = '/rw2/etc/pbx/wildix/tproxy_wms_include.conf';
    const FAXCOVER_SHARE_PATH = '/mnt/faxes';
    const BACKUPS_SHARE_PATH  = '/mnt/backups';

    const DEFAULT_PORTS = [
        [
            'transport' => 'TCP',
            'protocol'  => 'HTTP',
            'port'      => '443',
        ],
        [
            'transport' => 'TCP',
            'protocol'  => 'HTTP',
            'port'      => '80',
        ],
        [
            'transport' => 'UDP',
            'protocol'  => 'SIP',
            'port'      => '5060',
        ],
        [
            'transport' => 'TCP',
            'protocol'  => 'SIP',
            'port'      => '5060',
        ],
        [
            'transport' => 'TCP',
            'protocol'  => 'SIP',
            'port'      => '5061',
        ],
    ];

    private $_isWideband;

    private $_luaService;

    private $_featureCodes;

    public function getVersion(){
        return WMS_VERSION_FULL;
    }

    private $_eth0Serial = null;
    public function getEth0Serial(){
        if($this->_eth0Serial === null){
            $this->_eth0Serial = false;
            if(file_exists('/sys/class/net/eth0/address')){
                $this->_eth0Serial = trim(str_replace(':', '', file_get_contents('/sys/class/net/eth0/address')));
            }
        }

        return $this->_eth0Serial;
    }

    private $_fileSerial = null;
    public function getSerialFromFile(){
        if($this->_fileSerial=== null){
            $this->_fileSerial= false;
            if(file_exists('/etc/serial')){
                $this->_fileSerial= trim(file_get_contents('/etc/serial'));
            }
        }

        return $this->_fileSerial;
    }

    private $_serial = null;
    public function getSerial(){
        if ($this->_serial === null){
            $this->_serial = \Wildix\License::getInstance()->getLimitations('serial');
            if(is_array($this->_serial)){
                $this->_serial = null;
            }
            if(empty($this->_serial) && $this->getEth0Serial()){
                $this->_serial = $this->getEth0Serial();
            }
            if(empty($this->_serial) && $this->getSerialFromFile()){
                $this->_serial = $this->getSerialFromFile();
            }
        }
        return $this->_serial;
    }

    private $_logoPath = null;
    public function getLogoPath() {
        if ($this->_logoPath === null) {
            $serial          = $this->getSerial();
            $this->_logoPath = BASEPATH . 'images/' . md5($serial . substr($serial, 5, 4)) . '.png';
        }
        return $this->_logoPath;
    }

    private $_vpnIP = null;
    public function getVpnIP(){
        if($this->_vpnIP == null){
            $cmd = "[ -d /sys/class/net/tun0/ ] && /sbin/ifconfig tun0 | grep -E 'inet\s.*\s[5|172].*.0.[1|8]' | awk '{print($2)}'";

            $ll = exec($cmd, $output);

            if (is_array($output) && isset($output[0]) && is_ip($output[0])){
                $this->_vpnIP = $output[0];
            }
        }
        return $this->_vpnIP;
    }

    private $_networkAddresses = null;
    public function getNetworkInterfaces(){
        if($this->_networkAddresses === null){
            $this->_networkAddresses = array(
                    'interfaces' => array(),
                    'external' => array()
            );

            exec('/sbin/ifconfig -a', $output);

            $output = join("\n", $output);
            $output = preg_split("/\n\n/", $output);

            foreach($output as $key=>$int){
                preg_match("/^([A-z]*)([0-9\.]+)\:\s.*" .
                    "inet ([0-9.]+).*netmask ([0-9.]+).*" .
                    "/ims", $int, $regex);
                if(!empty($regex)){
                    if($regex[1] == 'eth'){
                        $this->_networkAddresses['interfaces'][] = array(
                                'type' => $regex[1],
                                'number' => $regex[2],
                                'ip' => $regex[3],
                                'mask' => $regex[4]

                        );
                    }
                }
            }

            if(file_exists('/tmp/provisioning_externip')){
                $content = trim(file_get_contents('/tmp/provisioning_externip'));
                if(!empty($content) && $content!='empty'){
                    $this->_networkAddresses['external'][] = array('ip'=>$content);
                }

            }
        }

        return $this->_networkAddresses;
    }

    private $_domain = null;
    public function getDomain(){
        if($this->_domain === null){
            $serial = $this->getSerial();
            $this->_domain = $serial.'.wildixin.com';
            if($serial){
                $pbx = PBXes::getInstance()->getPBXBySerial($serial);
                if($pbx){
                    $domain = $pbx->getDomain();
                    if (strpos($domain, '.wildixin.com') !== false){
                        $this->_domain = $domain;
                    }
                }
            }
        }
        return $this->_domain;
    }

    public function getExternalLinePrefix(){
        return WMSDB::getInstance()->getSystemVariable(WMSDB::SYSTEM_EXTERNAL_LINE_PREFIX);
    }


    private $_defaultFeatureCodes = null;
    private function getDefaultFeatureCodes(){
        if($this->_defaultFeatureCodes === null){
            // default values
            $this->_defaultFeatureCodes = array(
                    // features
                    'STATUS' => array(
                            'access' => '60',
                            'direct' => '_60!',
                            'change' => true
                    ),

                    'BCF' => array(
                            'access' => '61',
                            'direct' => '_61!'
                    ),

                    'UCF' => array(
                            'access' => '62',
                            'direct' => '_62!',
                    ),

                    'FCF' => array(
                            'access' => '63',
                            'direct' => '_63!',
                    ),

                    'CW' => array(
                            'access' => '64',
                            'direct' => '_64!',
                            'change' => true
                    ),

                    'MEXT' => array(
                            'access' => '75',
                            'direct' => '_75*!',
                    ),

                    'TOUT' => array(
                            'access' => '65',
                            'direct' => '_65!',
                    ),

                    'CALLBLOCK' => array(
                            'access' => '72',
                            'direct' => '_72*!',
                            'change' => true
                    ),

                    'ROAD' => array(
                            'access' => '68',
                            'direct' => '_68*!',
                            'change' => true
                    ),

                    'MOBCONFIRMATION' => array(
                            'access' => '69',
                            'direct' => '_69*!',
                            'change' => true
                    ),

                    'VMACCESS' => array(
                            'access' => '81',
                            'direct' => '_81!',
                    ),

                    'DIRECTORY' => array(
                            'access' => '82',
                            'direct' => '_82!',
                    ),

                    'LOGIN' => array(
                            'access' => '99',
                            'direct' => '_99!',
                    ),

                    'PERSONALRECORD' => array(
                            'access' => '84',
                            'direct' => '_84!',
                    ),

                    'PBXRECORD' => array(
                            'access' => '74',
                            'direct' => '_74!',
                    ),

                    'CBARGE' => array(
                            'access' => '85',
                            'direct' => '_85!',
                    ),

                    'SBARGE' => array(
                            'access' => '86',
                            'direct' => '_86!',
                    ),

                    'PBARGE' => array(
                            'access' => '87',
                            'direct' => '_87!',
                    ),

                    'SENDDOC' => array(
                            'access' => '89',
                            'direct' => '_89!',
                    ),

                    'FAXRELAY' => array(
                            'access' => '90',
                            'direct' => '_90!',
                    ),

                    'PAGING' => array(
                            'access' => '91',
                            'direct' => '_91!',
                    ),

                    'HIDECID' => array(
                            'access' => '92',
                            'direct' => '_92!',
                    ),

                    'SWITCH' => array(
                            'access' => '93',
                            'direct' => '_93!',
                    ),

                    '3SWITCH' => array(
                            'access' => '94',
                            'direct' => '_94!',
                    ),

                    'STIME' => array(
                            'access' => '95',
                            'direct' => '_95!',
                    ),

                    'PICKUP' => array(
                            'access' => '88',
                            'direct' => '_88!',
                    ),

                    'CONTINUITYCALL' => array(
                            'access' => '*5',
                            'direct' => '_5!',
                    ),

                    'QCALL' => array(
                            'access' => '59',
                            'direct' => '_59!',
                    ),

                    'CGMANAGER' => array(
                            'access' => '97',
                            'direct' => '_97!',
                    ),

                    'INTERCOM' => array(
                            'access' => '96',
                            'direct' => '_96!',
                    ),

                    'CONFERENCE' => array(
                            'access' => '98',
                            'direct' => '_98!',
                    ),

                    'ECHO' => array(
                            'access' => '76',
                    ),

                    'SHORTNUM' => array(
                            'access' => '80',
                            'direct' => '_80!',
                    ),

                    'PREANSWER' => array(
                            'gotovm' => '1',
                            'gotoprivat' => '2',
                            // 'gotoconference' => '3',
                            'gotointercom' => 4,
                            'gotocc' => '5',
                    ),

                    'PREFIX' => array(
                        'access' => ''
                    ),
            );

            if(\Bticino::getInstance()->isInstalled()){
                $this->_defaultFeatureCodes['WHOTELINSPECT'] = array(
                        'access' => '774',
                        'direct' => '_774!',
                        'change' => '[01]'
                );
                $this->_defaultFeatureCodes['WHOTELBAR'] = array(
                        'access' => '772',
                        'direct' => '_772!'
                );
            }

            $this->_defaultFeatureCodes['WHOTELMUR'] = array(
                    'access' => '771',
                    'direct' => '_771!',
                    'change' => '[01]'
            );
            $this->_defaultFeatureCodes['WHOTELALARM'] = array(
                    'access' => '773',
                    'direct' => '_773!'
            );
        }

        return $this->_defaultFeatureCodes;
    }

    private function getFeatureCodes() {
        if (!$this->_featureCodes){
            $this->_featureCodes = array_merge($this->getDefaultFeatureCodes(), $this->getLuaService()->getFeatures());
        }
        return $this->_featureCodes;
    }

    /**
     * Get feature code array with prefix
     * @param $name
     * @return null | string
     */
    public function getFeatureCode($name) {
        $featureCodes =  $this->getFeatureCodes();
        $prefix = $featureCodes['PREFIX']['access'];
        $code = $featureCodes[$name];
        if (is_array($code) ){
            //Most used case
            foreach($code as $k=>$v){
                $code[$k] = $prefix.$v;
            }
            return $code;
        } else if (isset($code)) {
            //For now not used but may be needed in future
            return $prefix.$code;
        } else {
            //Code not found
            return null;
        }
    }

    /**
     * Get feature access code with prefix
     * @param $name
     * @return null | string
     */
    public function getFeatureAccessCode($name) {
        $code = $this->getFeatureCode($name);
        if (is_array($code) && isset($code['access'])){
            return $code['access'];
        } else {
            return null;
        }
    }


    private $_customHttpsPort = null;
    public function getCustomHttpsPort(){
        if($this->_customHttpsPort === null){
            $this->_customHttpsPort = false;

            if(file_exists(self::TPROXY_CONF)){
                $content = file_get_contents(self::TPROXY_CONF);
                $content = trim($content);
                if(!empty($content)){
                    $content = explode(",\n", $content);
                    foreach($content as $key=>$value){
                        if (preg_match('/.*?port=(\d+);.*?/', $value, $matches)){
                            //{ host="0.0.0.0";port=1443; }
                            if(!empty($matches[1])){
                                $this->_customHttpsPort = $matches[1];
                                break;
                            }
                        }
                    }
                }
            }
        }

        return $this->_customHttpsPort;
    }

    private $_ports = null;
    public function getPorts() {
        if ($this->_ports === null) {
            $this->_ports = self::DEFAULT_PORTS;

            if (\Wildix\License::getInstance()->isCloud()) {
                $this->_ports[] = [
                    'transport' => 'UDP',
                    'protocol'  => 'RTP',
                    'port'      => '10000',
                ];
                $this->_ports[] = [
                    'transport' => 'UDP',
                    'protocol'  => 'RTP',
                    'port'      => '59999',
                ];

                return $this->_ports;
            }

            if ($this->getCustomHttpsPort() !== false) {
                $this->_ports[] = [
                    'transport' => 'TCP',
                    'protocol'  => 'HTTP',
                    'port'      => $this->getCustomHttpsPort(),
                ];
            }

            $udpechoStart = \Wildix\Settings\UdpEcho::getInstance()->get(\Wildix\Settings\UdpEcho::START);
            if ($udpechoStart !== '') {
                $this->_ports[] = [
                    'transport' => 'UDP',
                    'protocol'  => 'RTP',
                    'port'      => $udpechoStart,
                ];
            }
            $udpechoEnd = \Wildix\Settings\UdpEcho::getInstance()->get(\Wildix\Settings\UdpEcho::END);
            if ($udpechoEnd !== '') {
                $this->_ports[] = [
                    'transport' => 'UDP',
                    'protocol'  => 'RTP',
                    'port'      => $udpechoEnd,
                ];
            }
        }

        return $this->_ports;
    }


    static function cmpNetworkAddresses($aInterface, $bInterface){
        /*
         * 0 - local ip
         * 1 - external ip
         * 2 - domain
         */
        if(is_string($aInterface)){
            $aInterface = array('ip'=> $aInterface);
        }
        if(is_string($bInterface)){
            $bInterface= array('ip'=> $bInterface);
        }

        if(isset($_SERVER) && !empty($_SERVER['REMOTE_ADDR']) && \CIDR::validIP($_SERVER['REMOTE_ADDR'])){

            $ip = $_SERVER['REMOTE_ADDR'];
            //$ip = '10.100.1.6';
            //$ip = '192.168.248.25';
            //$ip = '172.18.128.54';

            $aCidr = null;
            $bCidr = null;
            if(!empty($aInterface['mask'])){
                $aCidr = \CIDR::alignedCIDR($aInterface['ip'], $aInterface['mask']);
            }

            if(!empty($bInterface['mask'])){
                $bCidr = \CIDR::alignedCIDR($bInterface['ip'], $bInterface['mask']);
            }

            $aPos = 2;
            $bPos = 2;

            if($aCidr && \CIDR::IPisWithinCIDR($ip, $aCidr)){
                $aPos = 0; // enters in the network
            }else{
                $aPos = 1; // not enters in the network
            }

            if($bCidr && \CIDR::IPisWithinCIDR($ip, $bCidr)){
                $bPos = 0;
            }else{
                $bPos = 1;
            }

            if ($aPos != $bPos) {
                return ($aPos < $bPos) ? -1 : 1;
            }
        }



        $aPos = 2;  // domain
        $bPos = 2; 	// domain

        if (\CIDR::validIP($aInterface['ip'])) {
            if(\CIDR::IPisWithinCIDR($aInterface['ip'],'10.0.0.0/8') ||  // 10.0.0.0 - 10.255.255.255
                    \CIDR::IPisWithinCIDR($aInterface['ip'],'172.16.0.0/12') ||   // 172.16.0.0 - 172.31.255.255
                    \CIDR::IPisWithinCIDR($aInterface['ip'],'192.168.0.0/16')){ // 192.168.0.0 - 192.168.255.255
                // if local ip
                $aPos = 0;
            }else{
                //external ip
                $aPos = 1;
            }
        }

        if (\CIDR::validIP($bInterface['ip'])) {
            if(\CIDR::IPisWithinCIDR($bInterface['ip'],'10.0.0.0/8') ||
                    \CIDR::IPisWithinCIDR($bInterface['ip'],'172.16.0.0/12') ||
                    \CIDR::IPisWithinCIDR($bInterface['ip'],'192.168.0.0/16')){
                // if local ip
                $bPos = 0;
            }else{
                //external ip
                $bPos = 1;
            }
        }

        if ($aPos == $bPos) {
            return 0;
        }
        return ($aPos < $bPos) ? -1 : 1;
    }


    public function isEnabledWmsNetwork(){
        return $this->getMode() > 0;
    }

    public function isMaster(){
        return $this->getMode() == 2;
    }

    public function isSlave(){
        return $this->getMode() == 1;
    }

    private $_mode = null;
    private function getMode() {
        if($this->_mode === null){
            $filename = '/rw2/etc/pbx/net.conf';
            $vals = parse_ini_file($filename, false, INI_SCANNER_RAW);

            $this->_mode = $vals['STARTUP'];

            // New LDAP doesn't have shared modules
            exec('sudo /bin/cat /etc/ldap/slapd.d/cn\=config/cn\=module\{0\}.ldif', $out);
            if (count($out) > 0) {
                if ($this->_mode == 2) {

                    $this->_mode = 0;

                    exec('sudo /bin/cat /etc/ldap/slapd.d/cn\=config/cn\=module\{0\}.ldif', $out);
                    $i = count($out);
                    for( $i; $i > -1; $i --){
                        if(stripos($out[$i], 'syncprov') !== false){
                            $this->_mode = 2;
                            break;
                        }
                    }
                }
            }
        }
        return $this->_mode;
    }

    private function getLuaService(): LuaService {
        if (!$this->_luaService) {
            $this->_luaService = new LuaService();
        }
        return $this->_luaService;
    }

    public function isWideband($ip){
        if(!$this->_isWideband){
            $this->_isWideband = $this->getLuaService()->isWideband($ip);
        }

        return $this->_isWideband;
    }

    private $_mounted = array();
    public function isCustomShareMounted($path){
        if(!isset($this->_mounted[$path])){
            $content = file_get_contents('/etc/mtab');
            if(strpos($content, $path) !==false){
                $this->_mounted[$path] = true;
            }else{
                $this->_mounted[$path] = false;
            }
        }
        return $this->_mounted[$path];
    }

    private $_kiteConf = null;
    public function getKiteConf($name){
        if($this->_kiteConf === null){
            $this->_kiteConf = [
                'domain' => parse_url(env('SERVICE_KITE_URI'), PHP_URL_HOST),
                'host' => env('SERVICE_KITE_HOST'),
            ];
        }
        return ($name)?$this->_kiteConf[$name]:$this->_kiteConf;
    }

    private $_hddIdentify = null;
    private function getHddIdentify(){
        if($this->_hddIdentify === null){
            $this->_hddIdentify = '';
            $drive = exec("/usr/sbin/rdev | awk 'BEGIN{ FS=\"/\"} {print substr($3, 1, 3)}'");
            $drive = trim($drive);
            if(!empty($drive)){
                $identifyFile = '/proc/ide/'.$drive.'/identify';

                if(file_exists($identifyFile)){
                    exec("sudo cat ".$identifyFile, $output);
                    $output = array_map('trim', $output);

                    $this->_hddIdentify = implode(" ", array_slice($output,0,6));
                }
            }
        }
        return $this->_hddIdentify;
    }

    public function getCfIdentify(){
        $data = @file('/etc/fstab');
        if (!is_array($data)){
            return false;
        }

        $output = '';
        $is_xen = substr($data[0],0,8) == '/dev/xvd';

        if($is_xen){
            $identify_filename = '/usr/ide/hd'.substr($data[0],8,1).'/identify';
            $rows_count = 6;
        }else{
            $identify_filename = '/proc/ide/hd'.substr($data[0],7,1).'/identify';
            $rows_count = 32;
        }

        if (file_exists($identify_filename)){
            @exec('sudo /bin/cat '.$identify_filename, $output);
            if (is_array($output) || count($output) == $rows_count){
                $output = array_slice($output, 0, 6);
                $output = trim(implode("\n", $output));
            }
        }

        return $output;
    }

    private $_identity = null;

    public function getIdentity(){
        if($this->_identity === null){
            $this->_identity = md5(preg_replace("/\s/","",strtoupper($this->getSerial()).strtolower($this->getHddIdentify())));
        }
        return $this->_identity;
    }

    private $_pbxKey = null;
    public function getPbxKey(){
        if($this->_pbxKey === null){
            $this->_pbxKey = \Wildix\License::getInstance()->getLimitations('pbxKey');

            if(empty($this->_pbxKey)){
                $this->_pbxKey = $this->getIdentity();
            }
        }
        return $this->_pbxKey;
    }


    private $_cpuInfo = null;
    public function getCpuInfo(){
        if($this->_cpuInfo === null){
        	$this->_cpuInfo = file_get_contents('/proc/cpuinfo');
        }
        return $this->_cpuInfo;
    }

    private $_memInfo = null;
    public function getMemInfo(){
    	if($this->_memInfo === null){
    		$this->_memInfo = file_get_contents('/proc/meminfo');
    	}
    	return $this->_memInfo;
    }

    private $_cpuModel = null;
    public function getCpuModel(){
    	if($this->_cpuModel === null){
    		$this->_cpuModel = false;
    		$cpuInfo = $this->getCpuInfo();
    		if (preg_match('/model name[^:]+:(.+)/', $cpuInfo, $matches)){
    			if($matches && !empty($matches[1])){
    				$this->_cpuModel= preg_replace('/\s+/', ' ', trim($matches[1]));
    			}
    		}
    	}
    	return $this->_cpuModel;
    }

    private $_totalMemory= null;
    public function getTotalMemory(){
    	if($this->_totalMemory === null){
    		$this->_totalMemory = false;
    		$memInfo = $this->getMemInfo();
    		if (preg_match('/MemTotal:[^\d]+(\d+)/', $memInfo, $matches)){
    			if($matches && !empty($matches[1])){
    				$this->_totalMemory = trim($matches[1])*1024;
    			}
    		}
    	}
    	return $this->_totalMemory;
    }

    public function getDn(){
        $dn = null;
        $serial = $this->getSerial();
        if ($serial) {
            $pbx = PBXes::getInstance()->getPBXBySerial($serial);
            if ($pbx) {
                $dn = $pbx->getDn();
            }
        }
        return $dn;
    }

    public function getFailovers(){
        $return = array();
        if($this->getSerial()){
            $dn = $this->getDn();
            $failovers = \WMS_Ldap::getInstance()->getEntries(\WMS_Ldap::FAILOVER, '(&(pbxowner=' . $dn . ')(enabled=1))', array('pbxFailover', 'priority'));
            if($failovers){
                $search = array();
                foreach($failovers as $val){
                    $search[$val['pbxFailover']] = $val['priority'];
                }
                $arr = array();
                foreach (PBXes::getInstance()->getPBXes() as $pbx){
                    if(isset($search[$pbx->getDn()])){
                        $arr[$search[$pbx->getDn()].$pbx->getDn()] = $pbx->getAsArray();
                    }
                }
                $return = array_values($arr);
            }
        }
        return $return;
    }

    /**
     * Get candidates.
     *
     * @return array Candidades.
     */
    public function getCandidates():array {
        $candidates = [];
        if (!\Wildix\License::getInstance()->isCloud()) {
            $networkAddresses = $this->getNetworkInterfaces();
            if (!empty($networkAddresses['interfaces'])) {
                $networkAddresses['interfaces'] = array_reverse($networkAddresses['interfaces']);
                usort($networkAddresses['interfaces'], array('Models\PBX', 'cmpNetworkAddresses'));
                foreach (array('interfaces', 'external') as $type) {
                    foreach ($networkAddresses[$type] as $address) {
                        $candidates[] = $address['ip'];
                    }
                }
                $candidates = array_values(array_unique($candidates));
            }
        }

        $candidates[] = $this->getDomain();

        return $candidates;
    }
}

