<?php

namespace Models;

use Slim\Views\PhpRenderer;
use Wildix\Colleagues\Colleague;
use Wildix\Colleagues\Colleagues;
use Wildix\Ejabberd;

/**
 * Description of VideoConference
 *
 * @author Valentyn Diduryk <stranger@ossystem.com.ua>
 */
class VideoConference {
    private $_logLevel = 1;

    private $_log = null;
    private function getLog(){
        if($this->_log === null){
            $this->_log = new \Syslog('VideoConference', $this->_logLevel);
        }
        return $this->_log;
    }

    private $me = null;

    private $conference = null;

    const cache_key_conference_phpsessid = '_conference_phpsessid';

    /**
     *
     */
    public function __construct() {

    }

    /**
     *
     * @param mixed $user
     */
    public function setUser($user) {
        $this->me = $user;
    }

    /**
     *
     * @param array $conference
     */
    public function setConference($conference) {
        $this->conference = $conference;
    }

    /**
     *
     * @param array $user
     * @param string $view
     * @return string
     * @throws \Exception
     */
    public function renderView($user, $schedule, $view) {
        $renderer = new PhpRenderer(__DIR__ . '/../templates');

        return $renderer->fetch(
            $view,
            [
                'sender' => $this->me,
                'recipient' => $user['payload'] ?? $user,
                'schedule' => $schedule,
                'conference' => $this->conference,
                'cfg' => $this->getCfg(),
                'features' => getGlobalFeatures()
            ]
        );
    }

    /**
     *
     * @param array   $user     User data.
     * @param boolean $force    Flag.
     * @param array   $schedule Conference schedule.
     * @return mixed
     * @throws \Exception
     */
    public function inviteByJabber($user, $force = false, $schedule) {
        $xmlns = 'jabber:client';
        $type  = 'chat';

        if (isset($user['payload'])) {
            $user = $user['payload'];
        }

        if (preg_match('#^\d+@.*$#', $user['jid'])) {
            $jid          = explode('@', $user['jid']);
            $recipient    = Colleagues::getInstance()->getUserByExtension($jid[0]);
            if (!$recipient instanceof Colleague) {
                throw new \Wildix\Exception('There is no such user on pbx');
            }
            $user['port'] = $this->getPBXPublicPortByDomain($jid[1]);
            $template     = $this->renderView($user, $schedule, 'jabberTemplate.php');

            return $this->inviteByJabberLocal($recipient, $template, $xmlns, $type, $force);
        } else {
            $recipient = $user['jid'];

            $template = $this->renderView($user, $schedule, 'jabberKiteTemplate.php');

            return $this->inviteByJabberRemote($recipient, $template, $xmlns, $type);
        }
    }

    /**
     *
     * @param string $domain.
     * @return string
     */
    public function getPBXPublicPortByDomain($domain) {
        $pbxData = \Wildix\PBXes\PBXes::getInstance()->getPBXByDomain($domain);

        $publicPortFromPBXData = $pbxData->getPublicPort();
        return empty($publicPortFromPBXData) ? '443' : $publicPortFromPBXData;
    }

    /**
     *
     * @param string $recipient
     * @param string $template
     * @param string $xmlns
     * @param string $type
     * @param bool $force
     * @return mixed
     */
    public function inviteByJabberLocal($recipient, $template, $xmlns, $type, $force) {
        if (
            ($force || Ejabberd::getInstance()->getUserOnlineStatus($recipient->getExtension())) &&
            ($this->me->getExtension() != $recipient->getExtension()) //Do not invite own user from the same extension!
           ) {

            if ($type !== 'chat') {
                return Ejabberd::getInstance()->sendMessage($this->me->getJid(), $recipient->getJid(), $type, $template);
            }

            $messageXml  = '<subject></subject>';
            $messageXml .= '<body>' . $template . '</body>';
            $messageXml .= '<markable xmlns=\'urn:xmpp:chat-markers:0\'/>';
            Ejabberd::getInstance()->sendCustomMessage($this->me->getJid(), $recipient->getJid(), $xmlns, $type, $messageXml);
            return true;
        } else {
            return 'skipped';
        }
    }

    /**
     *
     * @param string $recipient
     * @param string $template
     * @param string $xmlns
     * @param string $type
     * @return mixed
     */
    public function inviteByJabberRemote($recipient, $template, $xmlns, $type) {
        if ($type !== 'chat') {
            return Ejabberd::getInstance()->sendMessage($this->me->getJid(), $recipient, $type, $template);
        }
        $messageXml  = '<subject></subject>';
        $messageXml .= '<body>' . $template . '</body>';
        $messageXml .= '<markable xmlns=\'urn:xmpp:chat-markers:0\'/>';
        return Ejabberd::getInstance()->sendCustomMessage($this->me->getJid(), $recipient, $xmlns, $type, $messageXml);
    }

    /**
     *
     * @param mixed $conference
     * @param array $users
     * @param array $pbxes
     * @return array
     */
    public function createRoom($conference, array $colleagues = array(), array $users = array(), array $pbxes = array()) {
        $cfg = $this->getCfg();

        $remoteConference = $this->send('https://' . $cfg['host'] . '/api/room/create', array(
        		'subject'   => $conference['name'],
        		'owner'     => $conference['owner'],
        		'room'      => $conference['room'],
        		'colleagues'=> json_encode($colleagues),
        		'users'     => json_encode($users),
        		'pbxes'     => json_encode($pbxes),
        		'sender'    => json_encode(array('name' => $this->me->getName(),'email' => $this->me->getEmail())),
        		'reinvite'  => $conference['reinvite']||$conference['join'],
        		'schedule'  => $conference['schedule'],
        ));

        $conference['room'] = $remoteConference['result']['room'];
        $conference['pin'] = ($remoteConference['result']['pin'] ?? '');
        $conference['externalUrl'] = $remoteConference['result']['externalUrl'];
        $conference['proxyUrl'] = $remoteConference['result']['proxyUrl'];
        $conference['pbxHost'] = $remoteConference['result']['pbxHost'];
        $conference['pbxHosts'] = json_decode($remoteConference['result']['pbxHosts'], true);
        $conference['schedule'] = $this->convertScheduleToNewApiFormat($conference);
        $conference['subject']  = $conference['name']; // need for jabberTemplate

        $this->setConference($conference);
        if ($remoteConference['result']['action'] == 'create') {
            $_SESSION['videoConferenceRooms'] = (array)$_SESSION['videoConferenceRooms'];
            $_SESSION['videoConferenceRooms'][] = $conference['room'];
        }

        return $this->conference;
    }

    /**
     * Used for backward compatibility of jabber message template with old pbx api.
     *
     * @param array $conference Video conference object.
     *
     * @return array
     */
    private function convertScheduleToNewApiFormat(array $conference) :array {
        return [
            'start' => $conference['schedule']['from'] ?? '',
            'end' => $conference['schedule']['to'] ?? '',
            'recurrence' => $conference['schedule']['recurrence'] ?? null,
            'description' => $conference['schedule']['description'] ?? '',
            'enabled' => $conference['schedule']['scheduleEnabled'] ?? false,
            'country' => $conference['schedule']['country'] ?? '',
            'timezone' => $conference['schedule']['timezone'] ?? '',
            'lang' => $conference['schedule']['lang'] ?? '',
            'dialInNumbers' => $conference['schedule']['dialInNumbers'] ?? [],
            'changed' => $conference['schedule']['changed'] ?? false,
        ];
    }

    /**
     *
     * @return array
     * @throws \Exception
     */
    private function getCfg() {
        $cfg['host'] = parse_url(env('SERVICE_CONFERENCE_URI'), PHP_URL_HOST);

        if (!isset($cfg['host']) || !$cfg['host']) {
            throw new \Wildix\Exception('Videoconference host empty');
        }

        return $cfg;
    }

    private function readHeader($ch, $headerLine) {
        if (preg_match('/^Set-Cookie:.*PHPSESSID=([^;]*)/mi', $headerLine, $cookie) == 1)
            $_SESSION[self::cache_key_conference_phpsessid] = $cookie[1];

        return strlen($headerLine);
    }
    /**
     *
     * @param string $url
     * @param array $params
     * @return array
     * @throws \Exception
     */
    private function send($url, $params = null, $post = true, $tries = 2) {
        $requiredParams = array(
            'serial'    => PBX::getInstance()->getSerial(),
            'extension' => $this->me ? $this->me->getExtension() : '',
            'pbxVersion'=> WMS_VERSION_FULL,
        );
        if (isset($params) && is_array($params)){
            $params = array_merge($params, $requiredParams);
        } else {
            $params = $requiredParams;
        }
        if (!$post){
            $getParams = http_build_query($params);
            $url .= (strpos($url, '?')!==false?'&':'?').$getParams;
        }
        while ($tries-- > 0) {
            try {
                $ch = curl_init($url);
                if ($post) {
                    curl_setopt($ch, CURLOPT_POST, true);
                    if (!empty($params)) {
                        curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($params));
                    }
                }
                curl_setopt($ch, CURLOPT_USERAGENT, 'PBX Api');
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 3);
                curl_setopt($ch, CURLOPT_TIMEOUT, 10);
                curl_setopt($ch, CURLOPT_AUTOREFERER, true);

                curl_setopt($ch, CURLOPT_HEADERFUNCTION, array($this,'readHeader'));

                if ($_SESSION[self::cache_key_conference_phpsessid])
                    curl_setopt($ch, CURLOPT_COOKIE, "PHPSESSID=".$_SESSION[self::cache_key_conference_phpsessid]);

                $response = curl_exec($ch);
                if (!$response) {
                    throw new \Wildix\Exception('Cannot connect to API or wrong response: ' . curl_error($ch));
                }

                $parsed = json_decode($response, true);
                if (!$parsed) {
                    throw new \Wildix\Exception('Cannot parse json: ' . json_last_error());
                }

                if (isset($parsed['type']) && $parsed['type'] == 'error') {
                    throw new \Wildix\Exception(isset($parsed['reason']) && $parsed['reason'] ? $parsed['reason'] : 'API returned unknown error');
                }

                curl_close($ch);

                return json_decode($response, true);
            } catch (\Exception $e) {
                if ($ch) {
                    curl_close($ch);
                }

                $this->getLog()->error($e->getLine(), $e->getMessage());
                if ($tries===0){
                    throw $e;
                }
            }
        }

        $this->getLog()->error(__LINE__, 'Failed to get valid response from MCU');
    }
}
