<?php
declare(strict_types=1);

namespace Services;

use Wildix\Error;
use Wildix\Exception as WildixException;

/**
 * Class Helpers
 */
class ShellHelper {

    public static function installCaracal(string $host, string $name, string $user, string $pass): void {
        exec(sprintf('/usr/sbin/wms_xcaracal_install -h %s -n %s -u %s -p %s', escapeshellarg($host), escapeshellarg($name), escapeshellarg($user), escapeshellarg($pass)), $output, $resultCode);
        if ($resultCode !== 0) {
            throw new WildixException(Error::XcaracalIsNotInstalled);
        }
    }

    public static function isInstalledService(string $service, bool $isRegExp = false): bool {
        $output = [];
        $key = $isRegExp ? '-E ' : '';
        exec(sprintf('dpkg -l | grep %s %s', $key, escapeshellarg($service)), $output);

        return count($output) > 0;
    }

    public static function isActiveService(string $service): bool {
        $output = [];
        exec('service '. escapeshellarg($service) . ' status | grep Active', $output);
        foreach ($output as $item) {
            if (stripos($item, 'running')) {
                return true;
            }
        }
        return false;
    }

    public static function deleteCaracal(): void {
        exec('/usr/sbin/wms_xcaracal_uninstall 2>&1', $output, $resultCode);
        if ($resultCode !== 0) {
            throw new WildixException(Error::XcaracalIsNotRemoved);
        }
    }

    public static function getMohClasses(): array {
        exec("callweaver -x'moh show classes' | grep 'Class:' | cut -d' ' -f2", $result);
        sort($result);

        return $result;
    }
}
