<?php
namespace Services;

use Wildix\System\Systemd;

class TProxyService {
    const PROTOCOLS_CONFIG_PATH = '/rw2/etc/pbx/wildix/tproxy_wms_protocols_include.conf';

    const DEFAULT_LDAP_PARAMS = [
        'name' => 'ldap',
        'ssl' => '1',
        'host' => '127.0.0.1',
        'port' => '636',
        'dump' => '0',
        'opt' => ''
    ];

    private $systemd;

    private $config = [];

    public function __construct(Systemd $systemd) {
        $this->systemd = $systemd;
        if (file_exists(self::PROTOCOLS_CONFIG_PATH)) {
            $config = file_get_contents(self::PROTOCOLS_CONFIG_PATH);
            $config = explode(',', str_replace(PHP_EOL, '', $config));
            $config = array_filter($config);

            foreach ($config as $line) {
                $array = [];
                foreach (explode(';', $line) as $field) {
                    $tmp         = explode('=', $field);
                    $key         = trim($tmp[0], '{ }');
                    $value       = trim($tmp[1], '{ }"');
                    $array[$key] = $value;
                }
                array_push($this->config, $array);
            }
        }
    }

    public function getConfig(): array {
        return $this->config;
    }

    private function addCustomProtocolProxying(array $params): void {
        $entry = [
            'name' => $params['name'],
            'ssl'  => $params['ssl'],
            'host' => $params['host'],
            'port' => $params['port'],
            'dump' => $params['dump'],
            'opt'  => $params['opt']
        ];

        if (!in_array($entry, $this->config)) {
            array_push($this->config, $entry);
        }
    }

    private function removeCustomProtocolProxying(array $params): void {
        foreach ($this->config as $item) {
            if ($item['name'] === $params['name']
                && $item['host'] === $params['host']
                && $item['port'] == $params['port']
                && $item['ssl'] == $params['ssl']
            ) {
                $key = array_search($item, $this->config);
                if ($key !== false) {
                    unset($this->config[$key]);
                }
            }
        }
    }

    public function addLdapProxying(): void {
        $this->addCustomProtocolProxying(self::DEFAULT_LDAP_PARAMS);
    }

    public function removeLdapProxying(): void {
        $this->removeCustomProtocolProxying(self::DEFAULT_LDAP_PARAMS);
    }

    public function addHttpProxying($host, $opt): void {
        $this->addCustomProtocolProxying(
            [
                'name' => 'http',
                'ssl'  => '0',
                'host' => $host,
                'port' => '80',
                'dump' => '0',
                'opt'  => $opt
            ]
        );
        $this->addCustomProtocolProxying(
            [
                'name' => 'http',
                'ssl'  => '1',
                'host' => $host,
                'port' => '443',
                'dump' => '0',
                'opt'  => $opt
            ]
        );
    }

    public function removeHttpProxying($host): void {
        $this->removeCustomProtocolProxying(
            [
                'name' => 'http',
                'ssl'  => '0',
                'host' => $host,
                'port' => '80'
            ]
        );
        $this->removeCustomProtocolProxying(
            [
                'name' => 'http',
                'ssl'  => '1',
                'host' => $host,
                'port' => '443'
            ]
        );
    }

    public function saveAndReload(): void {
        $config = [];
        foreach ($this->config as $entry) {
            $line = sprintf(
                '{ name = "%s"; ssl = %d; host = "%s"; port = %d; dump = %d; opt = "%s" }',
                $entry['name'],
                $entry['ssl'],
                $entry['host'],
                $entry['port'],
                $entry['dump'],
                $entry['opt']
            );

            array_push($config, $line);
        }

        $config = implode(',' . PHP_EOL, $config);
        file_put_contents(self::PROTOCOLS_CONFIG_PATH, $config . PHP_EOL);
        $this->systemd->reloadOrRestart();
    }
}
