<?php

declare(strict_types=1);

namespace Wildix\Slim\Error\Renderers;

use Slim\Error\AbstractErrorRenderer;
use Slim\Interfaces\ErrorRendererInterface;
use Throwable;
use Wildix\Error;

class JsonErrorBatchOperationsRenderer extends AbstractErrorRenderer implements ErrorRendererInterface {

    public function __invoke(Throwable $exception, bool $displayErrorDetails): string {
        $data = [
            'code'   => Error::BatchOperationsNotComplete,
            'errors' => [],
            'reason' => Error::getMessage(Error::BatchOperationsNotComplete),
            'type'   => 'result',
        ];

        foreach ($exception->getErrors() as $key => $exceptionErrorCode) {
            $data['errors'][$key] = [
                'code'   => $exceptionErrorCode,
                'reason' => Error::getMessage($exceptionErrorCode),
            ];
        }

        return (string)json_encode($data, JSON_PRETTY_PRINT | JSON_UNESCAPED_SLASHES);
    }
}
