<?php

declare(strict_types=1);

namespace Wildix\Slim\Error\Renderers;

use Slim\Error\AbstractErrorRenderer;
use Slim\Exception\HttpException;
use Throwable;

use function json_encode;

use const JSON_PRETTY_PRINT;
use const JSON_UNESCAPED_SLASHES;

/**
 * Default Slim application JSON Error Renderer
 */
class JsonErrorRenderer extends AbstractErrorRenderer {

    protected $defaultErrorTitle = 'Internal Server Error';

    /**
     * @param Throwable $exception
     * @param bool      $displayErrorDetails
     *
     * @return string
     */
    public function __invoke(Throwable $exception, bool $displayErrorDetails): string {
        if (!$exception instanceof HttpException) {
            $message = !empty($exception->getMessage()) ? $exception->getMessage() : $this->defaultErrorTitle;
        } else {
            $message = $this->getErrorTitle($exception);
        }

        $error = [
            'type'   => 'error',
            'reason' => $message,
            'code' => $exception->getCode(),
            'result' => null,
        ];

        return (string)json_encode($error, JSON_PRETTY_PRINT | JSON_UNESCAPED_SLASHES);
    }
}
