<?php

declare(strict_types=1);

namespace Wildix\Slim\Error\Renderers;

use DataEncoder\XML;
use Slim\Error\AbstractErrorRenderer;
use Slim\Exception\HttpException;
use Throwable;

/**
 * Default Slim application JSON Error Renderer
 */
class XmlErrorRenderer extends AbstractErrorRenderer {

    protected $defaultErrorTitle = 'Internal Server Error';

    /**
     * @param Throwable $exception
     * @param bool      $displayErrorDetails
     *
     * @return string
     */
    public function __invoke(Throwable $exception, bool $displayErrorDetails): string {
        if (!$exception instanceof HttpException) {
            $message = !empty($exception->getMessage()) ? $exception->getMessage() : $this->defaultErrorTitle;
        } else {
            $message = $this->getErrorTitle($exception);
        }
        $error = [
            'type'   => 'error',
            'reason' => $message,
            'result' => null,
        ];

        return XML::encode($error);
    }
}
