<?php

declare(strict_types=1);

namespace Wildix\Slim\Handlers;

use Slim\Handlers\ErrorHandler;
use Wildix\Slim\Error\Renderers\JsonErrorCustomRenderer;
use Wildix\Slim\Error\Renderers\JsonErrorRenderer;
use Wildix\Slim\Error\Renderers\XmlErrorRenderer;

class ErrorsHandler extends ErrorHandler {

    protected $defaultErrorRendererContentType = 'application/json';
    protected $defaultErrorRenderer            = JsonErrorRenderer::class;

    protected $errorRenderers = [
        'application/json' => JsonErrorCustomRenderer::class,
        'application/xml'  => XmlErrorRenderer::class,
        'text/xml'         => XmlErrorRenderer::class,
    ];

    protected function determineStatusCode(): int {
        if ($this->method === 'OPTIONS') {
            return 200;
        }

        if ($this->exception instanceof \Exception) {
            $code = $this->exception->getCode();
            if (!is_string($code) && $code > 0) {
                return $code;
            }
            return 500;
        }

        return 503;
    }
}
