<?php

namespace Wildix\Slim\Middleware\Authorization;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Slim\Psr7\Factory\ResponseFactory;
use Wildix\Auth\Devices\Authenticator;
use Wildix\System\ADSingleSignOnService;

class Device extends BaseMiddleware implements MiddlewareInterface {

    protected Authenticator  $devicesAuthenticator;
    protected ADSingleSignOnService $adSingleSignOn;

    /**
     * DeviceMiddleware constructor
     *
     * @param Authenticator         $devicesAuthenticator Authenticator.
     * @param ADSingleSignOnService $singleSignOn         Authenticator.
     * @param ResponseFactory       $responseFactory      Response factory interface.
     */
    public function __construct(Authenticator $devicesAuthenticator, ADSingleSignOnService $singleSignOn, ResponseFactory $responseFactory) {
        parent::__construct($singleSignOn, $responseFactory);
        $this->devicesAuthenticator = $devicesAuthenticator;
    }

    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface {
        $token  = $this->getBearerToken($request);
        $device = $this->devicesAuthenticator->authenticateDevice($request->getHeaderLine('User-Agent'), $token);

        if (!isset($device)) {
            return $this->sendErrorUnauthorizedResponse($request);
        }
        $request = $request->withAttribute('device', $device);

        return $handler->handle($request);
    }
}
