<?php

namespace Wildix\Slim\Middleware\Authorization;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Wildix\Exception;
use Wildix\InvalidDataException;

class Logical extends BaseMiddleware implements MiddlewareInterface {

    /**
     * Middlewares
     *
     * @var MiddlewareInterface[]|array
     */
    private array $middlewares = [];

    private bool $success = false;

    private int $code      = 401;
    private string $reason = 'Unauthorized';
    private $errors;

    public function addMiddleware(MiddlewareInterface $middleware): static {
        $this->middlewares[] = $middleware;

        return $this;
    }

    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface {
        foreach ($this->middlewares as $middleware) {
            try {
                $this->getLog()->info(__LINE__, '[Middleware Logical] Start ' . $middleware::class);
                $resp = $middleware->process($request, $handler);
                if (in_array($resp->getStatusCode(), [200, 201], true)) {
                    $this->success = true;
                    $this->getLog()->error(__LINE__, '[Middleware Logical] Success');
                    break;
                } else {
                    $this->getLog()->error(__LINE__, '[Middleware Logical] Error ' . $resp->getReasonPhrase());
                }
            } catch (InvalidDataException $e) {
                $this->code   = 400;
                $this->reason = $e->getMessage();
                $this->errors = (array)$e->getErrors();
                $this->getLog()->error(__LINE__, '[Middleware Logical] Error Invalid data: ' . $e->getMessage());
            } catch (Exception $e) {
                $this->code   = (int)$e->getHttpCode();
                $this->reason = $e->getMessage();
                $this->getLog()->error(__LINE__, '[Middleware Logical] Error ' . $e->getMessage());
            } catch (\Throwable $e) {
                $this->getLog()->error(__LINE__, '[Middleware Logical] Error ' . $e->getMessage());
            }
        }

        if ($this->success) {
            return $handler->handle($request);
        }

        return $this->sendErrorResponse($request, $this->code, $this->reason, $this->errors);
    }
}
