<?php

namespace Wildix\Slim\Middleware\Authorization;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Slim\Psr7\Factory\ResponseFactory;
use Wildix\Auth\SmsService\SmsServiceAuthenticator;
use Wildix\System\ADSingleSignOnService;

class Sms extends BaseMiddleware implements MiddlewareInterface {

    protected SmsServiceAuthenticator $serviceAuthenticator;

    /**
     * ServiceMiddleware constructor
     *
     * @param SmsServiceAuthenticator $serviceAuthenticator Authenticator.
     * @param ADSingleSignOnService   $singleSignOn         Authenticator.
     * @param ResponseFactory         $responseFactory      Responce factory.
     */
    public function __construct(
        SmsServiceAuthenticator $serviceAuthenticator,
        ADSingleSignOnService $singleSignOn,
        ResponseFactory $responseFactory
    ) {
        parent::__construct($singleSignOn, $responseFactory);
        $this->serviceAuthenticator = $serviceAuthenticator;
    }

    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface {
        if (!$this->_checkServiceAuth($request)) {
            return $this->sendErrorUnauthorizedResponse($request);
        }

        return $handler->handle($request);
    }

    private function _checkServiceAuth(ServerRequestInterface $request): bool {
        $token = $this->getBearerToken($request);
        if (empty($token)) {
            $this->getLog()->error(__LINE__, '[ServiceAuth] Empty JWT token');

            return false;
        }

        $service = $this->serviceAuthenticator->authenticate($token);
        if ($service) {
            $request->withAttribute('service', $service);

            return true;
        }

        return false;
    }
}
