<?php

namespace Wildix\Slim\Middleware\Check;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Wildix\Core\Container;
use Wildix\Error;
use Wildix\Exception;
use WMS_Permissions;

class AccessControlList implements MiddlewareInterface {

    private string          $type;
    private string          $subject;
    private WMS_Permissions $permissions;

    /**
     * AccessControlList constructor.
     *
     * @param WMS_Permissions $permissions Object check permissions.
     * @param string          $type        Type check.
     * @param string          $subject     Subject check.
     */
    public function __construct(WMS_Permissions $permissions, string $type, string $subject) {
        $this->type        = $type;
        $this->subject     = $subject;
        $this->permissions = $permissions;
    }

    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface {
        if (!$this->permissions->is_allowed($this->type, $this->subject)) {
            $this->getLog()->error(__LINE__, sprintf('Class %s has error %s for %s', basename(self::class), 'Access not allowed', $this->subject));
            throw new Exception(Error::AccessError, 403);
        }

        return $handler->handle($request);
    }


    protected function getLog():\Logger\Log {
        return Container::get(\Logger\Log::class);
    }
}
