<?php

namespace Wildix\Slim\Middleware\Check;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Wildix\Core\Container;
use Wildix\Error;
use Wildix\Exception;

class AllowForRoot implements MiddlewareInterface {

    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface {
        if (!$request->getAttribute('user')) {
            $this->getLog()->error(__LINE__, sprintf('Class %s has error %s for %s', basename(self::class), 'Unauthorized', 'user'));
            throw new Exception(Error::Unauthorized, 401);
        }

        if (!$request->getAttribute('user')->isRoot()) {
            $this->getLog()->error(__LINE__, sprintf('Class %s has error %s for %s', basename(self::class), 'Access not allowed', 'root'));
            throw new Exception(Error::AccessError, 403);
        }

        return $handler->handle($request);
    }

    protected function getLog():\Logger\Log {
        return Container::get(\Logger\Log::class);
    }
}
