<?php

namespace Wildix\Slim\Middleware\Check;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Wildix\Core\Container;
use Wildix\Error;
use Wildix\Exception;

class UserCan implements MiddlewareInterface {

    public function __construct(
        private string $canType,
        private string $what,
        private ?string $destGroupDn = null
    ) {
    }

    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface {
        if (!$request->getAttribute('user')) {
            $this->getLog()->error(__LINE__, sprintf('Class %s has error %s for %s', basename(self::class), 'UserCan not unauthorized', $this->canType));
            throw new Exception(Error::Unauthorized, 401);
        }

        $isCan = $request->getAttribute('user')->checkACL($this->canType, $this->what, $this->destGroupDn);

        if (!$isCan) {
            $this->getLog()->error(__LINE__, sprintf('Class %s has error %s for %s', basename(self::class), 'UserCan not permission', $this->canType));
            throw new Exception(Error::AccessError, 403);
        }

        return $handler->handle($request);
    }

    protected function getLog():\Logger\Log {
        return Container::get(\Logger\Log::class);
    }
}
