<?php

namespace Wildix\Slim\Middleware;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Slim\Middleware\RoutingMiddleware;
use Slim\Routing\RouteContext;

class Lowercase extends RoutingMiddleware implements MiddlewareInterface {

    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface {
        $originUri  = $request->getRequestTarget();
        $originPath = parse_url($originUri, PHP_URL_PATH);
        $path       = mb_strtolower($request->getUri()->getPath());
        if (!str_ends_with($path, '/')) {
            $path .= '/';
        }
        $newRequest = $request
            ->withUri($request->getUri()->withPath($path));

        $actualRequest = $newRequest
            ->withAttribute('originAttribute', $this->getOriginAttributes($this->getPattern($newRequest), $originPath))
            ->withAttribute('originUri', $originUri);

        return $handler->handle($actualRequest);
    }

    private function getPattern(ServerRequestInterface $request) {
        $requestWithRoute = $this->performRouting($request);
        $currentRoute     = $requestWithRoute->getAttribute(RouteContext::ROUTE);
        return $currentRoute->getPattern();
    }

    private function getOriginAttributes(string $pattern, string $uri): array {
        $attributes      = [];
        $patternArr      = array_filter(explode('/', str_replace(['[', ']'], '', $pattern)));
        $uriArr          = array_filter(explode('/', urldecode($uri)));
        $countAttributes = substr_count($pattern, '{');
        $currentKey      = '';
        foreach ($uriArr as $key => $value) {
            if (strcasecmp($patternArr[$key], $value)) {
                $attributesKey = str_replace(['{', '}'], '', $patternArr[$key]);
                if ($this->isOptional($attributesKey)) {
                    $attributesKey = stristr($attributesKey, ':', true);
                }
                if ($countAttributes >= 1) {
                    $attributes[$attributesKey] = $value;
                    $currentKey                 = $attributesKey;
                } else {
                    $attributes[$currentKey] .= '/' . $value;
                }
                $countAttributes--;
            }
        }

        return $attributes;
    }

    private function isOptional(string $attribute): bool {
        return substr_count($attribute, ':') > 0;
    }
}
