<?php

use Logger\PsrLoggerAdapter;
use Slim\Factory\AppFactory;
use Slim\Middleware\ErrorMiddleware;
use Spatie\DataTransferObject\Exceptions\ValidationException;
use Wildix\Core\Container;
use Wildix\Exception\BaseException;
use Wildix\Slim\Handlers\ErrorsHandler;
use Wildix\Slim\Handlers\SpatieDataTransferObjectErrorHandler;
use Wildix\Slim\Handlers\WildixBatchOperationsExceptionHandler;
use Wildix\Slim\Handlers\WildixExceptionHandler;
use Wildix\Slim\Handlers\WildixInvalidDataExceptionHandler;

require_once __DIR__ . '/../init.php';
require_once BASEPATH . 'features/features.functions.php';

// @TODO use normal container! // php-di/php-di
$diContainer = Container::make([]);
AppFactory::setContainer($diContainer);
$app = AppFactory::create();

// Route caching
// todo enable before testing
$routeCollector = $app->getRouteCollector();
$routeCollector->setCacheFile('/tmp/cacheRoute.file');

(require __DIR__ . '/config/settings.php')($diContainer);

// $container / containerBuilder
(require __DIR__ . '/config/dependencies.php')($diContainer);

(require __DIR__ . '/config/middleware.php')($app);

(require __DIR__ . '/config/routes.php')($app);

// Add Error Middleware
/** @var ErrorMiddleware $errorMiddleware */
$errorMiddleware = $app->addErrorMiddleware(true, true, true);
// Add Error Middleware
// $errorMiddleware = $app->addErrorMiddleware($displayErrorDetails, $logError, $logErrorDetails);
/** @var PsrLoggerAdapter $loggerAdapter */
$loggerAdapter   = $app->getContainer()->get(PsrLoggerAdapter::class);
$errorApiHandler = new ErrorsHandler($app->getCallableResolver(), $app->getResponseFactory(), $loggerAdapter);
$errorMiddleware->setDefaultErrorHandler($errorApiHandler);

$spatieDataTransferObjectErrorHandler = new SpatieDataTransferObjectErrorHandler(
    $app->getCallableResolver(),
    $app->getResponseFactory(),
    $loggerAdapter
);

$wildixExceptionHandler                = new WildixExceptionHandler(
    $app->getCallableResolver(),
    $app->getResponseFactory(),
    $loggerAdapter
);
$wildixInvalidDataExceptionHandler     = new WildixInvalidDataExceptionHandler(
    $app->getCallableResolver(),
    $app->getResponseFactory(),
    $loggerAdapter
);
$wildixBatchOperationsExceptionHandler = new WildixBatchOperationsExceptionHandler(
    $app->getCallableResolver(),
    $app->getResponseFactory(),
    $loggerAdapter
);

$errorMiddleware->setErrorHandler([BaseException::class, Wildix\Exception::class], $wildixExceptionHandler);
$errorMiddleware->setErrorHandler(ValidationException::class, $spatieDataTransferObjectErrorHandler);
$errorMiddleware->setErrorHandler(Wildix\InvalidDataException::class, $wildixInvalidDataExceptionHandler);
$errorMiddleware->setErrorHandler(Wildix\BatchOperationsException::class, $wildixBatchOperationsExceptionHandler);

return $app;
