<?php
declare(strict_types=1);

namespace Api\Analytics\Caracal\Interfaces;

use Api\Analytics\Caracal\Configs\CaracalConfig;
use Api\Analytics\Caracal\Services\CaracalService;
use Api\Translation\Interfaces\TranslationStrategyInterface;
use Logger\Log;
use Wildix\DependencyInjection\ConfigInterface;
use Wildix\DependencyInjection\Container;
use Wildix\License;

/**
 * Class DiConfig
 */
class DiConfig implements ConfigInterface {

    public static function configure(Container $container): void {
        $container->singleton(
            CaracalServiceInterface::class,
            function () use ($container) {
                $license = $container->get(License::class);
                $config  = $container->get(CaracalConfigInterface::class);
                $log     = $container->get(Log::class);

                $translation = $container->get(TranslationStrategyInterface::class);

                return new CaracalService(
                    $config,
                    $log,
                    $translation,
                    $license
                );
            }
        );

        $container->singleton(
            CaracalConfigInterface::class,
            function () use ($container) {
                return new CaracalConfig(CaracalConfig::CONFIG_FILE, null, true);
            }
        );
    }
}
