<?php

declare(strict_types=1);

namespace Api\Database\Connectors;

use InvalidArgumentException;

/**
 * Class SQLiteConnector
 */
class SQLiteConnector extends Connector implements ConnectorInterface {

    /**
     * Establish a database connection.
     *
     * @param array $config Config database.
     *
     * @throws InvalidArgumentException Error.
     *
     * @return \PDO Pdo.
     */
    public function connect(array $config): \PDO {
        $options = $this->getOptions($config);

        if ($config['database'] == ':memory:') {
            return $this->createConnection('sqlite::memory:', $config, $options);
        }

        $path = realpath($config['database']);

        if ($path === false) {
            throw new InvalidArgumentException("Database (${config['database']}) does not exist.");
        }

        return $this->createConnection(sprintf('sqlite:%s', $path), $config, $options);
    }
}
