<?php

declare(strict_types=1);

namespace Api\Database;

use Exception;

/**
 * Trait DetectsLostConnections
 */
trait DetectsLostConnectionsTrait {

    /**
     * Determine if the given exception was caused by a lost connection.
     *
     * @param \Exception $e Exception.
     *
     * @return boolean Return result the given exception was caused by a lost connection.
     */
    protected function causedByLostConnection(Exception $e): bool {
        $message = $e->getMessage();

        return in_array(
            $message,
            [
            'server has gone away',
            'no connection to the server',
            'Lost connection',
            'is dead or not enabled',
            'Error while sending',
            'decryption failed or bad record mac',
            'server closed the connection unexpectedly',
            'SSL connection has been closed unexpectedly',
            'Error writing data to the connection',
            'Resource deadlock avoided',
            'Transaction() on null',
            ]
        );
    }
}
