<?php

declare(strict_types=1);

namespace Api\Database;

use Api\Database\Query\QueryBuilder;
use Latitude\QueryBuilder\Engine\MySqlEngine;
use PDO;
use PDOStatement;

/**
 * Class MySqlConnection
 */
class MySqlConnection extends Connection {
    /**
     * Bind values to their parameters in the given statement.
     *
     * @param PDOStatement $statement Statement.
     * @param array        $bindings  Bind values.
     *
     * @return void
     */
    public function bindValues(PDOStatement $statement, array $bindings) {
        foreach ($bindings as $key => $value) {
            $statement->bindValue(
                is_string($key) ? $key : $key + 1,
                $value,
                is_int($value) || is_float($value) ? PDO::PARAM_INT : PDO::PARAM_STR
            );
        }
    }

    /**
     * Get a new query builder instance.
     *
     * @return QueryBuilder
     */
    public function query(): QueryBuilder {
        $engine = new MySqlEngine();

        return new QueryBuilder($this, $engine);
    }

    /**
     * Dynamically pass methods to the default connection.
     *
     * @param string $method     Method.
     * @param array  $parameters Parameters.
     *
     * @return mixed
     */
    public function __call(string $method, array $parameters) {
        return $this->$method(...$parameters);
    }
}
