<?php
declare(strict_types=1);

namespace Api\Database\Query;

use Api\Database\QueryConditionEnum;
use Latitude\QueryBuilder\CriteriaInterface;
use Wildix\Exception;
use function Latitude\QueryBuilder\field;

/**
 * Class QueryCriteriaBuilder
 */
class QueryCriteriaBuilder {

    /**
     * Criteria condition
     *
     * @var array
     */
    private $_criteriaCondition;

    /**
     * Constructor QueryCriteriaBuilder
     *
     * @param array $_criteriaCondition Array with field and conditions.
     */
    public function __construct(array $_criteriaCondition) {
        $this->_criteriaCondition = $_criteriaCondition;
    }

    /**
     * Get _criteriaCondition
     *
     * @throws \Exception Error.
     *
     * @return CriteriaInterface|null
     */
    public function getCriteriaCondition(): ?CriteriaInterface {
        if (count($this->_criteriaCondition) == 2) {
            return field($this->_criteriaCondition[0])->eq($this->_criteriaCondition[1]);
        } else if (count($this->_criteriaCondition) >= 3) {
            $condition = $this->_criteriaCondition[2];
            if (!QueryConditionEnum::hasValue($condition)) {
                throw new Exception('Invalid query builder condition:' . $condition);
            }
            return field($this->_criteriaCondition[0])->$condition($this->_criteriaCondition[1]);
        }
        return null;
    }
}
