<?php

declare(strict_types=1);

namespace Api\Database;

use Api\Database\Query\QueryBuilder;
use Latitude\QueryBuilder\Engine\SqliteEngine;

/**
 * Class SQLiteConnection
 */
class SQLiteConnection extends Connection {

    /**
     * Get a new query builder instance.
     *
     * @return QueryBuilder
     */
    public function query(): QueryBuilder {
        $engine = new SqliteEngine();

        return new QueryBuilder($this, $engine);
    }

    /**
     * Get the elapsed time since a given starting point.
     *
     * @param integer $start Elapsed Time.
     *
     * @return float
     */
    protected function getElapsedTime(int $start): float {
        return round((microtime(true) - $start) * 1000, 2);
    }



    /**
     * Dynamically pass methods to the default connection.
     *
     * @param string $method     Method.
     * @param array  $parameters Parameters.
     *
     * @return mixed
     */
    public function __call(string $method, array $parameters) {
        return $this->$method(...$parameters);
    }
}
