<?php

declare(strict_types=1);

namespace Api\Database;

use Api\Database\Query\QueryBuilder;
use Closure;
use Exception;
use Latitude\QueryBuilder\Engine\SqlServerEngine;
use Throwable;

/**
 * Class SqlServerConnection
 */
class SqlServerConnection extends Connection {

    /**
     * Get a new query builder instance.
     *
     * @return QueryBuilder
     */
    public function query(): QueryBuilder {
        $engine = new SqlServerEngine();

        return new QueryBuilder($this, $engine);
    }

    /**
     * Execute a Closure within a transaction.
     *
     * @param \Closure $callback Closure within a transaction.
     * @param integer  $attempts Attempts.
     *
     * @return mixed
     *
     * @throws Throwable Error.
     * @throws Exception Error.
     */
    public function transaction(Closure $callback, int $attempts = 1) {
        for ($a = 1; $a <= $attempts; $a++) {
            if ($this->getDriverName() == 'sqlsrv') {
                return parent::transaction($callback);
            }

            $this->getPdo()->exec('BEGIN TRAN');
            try {
                $result = $callback($this);
                $this->getPdo()->exec('COMMIT TRAN');
            } catch (Exception | Throwable $e) {
                $this->getPdo()->exec('ROLLBACK TRAN');

                throw $e;
            }

            return $result;
        }
    }


    /**
     * Dynamically pass methods to the default connection.
     *
     * @param string $method     Method.
     * @param array  $parameters Parameters.
     *
     * @return mixed
     */
    public function __call(string $method, array $parameters) {
        return $this->$method(...$parameters);
    }
}
