<?php

namespace Api\Departments\Interfaces;

use Api\Departments\Objects\Tree;
use Api\Departments\Repository\DepartmentsRepository;
use Api\Departments\Services\DepartmentService;
use Api\Translation\Interfaces\TranslationStrategyInterface;
use Cache\FileCache;
use Wildix\DependencyInjection\ConfigInterface;
use Wildix\DependencyInjection\Container;

/**
 * Class DiConfig
 */
class DiConfig implements ConfigInterface {

    public static function configure(Container $container): void {
        $container->singleton(
            DepartmentServiceInterface::class,
            function () use ($container) {
                return new DepartmentService(
                    $container->get(DepartmentsRepository::class),
                    $container->get(FileCache::class)
                );
            }
        );
        $container->singleton(
            DepartmentsRepository::class,
            function () use ($container) {
                $translation = $container->get(TranslationStrategyInterface::class);

                $tree = new Tree($translation->t('features.all'), $translation->t('inccalls.Other'));

                return new DepartmentsRepository(
                    $container->get(\WMS_Ldap::class),
                    env('DEPARTMENTS_TREE_SEPARATOR'),
                    $tree
                );
            }
        );
    }
}
