<?php

namespace Api\Departments\Objects;

class Tree {

    private $_source    = [];
    private $_items     = [];
    private $_parentIds = [];
    private $_tree      = [];

    private $_allCategoryName   = 'All';
    private $_otherCategoryName = 'Other';

    public function __construct(string $allCategoryName, string $otherCategoryName) {
        $this->_allCategoryName   = $allCategoryName;
        $this->_otherCategoryName = $otherCategoryName;
    }

    public function setOtherCategoryName(string $name): void {
        $this->_otherCategoryName = $name;
    }

    public function getSource(): array {
        return $this->_source;
    }

    public function setSource(array $data): void {
        $this->_source = $data;
    }

    public function addCategory(string $id, string $parentId, string $name): void {
        if (!isset($this->_source[$id])) {
            $this->_source[$id] = $this->_getCategoryStructuredData($id, $parentId, $name);
        }
    }

    private function _getCategoryStructuredData(string $id, string $parentId, string $name, array $users = []): array {
        return [
            TreeCategory::FIELD_ID        => $id,
            TreeCategory::FIELD_PARENT_ID => $parentId,
            TreeCategory::FIELD_NAME      => $name,
            TreeCategory::FIELD_USERS     => $users,
        ];
    }

    public function addUserToCategory(string $catId, string $userExtension): void {
        if (empty($catId)) {
            $catId = $this->_otherCategoryName;
        }

        if (!isset($this->_source[$catId])) {
            $this->addCategory($catId, 0, $catId);
        }

        $this->_source[$catId][TreeCategory::FIELD_USERS][] = $userExtension;
    }

    public function buildTree(): void {
        $this->sortCategories();

        $source = $this->getSourceWithCategoryAll();
        foreach ($source as $data) {
            $categoryData = new CategoryData($data);
            $category     = new TreeCategory($categoryData);

            $this->_items[$category->getId()]             = $category;
            $this->_parentIds[$category->getParentId()][] = $category->getId();
        }

        $this->_tree = $this->buildTreeCategory($this->_parentIds[0]);
    }

    private function getSourceWithCategoryAll(): array {
        $allUsers = [];
        foreach ($this->_source as $data) {
            $allUsers[] = $data[TreeCategory::FIELD_USERS];
        }
        $allUsers = array_merge(...$allUsers);

        // add virtual category All to first position
        $allCategoryData = [
            $this->_allCategoryName => $this->_getCategoryStructuredData(
                $this->_allCategoryName,
                '0',
                $this->_allCategoryName,
                $allUsers
            )
        ];

        return $allCategoryData + $this->_source;
    }

    private function sortCategories(): void {
        uasort(
            $this->_source,
            function ($a, $b) {
                if ($a['name'] === $this->_otherCategoryName) {
                    return 1;
                } else if ($a['name'] === $b['name']) {
                    return 0;
                }
                return ($a['name'] < $b['name']) ? -1 : 1;
            }
        );
    }

    private function buildTreeCategory(array $child): array {
        $treeArr = [];
        foreach ($child as $id) {
            $category = $this->_items[$id];
            $category->setChild($this->buildTreeCategory($this->_parentIds[$category->getId()] ?? []));
            $treeArr[] = $category;
        }

        return $treeArr;
    }

    public function getDepartments(): Departments {
        $result = new Departments();
        foreach ($this->_tree as $category) {
            $result->push($category->toArray());
        }

        return $result;
    }
}
