<?php

namespace Api\Departments\Objects;

class TreeCategory {

    const FIELD_ID        = 'id';
    const FIELD_NAME      = 'name';
    const FIELD_ITEMS     = 'items';
    const FIELD_USERS     = 'users';
    const FIELD_PARENT_ID = 'parentId';

    private $_data;

    public function __construct(CategoryData $data) {
        $this->_data = [
            self::FIELD_ID        => $data->id,
            self::FIELD_NAME      => $data->name,
            self::FIELD_PARENT_ID => $data->parentId,
            self::FIELD_USERS     => $data->users,
            self::FIELD_ITEMS     => [],
        ];
    }

    public function addUser(string $extension): void {
        $this->_data[self::FIELD_USERS][] = $extension;
    }

    public function setChild($child): void {
        $this->_data[self::FIELD_ITEMS] = $child;
    }

    public function addChild(TreeCategory $item): void {
        $this->_data[self::FIELD_ITEMS][] = $item;
    }

    public function getId(): string {
        return $this->_data[self::FIELD_ID];
    }

    public function getName(): string {
        return $this->_data[self::FIELD_NAME];
    }

    public function getParentId(): string {
        return $this->_data[self::FIELD_PARENT_ID];
    }

    public function getItems(): array {
        return $this->_data[self::FIELD_ITEMS];
    }

    public function getUsers(): array {
        return $this->_data[self::FIELD_USERS];
    }

    public function toArray(): array {
        return [
            self::FIELD_ID        => $this->getId(),
            self::FIELD_NAME      => $this->getName(),
            self::FIELD_USERS     => $this->getUsers(),
            self::FIELD_ITEMS     => array_map(
                function ($item) {
                    return $item->toArray();
                },
                $this->getItems()
            ),
        ];
    }
}
