<?php

namespace Api\Departments\Repository;

use Api\Departments\Interfaces\RepositoryInterface;
use Api\Departments\Objects\Tree;

/**
 * Class DepartmentsRepository
 */
class DepartmentsRepository implements RepositoryInterface {

    /**
     * WMS Ldap class
     *
     * @var \WMS_Ldap $_ldap
     */
    private $_ldap;

    /**
     * Separator symbol
     *
     * @var string $_separator
     */
    private $_separator;

    /**
     * Departments tree
     *
     * @var Tree $_tree
     */
    protected $_tree;

    public function __construct(\WMS_Ldap $ldap, string $separator, Tree $tree) {
        $this->_ldap      = $ldap;
        $this->_separator = $separator;
        $this->_tree      = $tree;
    }

    public function getTree(): Tree {
        return $this->_tree;
    }

    public function loadData(): void {
        $users = $this->getUsersData();
        foreach ($users as $user) {
            $departStr = trim((string)($user['ou'] ?? ''));
            $ext       = (string)$user['telephoneNumber'];

            if (!$ext) {
                continue;
            }

            $this->addCategoryRecursive($departStr, $ext);
        }
    }

    private function addCategoryRecursive(string $departStr, string $ext = '') {
        $parts = !empty($departStr) ? array_filter(array_map('trim', explode($this->_separator, $departStr))) : [];

        $id = '';
        if (count($parts)) {
            $id       = implode($this->_separator, $parts);
            $name     = array_pop($parts);
            $parentId = count($parts) ? implode($this->_separator, $parts) : 0;

            $this->getTree()->addCategory($id, $parentId, $name);

            if ($parentId) {
                $this->addCategoryRecursive($parentId);
            }
        }

        if ($ext) {
            $this->getTree()->addUserToCategory($id, $ext);
        }
    }

    private function getUsersData(): array {
        $rows = $this->_ldap->getEntriesSortLimit(\WMS_Ldap::PERSONS, '', ['ou', 'telephoneNumber']);
        unset($rows['count']);

        return $rows;
    }
}
