<?php

namespace Api\Departments\Services;

use Api\Departments\Interfaces\DepartmentServiceInterface;
use Api\Departments\Interfaces\RepositoryInterface;
use Api\Departments\Objects\Tree;
use Cache\FileCache;

/**
 * Class DepartmentService
 */
class DepartmentService implements DepartmentServiceInterface {

    const CACHE_KEY = 'departments';
    const CACHE_TTL = 600;

    /**
     * Departments repository
     *
     * @var RepositoryInterface
     */
    private $_repository;

    /**
     * File Cache class
     *
     * @var FileCache $_cache
     */
    private $_cache;

    public function __construct(RepositoryInterface $repository, FileCache $cache) {
        $this->_repository = $repository;
        $this->_cache      = $cache;
    }

    public function getTree(): Tree {
        $treeData = $this->_cache->get(self::CACHE_KEY);
        if ($treeData !== false) {
            $this->repository()->getTree()->setSource($treeData);
        } else {
            $this->repository()->loadData();
            $treeData = $this->repository()->getTree()->getSource();
            $this->_cache->set(self::CACHE_KEY, $treeData, self::CACHE_TTL);
        }

        $this->repository()->getTree()->buildTree();

        return $this->repository()->getTree();
    }

    public function clearCache(): void {
        $this->_cache->delete(self::CACHE_KEY);
    }

    private function repository(): RepositoryInterface {
        return $this->_repository;
    }
}
