<?php

namespace Api\Device\Repository;

use Api\Device\Interfaces\DeviceRepositoryInterface;
use Wildix\Databases\Database;
use Wildix\Databases\DEVDB;

/**
 * Class DeviceRepository
 */
class DeviceRepository extends Database implements DeviceRepositoryInterface {

    protected $_table = DEVDB::TABLE_AUTOPROV;

    public function __construct() {
        $path = self::WILDIX_DEVDB;
        parent::__construct($path);
    }

    public function getTrunkIdDeviceMap(array $trunkIds): array {
        $query = sprintf(
            "SELECT a1.value AS trunkid, a2.value AS device FROM %s AS a1
                LEFT JOIN %s AS a2 ON (a1.mac = a2.mac AND a2.param = 'device')
                LEFT JOIN %s AS a3 ON (a1.mac = a3.mac AND a3.param = 'status')
             WHERE a1.value IN (%s) AND a1.param='trunkid'",
            $this->_table,
            $this->_table,
            $this->_table,
            implode(',', array_map('intval', $trunkIds))
        );

        return $this->getRows($query, 'trunkid');
    }

    public function getMacByTrunkId(int $id): string {
        return $this->first(
            sprintf(
                'SELECT `%s` FROM `%s` WHERE `%s`=\'%s\' and `value`=\'%s\'',
                'mac',
                DEVDB::TABLE_AUTOPROV,
                'param',
                'trunkid',
                $id
            )
        )['mac'] ?? '';
    }

    public function deleteTrunk(int $id): bool {
        return $this->exec(
            sprintf(
                "DELETE FROM `%s` WHERE `param`='trunkid' AND `value`=%d;",
                $this->_table,
                $id
            )
        );
    }
}
