<?php

namespace Api\Devices\Repository;

use Api\Devices\Factories\WairDeviceFactory;
use Api\Devices\Interfaces\WairRepositoryInterface;
use Api\Devices\Objects\WairDevice;
use Api\Devices\Objects\WairDevices;
use Wildix\Error;
use Wildix\Exception;
use Wildix\SipProxy;

class WairRepository implements WairRepositoryInterface {

    private $_sipProxy;

    public function __construct(SipProxy $sipProxy) {
        $this->_sipProxy = $sipProxy;
    }

    public function getItems(): WairDevices {
        $result = new WairDevices();
        $items  = $this->getSipProxy()->getWairDevices();

        foreach ($items as $item) {
            $result->push(WairDeviceFactory::make($item));
        }

        return $result;
    }

    public function findOrFail(string $ipei): WairDevice {
        $result = array_values(
            array_filter(
                $this->getItems()->all(),
                function ($device) use ($ipei) {
                    return $device->getIpei() === $ipei;
                }
            )
        )[0] ?? null;

        if (!$result) {
            throw new Exception(Error::DeviceNotFound, 404);
        }

        return $result;
    }

    private function getSipProxy(): SipProxy {
        return $this->_sipProxy;
    }
}
