<?php

namespace Api\Devices\Services;

use Api\Devices\Factories\WairDeviceFactory;
use Api\Devices\Interfaces\WairRepositoryInterface;
use Api\Devices\Interfaces\WairServiceInterface;
use Api\Devices\Objects\WairDevice;
use Services\LuaService;
use Wildix\Colleagues\Colleagues;
use Wildix\Error;
use Wildix\Exception;

class WairService implements WairServiceInterface {

    private $_repository;
    private $_colleague;
    private $_luaService;

    public function __construct(WairRepositoryInterface $repository, Colleagues $colleague, LuaService $luaService) {
        $this->_repository = $repository;
        $this->_colleague  = $colleague;
        $this->_luaService = $luaService;
    }

    public function getItems(): array {
        return $this->getRepository()->getItems()->toArray();
    }

    public function buildItem(WairDevice $device): array {
        return [
            'extension' => $device->getExtension(),
            'baseMac' => $device->getBaseMac(),
            'ipei' => $device->getIpei(),
            'model' => $device->getModel(),
        ];
    }

    public function update(string $id, $params = []): void {
        $newDevice = WairDeviceFactory::make($params);

        $currentDevice    = $this->getRepository()->findOrFail($id);
        $currentExtension = $currentDevice->getExtension();
        $wAirBaseMac      = $currentDevice->getBaseMac();
        $targetExtension  = $newDevice->getExtension();
        $displayName      = $this->getDisplayName($currentExtension, $targetExtension);
        $baseModel        = $currentDevice->getBaseModel();
        $contact          = $currentDevice->getContact();

        $result = $this->getLuaService()->assignWairUser($targetExtension, $displayName, $currentExtension, $wAirBaseMac, $id, $baseModel, $contact);

        if (!$result) {
            throw new Exception(Error::AssignUserFailed, 500);
        }
    }

    private function getDisplayName(string $currentExtension, string $targetExtension): string {
        if (stripos($currentExtension, 'unknown') === 0) {
            $result = sprintf('login%s', str_replace('unknown', '', $currentExtension));
        } else {
            $colleagueByExtension = $this->getColleague()->getUserByExtension($targetExtension === 'unknown' ? $currentExtension : $targetExtension);

            if (!$colleagueByExtension) {
                throw new Exception(Error::NotFoundColleague, 400);
            }

            $result = $colleagueByExtension->getName();
        }

        return $result;
    }

    private function getRepository(): WairRepositoryInterface {
        return $this->_repository;
    }

    private function getColleague(): Colleagues {
        return $this->_colleague;
    }

    private function getLuaService(): LuaService {
        return $this->_luaService;
    }
}
