<?php
declare(strict_types=1);

namespace Api\Dialplans\Rules\Imports\Request;

use Psr\Http\Message\ServerRequestInterface;

/**
 * Class ImportRequest
 */
class ImportRequest {

    /**
     * Name of file
     *
     * @var string
     */
    private $_fileName;

    /**
     * File name in tem path
     *
     * @var string
     */
    private $_fileTmpName;

    /**
     * File type
     *
     * @var string
     */
    private $_fileErrorMessage;

    /**
     * File extension
     *
     * @var string
     */
    private $_fileExtension;

    /**
     * Verify file type
     *
     * @var bool
     */
    private $_isDialPlanFile;

    /**
     * Create self from slim request
     *
     * @param ServerRequestInterface $request Request.
     *
     * @return ImportRequest
     */
    public static function make(ServerRequestInterface $request): ImportRequest {
        $fileData      = $request->getUploadedFiles()['importDialplanFile'];
        $fileExtension = basename($fileData->getClientFilename());
        $newClass      = new self();
        return $newClass
            ->setFileExtension($fileExtension)
            ->setFileName($fileData->getClientFilename())
            ->setFileTmpName($fileData->getFilePath())
            ->setFileErrorMessage('');
    }

    /**
     * Get File name
     *
     * @return string
     */
    public function getFileName(): string {
        return $this->_fileName;
    }

    /**
     * Set file name
     *
     * @param string $_fileName Name file.
     *
     * @return ImportRequest
     */
    public function setFileName(string $_fileName): ImportRequest {
        $this->_fileName = $_fileName;
        return $this;
    }

    /**
     * Get file ERROR
     *
     * @return string
     */
    public function getFileErrorMessage(): string {
        return $this->_fileErrorMessage;
    }

    public function hasErrorMessage(): bool {
        return !empty($this->getFileErrorMessage());
    }

    /**
     * Set file error
     *
     * @param string $_fileErrorMessage File type.
     *
     * @return ImportRequest
     */
    public function setFileErrorMessage(string $_fileErrorMessage): ImportRequest {
        $this->_fileErrorMessage = $_fileErrorMessage;
        return $this;
    }

    /**
     * Get file extension
     *
     * @return string
     */
    public function getFileExtension(): string {
        return $this->_fileExtension;
    }

    /**
     * Set file extension
     *
     * @param string $_fileExtension File extension.
     *
     * @return ImportRequest
     */
    public function setFileExtension(string $_fileExtension): ImportRequest {
        $this->_fileExtension = $_fileExtension;
        return $this;
    }

    /**
     * Verify file type
     *
     * @return boolean
     */
    public function isDialPlanFile(): bool {
        return $this->_isDialPlanFile;
    }

    /**
     * Set Verify file type
     *
     * @param boolean $_isDialPlanFile True/False.
     *
     * @return ImportRequest
     */
    public function setIsDialplanFile(bool $_isDialPlanFile): ImportRequest {
        $this->_isDialPlanFile = $_isDialPlanFile;
        return $this;
    }

    /**
     * Get temp file name
     *
     * @return string
     */
    public function getFileTmpName(): string {
        return $this->_fileTmpName;
    }

    /**
     * Set temp file name
     *
     * @param string $fileTmpName File name.
     *
     * @return ImportRequest
     */
    public function setFileTmpName(string $fileTmpName): ImportRequest {
        $this->_fileTmpName = $fileTmpName;
        return $this;
    }
}
