<?php
declare(strict_types=1);

namespace Api\Dialplans\Rules\Imports\Response;

use Api\Dialplans\Rules\Imports\Objects\RuleNames;
use Api\Support\Interfaces\ArrayableInterface;

/**
 * Class RulesImportResponse
 */
class RulesImportResponse implements ArrayableInterface {

    /**
     * Error text
     *
     * @var string Error text.
     */
    private $_error = '';

    /**
     * List of rule for backup
     *
     * @var RuleNames
     */
    private $_ruleNames;

    /**
     * Get error message
     *
     * @return string
     */
    public function getError(): string {
        return $this->_error;
    }

    /**
     * Set error message
     *
     * @param string $error Message for user.
     *
     * @return RulesImportResponse
     */
    public function setError(string $error): RulesImportResponse {
        $this->_error = $error;
        return $this;
    }

    /**
     * Get list of backup
     *
     * @return RuleNames
     */
    public function getRuleNames(): RuleNames {
        return $this->_ruleNames;
    }

    /**
     * Set list of backup
     *
     * @param RuleNames $ruleNames List of backup.
     *
     * @return RulesImportResponse
     */
    public function setRuleNames(RuleNames $ruleNames): RulesImportResponse {
        $this->_ruleNames = $ruleNames;
        return $this;
    }

    public function hasError(): bool {
        return !empty($this->getError());
    }

    public function toArray(): array {
        return ['records' => $this->getRuleNames()->toArray()];
    }
}
