<?php

declare(strict_types=1);

namespace Api\Dictionary\Objects;

use Api\Support\BaseCollectObject;
use Api\Translation\Interfaces\TranslationStrategyInterface;
use Api\Translation\Objects\TranslationInterface;
use Wildix\Core\Container;

/**
 * Class Contexts
 */
class Contexts extends BaseCollectObject {

    public const DIALPLAN_WITH_PREDEFINED_DESCRIPTION = [
        'internalcalls',
        'pbxfeatures',
        'pbxservices',
        'pbxinternal',
        'users',
        'main',
        'kite',
        'classound',
    ];

    /**
     * Translation instance
     *
     * @var TranslationInterface
     */
    protected $_translateService;

    public function __construct(array $items = []) {
        parent::__construct($items);
        $this->_translateService = Container::get(TranslationStrategyInterface::class);
    }

    /**
     * Format append to collection
     *
     * @param array $row Array for append.
     *
     * @return $this
     */
    public function appendByFormat(array $row): Contexts {
        if (in_array($row['context'], self::DIALPLAN_WITH_PREDEFINED_DESCRIPTION, true)) {
            $translate = $this->_translateService->t('dialplan.rule.' . $row['context']);
            $this->push($this->makeObjectSelect($row['context'], $row['context'] . ' (' . $translate . ')'));
        } else if ($row['ruledescription'] !== '') {
            $this->push($this->makeObjectSelect($row['context'], $row['context'] . ' (' . $row['ruledescription'] . ')'));
        } else {
            $this->push($this->makeObjectSelect($row['context'], $row['context']));
        }

        return $this;
    }

    /**
     * Create object for html select data
     *
     * @param string $value Value.
     * @param string $key   Key.
     *
     * @return SelectKeyValueObject
     */
    private function makeObjectSelect(string $value, string $key): SelectKeyValueObject {
        $keyValueObject = new SelectKeyValueObject();
        $keyValueObject
            ->setLabel($key)
            ->setValue($value);
        return $keyValueObject;
    }
}
