<?php

declare(strict_types=1);

namespace Api\Dictionary\Objects;

use Api\Support\Interfaces\ArrayableInterface;

/**
 * Class SelectKeyValueObject
 */
class SelectKeyValueObject implements ArrayableInterface {

    /**
     * Key object
     *
     * @var mixed $_label Key.
     */
    private $_label;

    /**
     * Value object
     *
     * @var mixed $_value Value.
     */
    private $_value;

    /**
     * Get the object as a plain array.
     *
     * @return array
     */
    public function toArray(): array {
        return [
            'label' => $this->getLabel(),
            'value' => $this->getValue(),
        ];
    }

    /**
     * Get key object
     *
     * @return mixed
     */
    public function getLabel() {
        return $this->_label;
    }

    /**
     * Set key object
     *
     * @param mixed $value Key.
     *
     * @return SelectKeyValueObject
     */
    public function setLabel($value): SelectKeyValueObject {
        $this->_label = $value;
        return $this;
    }

    /**
     * Get value object
     *
     * @return mixed
     */
    public function getValue() {
        return $this->_value;
    }

    /**
     * Set value object
     *
     * @param mixed $_value Value.
     *
     * @return SelectKeyValueObject
     */
    public function setValue($_value): SelectKeyValueObject {
        $this->_value = $_value;
        return $this;
    }
}
