<?php

declare(strict_types=1);

namespace Api\Dictionary\Objects;

use Api\Dictionary\Enum\TechnologyEnum;
use Api\Support\BaseCollectObject;

/**
 * Class Trunks
 */
class Trunks extends BaseCollectObject {

    /**
     * Array params
     *
     * @var int[]
     */
    private $_lines = [
        'bri' => 1, 'pri' => 1, 'gsm' => 1, 'fxo' => 1,
    ];

    /**
     * Append a value to collection by format
     *
     * @param array $trunk Array for append.
     *
     * @return void
     */
    public function appendByFormat(array $trunk): void {
        if ($trunk['technology'] === TechnologyEnum::TRUNK) {
            $peername = $trunk['username'];
            if (!empty($trunk['settings_pbx'])) {
                $trunk['settings_pbx'] = json_decode($trunk['settings_pbx'], true);
                if (!empty($trunk['settings_pbx']['peername'])) {
                    $peername = $trunk['settings_pbx']['peername'];
                }
            }
            $explodedUsername = explode('@', $peername);

            if (!empty($trunk['title'])) {
                $this->push($this->makeObjectSelect($trunk['title'] . ' - ' . $peername, $this->escape($explodedUsername[0])));
            } else {
                $this->push($this->makeObjectSelect($peername, $this->escape($explodedUsername[0])));
            }
        } else if (in_array($trunk['technology'], ['bri', 'pri', 'gsm', 'fxo'])) {
            $gwLines = $this->_lines[$trunk['technology']];
            for ($p = 0; $p < $trunk['ports']; $p++) {
                for ($l = 0; $l < $gwLines; $l++) {
                    if ($trunk['technology'] === TechnologyEnum::FXO) {
                        $trunkID   = 'FXO MEDIA GATEWAY ' . str_replace('fxo', '', $trunk['username']) . ' PORT ' . ($p + 1);
                        $trunkName = $trunk['username'] . '_' . $p;
                        $this->push($this->makeObjectSelect($trunkID, $trunkName));
                    } else if ($trunk['technology'] === TechnologyEnum::BRI || $trunk['technology'] === TechnologyEnum::PRI) {
                        $trunkID   = 'ISDN ' . strtoupper($trunk['technology']) . ' MEDIA GATEWAY ' . preg_replace('/(bri|pri)/i', '', $trunk['username']) . ' PORT ' . ($p + 1);
                        $trunkName = $trunk['username'] . '_' . $p . '_' . $l;
                        $this->push($this->makeObjectSelect($trunkID, $trunkName));
                    } else if ($trunk['technology'] === TechnologyEnum::GSM) {
                        $trunkID   = 'GSM MEDIA GATEWAY ' . str_replace('gsm', '', $trunk['username']) . ' PORT ' . ($p + 1);
                        $trunkName = $trunk['username'] . '_' . $p . '_' . $l;
                        $this->push($this->makeObjectSelect($trunkID, $trunkName));
                    } else {
                        $trunkID   = $trunk['username'] . '_' . ($p + 1) . '_' . $l;
                        $trunkName = $trunk['username'] . '_' . $p . '_' . $l;
                        $this->push($this->makeObjectSelect($trunkID, $trunkName));
                    }
                }
            }
        }
    }

    /**
     * Create object for html select data
     *
     * @param string $key   Key.
     * @param string $value Value.
     *
     * @return SelectKeyValueObject
     */
    private function makeObjectSelect(string $key, string $value): SelectKeyValueObject {
        $keyValueObject = new SelectKeyValueObject();
        $keyValueObject
            ->setLabel($key)
            ->setValue($value);
        return $keyValueObject;
    }

    /**
     * Return Escape str
     *
     * @param string $str String.
     *
     * @return string
     */
    private function escape(string $str): string {
        $trans = [' ' => '%20'];
        return strtr($str, $trans);
    }
}
