<?php
declare(strict_types=1);

namespace Api\Dictionary\Repository;

use Api\Dictionary\Enum\AttachFormatsEnum;
use Api\Dictionary\Enum\CallTypesEnum;
use Api\Dictionary\Enum\CauseCodesEnum;
use Api\Dictionary\Enum\ConditionExamplesEnum;
use Api\Dictionary\Enum\DialStatusesEnum;
use Api\Dictionary\Enum\HgStrategiesEnum;
use Api\Dictionary\Enum\UserStatusesEnum;
use Api\Dictionary\Interfaces\DialplanRulesRepositoryInterface;
use Api\Translation\Interfaces\TranslationStrategyInterface;
use Wildix\Databases\Database;
use Api\Translation\Objects\TranslationInterface;

/**
 * Class DialplanRulesRepository
 */
class DictionaryRepository extends Database implements DialplanRulesRepositoryInterface {

    public function __construct(
        protected TranslationInterface $_translateService
    ) {
        $path = self::WILDIX_WMSDB;
        parent::__construct($path);
    }

    public function getCallGroups(): array {
        $sql = 'SELECT id, call_groupname FROM call_groups;';
        return $this->getRows($sql);
    }

    public function getContexts(): array {
        $sql = "SELECT context, ruledescription FROM
            (SELECT DISTINCT rulename AS context, ruledescription AS ruledescription FROM dialplan_rulenames
            UNION SELECT 'pbxinternal' AS context, '' AS ruledescription
            UNION SELECT 'pbxfeatures' AS context, '' AS ruledescription
            UNION SELECT 'pbxservices' AS context, '' AS ruledescription
            UNION SELECT 'internalcalls' AS context, '' AS ruledescription)
            ORDER BY context ASC;";

        return $this->getRows($sql);
    }

    public function getHuntGroups(): array {
        $sql = 'SELECT id, groupname, description FROM outgoing_groups_main;';
        return $this->getRows($sql);
    }

    public function getIvrTrees(): array {
        $sql = "SELECT number FROM ivr_tree WHERE parent_id='0';";
        return $this->getRows($sql);
    }

    public function getPageGroups(): array {
        $sql = 'SELECT id, name FROM paging;';
        return $this->getRows($sql);
    }

    public function getTrunks(): array {
        $sql = "SELECT username, title, 'trunk' AS technology, '1' AS ports, settings_pbx FROM trunks UNION SELECT
                    username, username AS title, technology, ports, '' as settings_pbx FROM pstn_trunks ORDER BY 2;";
        return $this->getRows($sql);
    }

    public function getAttachFormats(): array {
        return AttachFormatsEnum::getEnumValues();
    }

    public function getCallTypes(): array {
        return CallTypesEnum::getEnumValues();
    }

    public function getCauseCodes(): array {
        return CauseCodesEnum::getEnumValues();
    }

    public function getConditionExamples(): array {
        return ConditionExamplesEnum::getEnumValues();
    }

    public function getDialStatuses(): array {
        return DialStatusesEnum::getEnumValues();
    }

    public function getHgStrategies(): array {
        return HgStrategiesEnum::getEnumValues();
    }

    public function getTimeTables(): array {
        $sql = 'SELECT id, timetable FROM `timetable_main`;';
        return $this->getRows($sql);
    }

    public function getUserStatuses(): array {
        return UserStatusesEnum::getEnumValues();
    }

    public function getWms3Switches(): array {
        $sql = "SELECT id, switchname FROM `wmsswitches` WHERE swtype='3';";
        return $this->getRows($sql);
    }

    public function getWmsSwitches(): array {
        $sql = "SELECT id, switchname FROM `wmsswitches` WHERE swtype='0';";
        return $this->getRows($sql);
    }
}
