<?php

namespace Api\Jobs;

use Api\Departments\Interfaces\DepartmentServiceInterface;
use Api\Jobs\Interfaces\JobInterface;
use Wildix\Colleagues\Colleagues;
use Wildix\Colleagues\Groups;

class FillDepartmentField implements JobInterface {

    /**
     * LDAP
     *
     * @var \WMS_Ldap $_ldap
     */
    private $_ldap;

    /**
     * Colleagues
     *
     * @var Colleagues $_colleagues
     */
    private $_colleagues;

    /**
     * Department service
     *
     * @var DepartmentServiceInterface $_departmentService
     */
    private $_departmentService;

    public function __construct(\WMS_Ldap $ldap, Colleagues $colleagues, DepartmentServiceInterface $departmentService) {
        $this->_ldap              = $ldap;
        $this->_colleagues        = $colleagues;
        $this->_departmentService = $departmentService;
    }

    public function run(): bool {
        $colleagues = $this->getLocalColleaguesWithEmptyDepartment();
        if (count($colleagues) === 0) {
            return true;
        }

        foreach ($colleagues as $colleague) {
            $group = Groups::getInstance()->getGroupByDn($colleague->getGroupDn());
            $colleague->setLdapProperty('department', $group->getName());
            $this->colleagues()->updateUser($colleague);
        }

        $this->departmentsService()->clearCache();

        return true;
    }

    private function getLocalColleaguesWithEmptyDepartment(): array {
        $rows = $this->ldap()->getEntriesSortLimit(
            \WMS_Ldap::PERSONS,
            '(!(ou=*))',
            $this->colleagues()->getLdapKeys()
        );

        $result = [];
        foreach ($rows as $row) {
            // skip external synced users
            if (!is_array($row) || $row['uid'] !== $row['sourceId']) {
                continue;
            }

            $result[] = $this->colleagues()->getUserByLdapAttributes($row);
        }

        return $result;
    }

    private function departmentsService(): DepartmentServiceInterface {
        return $this->_departmentService;
    }

    private function ldap(): \WMS_Ldap {
        return $this->_ldap;
    }

    private function colleagues(): Colleagues {
        return $this->_colleagues;
    }
}
