<?php

namespace Api\Network\Builder;

use Api\Network\Interfaces\NetworkFailOverServiceInterface;
use Api\Network\Interfaces\NetworkParticipantBuilderInterface;
use Api\Network\Objects\NetworkParticipant;
use Wildix\PBXes\PBX;

/**
 * Class NetworkParticipantDataBuilder
 */
class NetworkParticipantDataBuilder implements NetworkParticipantBuilderInterface {

    private $_networkParticipant;
    private $_data;

    public function __construct(array $data) {
        $this->_data = $data;
    }

    public function createNetworkParticipant(): void {
        $this->_networkParticipant = new NetworkParticipant();
    }

    public function addIp(): void {
        $this->getNetworkParticipant()->setIp($this->getData(PBX::PUBLIC_IP));
    }

    public function addPort(): void {
        $this->getNetworkParticipant()->setPort((int)$this->getData(PBX::PUBLIC_PORT));
    }

    public function addHost(): void {
        $this->getNetworkParticipant()->setHost($this->getData(PBX::DOMAIN));
    }

    public function addSerial(): void {
        $this->getNetworkParticipant()->setSerial($this->getData(PBX::SERIAL));
    }

    public function addIsServer(): void {
        $this->getNetworkParticipant()->setIsServer($this->getData(PBX::IS_MASTER));
    }

    public function addFailOver(NetworkFailOverServiceInterface $networkFailOverService): void {
        $failOver = $networkFailOverService->getFailOverSerial($this->getData(PBX::SERIAL));

        $this->getNetworkParticipant()->setFailOver($failOver);
    }

    public function addVersion(): void {
        $this->getNetworkParticipant()->setVersion($this->getData('pbxVersion'));
    }

    public function addDn(): void {
        $this->getNetworkParticipant()->setDn($this->getData('dn'));
    }

    public function getNetworkParticipant(): NetworkParticipant {
        return $this->_networkParticipant;
    }

    private function getData(string $field = ''): string {
        return $this->_data[$field] ?? '';
    }
}
