<?php

namespace Api\Network\Builder;

use Api\Network\Interfaces\NetworkFailOverServiceInterface;
use Api\Network\Interfaces\NetworkParticipantBuilderInterface;
use Api\Network\Objects\NetworkParticipant;
use Models\PBX;
use Wildix\PBXes\PBXes;

/**
 * Class NetworkParticipantPbxModelBuilder
 */
class NetworkParticipantPbxModelBuilder implements NetworkParticipantBuilderInterface {

    private $_networkParticipant;
    private $_data;
    private $_pbxes;

    public function __construct(Pbx $data, PBXes $pbxes) {
        $this->_data  = $data;
        $this->_pbxes = $pbxes;
    }

    public function createNetworkParticipant(): void {
        $this->_networkParticipant = new NetworkParticipant();
    }

    public function addIp(): void {
        $ip = $this->getPbxes()->getPBXByDomain($this->getData()->getDomain())->getPublicIp();
        $this->getNetworkParticipant()->setIp($ip);
    }

    public function addPort(): void {
        $port = (int)$this->getPbxes()->getPBXByDomain($this->getData()->getDomain())->getPublicPort();
        $this->getNetworkParticipant()->setPort($port);
    }

    public function addHost(): void {
        $this->getNetworkParticipant()->setHost($this->getData()->getDomain());
    }

    public function addSerial(): void {
        $this->getNetworkParticipant()->setSerial($this->getData()->getSerial());
    }

    public function addIsServer(): void {
        $this->getNetworkParticipant()->setIsServer(false);
    }

    public function addFailOver(NetworkFailOverServiceInterface $networkFailOverService): void {
        $failOver = $networkFailOverService->getFailOverSerial($this->getData()->getSerial());

        $this->getNetworkParticipant()->setFailOver($failOver);
    }

    public function addVersion(): void {
        $this->getNetworkParticipant()->setVersion(explode('~', $this->getData()->getVersion())[0]);
    }

    public function addDn(): void {
        $this->getNetworkParticipant()->setDn($this->getData()->getDn());
    }

    public function getNetworkParticipant(): NetworkParticipant {
        return $this->_networkParticipant;
    }

    private function getPbxes(): PBXes {
        return $this->_pbxes;
    }

    private function getData(): PBX {
        return $this->_data;
    }
}
