<?php
declare(strict_types=1);

namespace Api\Network\Interfaces;

use Api\Network\Repository\NetworkFailOverRepository;
use Api\Network\Repository\NetworkRepository;
use Api\Network\Services\NetworkFailOverService;
use Api\Network\Services\NetworkService;
use Models\PBX;
use multipbx;
use Wildix\DependencyInjection\ConfigInterface;
use Wildix\DependencyInjection\Container;
use Wildix\Failovers\Failovers;
use Wildix\PBXes\PBXes;
use WMS_Ldap;

/**
 * Class DiConfig
 */
class DiConfig implements ConfigInterface {

    public static function configure(Container $container): void {
        $container->singleton(
            NetworkServiceInterface::class,
            function () use ($container) {
                $networkFaiOverService = $container->get(NetworkFailOverServiceInterface::class);
                $pbxex                 = $container->get(PBXes::class);

                return new NetworkService(
                    $container->get(NetworkRepositoryInterface::class),
                    $networkFaiOverService,
                    $pbxex
                );
            }
        );

        $container->singleton(
            NetworkRepositoryInterface::class,
            function () use ($container) {
                $multiPbx = new multipbx();
                $pbx      = $container->get(PBX::class);
                $ldap     = WMS_Ldap::getInstance();

                return new NetworkRepository($multiPbx, $pbx, $ldap);
            }
        );

        $container->singleton(
            NetworkFailOverServiceInterface::class,
            function () use ($container) {
                $repository = $container->get(NetworkFailOverRepositoryInterface::class);
                $ldap       = WMS_Ldap::getInstance();

                return new NetworkFailOverService(
                    $repository,
                    $ldap
                );
            }
        );

        $container->singleton(
            NetworkFailOverRepositoryInterface::class,
            function () use ($container) {
                $failOver = Failovers::getInstance();
                $pbx      = $container->get(PBXes::class);

                return new NetworkFailOverRepository($failOver, $pbx);
            }
        );
    }
}
