<?php
declare(strict_types=1);

namespace Api\Network\Objects;

use Api\Network\Enum\NetworkParticipantResponseFieldsEnum;
use Api\Support\DTOValidate\DTOValidate;
use Api\Support\Interfaces\ArrayableInterface;

/**
 * Class NetworkParticipant
 */
class NetworkParticipant extends DTOValidate implements ArrayableInterface {

    public $ip       = '';
    public $port     = 443;
    public $serial   = '';
    public $host     = '';
    public $isServer = false;
    public $failOver = '';
    public $version  = '';
    public $dn       = '';

    public function getIp(): string {
        return $this->ip;
    }

    public function setIp(string $ip): self {
        $this->ip = $ip;

        return $this;
    }

    public function getSerial(): string {
        return $this->serial;
    }

    public function setSerial(string $serial): self {
        $this->serial = $serial;

        return $this;
    }

    public function getHost(): string {
        return $this->host;
    }

    public function setHost(string $host): self {
        $this->host = $host;

        return $this;
    }

    public function isServer(): bool {
        return $this->isServer;
    }

    public function setIsServer(bool $isServer): self {
        $this->isServer = $isServer;

        return $this;
    }

    public function getPort(): int {
        return $this->port;
    }

    public function setPort(int $port): self {
        if ($port) {
            $this->port = $port;
        }

        return $this;
    }

    public function getFailOver(): string {
        return $this->failOver;
    }

    public function setFailOver(string $failOver): self {
        $this->failOver = $failOver;

        return $this;
    }

    public function getVersion(): string {
        return $this->version;
    }

    public function getDn(): string {
        return $this->dn;
    }

    public function setVersion(string $version): self {
        $this->version = $version;

        return $this;
    }

    public function setDn(string $dn): self {
        $this->dn = $dn;

        return $this;
    }

    public function toArray(): array {
        return [
            NetworkParticipantResponseFieldsEnum::IP => $this->getIp(),
            NetworkParticipantResponseFieldsEnum::SERIAL => $this->getSerial(),
            NetworkParticipantResponseFieldsEnum::HOST => $this->getHost(),
            NetworkParticipantResponseFieldsEnum::IS_SERVER => $this->isServer(),
            NetworkParticipantResponseFieldsEnum::PORT => $this->getPort(),
            NetworkParticipantResponseFieldsEnum::FAIL_OVER => $this->getFailOver(),
            NetworkParticipantResponseFieldsEnum::VERSION => $this->getVersion(),
            NetworkParticipantResponseFieldsEnum::DN => $this->getDn(),
        ];
    }

    public function rules(): array {
        return [
            NetworkParticipantResponseFieldsEnum::IP => 'ip',
            NetworkParticipantResponseFieldsEnum::SERIAL => ['ExistsLdapPbxBySerial', 'string'],
            NetworkParticipantResponseFieldsEnum::HOST => 'DomainOrIp',
            NetworkParticipantResponseFieldsEnum::IS_SERVER => 'boolean',
            NetworkParticipantResponseFieldsEnum::PORT => ['IpPort', 'StrictInteger'],
            NetworkParticipantResponseFieldsEnum::FAIL_OVER => ['ExistsLdapPbxBySerial', 'string'],
            NetworkParticipantResponseFieldsEnum::VERSION => 'string',
            NetworkParticipantResponseFieldsEnum::DN => 'string',
        ];
    }
}
