<?php

namespace Api\Network\Repository;

use Api\Network\Interfaces\NetworkRepositoryInterface;
use Models\PBX as PbxModel;
use multipbx;
use WMS_Ldap;

/**
 * Class NetworkRepository
 */
class NetworkRepository implements NetworkRepositoryInterface {

    private $_multiPbx;
    private $_pbx;
    private $_ldap;

    public function __construct(multipbx $multiPbx, PbxModel $pbx, WMS_Ldap $ldap) {
        $this->_multiPbx = $multiPbx;
        $this->_pbx      = $pbx;
        $this->_ldap     = $ldap;
    }

    public function getCurrentPbx(): PbxModel {
        return $this->_pbx;
    }

    public function getNetworkParticipantsInfo(): array {
        return $this->getMultiPbx()::getAllPbxes();
    }

    public function getCurrentFailOverDn(string $serial): string {
        $failOver = $this->getLdap()->getEntry(WMS_Ldap::FAILOVER, sprintf('(pbxowner=%s)', $this->getLdap()->getDnByPbxSerial($serial)), ['dn']);

        return $failOver['dn'] ?? '';
    }
    public function getCurrentOwnerDn(string $failOverSerial): string {
        $failOver = $this->getLdap()->getEntry(WMS_Ldap::FAILOVER, sprintf('(pbxFailover=%s)', $this->getLdap()->getDnByPbxSerial($failOverSerial)), ['pbxowner']);

        return $failOver['pbxowner'] ?? '';
    }

    public function deleteFailOver(string $failOverDn): bool {
        return $this->getLdap()->deleteEntryByDn($failOverDn);
    }

    public function addFailOver(string $ownerSerial, string $failOverSerial): void {
        $this->getLdap()->addFailover(
            [
                'pbxowner' => $this->getLdap()->getDnByPbxSerial($ownerSerial),
                'pbxFailover' => $this->getLdap()->getDnByPbxSerial($failOverSerial),
                'priority' => 1,
                'enabled' => 1
            ]
        );
    }

    public function deletePbx(string $serial, string $migrateToSerial): void {
        exec(
            sprintf(
                'nohup php /usr/sbin/wms_network_remove_pbx --oldpbx %s --newpbx %s >/dev/null &',
                escapeshellarg($serial),
                escapeshellarg($migrateToSerial)
            )
        );
    }

    public function isMaster(): bool {
        return $this->getCurrentPbx()->isMaster();
    }

    public function getMasterSerial(): string {
        return $this->getMultiPbx()->getNetworkServerPbxSerial();
    }

    private function getMultiPbx(): multipbx {
        return $this->_multiPbx;
    }

    private function getLdap(): WMS_Ldap {
        return $this->_ldap;
    }
}
