<?php

namespace Api\Network\Services;

use Api\Network\Interfaces\NetworkFailOverRepositoryInterface;
use Api\Network\Interfaces\NetworkFailOverServiceInterface;
use Wildix\PBXes\PBX;

/**
 * Class NetworkFailOverService
 */
class NetworkFailOverService implements NetworkFailOverServiceInterface {

    private $_repository;
    private $_ldap;

    public function __construct(
        NetworkFailOverRepositoryInterface $networkFailOverRepository,
        \WMS_Ldap $ldap
    ) {
        $this->_repository = $networkFailOverRepository;
        $this->_ldap       = $ldap;
    }

    public function getFailOverSerial(string $ownerSerial): string {
        $result = '';

        $ownerDn = $this->getLdap()->getDnByPbxSerial($ownerSerial);

        $failOverDn = $this->repository()->getFailOverDn($ownerDn);

        if ($failOverDn) {
            $failOverPbx = $this->getFailOverPbx($failOverDn);

            if ($failOverPbx) {
                $result = $failOverPbx->getSerial();
            }
        }

        return $result;
    }

    public function getFailOverPbx(string $dn): ?PBX {
        return $this->repository()->getFailOverPbx($dn);
    }

    private function repository(): NetworkFailOverRepositoryInterface {
        return $this->_repository;
    }

    public function getLdap(): \WMS_Ldap {
        return $this->_ldap;
    }
}
