<?php
declare(strict_types=1);

namespace Api\Support;

use InvalidArgumentException;

/**
 * Class AbstractEnum
 */
abstract class AbstractEnum {

    static protected $_enums;

    protected $_value;

    public function __construct($type) {
        if (!in_array($type, static::$_enums, true)) {
            throw new InvalidArgumentException(sprintf('%s not in [%s]', $type, implode(',', self::getEnumValues())));
        }
        $this->_value = $type;
    }

    public static function getEnumValues(): array {
        return array_values(static::$_enums);
    }

    public static function getEnumKeys(): array {
        return array_keys(static::$_enums);
    }

    public static function getIdByValue($value) {
        return array_search($value, static::$_enums, true);
    }

    public static function hasId(?int $id): bool {
        return !empty(static::$_enums[$id]);
    }

    public static function hasValue(?string $id): bool {
        return in_array($id, static::$_enums);
    }

    public static function createEnumFromId($id) {
        return new static(static::getValueById($id));
    }

    public static function getValueById($id) {
        return (string)@static::$_enums[$id];
    }

    public static function __callStatic($name, array $arguments = []) {
        return new static(constant('static::' . $name));
    }

    public function isEqual(AbstractEnum $abstractEnum) {
        return $this->getId() === $abstractEnum->getId();
    }

    public function getId() {
        return array_search($this->_value, static::$_enums, true);
    }

    public function isEqualForId($comparableId): bool {
        return $this->getId() === $comparableId;
    }

    public function isEqualForValue($comparableId): bool {
        return $this->getValue() === $comparableId;
    }

    public function getValue() {
        return $this->_value;
    }
}
