<?php
declare(strict_types=1);

namespace Api\Translation\Enums;

use Api\Support\AbstractEnum;

/**
 * Class LanguagesEnum
 */
class LanguagesEnum extends AbstractEnum {

    const DEFAULT_LANG = 'en';
    const SOURCE_WMS   = 'lang/%s/wms.json';
    const SOURCE_COL   = 'lang/%s/collaboration.json';

    public const AM = 'en-US';
    public const BG = 'bg';
    public const DA = 'da';
    public const DE = 'de';
    public const EE = 'et';
    public const EN = 'en';
    public const ES = 'es-ES';
    public const FI = 'fi';
    public const FR = 'fr';
    public const IT = 'it';
    public const NL = 'nl';
    public const NO = 'no';
    public const SE = 'sv-SE';
    public const EU = 'eu';
    public const PT = 'pt-PT';

    protected static $_enums = [
        'american' => self::AM,
        'bulgarian' => self::BG,
        'danish' => self::DA,
        'dutch' => self::NL,
        'english' => self::EN,
        'estonian' => self::EE,
        'finnish' => self::FI,
        'french' => self::FR,
        'german' => self::DE,
        'italian' => self::IT,
        'norwegian' => self::NO,
        'spanish' => self::ES,
        'swedish' => self::SE,
        'basque' => self::EU,
        'portuguese' => self::PT,
        'en-us' => self::AM,
        'bg' => self::BG,
        'da' => self::DA,
        'nl' => self::NL,
        'en' => self::EN,
        'et' => self::EE,
        'ee' => self::EE,
        'fi' => self::FI,
        'fr' => self::FR,
        'de' => self::DE,
        'it' => self::IT,
        'no' => self::NO,
        'es' => self::ES,
        'es-es' => self::ES,
        'es-us' => self::ES,
        'se' => self::SE,
        'eu' => self::EU,
        'pt' => self::PT,
    ];

    public static function am(): LanguagesEnum {
        return new self(self::AM);
    }

    public static function bg(): LanguagesEnum {
        return new self(self::BG);
    }

    public static function da(): LanguagesEnum {
        return new self(self::DA);
    }

    public static function de(): LanguagesEnum {
        return new self(self::DE);
    }

    public static function ee(): LanguagesEnum {
        return new self(self::EE);
    }

    public static function en(): LanguagesEnum {
        return new self(self::EN);
    }

    public static function es(): LanguagesEnum {
        return new self(self::ES);
    }

    public static function fi(): LanguagesEnum {
        return new self(self::FI);
    }

    public static function fr(): LanguagesEnum {
        return new self(self::FR);
    }

    public static function it(): LanguagesEnum {
        return new self(self::IT);
    }

    public static function nl(): LanguagesEnum {
        return new self(self::NL);
    }

    public static function no(): LanguagesEnum {
        return new self(self::NO);
    }

    public static function se(): LanguagesEnum {
        return new self(self::SE);
    }

    public static function eu(): LanguagesEnum {
        return new self(self::EU);
    }

    public static function pt(): LanguagesEnum {
        return new self(self::PT);
    }

    public static function getWmsSourceByCode(string $code = self::DEFAULT_LANG): string {
        $lang = self::getValueById(mb_strtolower($code)) ?: self::DEFAULT_LANG;
        return sprintf(self::SOURCE_WMS, $lang);
    }

    public static function getCollaborationSourceByCode(string $code = self::DEFAULT_LANG): string {
        $lang = self::getValueById(mb_strtolower($code)) ?: self::DEFAULT_LANG;
        return sprintf(self::SOURCE_COL, $lang);
    }

    public static function getWmsDictionaryByCode(string $code = self::DEFAULT_LANG): array {
        $path = BASEPATH . self::getWmsSourceByCode($code);
        $data = [];

        if (is_file($path)) {
            $data = json_decode(file_get_contents($path), true);
        }

        return $data;
    }

    public static function getCollaborationDictionaryByCode(string $code = self::DEFAULT_LANG): array {
        $path = BASEPATH . self::getCollaborationSourceByCode($code);
        $data = [];

        if (is_file($path)) {
            $data = json_decode(file_get_contents($path), true);
        }

        return $data;
    }
}
