<?php
declare(strict_types=1);

namespace Api\Translation\Factory;

use Api\Translation\Enums\LanguagesEnum;
use Api\Translation\Errors\ClassNotFoundException;
use Api\Translation\Interfaces\TranslationStrategyInterface;
use Api\Translation\Objects\TranslationInterface;

/**
 * Class LanguageFactory
 */
class TranslationFactory {
    /**
     * Make language class
     *
     * @param string $language Name of language.
     *
     * @return TranslationStrategyInterface
     *
     * @throws ClassNotFoundException Error.
     */
    public static function make(string $language = LanguagesEnum::DEFAULT_LANG): TranslationStrategyInterface {
        $key = LanguagesEnum::getValueById($language);

        return new TranslationInterface($key);
    }

    public static function getByLang(string $language): TranslationStrategyInterface {
        return self::make(mb_strtolower($language));
    }
}
