<?php
declare(strict_types=1);

namespace Api\Translation\Objects;

use Api\Translation\Enums\LanguagesEnum;
use Api\Translation\Interfaces\TranslationStrategyInterface;

class TranslationInterface implements TranslationStrategyInterface {

    protected $_displayText = [];
    protected $_language    = 'en';

    public function __construct(string $key) {
        $this->_language    = $key;
        $this->_displayText = LanguagesEnum::getWmsDictionaryByCode($key);
    }

    /**
     * Get translation text
     *
     * @param string $phrase Key for translate.
     *
     * @return string
     */
    public function t(string $phrase): string {
        return $this->_displayText[trim($phrase)] ?? trim($phrase);
    }

    public function getDictionary(): array {
        return $this->_displayText;
    }

    public function getCurrentLanguage(): string {
        return $this->_language;
    }
}
