<?php

namespace Api\Trunks\Adapter;

use JsonException;

/**
 * Class JsonAdapter
 * if the array contains json strings, they can be easily converted into an array by passing the names of the json keys
 */
class JsonAdapter {

    /**
     * @var array
     */
    protected $_data;

    /**
     * @var array
     */
    protected $fields;

    /**
     * @var array
     */
    protected $jsonData;

    /**
     * JsonAdapter constructor.
     *
     * @param array $_data  Data for adapt.
     * @param array $fields Name fields.
     */
    public function __construct(array $_data, array $fields) {
        $this->_data    = $_data;
        $this->fields   = $fields;
        $this->jsonData = [];
        $this->convertToArray();
    }

    public function convertToArray(): void {
        foreach ($this->fields as $field) {
            if (array_key_exists($field, $this->_data)) {
                $this->jsonData[$field] = json_decode($this->_data[$field], true);
                if (json_last_error()) {
                    throw new JsonException('JSON decoding error: ' . json_last_error_msg());
                }
            }
        }
    }

    /**
     * @return array
     */
    public function getJsonData(): array {
        return $this->jsonData;
    }

    /**
     * @param string $name
     *
     * @return array|null
     */
    public function __get(string $name): ?array {
        if (array_key_exists($name, $this->jsonData)) {
            return $this->jsonData[$name];
        }
        return null;
    }
}