<?php

declare(strict_types=1);

namespace Api\Trunks\Configs;

use Wildix\Settings\ConfigFile;

/**
 * Class TrunkConfigExtraFile
 */
class TrunkConfigExtraFile extends ConfigFile {

    const LANG_MAP_BY_COUNTRY_CODE = [
        43 => 'de',
        41 => 'de',
    ];

    protected function prepareContent(): string {
        $sipExtra = '';
        if (count($this->getDefault())) {
            foreach ($this->getDefault() as $peername => $params) {
                $explodedPeername = explode('@', (string)$peername);
                $paramsStr        = '[' . \SQLite3::escapeString($explodedPeername[0]) . ']' . PHP_EOL;

                $params['settings_pbx']['language'] = self::LANG_MAP_BY_COUNTRY_CODE[$params['settings_pbx']['country_code']] ?? $params['settings_pbx']['language'];
                foreach ($params['settings_pbx'] as $k => $v) {
                    if ($k == 'transport_wildix' && $v == 'dns-srv') {
                        continue;
                    }
                    if ($k == 'allow') {
                        foreach (explode(',', $v) as $codec) {
                            $paramsStr .= 'allow=' . $codec . PHP_EOL;
                        }
                    } else {
                        if ($k == 'username') {
                            $v = \SQLite3::escapeString($v);
                        }
                        $paramsStr .= $k . '=' . $v . PHP_EOL;
                    }
                }
                $sipExtra .= $paramsStr . PHP_EOL;
                if ($params['register'] != '') {
                    $sipReg .= 'register => ' . $params['register'] . PHP_EOL;
                }
            }
        }

        return $sipExtra;
    }
}
