<?php

namespace Api\Trunks\Fxo\Factory;

use Api\Trunks\Fxo\Enum\FxoTrunkColumnsEnum;
use Api\Trunks\Fxo\Enum\SettingsMgwFieldsEnum;
use Api\Trunks\Fxo\Objects\FxoTrunk;
use Api\Trunks\Fxo\Objects\SettingsMgw;
use Api\Trunks\Fxo\Objects\SettingsMgwPorts;
use Api\Trunks\Fxo\Objects\SettingsPbx;
use Api\Trunks\Pstn\Enum\TrunkColumnsEnum;
use Api\Trunks\Pstn\Transformer\TrunkPortTransformer;
use Wildix\Validator;

class FxoTrunkFactory {

    public static function makeFromRequest($request): FxoTrunk {
        $trunk       = new FxoTrunk($data[TrunkColumnsEnum::ID] ?? 0, $request[TrunkColumnsEnum::USERNAME] ?? '');
        $settingsPbx = new SettingsPbx($request['settings_pbx']);

        $settingsMgw            = new SettingsMgw();
        $settingsMgwFromRequest = $request['settingsMgw'];
        $countryCode            = (int)$settingsMgwFromRequest[SettingsMgwFieldsEnum::COUNTRY_CODE] ?? null;
        $settingsMgw->setBusyToneDetected((bool)$settingsMgwFromRequest['busyToneDetected'])
            ->setCountryCode((int)$countryCode)
            ->setToneZone((string)$settingsMgwFromRequest['toneZone'])
            ->setCurrentDetected((bool)$settingsMgwFromRequest['currentDetected'])
            ->setCurrentDisconnectThreshold((int)$settingsMgwFromRequest['currentDisconnectThreshold'])
            ->setDcImpedance($settingsMgwFromRequest['dcImpedance'])
            ->setFskCidField((int)$settingsMgwFromRequest['fskCidField'])
            ->setImpedance((int)$settingsMgwFromRequest['impedance'])
            ->setPolarityNormalDetected((bool)$settingsMgwFromRequest['polarityNormalDetected'])
            ->setSilenceDetection((int)$settingsMgwFromRequest['silenceDetection'])
            ->setSilenceDetectionEnabled($settingsMgwFromRequest['silenceDetectionEnabled']);

        $settingsMgwPorts = new SettingsMgwPorts();
        ksort($settingsMgwFromRequest);

        foreach ($settingsMgwFromRequest['ports'] as $port => $values) {
            foreach ($values as $key => $value) {
                $castValue = TrunkPortTransformer::castPortParams($key, $value);
                if ($settingsMgwPorts->offsetExists($port)) {
                    $dataPort = array_merge($settingsMgwPorts->offsetGet($port), [$key => $castValue]);
                } else {
                    $dataPort = [
                        'port' => $port, $key => $castValue
                    ];
                }
                $settingsMgwPorts->put($port, $dataPort);
            }
        }
        $settingsMgw->setPorts($settingsMgwPorts);
        $trunk
            ->setTitle(self::buildTrunkTitleByTechnology($request[TrunkColumnsEnum::USERNAME]))
            ->setPorts($settingsMgwPorts->count())
            ->setSettingsPbx($settingsPbx)
            ->setSettingsMgw($settingsMgw);

        return $trunk;
    }

    public static function makeFromStorage($data): FxoTrunk {
        $settingsPbxFromDb = json_decode($data[FxoTrunkColumnsEnum::SETTINGS_PBX], true);
        $settingsMgwFromDb = json_decode($data[TrunkColumnsEnum::SETTINGS_MGW], true);
        $settingsPbx       = new SettingsPbx($settingsPbxFromDb);
        $settingsMgw       = new SettingsMgw();
        $countryCode       = (int)$settingsMgwFromDb[SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::COUNTRY_CODE)] ?? null;

        $settingsMgw->setBusyToneDetected((int)$settingsMgwFromDb['busy_tone_detected'] === 1)
            ->setCountryCode((int)$countryCode)
            ->setToneZone((string)$settingsMgwFromDb['tonezone'])
            ->setCurrentDetected((bool)$settingsMgwFromDb['current_detected'])
            ->setCurrentDisconnectThreshold((int)!in_array($settingsMgwFromDb['current_disconnect_threshold'], [0, null, '', false]) ? $settingsMgwFromDb['current_disconnect_threshold'] : 200)
            ->setDcImpedance($settingsMgwFromDb['dc_impedance'] === 'yes')
            ->setFskCidField((int)$settingsMgwFromDb['fsk_cid_field'])
            ->setImpedance(empty($settingsMgwFromDb['impedance']) ? 1 : $settingsMgwFromDb['impedance'])
            ->setPolarityNormalDetected((bool)$settingsMgwFromDb['polarity_normal_detected'])
            ->setSilenceDetection((int)(!in_array($settingsMgwFromDb['silence_detection'], [0, null, '', false]) ? $settingsMgwFromDb['silence_detection'] : 60))
            ->setSilenceDetectionEnabled(Validator::isTrue($settingsMgwFromDb['silence_detection_enabled']));

        $settingsMgwPorts = new SettingsMgwPorts();
        ksort($settingsMgwFromDb);

        foreach ($settingsMgwFromDb as $key => $values) {
            if (!SettingsMgwFieldsEnum::getValueById($key)) {
                foreach ($values as $port => $value) {
                    $currentPort = ++$port;
                    if ($key == 'port_pinout') {
                        $key = 'pinOut';
                    }
                    $castValue = TrunkPortTransformer::castPortParams($key, $value);
                    if ($settingsMgwPorts->offsetExists($currentPort)) {
                        $dataPort = array_merge($settingsMgwPorts->offsetGet($currentPort), [$key => $castValue]);
                    } else {
                        $dataPort = [
                            'port' => $currentPort, $key => $castValue
                        ];
                    }
                    $settingsMgwPorts->put($currentPort, $dataPort);
                }
            }
        }
        $settingsMgw->setPorts($settingsMgwPorts);
        $trunk = new FxoTrunk($data[TrunkColumnsEnum::ID] ?? 0, $request[TrunkColumnsEnum::USERNAME] ?? '');
        $trunk
            ->setTitle(self::buildTrunkTitleByTechnology($data[TrunkColumnsEnum::USERNAME]))
            ->setUsername($data[TrunkColumnsEnum::USERNAME])
            ->setPorts($data[TrunkColumnsEnum::PORTS] ?? 0)
            ->setSettingsPbx($settingsPbx)
            ->setSettingsMgw($settingsMgw);

        return $trunk;
    }

    private static function buildTrunkTitleByTechnology($userName):string {
        return sprintf('FXO MEDIA GATEWAY %s', preg_replace('/[^0-9]/', '', $userName));
    }
}
