<?php

declare(strict_types=1);

namespace Api\Trunks\Fxo\Objects;

use Api\Support\Interfaces\ArrayableInterface;
use Api\Translation\Interfaces\TrunkInterface;
use Api\Trunks\Pstn\Enum\TrunkRequestFieldsEnum;
use Api\Trunks\Pstn\Enum\TrunkTechnologyEnum;
use Api\Trunks\Pstn\Objects\TrunkFxoStatus;
use Api\Trunks\Sip\Interfaces\TrunkStatusInterface;

/**
 * Class FxoTrunk
 */
class FxoTrunk implements ArrayableInterface, TrunkInterface {

    private $id;
    private $username;
    private $title      = '';
    private $technology = 'fxo';
    private $address;
    private $model;
    private $settingsMgw;
    private $status;

    /**
     * FxoTrunk constructor.
     *
     * @param integer|null $id       Fxo id.
     * @param string|null  $username Fxo user name.
     */
    public function __construct(?int $id, ?string $username) {
        $this->id       = $id;
        $this->username = $username;
    }


    public function isBri(): bool {
        return false;
    }

    public function isPri(): bool {
        return false;
    }

    public function isGsm(): bool {
        return false;
    }

    public function getPorts(): int {
        return $this->_ports;
    }

    public function setPorts(int $ports): self {
        $this->_ports = $ports;
        return $this;
    }

    public function toArray(): array {
        return [
            TrunkRequestFieldsEnum::ID => $this->getId(),
            'username' => $this->getUsername(),
            TrunkRequestFieldsEnum::TITLE => $this->getTitle(),
            TrunkRequestFieldsEnum::TECHNOLOGY => $this->getTechnology(),
            TrunkRequestFieldsEnum::ADDRESS => $this->getAddress(),
            TrunkRequestFieldsEnum::MODEL => $this->getModel(),
            TrunkRequestFieldsEnum::STATUS => $this->getStatus()->toArray(),
            TrunkRequestFieldsEnum::SETTINGS_MGW => $this->getSettingsMgw()->toArray(),
        ];
    }

    public function getModel(): string {
        return (string)$this->model;
    }

    public function setModel(string $model): self {
        $this->model = $model;
        return $this;
    }

    public function getId(): int {
        return $this->id;
    }

    public function setId(int $id): self {
        $this->id = $id;
        return $this;
    }

    public function getUsername(): string {
        return $this->username;
    }

    public function setUsername(string $username): self {
        $this->username = $username;
        return $this;
    }

    public function getTitle(): string {
        return $this->title;
    }

    public function setTitle($title): self {
        $this->title = $title;

        return $this;
    }

    public function getTechnology(): string {
        return (string)$this->technology;
    }

    public function getAddress(): string {
        return (string)$this->address;
    }

    public function setAddress(string $address): self {
        $this->address = $address;

        return $this;
    }

    public function getSettingsPbx(): SettingsPbx {
        return $this->settingsPbx;
    }

    public function setSettingsPbx(SettingsPbx $settingsPbx): self {
        $this->settingsPbx = $settingsPbx;
        return $this;
    }

    public function getSettingsMgw(): SettingsMgw {
        return $this->settingsMgw;
    }

    public function setSettingsMgw(SettingsMgw $settingsMgw): self {
        $this->settingsMgw = $settingsMgw;
        return $this;
    }

    public function getStatus(): TrunkFxoStatus {
        $trunkStatus = new TrunkFxoStatus();
        return $this->status ?? $trunkStatus;
    }

    public function setStatus(TrunkStatusInterface $status): FxoTrunk {
        $this->status = $status;

        return $this;
    }

    public function isFxo(): bool {
        return $this->getTechnology() === TrunkTechnologyEnum::FXO;
    }


    public function getAuthNamesByPorts(): array {
        $result = [];

        foreach ($this->getSettingsMgw()->getPorts() as $index => $port) {
            $result[] = $this->getUsername() . '_' . $index;
        }

        return $result;
    }

    public function generateKamailioSecret($portIndex): string {
        return substr(md5($this->getUsername() . '_' . $portIndex), 0, 7);
    }
}
