<?php

declare(strict_types=1);

namespace Api\Trunks\Fxo\Objects;

use Api\Support\Interfaces\ArrayableInterface;
use Api\Trunks\Fxo\Enum\SettingsMgwFieldsEnum;

class SettingsMgw implements ArrayableInterface {

    private $toneZone;
    private $countryCode;
    private $impedance;
    private $dcImpedance;
    private $fskCidField;
    private $busyToneDetected;
    private $polarityNormalDetected;
    private $currentDetected;
    private $currentDisconnectThreshold;
    private $silenceDetectionEnabled;
    private $silenceDetection;
    private $ports;

    public function isBusyToneDetected(): bool {
        return $this->busyToneDetected;
    }


    public function setBusyToneDetected(bool $busyToneDetected): SettingsMgw {
        $this->busyToneDetected = $busyToneDetected;
        return $this;
    }


    public function isPolarityNormalDetected(): bool {
        return $this->polarityNormalDetected;
    }


    public function setPolarityNormalDetected(bool $polarityNormalDetected): SettingsMgw {
        $this->polarityNormalDetected = $polarityNormalDetected;

        return $this;
    }


    public function isCurrentDetected(): bool {
        return $this->currentDetected;
    }


    public function setCurrentDetected(bool $currentDetected): SettingsMgw {
        $this->currentDetected = $currentDetected;

        return $this;
    }

    public function getCurrentDisconnectThreshold(): int {
        return $this->currentDisconnectThreshold;
    }


    public function setCurrentDisconnectThreshold(int $currentDisconnectThreshold): SettingsMgw {
        $this->currentDisconnectThreshold = $currentDisconnectThreshold;

        return $this;
    }

    public function isSilenceDetectionEnabled(): bool {
        return $this->silenceDetectionEnabled;
    }

    public function setSilenceDetectionEnabled(bool $silenceDetectionEnabled): SettingsMgw {
        $this->silenceDetectionEnabled = $silenceDetectionEnabled;

        return $this;
    }

    public function getSilenceDetection(): int {
        return $this->silenceDetection;
    }

    public function setSilenceDetection(int $silenceDetection): SettingsMgw {
        $this->silenceDetection = $silenceDetection;

        return $this;
    }

    public function getPorts(): SettingsMgwPorts {
        return $this->ports;
    }


    public function setPorts(SettingsMgwPorts $ports): SettingsMgw {
        $this->ports = $ports;

        return $this;
    }


    public function getToneZone(): string {
        return $this->toneZone;
    }


    public function setToneZone(string $toneZone): SettingsMgw {
        $this->toneZone = $toneZone;

        return $this;
    }


    public function getCountryCode(): ?int {
        return $this->countryCode;
    }


    public function setCountryCode(int $countryCode): SettingsMgw {
        $this->countryCode = $countryCode;

        return $this;
    }


    public function getImpedance(): int {
        return $this->impedance;
    }

    public function setImpedance(int $impedance): SettingsMgw {
        $this->impedance = $impedance;

        return $this;
    }


    public function getDcImpedance(): bool {
        return $this->dcImpedance;
    }


    public function setDcImpedance(bool $dcImpedance): SettingsMgw {
        $this->dcImpedance = $dcImpedance;

        return $this;
    }


    public function getFskCidField(): int {
        return $this->fskCidField;
    }


    public function setFskCidField(int $fskCidField): SettingsMgw {
        $this->fskCidField = $fskCidField;

        return $this;
    }

    public function prepareForDb(): array {
        return array_merge(
            [
                "busy_tone_detected"           => $this->isBusyToneDetected() ? '1' : '0',
                "polarity_normal_detected"     => $this->isPolarityNormalDetected() ? '1' : '0',
                "current_detected"             => $this->isCurrentDetected() ? '1' : '0',
                "current_disconnect_threshold" => (string)$this->getCurrentDisconnectThreshold(),
                "silence_detection_enabled"    => $this->isSilenceDetectionEnabled(),
                "silence_detection"            => (string)$this->getSilenceDetection(),
                "tonezone"                     => (string)$this->getToneZone(),
                "country_code"                 => $this->getCountryCode() !== null && $this->getCountryCode() !== 0 ? (string)$this->getCountryCode() : '',
                "impedance"                    => (string)$this->getImpedance(),
                "dc_impedance"                 => $this->getDcImpedance() ? 'yes' : 'no',
                "fsk_cid_field"                => (string)$this->getFskCidField(),
            ],
            $this->getPorts()->prepareForDb()
        );
    }

    public function toArray(): array {
        return [
            "toneZone"                   => $this->getToneZone(),
            "countryCode"                => $this->getCountryCode(),
            "impedance"                  => $this->getImpedance(),
            "dcImpedance"                => $this->getDcImpedance(),
            "fskCidField"                => $this->getFskCidField(),
            "busyToneDetected"           => $this->isBusyToneDetected(),
            "polarityNormalDetected"     => $this->isPolarityNormalDetected(),
            "currentDetected"            => $this->isCurrentDetected(),
            "currentDisconnectThreshold" => $this->getCurrentDisconnectThreshold(),
            "silenceDetectionEnabled"    => $this->isSilenceDetectionEnabled(),
            "silenceDetection"           => $this->getSilenceDetection(),
            SettingsMgwFieldsEnum::PORTS => array_values($this->getPorts()->toArray())
        ];
    }
}
