<?php

declare(strict_types=1);

namespace Api\Trunks\Fxo\Objects;

use Api\Support\BaseCollectObject;

class SettingsMgwPorts extends BaseCollectObject {

    public function setStatus(array $status, int $port) {
        $this->_items[$port]['status'] = $status;
    }

    private function changeKey(&$array, $oldKey, $newKey): array {
        if (! array_key_exists($oldKey, $array)) {
            return $array;
        }
        $keys = array_keys($array);
        $keys[array_search($oldKey, $keys)] = $newKey;
        return array_combine($keys, $array);
    }

    public function toArray(): array {
        foreach ($this->_items as $index => $item) {
            foreach ($item as $key => $value) {
                if ($key === 'port_pricelist') {
                    $newKey = 'priceList';
                } else {
                    $newKey = lcfirst(
                        str_replace(' ', '', ucwords(str_replace('_', ' ', str_replace('port_', '', $key))))
                    );
                }
                $this->_items[$index] = $this->changeKey($this->_items[$index], $key, $newKey);
            }
            $this->_items[$index] = $this->addMissingFields($this->_items[$index]);
        }

        return $this->_items;
    }

    private function addMissingFields(array &$items): array {
        if (!isset($items['destinationCode'])) {
            $items['destinationCode'] = '';
        }
        if (!isset($items['cidType'])) {
            $items['cidType'] = 1;
        }
        if (!isset($items['flashTime'])) {
            $items['flashTime'] = 300;
        }
        if (!isset($items['faxSpeed'])) {
            $items['faxSpeed'] = 1440;
        }
        if (!isset($items['priceList'])) {
            $items['priceList'] = 0;
        }
        return $items;
    }

    public function prepareForDb(): array {
        $data = [];
        foreach ($this->_items as $index => $item) {
            foreach ($item as $key => $value) {
                if ($key !== 'port') {
                    if ($key == 'priceList') {
                        $newKey = 'port_pricelist';
                    } else if ($key == 'pinOut') {
                        $newKey = 'port_pinout';
                    } else {
                        $newKey = 'port_' . strtolower(preg_replace('/(?<!^)[A-Z]/', '_$0', $key));
                    }
                    if ($newKey === 'port_status') {
                        continue;
                    }
                    if (array_key_exists($newKey, $data)) {
                        array_push($data[$newKey], strval($value));
                    } else {
                        $data[$newKey] = [strval($value)];
                    }
                    $data[$newKey] = array_values($data[$newKey]);
                }
            }
        }
        return $data;
    }
}
