<?php

declare(strict_types=1);

namespace Api\Trunks\Fxo\Objects;

use Api\Support\Interfaces\ArrayableInterface;
use Api\Trunks\Fxo\Enum\SettingsPbxFieldsEnum;

class SettingsPbx implements ArrayableInterface {

    private $username = 'username';
    private $insecure = 'very';
    private $host     = 'dynamic';
    private $type     = 'friend';

    public function __construct(array $data = null) {
        if (!empty($data)) {
            $this->setHost($data[SettingsPbxFieldsEnum::HOST] ?? 'dynamic')
                ->setType($data[SettingsPbxFieldsEnum::TYPE] ?? 'very')
                ->setInsecure($data[SettingsPbxFieldsEnum::INSECURE] ?? 'friend')
                ->setUsername($data[SettingsPbxFieldsEnum::USERNAME]);
        }
    }


    public function toArray(): array {
        return [
            SettingsPbxFieldsEnum::HOST     => $this->getHost(),
            SettingsPbxFieldsEnum::USERNAME => $this->getUsername(),
            SettingsPbxFieldsEnum::TYPE     => $this->getType(),
            SettingsPbxFieldsEnum::INSECURE => $this->getInsecure()
        ];
    }

    public function getUsername(): string {
        return $this->username;
    }

    public function setUsername(?string $username): self {
        if ($this->username !== $username && !empty($username)) {
            $this->username = $username;
        }
        return $this;
    }

    public function getInsecure(): string {
        return $this->insecure;
    }

    public function setInsecure(?string $insecure): self {
        if ($this->insecure !== $insecure && !empty($insecure)) {
            $this->insecure = $insecure;
        }
        return $this;
    }

    public function getHost(): string {
        return $this->host;
    }

    public function setHost(?string $host): self {
        if ($this->host !== $host && !empty($host)) {
            $this->host = $host;
        }
        return $this;
    }

    public function getType(): string {
        return $this->type;
    }

    public function setType(?string $type): self {
        if ($this->type !== $type && !empty($type)) {
            $this->type = $type;
        }
        return $this;
    }

    public function prepareForDb(): array {
        return $this->toArray();
    }
}
