<?php
declare(strict_types=1);

namespace Api\Trunks\PriceList\Interfaces;

use Api\Trunks\PriceList\Repository\PriceListCardRepository;
use Api\Trunks\PriceList\Repository\PriceListRepository;
use Api\Trunks\PriceList\Services\PriceListService;
use Wildix\DependencyInjection\ConfigInterface;
use Wildix\DependencyInjection\Container;

/**
 * Class DiConfig
 */
class DiConfig implements ConfigInterface {

    private static $_instancePriceListCardRepository;

    public static function configure(Container $container): void {
        $container->singleton(
            PriceListCardRepositoryInterface::class,
            function () use ($container) {
                if (!isset(self::$_instancePriceListCardRepository)) {
                    self::$_instancePriceListCardRepository = new PriceListCardRepository();
                }
                return self::$_instancePriceListCardRepository;
            }
        );
        $container->singleton(
            PriceListRepositoryInterface::class,
            function () {
                return new PriceListRepository();
            }
        );
        $container->singleton(
            PriceListServiceInterface::class,
            function () use ($container) {
                $repository     = $container->get(PriceListCardRepositoryInterface::class);
                $repositoryRate = $container->get(PriceListRepositoryInterface::class);
                return new PriceListService($repository, $repositoryRate);
            }
        );
    }
}
