<?php

namespace Api\Trunks\PriceList\Repository;

use Api\Trunks\PriceList\Interfaces\PriceListCardRepositoryInterface;
use Api\Trunks\PriceList\Objects\Price;
use Api\Trunks\PriceList\Objects\Prices;
use Wildix\Databases\Database;
use Wildix\Error;
use Wildix\InvalidDataException;

/**
 * Class PriceListCardRepository
 */
class PriceListCardRepository extends Database implements PriceListCardRepositoryInterface {

    private $_table = 'ratecard';

    /**
     * PriceListRepository constructor.
     */
    public function __construct() {
        $path = self::WILDIX_WMSDB;
        parent::__construct($path);
    }

    public function create(string $name): int {
        $this->insert($this->_table, ['ratecard_name' => $name]);
        return $this->getLastInsertId();
    }

    public function update(int $id, array $params): bool {
        $sql = sprintf(
            'UPDATE `%s` SET ratecard_name=\'%s\' WHERE ratecard_id=%s',
            $this->_table,
            $this->realEscapeString($params['name']),
            $id
        );

        return $this->exec($sql);
    }

    public function getAll(): Prices {
        $sql   = sprintf('SELECT ratecard_id, ratecard_name FROM `%s`', $this->_table);
        $rates = new Prices();
        $data  = $this->getRows($sql, null, Price::class);
        foreach ($data as $rate) {
            $rates->push($rate);
        }
        return $rates;
    }

    public function delete(int $id): bool {
        return $this->exec(sprintf('DELETE FROM `%s` WHERE ratecard_id=%s', $this->_table, $id));
    }

    public function findOrFail(int $id): Price {
        $sql   = sprintf('SELECT * FROM `%s` WHERE ratecard_id=%s', $this->_table, $id);
        $price = $this->first($sql);
        if (!$price) {
            throw new InvalidDataException(Error::NotFound, [], 404);
        }

        return new Price($price);
    }

    public function getAllWithout(int $id): Prices {
        $sql   = sprintf('SELECT ratecard_id, ratecard_name FROM `%s` where ratecard_id !=%s', $this->_table, $id);
        $rates = new Prices();
        $data  = $this->getRows($sql, null, Price::class);
        foreach ($data as $rate) {
            $rates->push($rate);
        }

        return $rates;
    }
}
