<?php

namespace Api\Trunks\PriceList\Repository;

use Api\Trunks\PriceList\Interfaces\PriceListRepositoryInterface;
use Api\Trunks\PriceList\Objects\Rate;
use Api\Trunks\PriceList\Objects\Rates;
use Wildix\Databases\Database;
use Wildix\Error;
use Wildix\InvalidDataException;

/**
 * Class PriceListRepository
 */
class PriceListRepository extends Database implements PriceListRepositoryInterface {

    /**
     * Table
     *
     * @var string
     */
    private $_table = 'rate';

    /**
     * PriceListRepository constructor.
     */
    public function __construct() {
        $path = self::WILDIX_WMSDB;
        parent::__construct($path);
    }

    public function delete(int $id): bool {
        return $this->exec(sprintf('DELETE FROM `%s` WHERE ratecard_id=%s', $this->_table, $id));
    }

    public function get(int $id): Rates {
        $items = $this->getRows(sprintf('SELECT * FROM `%s` WHERE ratecard_id=%s', $this->_table, $id), null, Rate::class);
        $rates = new Rates();
        foreach ($items as $item) {
            $rates->push($item);
        }
        return $rates;
    }

    public function findOrFail(int $id): Rates {
        $rates = $this->get($id);
        if ($rates->isEmpty()) {
            throw new InvalidDataException(Error::NotFound, [], 404);
        }
        return $rates;
    }
}
