<?php

declare(strict_types=1);

namespace Api\Trunks\Pstn\Factory;

use Api\Trunks\Pstn\Enum\SettingsMgwFieldsEnum;
use Api\Trunks\Pstn\Enum\SettingsPbxFieldsEnum;
use Api\Trunks\Pstn\Enum\TrunkColumnsEnum;
use Api\Trunks\Pstn\Enum\TrunkTechnologyEnum;
use Api\Trunks\Pstn\Objects\SettingsMgw;
use Api\Trunks\Pstn\Objects\SettingsMgwPorts;
use Api\Trunks\Pstn\Objects\SettingsPbx;
use Api\Trunks\Pstn\Objects\Trunk;
use Api\Trunks\Pstn\Transformer\TrunkPortTransformer;
use Wildix\Validator;

/**
 * Class TrunkFactory
 */
class TrunkFactory {
    public static function make(array $data): Trunk {
        $trunk = new Trunk();

        $settingsPbxFromDb = json_decode($data[TrunkColumnsEnum::SETTINGS_PBX], true);

        $settingsPbx = new SettingsPbx();
        $settingsPbx
            ->setUsername(
                arrayGet($settingsPbxFromDb, SettingsPbxFieldsEnum::getIdByValue(SettingsPbxFieldsEnum::USERNAME), $data[SettingsPbxFieldsEnum::USERNAME])
            )
            ->setPort($settingsPbxFromDb[SettingsPbxFieldsEnum::getIdByValue(SettingsPbxFieldsEnum::PORT)] ?? 0)
            ->setHost(
                arrayGet($settingsPbxFromDb, SettingsPbxFieldsEnum::getIdByValue(SettingsPbxFieldsEnum::HOST), 'dynamic')
            )
            ->setContext($settingsPbxFromDb[SettingsPbxFieldsEnum::getIdByValue(SettingsPbxFieldsEnum::CONTEXT)] ?? '')
            ->setDtmfMode(
                $settingsPbxFromDb[SettingsPbxFieldsEnum::getIdByValue(SettingsPbxFieldsEnum::DTMF_MODE)] ?? ''
            )
            ->setFromUser(
                $settingsPbxFromDb[SettingsPbxFieldsEnum::getIdByValue(SettingsPbxFieldsEnum::FROM_USER)] ?? ''
            )
            ->setInsecure(
                arrayGet($settingsPbxFromDb, SettingsPbxFieldsEnum::getIdByValue(SettingsPbxFieldsEnum::INSECURE), 'very')
            )
            ->setSecret($settingsPbxFromDb[SettingsPbxFieldsEnum::getIdByValue(SettingsPbxFieldsEnum::SECRET)] ?? '')
            ->setType(
                arrayGet($settingsPbxFromDb, SettingsPbxFieldsEnum::getIdByValue(SettingsPbxFieldsEnum::TYPE), 'friend')
            );
        $settingsMgwFromDb = json_decode($data[TrunkColumnsEnum::SETTINGS_MGW], true);

        $settingsMgw = new SettingsMgw();

        $countryCode = $settingsMgwFromDb[SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::COUNTRY_CODE)] ?? null;
        $settingsMgw
            ->setBearerCapG711(
                (int)$settingsMgwFromDb[SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::BEARERCAP_G711)] ?? ''
            )
            ->setBearerCapG729(
                (int)$settingsMgwFromDb[SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::BEARERCAP_G729)] ?? ''
            )
            ->setBusyResponse(
                (int)$settingsMgwFromDb[SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::BUSY_RESPONSE)] ?? ''
            )
            ->setBusyToneDetected(
                $settingsMgwFromDb[SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::BUSY_TONE_DETECTED)] ?? ''
            )
            ->setClockReferencePort(
                $settingsMgwFromDb[SettingsMgwFieldsEnum::getIdByValue(
                    SettingsMgwFieldsEnum::CLOCK_REFERENCE_PORT
                )] ?? ''
            )
            ->setCountryCode(empty($countryCode) ? null : (int)$countryCode)
            ->setCurrentDetected(
                $settingsMgwFromDb[SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::CURRENT_DETECTED)] ?? ''
            )
            ->setCurrentDisconnectThreshold(
                $settingsMgwFromDb[SettingsMgwFieldsEnum::getIdByValue(
                    SettingsMgwFieldsEnum::CURRENT_DISCONNECT_THRESHOLD
                )] ?? ''
            )
            ->setDcImpedance(
                $settingsMgwFromDb[SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::DC_IMPEDANCE)] ?? ''
            )
            ->setDialTone(
                $settingsMgwFromDb[SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::DIALTONE)] ?? ''
            )
            ->setDtmfDebounce(
                $settingsMgwFromDb[SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::DTMF_DEBOUNCE)] ?? ''
            )
            ->setFskCidField(
                $settingsMgwFromDb[SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::FSK_CID_FIELD)] ?? ''
            )
            ->setImpedance(
                $settingsMgwFromDb[SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::IMPEDANCE)] ?? ''
            )
            ->setLanguage(
                $settingsMgwFromDb[SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::LANGUAGE)] ?? ''
            )
            ->setLineType(
                $settingsMgwFromDb[SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::LINE_TYPE)] ?? ''
            )
            ->setPolarityNormalDetected(
                $settingsMgwFromDb[SettingsMgwFieldsEnum::getIdByValue(
                    SettingsMgwFieldsEnum::POLARITY_NORMAL_DETECTED
                )] ?? ''
            )
            ->setPoundSupport(
                $settingsMgwFromDb[SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::POUND_SUPPORT)] ?? false
            )
            ->setPreserveOrigCid(
                ($settingsMgwFromDb[SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::PRESERVE_ORIG_CID)] ?? 'no') === 'yes'
            )
            ->setPriceList(
                $settingsMgwFromDb[SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::PRICELIST)] ?? ''
            )
            ->setSilenceDetection(
                $settingsMgwFromDb[SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::SILENCE_DETECTION)] ?? ''
            )
            ->setSmsDeliveryTries(
                (int)$settingsMgwFromDb[SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::SMS_DELIVERY_TRIES)] ?? ''
            )
            ->setToneZone(
                (string)($settingsMgwFromDb[SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::TONEZONE)] ?? '')
            )
            ->setVoipOutputGain(
                (int)$settingsMgwFromDb[SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::VOIP_OUTPUT_GAIN)] ?? ''
            );
        $silenceDetectionEnabledKey = SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::SILENCE_DETECTION_ENABLED);
        $silenceDetectionEnabledVal = Validator::isTrue($settingsMgwFromDb[$silenceDetectionEnabledKey] ?? false);
        $settingsMgw->setSilenceDetectionEnabled($silenceDetectionEnabledVal);

        $settingsMgwPorts = new SettingsMgwPorts();
        ksort($settingsMgwFromDb);
        foreach ($settingsMgwFromDb as $key => $values) {
            if (!SettingsMgwFieldsEnum::getValueById($key)) {
                foreach ($values as $port => $value) {
                    $currentPort = ++$port;
                    if ($key == 'port_pinout') {
                        $key = 'pinOut';
                    }
                    $castValue = TrunkPortTransformer::castPortParams($key, $value);
                    if ($settingsMgwPorts->offsetExists($currentPort)) {
                        $dataPort = array_merge($settingsMgwPorts->offsetGet($currentPort), [$key => $castValue]);
                    } else {
                        $dataPort = [
                            'port' => $currentPort, $key => $castValue
                        ];
                    }
                    $settingsMgwPorts->put($currentPort, $dataPort);
                }
            }
        }

        $settingsMgw->setPorts($settingsMgwPorts);

        $userName   = $data[TrunkColumnsEnum::USERNAME];
        $technology = $data[TrunkColumnsEnum::TECHNOLOGY];
        $trunk->setTechnology($technology ?? '');

        $voipInputGainField = SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::VOIP_INPUT_GAIN);
        if ($trunk->isGsm()) {
            $settingsMgw->setVoipInputGain(
                isset($settingsMgwFromDb[$voipInputGainField]) ? (int)$settingsMgwFromDb[$voipInputGainField] : 6
            );
        } else {
            $settingsMgw->setVoipInputGain(
                (int)$settingsMgwFromDb[$voipInputGainField] ?? ''
            );
        }

        $trunk
            ->setId($data[TrunkColumnsEnum::ID] ?? 0)
            ->setTitle(self::buildTrunkTitleByTechnology($userName, $technology))
            ->setUsername($userName ?? '')
            ->setPorts($data[TrunkColumnsEnum::PORTS] ?? 0)
            ->setSettingsPbx($settingsPbx)
            ->setSettingsMgw($settingsMgw);

        return $trunk;
    }

    private static function buildTrunkTitleByTechnology($userName, $technology):string {
        $title = '';
        if ($technology == TrunkTechnologyEnum::BRI || $technology == TrunkTechnologyEnum::PRI) {
            $title = sprintf('ISDN %s MEDIA GATEWAY %s', strtoupper($technology), preg_replace('/[^0-9]/', '', $userName));
        } else if ($technology == TrunkTechnologyEnum::FXO) {
            $title = sprintf('FXO MEDIA GATEWAY %s', preg_replace('/[^0-9]/', '', $userName));
        } else if ($technology == TrunkTechnologyEnum::GSM) {
            $title = sprintf('GSM MEDIA GATEWAY %s', preg_replace('/[^0-9]/', '', $userName));
        }
        return $title;
    }
}
