<?php

declare(strict_types=1);

namespace Api\Trunks\Pstn\Factory;

use Api\Trunks\Pstn\Enum\SettingsMgwFieldsEnum;
use Api\Trunks\Pstn\Enum\SettingsPbxFieldsEnum;
use Api\Trunks\Pstn\Enum\TrunkCastPortParamsEnum;
use Api\Trunks\Pstn\Enum\TrunkColumnsEnum;
use Api\Trunks\Pstn\Objects\SettingsMgw;
use Api\Trunks\Pstn\Objects\SettingsMgwPorts;
use Api\Trunks\Pstn\Objects\SettingsPbx;
use Api\Trunks\Pstn\Objects\Trunk;
use Api\Trunks\Pstn\Transformer\TrunkPortTransformer;
use Wildix\Validator;

/**
 * Class TrunkRequestFactory
 */
class TrunkRequestFactory {
    public static function make(array $data): Trunk {
        $trunk = new Trunk();

        $dataSettingsPbx = $data[TrunkColumnsEnum::getIdByValue(TrunkColumnsEnum::SETTINGS_PBX)];

        $settingsPbx = new SettingsPbx();
        $settingsPbx
            ->setUsername((string)$dataSettingsPbx[SettingsPbxFieldsEnum::USERNAME] ?? '')
            ->setPort($dataSettingsPbx[SettingsPbxFieldsEnum::PORT] ?? 0)
            ->setHost($dataSettingsPbx[SettingsPbxFieldsEnum::HOST] ?? 'dynamic')
            ->setContext($dataSettingsPbx[SettingsPbxFieldsEnum::CONTEXT] ?? '')
            ->setDtmfMode($dataSettingsPbx[SettingsPbxFieldsEnum::DTMF_MODE] ?? '')
            ->setFromUser($dataSettingsPbx[SettingsPbxFieldsEnum::FROM_USER] ?? '')
            ->setInsecure($dataSettingsPbx[SettingsPbxFieldsEnum::INSECURE] ?? 'very')
            ->setSecret($dataSettingsPbx[SettingsPbxFieldsEnum::SECRET] ?? '')
            ->setType($dataSettingsPbx[SettingsPbxFieldsEnum::TYPE] ?? 'friend');

        $dataSettingsMgw = $data[TrunkColumnsEnum::getIdByValue(TrunkColumnsEnum::SETTINGS_MGW)];

        $settingsMgw = new SettingsMgw();
        $settingsMgw
            ->setBearerCapG711($dataSettingsMgw[SettingsMgwFieldsEnum::BEARERCAP_G711] ?? '')
            ->setBearerCapG729($dataSettingsMgw[SettingsMgwFieldsEnum::BEARERCAP_G729] ?? '')
            ->setBusyResponse($dataSettingsMgw[SettingsMgwFieldsEnum::BUSY_RESPONSE] ?? '')
            ->setBusyToneDetected($dataSettingsMgw[SettingsMgwFieldsEnum::BUSY_TONE_DETECTED] ?? '')
            ->setClockReferencePort($dataSettingsMgw[SettingsMgwFieldsEnum::CLOCK_REFERENCE_PORT] ?? '')
            ->setCountryCode($dataSettingsMgw[SettingsMgwFieldsEnum::COUNTRY_CODE])
            ->setCurrentDetected($dataSettingsMgw[SettingsMgwFieldsEnum::CURRENT_DETECTED] ?? '')
            ->setCurrentDisconnectThreshold($dataSettingsMgw[SettingsMgwFieldsEnum::CURRENT_DISCONNECT_THRESHOLD] ?? '')
            ->setDcImpedance($dataSettingsMgw[SettingsMgwFieldsEnum::DC_IMPEDANCE] ?? '')
            ->setDialTone($dataSettingsMgw[SettingsMgwFieldsEnum::DIALTONE] ?? '')
            ->setDtmfDebounce($dataSettingsMgw[SettingsMgwFieldsEnum::DTMF_DEBOUNCE] ?? '')
            ->setFskCidField($dataSettingsMgw[SettingsMgwFieldsEnum::FSK_CID_FIELD] ?? '')
            ->setImpedance($dataSettingsMgw[SettingsMgwFieldsEnum::IMPEDANCE] ?? '')
            ->setLanguage($dataSettingsMgw[SettingsMgwFieldsEnum::LANGUAGE] ?? '')
            ->setLineType($dataSettingsMgw[SettingsMgwFieldsEnum::LINE_TYPE] ?? '')
            ->setPolarityNormalDetected($dataSettingsMgw[SettingsMgwFieldsEnum::POLARITY_NORMAL_DETECTED] ?? '')
            ->setPoundSupport($dataSettingsMgw[SettingsMgwFieldsEnum::POUND_SUPPORT] ?? false)
            ->setPreserveOrigCid($dataSettingsMgw[SettingsMgwFieldsEnum::PRESERVE_ORIG_CID] ?? false)
            ->setPriceList($dataSettingsMgw[SettingsMgwFieldsEnum::PRICELIST] ?? '')
            ->setSilenceDetection($dataSettingsMgw[SettingsMgwFieldsEnum::SILENCE_DETECTION] ?? '')
            ->setSilenceDetectionEnabled(Validator::isTrue($dataSettingsMgw[SettingsMgwFieldsEnum::SILENCE_DETECTION_ENABLED] ?? false))
            ->setSmsDeliveryTries((string)$dataSettingsMgw[SettingsMgwFieldsEnum::SMS_DELIVERY_TRIES] ?? '')
            ->setToneZone($dataSettingsMgw[SettingsMgwFieldsEnum::TONEZONE] ?? '')
            ->setVoipInputGain((string)$dataSettingsMgw[SettingsMgwFieldsEnum::VOIP_INPUT_GAIN] ?? '')
            ->setVoipOutputGain((string)$dataSettingsMgw[SettingsMgwFieldsEnum::VOIP_OUTPUT_GAIN] ?? '');

        $trunk
            ->setTitle($data['title'])
            ->setUsername($settingsPbx->getUsername() ?? '')
            ->setTechnology(strtolower($data[TrunkColumnsEnum::TECHNOLOGY]) ?? '')
            ->setPorts($data[TrunkColumnsEnum::PORTS] ?? 1);
        if ($trunk->isGsm()) {
            foreach ($dataSettingsMgw[SettingsMgwFieldsEnum::PORTS] as $port => $value) {
                if (!isset($dataSettingsMgw[SettingsMgwFieldsEnum::PORTS][$port]['email'])) {
                    $dataSettingsMgw[SettingsMgwFieldsEnum::PORTS][$port]['email'] = '';
                }
                if (!isset($dataSettingsMgw[SettingsMgwFieldsEnum::PORTS][$port]['smsc'])) {
                    $dataSettingsMgw[SettingsMgwFieldsEnum::PORTS][$port]['smsc'] = '';
                }
            }
        }

        $settingsMgw->setPorts(self::makePorts($dataSettingsMgw[SettingsMgwFieldsEnum::PORTS], $trunk));

        return $trunk
            ->setSettingsPbx($settingsPbx)
            ->setSettingsMgw($settingsMgw);
    }

    private static function makePorts($data, $trunk) {
        $settingsMgwPorts = new SettingsMgwPorts();
        foreach ($data as $key => $value) {
            $value = array_filter(
                $value,
                function ($key) use ($trunk) {
                    return !($key === TrunkCastPortParamsEnum::LINE_FRAMING && $trunk->isBri());
                },
                ARRAY_FILTER_USE_KEY
            );

            $value = array_filter(
                $value,
                function ($key) use ($trunk) {
                    return !($key == TrunkCastPortParamsEnum::PIN_OUT && ($trunk->isBri()));
                },
                ARRAY_FILTER_USE_KEY
            );

            $value = array_filter(
                $value,
                function ($key) use ($trunk) {
                    return !($key == TrunkCastPortParamsEnum::CONNECTION_TYPE && $trunk->isPri());
                },
                ARRAY_FILTER_USE_KEY
            );
            foreach ($value as $portKey => $portValue) {
                $value[$portKey] = TrunkPortTransformer::castPortParamsForDb($portKey, $portValue);
            }
            unset($value['status']);
            $settingsMgwPorts->put($key, $value);
        }

        return $settingsMgwPorts;
    }
}
