<?php

declare(strict_types=1);

namespace Api\Trunks\Pstn\Interfaces;

use Api\Device\Interfaces\DeviceRepositoryInterface;
use Api\Trunks\Interfaces\TrunkConfigCwServiceInterface;
use Api\Trunks\Interfaces\TrunkRepositoryInterface;
use Api\Trunks\PriceList\Interfaces\PriceListCardRepositoryInterface;
use Api\Trunks\Pstn\Repository\PeerRepository;
use Api\Trunks\Pstn\Services\PeerService;
use Api\Trunks\Pstn\Services\PstnTrunkService;
use Logger\Log;
use PBX;
use Wildix\DependencyInjection\ConfigInterface;
use Wildix\DependencyInjection\Container;
use Wildix\SipProxy;

/**
 * Class DiConfig
 */
class DiConfig implements ConfigInterface {

    private static $_instancePeerRepository;

    public static function configure(Container $container): void {
        $container->singleton(
            PstnTrunkServiceInterface::class,
            function () use ($container) {
                return new PstnTrunkService(
                    $container->get(TrunkRepositoryInterface::class),
                    $container->get(DeviceRepositoryInterface::class),
                    $container->get(PeerServiceInterface::class),
                    $container->get(TrunkConfigCwServiceInterface::class),
                    $container->get(PriceListCardRepositoryInterface::class),
                    $container->get(SipProxy::class),
                    $container->get(Log::class),
                    PBX::getInstance()
                );
            }
        );

        $container->singleton(
            PeerServiceInterface::class,
            function () use ($container) {
                return new PeerService(
                    $container->get(PeerRepositoryInterface::class)
                );
            }
        );

        $container->singleton(
            PeerRepositoryInterface::class,
            function () use ($container) {
                if (!isset(self::$_instancePeerRepository)) {
                    self::$_instancePeerRepository = new PeerRepository();
                }
                return self::$_instancePeerRepository;
            }
        );
    }
}
