<?php

declare(strict_types=1);

namespace Api\Trunks\Pstn\Objects;

use Api\Support\Interfaces\ArrayableInterface;
use Api\Trunks\Pstn\Enum\SettingsMgwFieldsEnum;

/**
 * Class SettingsMgw
 */
class SettingsMgw implements ArrayableInterface {

    private $_ports;

    private $_clockReferencePort;
    private $_poundSupport;
    private $_preserveOrigCid;
    private $_dialTone;
    private $_countryCode;
    private $_language;
    private $_busyResponse;
    private $_smsDeliveryTries;
    private $_dtmfDebounce;
    private $_priceList;
    private $_bearerCapG711;
    private $_bearerCapG729;
    private $_voipInputGain;
    private $_voipOutputGain;
    private $_silenceDetectionEnabled;
    private $_silenceDetection;
    private $_lineType;
    private $_impedance;
    private $_dcImpedance;
    private $_toneZone;
    private $_fskCidField;
    private $_currentDisconnectThreshold;
    private $_busyToneDetected;
    private $_polarityNormalDetected;
    private $_currentDetected;

    public function toArray(): array {
        return [
                SettingsMgwFieldsEnum::CURRENT_DETECTED => $this->getCurrentDetected(),
                SettingsMgwFieldsEnum::POLARITY_NORMAL_DETECTED => $this->getPolarityNormalDetected(),
                SettingsMgwFieldsEnum::BUSY_TONE_DETECTED => $this->getBusyToneDetected(),
                SettingsMgwFieldsEnum::CURRENT_DISCONNECT_THRESHOLD => $this->getCurrentDisconnectThreshold(),
                SettingsMgwFieldsEnum::FSK_CID_FIELD => $this->getFskCidField(),
                SettingsMgwFieldsEnum::TONEZONE => $this->getToneZone(),
                SettingsMgwFieldsEnum::DC_IMPEDANCE => $this->getDcImpedance(),
                SettingsMgwFieldsEnum::IMPEDANCE => $this->getImpedance(),
                SettingsMgwFieldsEnum::LINE_TYPE => $this->getLineType(),
                SettingsMgwFieldsEnum::SILENCE_DETECTION => $this->getSilenceDetection(),
                SettingsMgwFieldsEnum::SILENCE_DETECTION_ENABLED => $this->getSilenceDetectionEnabled(),
                SettingsMgwFieldsEnum::VOIP_OUTPUT_GAIN => $this->getVoipOutputGain(),
                SettingsMgwFieldsEnum::VOIP_INPUT_GAIN => $this->getVoipInputGain(),
                SettingsMgwFieldsEnum::BEARERCAP_G729 => $this->getBearerCapG729(),
                SettingsMgwFieldsEnum::BEARERCAP_G711 => $this->getBearerCapG711(),
                SettingsMgwFieldsEnum::PRICELIST => $this->getPriceList(),
                SettingsMgwFieldsEnum::DTMF_DEBOUNCE => $this->getDtmfDebounce(),
                SettingsMgwFieldsEnum::SMS_DELIVERY_TRIES => $this->getSmsDeliveryTries(),
                SettingsMgwFieldsEnum::BUSY_RESPONSE => $this->getBusyResponse(),
                SettingsMgwFieldsEnum::LANGUAGE => $this->getLanguage(),
                SettingsMgwFieldsEnum::COUNTRY_CODE => $this->getCountryCode(),
                SettingsMgwFieldsEnum::DIALTONE => $this->getDialTone(),
                SettingsMgwFieldsEnum::PRESERVE_ORIG_CID => $this->getPreserveOrigCid(),
                SettingsMgwFieldsEnum::POUND_SUPPORT => $this->getPoundSupport(),
                SettingsMgwFieldsEnum::CLOCK_REFERENCE_PORT => $this->getClockReferencePort(),
                SettingsMgwFieldsEnum::PORTS => array_values($this->getPorts()->toArray())
            ];
    }

    public function prepareForDb(): array {
        return array_merge(
            [
                SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::CURRENT_DETECTED) => $this->getCurrentDetected(),
                SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::POLARITY_NORMAL_DETECTED) => $this->getPolarityNormalDetected(),
                SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::BUSY_TONE_DETECTED) => $this->getBusyToneDetected(),
                SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::CURRENT_DISCONNECT_THRESHOLD) => $this->getCurrentDisconnectThreshold(),
                SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::FSK_CID_FIELD) => $this->getFskCidField(),
                SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::TONEZONE) => $this->getToneZone(),
                SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::DC_IMPEDANCE) => $this->getDcImpedance(),
                SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::IMPEDANCE) => $this->getImpedance(),
                SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::LINE_TYPE) => $this->getLineType(),
                SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::SILENCE_DETECTION) => $this->getSilenceDetection(),
                SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::SILENCE_DETECTION_ENABLED) => $this->getSilenceDetectionEnabled(),
                SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::VOIP_OUTPUT_GAIN) => (string)$this->getVoipOutputGain(),
                SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::VOIP_INPUT_GAIN) => (string)$this->getVoipInputGain(),
                SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::BEARERCAP_G729) => (string)$this->getBearerCapG729(),
                SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::BEARERCAP_G711) => (string)$this->getBearerCapG711(),
                SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::PRICELIST) => $this->getPriceList(),
                SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::DTMF_DEBOUNCE) => $this->getDtmfDebounce(),
                SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::SMS_DELIVERY_TRIES) => $this->getSmsDeliveryTries(),
                SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::BUSY_RESPONSE) => $this->getBusyResponse(),
                SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::LANGUAGE) => $this->getLanguage(),
                SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::COUNTRY_CODE) => (string)$this->getCountryCode(),
                SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::DIALTONE) => $this->getDialTone(),
                SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::PRESERVE_ORIG_CID) => $this->getPreserveOrigCid() ? 'yes' : 'no',
                SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::POUND_SUPPORT) => $this->getPoundSupport() ? '1' : '0',
                SettingsMgwFieldsEnum::getIdByValue(SettingsMgwFieldsEnum::CLOCK_REFERENCE_PORT) => (string)$this->getClockReferencePort(),
            ],
            $this->getPorts()->prepareForDb()
        );
    }

    public function getClockReferencePort(): int {
        return (int)$this->_clockReferencePort;
    }

    public function setClockReferencePort($clockReferencePort): self {
        $this->_clockReferencePort = $clockReferencePort;
        return $this;
    }

    public function getPoundSupport(): bool {
        return (bool)$this->_poundSupport;
    }

    public function setPoundSupport($poundSupport): self {
        $this->_poundSupport = $poundSupport;
        return $this;
    }

    public function getPreserveOrigCid(): bool {
        return $this->_preserveOrigCid;
    }

    public function setPreserveOrigCid($preserveOrigCid): self {
        $this->_preserveOrigCid = (bool)$preserveOrigCid;
        return $this;
    }

    public function getDialTone(): string {
        return $this->_dialTone;
    }

    public function setDialTone($dialTone): self {
        $this->_dialTone = (string)$dialTone;
        return $this;
    }

    public function getCountryCode(): ?int {
        return $this->_countryCode;
    }

    public function setCountryCode($countryCode): self {
        $this->_countryCode = $countryCode;
        return $this;
    }

    public function getLanguage(): string {
        return $this->_language;
    }

    public function setLanguage($language): self {
        $this->_language = $language;
        return $this;
    }

    public function getBusyResponse(): int {
        return (int)$this->_busyResponse;
    }

    public function setBusyResponse($busyResponse): self {
        $this->_busyResponse = $busyResponse;
        return $this;
    }

    public function getSmsDeliveryTries(): int {
        return (int)$this->_smsDeliveryTries;
    }

    public function setSmsDeliveryTries($smsDeliveryTries): self {
        $this->_smsDeliveryTries = $smsDeliveryTries;
        return $this;
    }

    public function getDtmfDebounce(): string {
        return $this->_dtmfDebounce;
    }

    public function setDtmfDebounce($dtmfDebounce): self {
        $this->_dtmfDebounce = (string)$dtmfDebounce;
        return $this;
    }

    public function getPriceList(): string {
        return $this->_priceList;
    }

    public function setPriceList($priceList): self {
        $this->_priceList = $priceList;
        return $this;
    }

    public function getBearerCapG711(): int {
        return (int)$this->_bearerCapG711;
    }

    public function setBearerCapG711($bearerCapG711): self {
        $this->_bearerCapG711 = $bearerCapG711;
        return $this;
    }

    public function getBearerCapG729(): int {
        return (int)$this->_bearerCapG729;
    }

    public function setBearerCapG729($bearerCapG729): self {
        $this->_bearerCapG729 = $bearerCapG729;
        return $this;
    }

    public function getVoipInputGain(): int {
        return (int)$this->_voipInputGain;
    }

    public function setVoipInputGain($voipInputGain): self {
        $this->_voipInputGain = $voipInputGain;
        return $this;
    }

    public function getVoipOutputGain(): int {
        return (int)$this->_voipOutputGain;
    }

    public function setVoipOutputGain($voipOutputGain): self {
        $this->_voipOutputGain = $voipOutputGain;
        return $this;
    }

    public function getSilenceDetectionEnabled(): bool {
        return $this->_silenceDetectionEnabled;
    }

    public function setSilenceDetectionEnabled(bool $silenceDetectionEnabled): self {
        $this->_silenceDetectionEnabled = $silenceDetectionEnabled;
        return $this;
    }

    public function getSilenceDetection(): string {
        return $this->_silenceDetection;
    }

    public function setSilenceDetection($silenceDetection): self {
        $this->_silenceDetection = $silenceDetection;
        return $this;
    }

    public function getLineType(): string {
        return $this->_lineType;
    }

    public function setLineType($lineType): self {
        $this->_lineType = (string)$lineType;
        return $this;
    }

    public function getImpedance(): string {
        return $this->_impedance;
    }

    public function setImpedance($impedance): self {
        $this->_impedance = $impedance;
        return $this;
    }

    public function getDcImpedance(): string {
        return $this->_dcImpedance;
    }

    public function setDcImpedance($dcImpedance): self {
        $this->_dcImpedance = $dcImpedance;
        return $this;
    }

    public function getToneZone(): string {
        return $this->_toneZone;
    }

    public function setToneZone($toneZone): self {
        $this->_toneZone = (string)$toneZone;
        return $this;
    }

    public function getFskCidField(): string {
        return $this->_fskCidField;
    }

    public function setFskCidField($fskCidField): self {
        $this->_fskCidField = $fskCidField;
        return $this;
    }

    public function getCurrentDisconnectThreshold(): string {
        return $this->_currentDisconnectThreshold;
    }

    public function setCurrentDisconnectThreshold($currentDisconnectThreshold): self {
        $this->_currentDisconnectThreshold = $currentDisconnectThreshold;
        return $this;
    }

    public function getBusyToneDetected(): string {
        return $this->_busyToneDetected;
    }

    public function setBusyToneDetected($busyToneDetected): self {
        $this->_busyToneDetected = $busyToneDetected;
        return $this;
    }

    public function getPolarityNormalDetected(): string {
        return $this->_polarityNormalDetected;
    }

    public function setPolarityNormalDetected($polarityNormalDetected): self {
        $this->_polarityNormalDetected = $polarityNormalDetected;
        return $this;
    }

    public function getCurrentDetected(): string {
        return $this->_currentDetected;
    }

    public function setCurrentDetected($currentDetected): self {
        $this->_currentDetected = $currentDetected;
        return $this;
    }

    public function getPorts(): SettingsMgwPorts {
        return $this->_ports;
    }

    public function setPorts(SettingsMgwPorts $ports): self {
        $this->_ports = $ports;
        return $this;
    }
}
