<?php

declare(strict_types=1);

namespace Api\Trunks\Pstn\Objects;

use Api\Support\Interfaces\ArrayableInterface;
use Api\Trunks\Pstn\Enum\SettingsPbxFieldsEnum;

/**
 * Class SettingsPbx
 */
class SettingsPbx implements ArrayableInterface {

    private $_username;
    private $_host;
    private $_port;
    private $_context;
    private $_type;
    private $_secret;
    private $_fromUser;
    private $_insecure;
    private $_dtmfMode;

    public function toArray(): array {
        return [
            SettingsPbxFieldsEnum::USERNAME => $this->getUsername(),
            SettingsPbxFieldsEnum::TYPE => $this->getType(),
            SettingsPbxFieldsEnum::SECRET => $this->getSecret(),
            SettingsPbxFieldsEnum::INSECURE => $this->getInsecure(),
            SettingsPbxFieldsEnum::FROM_USER => $this->getFromUser(),
            SettingsPbxFieldsEnum::DTMF_MODE => $this->getDtmfMode(),
            SettingsPbxFieldsEnum::CONTEXT => $this->getContext(),
            SettingsPbxFieldsEnum::HOST => $this->getHost(),
            SettingsPbxFieldsEnum::PORT => $this->getPort(),
        ];
    }

    public function prepareForDb(): array {
        return [
            SettingsPbxFieldsEnum::getIdByValue(SettingsPbxFieldsEnum::USERNAME) => $this->getUsername(),
            SettingsPbxFieldsEnum::getIdByValue(SettingsPbxFieldsEnum::TYPE) => $this->getType(),
            SettingsPbxFieldsEnum::getIdByValue(SettingsPbxFieldsEnum::SECRET) => $this->getSecret(),
            SettingsPbxFieldsEnum::getIdByValue(SettingsPbxFieldsEnum::INSECURE) => $this->getInsecure(),
            SettingsPbxFieldsEnum::getIdByValue(SettingsPbxFieldsEnum::FROM_USER) => $this->getFromUser(),
            SettingsPbxFieldsEnum::getIdByValue(SettingsPbxFieldsEnum::DTMF_MODE) => $this->getDtmfMode(),
            SettingsPbxFieldsEnum::getIdByValue(SettingsPbxFieldsEnum::CONTEXT) => $this->getContext(),
            SettingsPbxFieldsEnum::getIdByValue(SettingsPbxFieldsEnum::HOST) => $this->getHost(),
            SettingsPbxFieldsEnum::getIdByValue(SettingsPbxFieldsEnum::PORT) => $this->getPort(),
        ];
    }

    public function getUsername(): string {
        return $this->_username;
    }

    public function setUsername(string $username): self {
        $this->_username = $username;
        return $this;
    }

    public function getHost(): string {
        return $this->_host;
    }

    public function setHost(string $host): self {
        $this->_host = $host;
        return $this;
    }

    public function getPort(): int {
        return $this->_port;
    }

    public function setPort(int $port): self {
        $this->_port = $port;
        return $this;
    }

    public function getContext(): string {
        return $this->_context;
    }

    public function setContext(string $context): self {
        $this->_context = $context;
        return $this;
    }

    public function getType(): string {
        return $this->_type;
    }

    public function setType(string $type): self {
        $this->_type = $type;
        return $this;
    }

    public function getSecret(): string {
        return $this->_secret;
    }

    public function setSecret(string $secret): self {
        $this->_secret = $secret;
        return $this;
    }

    public function getFromUser(): string {
        return $this->_fromUser;
    }

    public function setFromUser(string $fromUser): self {
        $this->_fromUser = $fromUser;
        return $this;
    }

    public function getInsecure(): string {
        return $this->_insecure;
    }

    public function setInsecure(string $insecure): self {
        $this->_insecure = $insecure;
        return $this;
    }

    public function getDtmfMode(): string {
        return $this->_dtmfMode;
    }

    public function setDtmfMode(string $dtmfMode): self {
        $this->_dtmfMode = $dtmfMode;
        return $this;
    }
}
