<?php

declare(strict_types=1);

namespace Api\Trunks\Pstn\Objects;

use Api\Support\Interfaces\ArrayableInterface;
use Api\Translation\Interfaces\TrunkInterface;
use Api\Trunks\Pstn\Enum\TrunkRequestFieldsEnum;
use Api\Trunks\Pstn\Enum\TrunkTechnologyEnum;
use Api\Trunks\Sip\Interfaces\TrunkStatusInterface;

/**
 * Class Trunk
 */
class Trunk implements ArrayableInterface, TrunkInterface {

    private $_id;
    private $_title;
    private $_username;
    private $_technology;
    private $_ports;
    private $_settingsPbx;
    private $_settingsMgw;
    private $_status;
    private $_deviceMap;
    private $_address;

    public function getAddress():string {
        return (string)$this->_address;
    }

    public function setAddress(string $address): Trunk {
        $this->_address = $address;

        return $this;
    }


    public function getId(): int {
        return $this->_id;
    }

    public function setId(int $id): self {
        $this->_id = $id;
        return $this;
    }

    public function getUsername(): string {
        return $this->_username;
    }

    public function setUsername(string $username): self {
        $this->_username = $username;
        return $this;
    }

    public function getTechnology(): string {
        return $this->_technology;
    }

    public function setTechnology(string $technology): self {
        $this->_technology = $technology;
        return $this;
    }

    public function getPorts(): int {
        return $this->_ports;
    }

    public function setPorts(int $ports): self {
        $this->_ports = $ports;
        return $this;
    }

    public function getSettingsPbx(): SettingsPbx {
        return $this->_settingsPbx;
    }

    public function setSettingsPbx(SettingsPbx $settingsPbx): self {
        $this->_settingsPbx = $settingsPbx;
        return $this;
    }

    public function getSettingsMgw(): SettingsMgw {
        return $this->_settingsMgw;
    }

    public function setSettingsMgw(SettingsMgw $settingsMgw): self {
        $this->_settingsMgw = $settingsMgw;
        return $this;
    }

    public function isFxo(): bool {
        return $this->getTechnology() === TrunkTechnologyEnum::FXO;
    }

    public function isBri(): bool {
        return $this->getTechnology() === TrunkTechnologyEnum::BRI;
    }

    public function isPri(): bool {
        return $this->getTechnology() === TrunkTechnologyEnum::PRI;
    }

    public function isGsm(): bool {
        return $this->getTechnology() === TrunkTechnologyEnum::GSM;
    }

    public function toArray(): array {
        return [
            TrunkRequestFieldsEnum::ID => $this->getId(),
            TrunkRequestFieldsEnum::USERNAME => $this->getUsername(),
            TrunkRequestFieldsEnum::TITLE => $this->getTitle(),
            TrunkRequestFieldsEnum::TECHNOLOGY => $this->getTechnology(),
            TrunkRequestFieldsEnum::PORTS => $this->getPorts(),
            TrunkRequestFieldsEnum::SETTINGS_PBX => $this->getSettingsPbx()->toArray(),
            TrunkRequestFieldsEnum::SETTINGS_MGW => $this->getSettingsMgw()->toArray(),
            TrunkRequestFieldsEnum::STATUS => $this->getStatus()->toArray(),
            TrunkRequestFieldsEnum::ADDRESS => $this->getAddress(),
        ];
    }

    public function setStatus(TrunkStatusInterface $status): Trunk {
        $this->_status = $status;
        return $this;
    }

    public function getStatus(): TrunkStatusInterface {
        $trunkStatus = new TrunkIsdnStatus();
        return $this->_status ?? $trunkStatus;
    }

    /**
     * Get _deviceMap
     *
     * @return mixed
     */
    public function getDeviceMap(): array {
        return is_array($this->_deviceMap) ? $this->_deviceMap : [];
    }

    public function setDeviceMap(array $deviceMap): Trunk {
        $this->_deviceMap = $deviceMap;

        return $this;
    }

    /**
     * Get _title
     *
     * @return mixed
     */
    public function getTitle() {
        return $this->_title;
    }

    /**
     * Set _title
     *
     * @param mixed $title Title trunk.
     *
     * @return Trunk
     */
    public function setTitle($title): Trunk {
        $this->_title = $title;

        return $this;
    }

    public function getAuthNamesByPorts(): array {
        $result = [];

        foreach ($this->getSettingsMgw()->getPorts() as $index => $port) {
            $result[] = $this->getUsername() . '_' . $index . '_0';
        }

        return $result;
    }

    public function generateKamailioSecret($portIndex): string {
        return substr(md5($this->getUsername() . '_' . $portIndex), 0, 7);
    }
}
