<?php

declare(strict_types=1);

namespace Api\Trunks\Pstn\Objects;

use Api\Trunks\Sip\Interfaces\TrunkStatusInterface;

/**
 * Class TrunkGsmStatus
 */
class TrunkGsmStatus implements TrunkStatusInterface {

    /**
     * Status
     *
     * @var boolean
     */
    private $_status = false;

    private $_signalLevel = 0;

    private $_wgsm = false;

    private $_title = '';

    private $_supportSignalLevel = false;

    public function toJson($options = 0) {
        json_encode($this->toArray(), $options);
    }

    public function toArray(): array {
        return [
            'active'                => $this->isStatus(),
            'signal'                => $this->getSignalLevel(),
            'wgsm'                  => $this->isWgsm(),
            'title'                 => $this->getTitle(),
            'signalLevelSupported'  => $this->isSignalLevelSupport()
        ];
    }

    /**
     * Get status
     *
     * @return boolean
     */
    public function isStatus(): bool {
        return $this->_status;
    }

    /**
     * Set status
     *
     * @param boolean $_status Status.
     *
     * @return TrunkGsmStatus
     */
    public function setStatus(bool $_status): TrunkGsmStatus {
        $this->_status = $_status;

        return $this;
    }

    /**
     * Get _signalLevel
     *
     * @return integer
     */
    public function getSignalLevel(): int {
        return $this->_signalLevel;
    }

    /**
     * Set signal
     *
     * @param integer $signalLevel Signal level.
     *
     * @return TrunkGsmStatus
     */
    public function setSignalLevel(int $signalLevel): TrunkGsmStatus {
        $this->_signalLevel = $signalLevel;

        return $this;
    }

    /**
     * Get _wgsm
     *
     * @return boolean
     */
    public function isWgsm(): bool {
        return $this->_wgsm;
    }

    /**
     * Set wgsm type
     *
     * @param boolean $wgsm Is wgsm.
     *
     * @return TrunkGsmStatus
     */
    public function setWgsm(bool $wgsm): TrunkGsmStatus {
        $this->_wgsm = $wgsm;

        return $this;
    }

    /**
     * Set whether trunk's device support signal level
     *
     * @param boolean $supportSignalLevel Is support signal level.
     *
     * @return TrunkGsmStatus
     */
    public function setSignalLevelSupport(bool $supportSignalLevel): TrunkGsmStatus {
        $this->_supportSignalLevel = $supportSignalLevel;

        return $this;
    }


    /**
     * Get _supportSignalLevel
     *
     * @return boolean
     */
    public function isSignalLevelSupport(): bool {
        return $this->_supportSignalLevel;
    }

    /**
     * Get _title
     *
     * @return string
     */
    public function getTitle(): string {
        return $this->_title;
    }

    public function setTitle(string $title): TrunkGsmStatus {
        $this->_title = $title;

        return $this;
    }
}
