<?php

declare(strict_types=1);

namespace Api\Trunks\Pstn\Repository;

use Api\Trunks\Pstn\Interfaces\PeerRepositoryInterface;
use Wildix\Databases\Database;

/**
 * Class PeerRepository
 */
class PeerRepository extends Database implements PeerRepositoryInterface {

    private $_staticPeersTable  = 'static_peers';
    private $_dynamicPeersTable = 'dynamic_peers';

    private $_peers;

    public function __construct() {
        $path = self::WILDIX_HTABLES;
        parent::__construct($path);
    }

    public function setStaticPeerType(): PeerRepositoryInterface {
        $this->_peers = $this->_staticPeersTable;
        return $this;
    }

    public function setDynamicPeerType(): PeerRepositoryInterface {
        $this->_peers = $this->_dynamicPeersTable;
        return $this;
    }

    public function delete(int $id): bool {
        return $this->exec(sprintf('DELETE FROM `%s` WHERE `wms_id`=%d', $this->getPeersTable(), $id));
    }

    public function create(int $id, string $keyName, string $keyValue): int {
        $this->insert(
            $this->getPeersTable(),
            [
                'key_name' => $keyName,
                'key_value' => $keyValue,
                'wms_id' => $id,
            ]
        );
        return $this->getLastInsertId();
    }

    public function reloadPeers(): void {
        exec(sprintf('sudo /usr/sbin/kamcmd htable.reload %s', $this->getPeersTable()));
    }

    private function getPeersTable(): string {
        return $this->_peers;
    }
}
