<?php

declare(strict_types=1);

namespace Api\Trunks\Pstn\Services;

use Api\Trunks\Pstn\Interfaces\PeerRepositoryInterface;
use Api\Trunks\Pstn\Interfaces\PeerServiceInterface;

/**
 * Class PeerService
 */
class PeerService implements PeerServiceInterface {

    private $_peerRepository;

    public function __construct(
        PeerRepositoryInterface $peerRepository
    ) {
        $this->_peerRepository = $peerRepository;
    }

    public function delete(int $id): bool {
        $this->deleteStaticPeer($id);
        $this->deleteDynamicPeer($id);
        return true;
    }

    public function deleteStaticPeer(int $id): bool {
        return $this->getPeerRepository()->setStaticPeerType()->delete($id);
    }

    public function deleteDynamicPeer(int $id): bool {
        return $this->getPeerRepository()->setDynamicPeerType()->delete($id);
    }

    public function createStaticPeer(int $id, string $keyName, string $keyValue):int {
            return $this->getPeerRepository()->setStaticPeerType()->create($id, $keyName, $keyValue);
    }

    public function createDynamicPeer(int $id, string $keyName, string $keyValue):int {
        return $this->getPeerRepository()->setDynamicPeerType()->create($id, $keyName, $keyValue);
    }

    public function storeIp(): void {
        exec('curl -X POST --url http://127.0.0.1:5060/v1/trunks/static/ip/store/');
    }

    public function reloadPeers(): void {
        $this->getPeerRepository()->setStaticPeerType()->reloadPeers();
        $this->getPeerRepository()->setDynamicPeerType()->reloadPeers();
    }

    public function getPeerRepository(): PeerRepositoryInterface {
        return $this->_peerRepository;
    }
}
