<?php

declare(strict_types=1);

namespace Api\Trunks\Sip\Builder;

use Api\Trunks\Sip\Objects\SettingsKamailio;
use Api\Trunks\Sip\Objects\SettingsPbx;
use Api\Trunks\Sip\Objects\SettingsWms;

/**
 * Class SettingsKamailioBuilder
 */
class SettingsKamailioBuilder {

    const DEFAULT_OUTBOUND_PROXY_PORT = '5060';

    public static function build(?SettingsPbx $settingsPbx, ?SettingsWms $settingsWms): SettingsKamailio {
        $settingsKamailio = new SettingsKamailio();

        if ($settingsPbx->isDynamicHost()) {
            $settingsKamailio
                ->setUsername(trim($settingsPbx->getUserName()))
                ->setHost($settingsPbx->getHost())
                ->setPort((string)$settingsPbx->getPort())
                ->setContext($settingsPbx->getContext())
                ->setSecret($settingsPbx->getSecret())
                ->setFromUser($settingsPbx->getFromUser())
                ->setPeerName($settingsPbx->getPeerName());
        } else {
            $settingsKamailio
                ->setHost($settingsPbx->getHost())
                ->setOutboundProxy($settingsWms->getOutboundProxy())
                ->setOutboundProxyPort((string)$settingsWms->getOutboundProxyPort())
                ->setUseRport($settingsPbx->getRport());

            if ($settingsPbx->isDnsServer()) {
                $settingsKamailio->setTransport(strtoupper($settingsPbx->getTransportWildix()));
            }

            if (!empty($settingsKamailio->getOutboundProxy()) && empty($settingsKamailio->getOutboundProxyPort())) {
                $settingsKamailio->setOutboundProxyPort(self::DEFAULT_OUTBOUND_PROXY_PORT);
            }
        }

        if (!empty($settingsPbx->getUserName())) {
            $settingsKamailio->setAuthName($settingsPbx->getUserName());
        }

        $settingsKamailio->setNatIp($settingsWms->getNatIp());

        $forceSrtp = (int)$settingsPbx->getForceSrtp();
        $settingsKamailio->setForceSrtp((string)$forceSrtp);

        return $settingsKamailio;
    }
}
