<?php

declare(strict_types=1);

namespace Api\Trunks\Sip\Factory;

use Api\Trunks\Sip\Objects\SettingsPbx;

/**
 * Class SettingsPbxFactory
 */
class SettingsPbxFactory {

    public static function extJsonDecode($str, $mode = false): string {
        $str = preg_replace('/([{,])(\s*)([A-Za-z0-9_\-]+?)\s*:/', '$1"$3":', $str);
        $str = str_replace(' ', '', $str);
        $str = str_replace('\t', '', $str);
        $str = str_replace('\r', '', $str);
        $str = str_replace('\l', '', $str);
        $str = preg_replace('/s+/', '', $str);

        return json_decode($str, $mode);
    }

    /**
     * Make settings object
     *
     * @param array $settings Data.
     *
     * @return SettingsPbx Return SettingsPbx object.
     */
    public static function make(array $settings): SettingsPbx {
        $settingsPbx = new SettingsPbx();
        $data        = json_decode($settings['settings_pbx'], true);

        $settingsPbx
            ->setPriceList((int)($data['pricelist'] ?? 0))
            ->setPeerName((string)$data['peername'])
            ->setUserName((string)$data['username'])
            ->setFromUser((string)($data['fromuser'] ?? ''))
            ->setFromDomain((string)($data['fromdomain'] ?? ''))
            ->setHost((string)$data['host'])
            ->setPort((string)($data['port'] ?? ''))
            ->setSecret((string)($data['secret'] ?? ''))
            ->setContext((string)$data['context'])
            ->setToneZone((string)($data['tonezone'] ?? ''))
            ->setCountryCode(isset($data['country_code']) ? (int)$data['country_code'] : null)
            ->setFromNumber((string)($data['fromnumber'] ?? ''))
            ->setFromName((string)($data['fromname'] ?? ''))
            ->setCidHeader((string)($data['cidheader'] ?? ''))
            ->setCidBody((string)($data['cidbody'] ?? ''))
            ->setTrustRpid($data['trustrpid'] == 'yes')
            ->setPrivacyHeader((string)($data['privacyheader'] ?? ''))
            ->setDiversionHeader((string)($data['diversion_header'] ?? ''))
            ->setHistoryInfoHeader((string)($data['historyinfo_header'] ?? ''))
            ->setPreserveOrigCid($data['preserve_orig_cid'] == 'yes')
            ->setAllowTransfer($data['allowtransfer'] == 'on')
            ->setSessionTimer($data['session_timer'] == 'on')
            ->setSessionMinse((int)$data['session-minse'])
            ->setSessionExpires((int)$data['session-expires']);
        $settingsPbx
            ->setThirtyEightString((string)$data['t38pt_udptl'])
            ->setSsrcChange($data['ssrcchange'] === 'no')
            ->setRport((string)$data['rport'])
            ->setForceSrtp($data['force_srtp'] == 'yes')
            ->setTransportWildix((string)$data['transport_wildix'])
            ->setDtmfMode((string)$data['dtmfmode'])
            ->setRfcPayload(isset($data['rfc2833payload']) ? (int)$data['rfc2833payload'] : 101)
            ->setType((string)$data['type'])
            ->setLanguage((string)($data['language'] ?? ''))
            ->setQualify($data['qualify'] == 'yes')
            ->setInsecure((string)$data['insecure'])
            ->setSymmetricRtp($data['symmetric_rtp'] == 'yes')
            ->setDisallow((string)$data['disallow'])
            ->setAllow((string)$data['allow'])
            ->setAudioCodecsFromAllow((string)$data['allow'])
            ->setVideoCodecsFromAllow((string)$data['allow'])
            ->setPlayRemoteMoh(($data['play_remote_moh'] ?? '') === 'on')
            ->setContactNumber((string)$data['contactnumber']);

        return $settingsPbx;
    }
}
