<?php

declare(strict_types=1);

namespace Api\Trunks\Sip\Objects;

use Api\Support\Interfaces\ArrayableInterface;

/**
 * Class SettingsKamailio
 */
class SettingsKamailio implements ArrayableInterface {

    /**
     * Auth Login
     *
     * @var string
     */
    private $_username;

    /**
     * Host Name
     *
     * @var string
     */
    private $_host;

    /**
     * Port
     *
     * @var string
     */
    private $_port;

    /**
     * Dialplan
     *
     * @var string
     */
    private $_context;

    /**
     * Password
     *
     * @var string
     */
    private $_secret;

    /**
     * From user
     *
     * @var string
     */
    private $_fromUser;

    /**
     * Trunk name
     *
     * @var string
     */
    private $_peerName;

    /**
     * Get Auth Login
     *
     * @var string
     */
    private $_authName;

    /**
     * NAT IP
     *
     * @var string
     */
    private $_natIp;

    /**
     * Outbound proxy
     *
     * @var string
     */
    private $_outboundProxy;

    /**
     * Outbound proxy port
     *
     * @var string
     */
    private $_outboundProxyPort = '';

    /**
     * Use Rport
     *
     * @var string
     */
    private $_useRport;

    /**
     * Transport
     *
     * @var string
     */
    private $_transport;

    /**
     * SDES-SRTP
     *
     * @var string
     */
    private $_forceSrtp;

    /**
     * Get Outbound proxy
     *
     * @return string
     */
    public function getOutboundProxyPort(): string {
        return $this->_outboundProxyPort ?? '';
    }

    /**
     * Set Outbound proxy
     *
     * @param string $outboundProxy Outbound proxy.
     *
     * @return SettingsKamailio
     */
    public function setOutboundProxyPort(string $outboundProxy): SettingsKamailio {
        $this->_outboundProxyPort = $outboundProxy;

        return $this;
    }

    public function toArray(): array {
        return [
            'username' => $this->getUsername(),
            'host' => $this->getHost(),
            'port' => $this->getPort(),
            'context' => $this->getContext(),
            'secret' => $this->getSecret(),
            'fromuser' => $this->getFromUser(),
            'peername' => $this->getPeerName(),
            'authname' => $this->getAuthName(),
            'natip' => $this->getNatIp(),
            'outboundproxy' => $this->getOutboundProxy(),
            'outboundproxy_port' => $this->getOutboundProxyPort(),
            'use_rport' => $this->getUseRport(),
            'transport' => $this->getTransport(),
            'force_srtp' => $this->getForceSrtp(),
        ];
    }

    /**
     * Get Username
     *
     * @return string
     */
    public function getUsername(): string {
        return $this->_username ?? '';
    }

    /**
     * Set Username
     *
     * @param string $username Username.
     *
     * @return SettingsKamailio
     */
    public function setUsername(string $username): SettingsKamailio {
        $this->_username = $username;

        return $this;
    }

    /**
     * Get Host Name
     *
     * @return string
     */
    public function getHost(): string {
        return $this->_host ?? '';
    }

    /**
     * Set Host Name
     *
     * @param string $host Host Name.
     *
     * @return SettingsKamailio
     */
    public function setHost(string $host): SettingsKamailio {
        $this->_host = $host;

        return $this;
    }

    /**
     * Get Port
     *
     * @return string
     */
    public function getPort(): string {
        return $this->_port ?? '';
    }

    /**
     * Port
     *
     * @param string $port Port.
     *
     * @return SettingsKamailio
     */
    public function setPort(string $port): SettingsKamailio {
        $this->_port = $port;

        return $this;
    }

    /**
     * Get Dialplan
     *
     * @return string
     */
    public function getContext(): string {
        return $this->_context ?? '';
    }

    /**
     * Set Dialplan
     *
     * @param string $context Dialplan.
     *
     * @return SettingsKamailio
     */
    public function setContext(string $context): SettingsKamailio {
        $this->_context = $context;

        return $this;
    }

    /**
     * Get Password
     *
     * @return string
     */
    public function getSecret(): string {
        return $this->_secret ?? '';
    }

    /**
     * Set Password
     *
     * @param string $secret Password.
     *
     * @return SettingsKamailio
     */
    public function setSecret(string $secret): SettingsKamailio {
        $this->_secret = $secret;

        return $this;
    }

    /**
     * Get From user
     *
     * @return string
     */
    public function getFromUser(): string {
        return $this->_fromUser ?? '';
    }

    /**
     * Set From user
     *
     * @param string $fromUser From user.
     *
     * @return SettingsKamailio
     */
    public function setFromUser(string $fromUser): SettingsKamailio {
        $this->_fromUser = $fromUser;

        return $this;
    }

    /**
     * Get Trunk name
     *
     * @return string
     */
    public function getPeerName(): string {
        return $this->_peerName ?? '';
    }

    /**
     * Set Trunk name
     *
     * @param string $peerName Trunk name.
     *
     * @return SettingsKamailio
     */
    public function setPeerName(string $peerName): SettingsKamailio {
        $this->_peerName = $peerName;

        return $this;
    }

    /**
     * Get Auth name
     *
     * @return string
     */
    public function getAuthName(): string {
        return $this->_authName ?? '';
    }

    /**
     * Set Auth name
     *
     * @param string $authName Auth name.
     *
     * @return SettingsKamailio
     */
    public function setAuthName(string $authName): SettingsKamailio {
        $this->_authName = $authName;

        return $this;
    }

    /**
     * Get NAT IP
     *
     * @return string
     */
    public function getNatIp(): string {
        return $this->_natIp ?? '';
    }

    /**
     * Set NAT IP
     *
     * @param string $natIp NAT IP.
     *
     * @return SettingsKamailio
     */
    public function setNatIp(string $natIp): SettingsKamailio {
        $this->_natIp = $natIp;

        return $this;
    }

    /**
     * Get Outbound proxy port
     *
     * @return string
     */
    public function getOutboundProxy(): string {
        return $this->_outboundProxy ?? '';
    }

    /**
     * Set Outbound proxy port
     *
     * @param string $outboundProxyPort Outbound proxy port.
     *
     * @return SettingsKamailio
     */
    public function setOutboundProxy(string $outboundProxyPort): SettingsKamailio {
        $this->_outboundProxy = $outboundProxyPort;

        return $this;
    }

    /**
     * Get Use Rport
     *
     * @return string
     */
    public function getUseRport(): string {
        return $this->_useRport ?? '';
    }

    /**
     * Set Use Rport
     *
     * @param string $useRport Rport.
     *
     * @return SettingsKamailio
     */
    public function setUseRport(string $useRport): SettingsKamailio {
        $this->_useRport = $useRport;

        return $this;
    }

    /**
     * Get Transport
     *
     * @return string
     */
    public function getTransport(): string {
        return $this->_transport ?? '';
    }

    /**
     * Set Transport
     *
     * @param string $transport Transport.
     *
     * @return SettingsKamailio
     */
    public function setTransport(string $transport): SettingsKamailio {
        $this->_transport = $transport;

        return $this;
    }

    /**
     * Get SDES-SRTP
     *
     * @return string
     */
    public function getForceSrtp(): string {
        return $this->_forceSrtp ?? '0';
    }

    /**
     * Set SDES-SRTP
     *
     * @param string $forceSrtp SDES-SRTP.
     *
     * @return SettingsKamailio
     */
    public function setForceSrtp(string $forceSrtp): SettingsKamailio {
        $this->_forceSrtp = $forceSrtp;

        return $this;
    }
}
