<?php

declare(strict_types=1);

namespace Api\Trunks\Sip\Objects;

use Api\Support\Interfaces\ArrayableInterface;
use Api\Trunks\Sip\Interfaces\TrunkStatusInterface;
use Wildix\Trunks\SipTrunks\Trunk as TrunkModel;

/**
 * Class Trunk
 */
class Trunk implements ArrayableInterface {

    /**
     * Id
     *
     * @var int
     */
    private $_id;

    /**
     * User name
     *
     * @var string
     */
    private $_username;

    /**
     * Title
     *
     * @var string
     */
    private $_title;

    /**
     * Register
     *
     * @var string
     */
    private $_register;

    /**
     * Settings Pbx
     *
     * @var SettingsPbx
     */
    private $_settingsPbx;

    /**
     * Settings Wms
     *
     * @var SettingsWms
     */
    private $_settingsWms;

    /**
     * Sip Status
     *
     * @var TrunkStatusInterface
     */
    private $_sipStatus;

    public function toArray(): array {
        return [
            TrunkModel::FIELD_ID => $this->getId(),
            TrunkModel::FIELD_REGISTER => $this->getRegister(),
            TrunkModel::FIELD_SETTINGS_PBX => $this->getSettingsPbx()->toArray(),
            TrunkModel::FIELD_SETTINGS_WMS => $this->getSettingsWms()->toArray(),
            TrunkModel::FIELD_TITLE => $this->getTitle(),
            TrunkModel::FIELD_USERNAME => $this->getUsername(),
            TrunkModel::FIELD_STATUS => $this->getSipStatus()->toArray(),
        ];
    }

    /**
     * Get ID
     *
     * @return integer
     */
    public function getId(): int {
        return $this->_id;
    }

    /**
     * Set ID
     *
     * @param integer $id ID.
     *
     * @return Trunk
     */
    public function setId(int $id): Trunk {
        $this->_id = $id;

        return $this;
    }

    /**
     * Get Register
     *
     * @return string
     */
    public function getRegister(): string {
        return $this->_register;
    }

    /**
     * Set Register
     *
     * @param string $register Register.
     *
     * @return Trunk
     */
    public function setRegister(string $register): Trunk {
        $this->_register = $register;

        return $this;
    }

    /**
     * Get Settings Pbx
     *
     * @return SettingsPbx
     */
    public function getSettingsPbx(): SettingsPbx {
        return $this->_settingsPbx;
    }

    /**
     * Set Settings Pbx
     *
     * @param SettingsPbx $settingsPbx Settings Pbx.
     *
     * @return Trunk
     */
    public function setSettingsPbx(SettingsPbx $settingsPbx): Trunk {
        $this->_settingsPbx = $settingsPbx;

        return $this;
    }

    /**
     * Get SettingsWms
     *
     * @return SettingsWms
     */
    public function getSettingsWms(): SettingsWms {
        return $this->_settingsWms;
    }

    /**
     * Set Settings Wms
     *
     * @param SettingsWms $settingsWms Settings Wms.
     *
     * @return Trunk
     */
    public function setSettingsWms(SettingsWms $settingsWms): Trunk {
        $this->_settingsWms = $settingsWms;

        return $this;
    }

    /**
     * Get Title
     *
     * @return string
     */
    public function getTitle(): string {
        return $this->_title;
    }

    /**
     * Set Title
     *
     * @param string $title Title.
     *
     * @return Trunk
     */
    public function setTitle(string $title): Trunk {
        $this->_title = $title;

        return $this;
    }

    /**
     * Get Username
     *
     * @return string
     */
    public function getUsername(): string {
        return $this->_username;
    }

    /**
     * Set Username
     *
     * @param string $username Username.
     *
     * @return Trunk
     */
    public function setUsername(string $username): Trunk {
        $this->_username = $username;

        return $this;
    }

    /**
     * Get _sipStatus
     *
     * @return TrunkStatusInterface
     */
    public function getSipStatus(): TrunkStatusInterface {
        $statusDefault = new TrunkSipStatus();
        return $this->_sipStatus ?? $statusDefault;
    }

    /**
     * Set sSip status
     *
     * @param TrunkStatusInterface $sipStatus Sip status.
     *
     * @return $this
     */
    public function setSipStatus(TrunkStatusInterface $sipStatus): Trunk {
        $this->_sipStatus = $sipStatus;

        return $this;
    }
}
