<?php

declare(strict_types=1);

namespace Api\Trunks\Sip\Objects;

use Api\Trunks\Sip\Interfaces\TrunkStatusInterface;

/**
 * Class SipStatus
 */
class TrunkSipStatus implements TrunkStatusInterface {

    const STATE_OFF          = 'off';
    const STATE_ON           = 'on';
    const STATE_UNREGISTERED = 'unregistered';

    private $_incoming = [
        'state' => self::STATE_UNREGISTERED,
        'title' => 'Unregistered'
    ];
    private $_outgoing = [
        'state' => self::STATE_UNREGISTERED,
        'title' => 'Unregistered'
    ];

    public function toJson($options = 0) {
        return json_encode($this->toArray(), $options);
    }

    public function toArray(): array {
        return [
            'outgoing' => $this->getOutgoing(),
            'incoming' => $this->getIncoming(),
        ];
    }

    /**
     * Get outgoing
     *
     * @return array
     */
    public function getOutgoing(): array {
        return $this->_outgoing;
    }

    /**
     * Set outgoing status
     *
     * @param array $_outgoing Outgoing status.
     *
     * @return TrunkSipStatus
     */
    public function setOutgoing(array $_outgoing): TrunkSipStatus {
        $this->_outgoing = $_outgoing;

        return $this;
    }

    /**
     * Get incoming
     *
     * @return array
     */
    public function getIncoming(): array {
        return $this->_incoming;
    }

    /**
     * Set incoming status
     *
     * @param array $_incoming Incoming.
     *
     * @return TrunkSipStatus
     */
    public function setIncoming(array $_incoming): TrunkSipStatus {
        $this->_incoming = $_incoming;

        return $this;
    }
}
