<?php

namespace Cache;


/**
 * Class FileCache
 */
interface FileCacheInterface {

    /**
     * Set cache.
     *
     * @param string  $key        Cache key.
     * @param mixed   $data       Cached data.
     * @param integer $expiration Ttl for cache in second.
     * @param string  $group      Cache group.
     *
     * @return void
     */
    public function set(string $key, $data, int $expiration, string $group = ''): void;

    /**
     * Get cache.
     *
     * @param string $key   Cache key.
     * @param string $group Cache group.
     *
     * @return boolean
     */
    public function get(string $key, string $group = '');

    public function getKeyRawData(string $key, string $group = '');

    /**
     * Get created time for cache.
     *
     * @param string $key   Cache key.
     * @param string $group Cache group.
     *
     * @return false|integer
     */
    public function getCacheCreatedTime(string $key, string $group = '');

    public function delete(string $key, string $group = '');

    /**
     * Real TTL for cache.
     *
     * @param integer $realTtl Real TTL.
     *
     * @return void
     */
    public function setRealTtl(int $realTtl): void;

    /**
     * Try set lock for cache.
     *
     * @param string $key   Cache key.
     * @param string $group Cache group.
     *
     * @return boolean
     */
    public function setLock(string $key, string $group = ''): bool;

    /**
     * Remove lock.
     *
     * @param string $file Cache file.
     *
     * @return void
     */
    public function removeLock(string $file): void;

    public function clear(string $group): void;
    public function useCompressing(bool $compress = true): void;
}
