<?php

namespace Logger\Formatter;

/**
 * Class SingleLine
 */
class SingleLine implements IFormatterInterface {

    /**
     * Formatting message array.
     *
     * @param array $message Message array.
     *
     * @return string
     */
    public function getMessage(array $message) {
        $result = '';

        if (!empty($message['message'])) {
            $result .= $message['message'] . '. ';
        }

        if (!empty($message['context']) && is_object($message['context']) && method_exists($message['context'], 'asArray')) {
            $message['context'] = $message['context']->asArray();

            foreach ($message['context'] as $key => $value) {
                $result .= $key . ': ' . $value . '; ';
            }
        }

        unset($key, $value, $message['message'], $message['context']);

        foreach ($message as $key => $value) {
            $result .= $key . ': ' . $this->_mixedToString($value);
        }

        return $result;
    }

    private function _mixedToString($value): string {
        if (!isset($value)) {
            return 'null; ';
        }

        if (is_scalar($value)) {
            return $value . '; ';
        }

        if (is_object($value) && !$value instanceof \stdClass) {
            return '~Object > ' . get_class($value) . '~; ';
        }

        if (is_resource($value)) {
            return '~Resource > ' . get_resource_type($value) . '~; ';
        }

        $result = '{';

        foreach ($value as $key => $val) {
            $result .= $key . ' => ' . $this->_mixedToString($val);
        }

        $result .= '}; ';

        return $result;
    }
}
