<?php

namespace Logger;

/**
 * Class LoggerFactory which returns only one instance of logger.
 */
class LoggerFactory {

    /**
     * Log instance.
     *
     * @var Log
     */
    private static $_logger;

    /**
     * Returns Log instance.
     *
     * @return Log
     */
    public static function getInstance(): Log {
        if (self::$_logger === null) {
            $writer    = new \Logger\Writer\SysLog('wms');
            $formatter = new \Logger\Formatter\SingleLine();
            $context   = self::buildContext();

            self::$_logger = new Log($writer, $formatter, $context);
        }

        return self::$_logger;
    }

    public static function buildContext(): Context {
        $context = new \Logger\Context(
            [
                'RequestId' => self::generateId()
            ]
        );

        if (strpos(PHP_SAPI, 'cgi') !== false) {
            $remoteIp   = $_SERVER['REMOTE_ADDR'];
            $remotePort = $_SERVER['REMOTE_PORT'];
            $localIp    = $_SERVER['SERVER_ADDR'];
            $localPort  = $_SERVER['SERVER_PORT'];

            $context->add('remoteAddress', $remoteIp . ':' . $remotePort);
            $context->add('localAddress', $localIp . ':' . $localPort);
            $context->add('localAddress', $localIp . ':' . $localPort);

            if (isset($_SERVER['REQUEST_SCHEME'])) {
                $context->add('requestScheme', $_SERVER['REQUEST_SCHEME']);
            }
            if (isset($_SERVER['REQUEST_URI'])) {
                $context->add('uri', $_SERVER['REQUEST_URI']);
            }
            if (isset($_SERVER['HTTP_USER_AGENT'])) {
                $context->add('userAgent', $_SERVER['HTTP_USER_AGENT']);
            }
            if (isset($_SERVER['HTTP_REFERER'])) {
                $context->add('httpReferrer', $_SERVER['HTTP_REFERER']);
            }
            if (isset($_SERVER['SERVER_NAME'])) {
                $context->add('host', $_SERVER['SERVER_NAME']);
            }

            $portalUser = $_SESSION['portalUserInfo']['user'] ?? null;

            if (is_array($portalUser)) {
                $context->add('portalUserId', $portalUser['id'] ?? '');
                $context->add('portalUserName', $portalUser['fullname'] ?? '');
                $context->add('portalUserEmail', $portalUser['email'] ?? '');
                $context->add('portalUserLoginAs', $_SESSION['portalUserInfo']['loginAs'] ?? '');
            }
        }

        return $context;
    }

    private static function generateId() {
        return $_SERVER['REQUEST_ID'] ?? rand(1000, 9999);
    }
}
