<?php

namespace Microsoft;



class ExchangeServer extends \Singleton{

	private $_server = null;
	private $_username = null;
	private $_password = null;
	private $_version = null;

	public function __construct($server, $username, $password, $version = null) {

		spl_autoload_register(__NAMESPACE__ . "\\ExchangeServer::autoload");

		$this->_server = $server;
		$this->_username = $username;
		$this->_password = $password;

		if(!empty($version)){
			$this->_version = $version;
		}else{
			$this->_version = \ExchangeWebServices::VERSION_2010;
		}
	}

	/**
	 * Function to autoload the requested class name.
	 *
	 * @param string $class_name Name of the class to be loaded.
	 * @return boolean Whether the class was loaded or not.
	 */
	public static function autoload($className){
		// Start from the base path and determine the location from the class name,
		$base_path = __DIR__.'/php-ews';
		$include_file = $base_path . '/' . str_replace('_', '/', $className) . '.php';
		return (file_exists($include_file) ? require_once $include_file : false);
	}

	public function getPhonebooks($start = 0, $count = 100){
		$folders = array();
		$folders['PublicFolders'] = array(
				'FolderId' => 'publicfoldersroot',
				'FolderClass'=>'IPF.Note',
				'DisplayName'=>'Public Folders',
				'Patch' => '/Public Folders'
		);

		$this->_getChildFolders($folders['PublicFolders'], 'publicfoldersroot', null, $start, $count);


		$myContactsFolders = $this->getMyPhonebooks($start, $count);
		if($myContactsFolders && count($myContactsFolders['entry']) > 0){
			$folders['ContactsFolder'] = array(
					'FolderClass' => 'IPF.Note',
					'DisplayName' => 'My Contacts',
					'Patch' => '/My Contacts',
					'Childs' => array()

			);
			foreach ($myContactsFolders['entry'] as $folder){
				$folders['ContactsFolder']['Childs'][$folder['FolderId']] = $folder;
				$folders['ContactsFolder']['Childs'][$folder['FolderId']]['Patch'] = $folders['ContactsFolder']['Patch'].'/'.$folder['DisplayName'];

			}
		}

		$this->_prepareFolders($folders, '', $result);
		return $result;
	}

	public function getMyPhonebooks($start = 0, $count = 100){
		// NOTE: mind the version of exchange you are connecting to...

		$request = new \EWSType_FindFolderType();
		$request->Traversal = \EWSType_FolderQueryTraversalType::DEEP; // use EWSType_FolderQueryTraversalType::DEEP for subfolders too
		$request->FolderShape = new \EWSType_FolderResponseShapeType();
		$request->FolderShape->BaseShape = \EWSType_DefaultShapeNamesType::ALL_PROPERTIES;

		$request->IndexedPageItemView = new \EWSType_IndexedPageViewType();  // пагинация
		$request->IndexedPageItemView->MaxEntriesReturned = $count;
		$request->IndexedPageItemView->BasePoint = \EWSType_BasePointType::BEGINNING;
		$request->IndexedPageItemView->Offset = $start;

		$request->ParentFolderIds = new \EWSType_NonEmptyArrayOfBaseFolderIdsType();

		// use a distinguished folder name to find folders inside it
		$request->ParentFolderIds->DistinguishedFolderId = new \EWSType_DistinguishedFolderIdType();
		$request->ParentFolderIds->DistinguishedFolderId->Id = \EWSType_DistinguishedFolderIdNameType::ROOT;

		// if you know exact folder id, then use this piece of code instead. For example
		//$folder_id = 'AQEuAAADGkRzkKpmEc2byACqAC/EWgMAhSGL8sb6Sk+DTnyJFcZ0VgAAAQWsgwAAAA==';
		//$request->ParentFolderIds->FolderId = new \EWSType_FolderIdType();
		//$request->ParentFolderIds->FolderId->Id = $folder_id;


		$request->Restriction = new \EWSType_RestrictionType();
		$request->Restriction->IsEqualTo->FieldURI = new \stdClass();
		$request->Restriction->IsEqualTo->FieldURI->FieldURI = \EWSType_UnindexedFieldURIType::FOLDER_FOLDER_CLASS;
		$request->Restriction->IsEqualTo->FieldURIOrConstant->Constant->Value = 'IPF.Contact'; //\EWSType_ItemClassType::CONTACT //DISTRIBUTION_LIST //CONTACT

		// request
		$response = $this->getExchangeWebServices()->FindFolder($request);
		$folders = $this->_parseFoldersResponse($response);

		//echo '<pre>'.print_r($response, true).'</pre>';

		return $folders;
	}

	private $_exchangeWebServices = null;
	private function getExchangeWebServices(){
		if($this->_exchangeWebServices === null){
			$this->_exchangeWebServices = new \ExchangeWebServices($this->_server, $this->_username, $this->_password, $this->_version);
		}

		return $this->_exchangeWebServices;
	}

	private function _prepareFolders($folders, $parentPatch='', &$result){
		foreach ($folders as $key => $folder){
			if($folder['FolderClass'] == 'IPF.Contact'){
				$result[] = $folder;
			}
			if($folder['Childs']){
				$this->_prepareFolders($folders[$key]['Childs'], $folder['Patch'], $result);
			}
		}
	}


	private function _getChildFolders(&$foldersTree, $distinguishedFolderId = null, $folderId = null, $start = 0, $count = 100){
		if($foldersTree === null){
			$foldersTree = array();
		}
		if(!$foldersTree['Childs']){
			$foldersTree['Childs'] = array();
		}

		$request = new \EWSType_FindFolderType();
		if($distinguishedFolderId == 'publicfoldersroot' || $distinguishedFolderId == null){
			$request->Traversal = \EWSType_FolderQueryTraversalType::SHALLOW; // use EWSType_FolderQueryTraversalType::DEEP for subfolders too
		}else{
			$request->Traversal = \EWSType_FolderQueryTraversalType::DEEP;
		}

		$request->FolderShape = new \EWSType_FolderResponseShapeType();
		$request->FolderShape->BaseShape = \EWSType_DefaultShapeNamesType::ALL_PROPERTIES;

		$request->IndexedPageItemView = new \EWSType_IndexedPageViewType();  // пагинация
		$request->IndexedPageItemView->MaxEntriesReturned = $count;
		$request->IndexedPageItemView->BasePoint = \EWSType_BasePointType::BEGINNING;
		$request->IndexedPageItemView->Offset = $start;

		$request->ParentFolderIds = new \EWSType_NonEmptyArrayOfBaseFolderIdsType();

		if($distinguishedFolderId !== null){
			// use a distinguished folder name to find folders inside it
			$request->ParentFolderIds->DistinguishedFolderId = new \EWSType_DistinguishedFolderIdType();
			$request->ParentFolderIds->DistinguishedFolderId->Id = $distinguishedFolderId;
		}else if($folderId !== null){
			// if you know exact folder id, then use this piece of code instead. For example
			$request->ParentFolderIds->FolderId = new \EWSType_FolderIdType();
			$request->ParentFolderIds->FolderId->Id = $folderId;
		}

		$request->Restriction = new \EWSType_RestrictionType();

		$request->Restriction->Or = new \EWSType_NonEmptyArrayOfPathsToElementType();
		$fields = Array();
		$i=0;
		foreach (array('IPF.Note', 'IPF.Contact') as $class){
			$fields[$i] = new \EWSType_ContainsExpressionType();
			$fields[$i]->FieldURI = new \stdClass();
			$fields[$i]->FieldURI->FieldURI = \EWSType_UnindexedFieldURIType::FOLDER_FOLDER_CLASS;
			$fields[$i]->Constant = new \EWSType_ConstantValueType();
			$fields[$i]->Constant->Value = $class;
			$i++;
		}
		$request->Restriction->Or->Contains = $fields;

		// request
		$response = $this->getExchangeWebServices()->FindFolder($request);
		$folders = $this->_parseFoldersResponse($response);
		if($folders && count($folders['entry'] > 0)){
			foreach ($folders['entry'] as $key=>$value){

				$value['Patch'] = $foldersTree['Patch'].'/'.$value['DisplayName'];
				$foldersTree['Childs'][$value['FolderId']] = $value;
				if($value['FolderClass'] != 'IPF.Contact' && $value['ChildFolderCount'] > 0){
					if(!$foldersTree['Childs'][$value['FolderId']]['Childs']){
						$foldersTree['Childs'][$value['FolderId']]['Childs'] = array();
					}
					$this->_getChildFolders($foldersTree['Childs'][$value['FolderId']], null, $value['FolderId'], $start, $count);
					if(isset($foldersTree['Childs'][$value['FolderId']]) && empty($foldersTree['Childs'][$value['FolderId']]['Childs'])){
						unset ($foldersTree['Childs'][$value['FolderId']]);
					}
				}
				if($value['FolderClass'] != 'IPF.Contact' && $value['ChildFolderCount'] == 0){
					unset ($foldersTree['Childs'][$value['FolderId']]);
				}
			}
		}
	}




	private function _parseFoldersResponse($response){
		$result = array();
		if($response
				&& is_object($response)
				&& is_object($response->ResponseMessages)
				&& is_object($response->ResponseMessages->FindFolderResponseMessage)
				&& $response->ResponseMessages->FindFolderResponseMessage->ResponseClass == 'Success'
				&& is_object($response->ResponseMessages->FindFolderResponseMessage->RootFolder)){

			$rootFolder = $response->ResponseMessages->FindFolderResponseMessage->RootFolder;

			if(!empty($rootFolder->TotalItemsInView)){
				$result['total'] = $rootFolder->TotalItemsInView;
			}

			if(is_object($rootFolder->Folders) && (is_array($rootFolder->Folders->Folder) || is_object($rootFolder->Folders->Folder))){
				if(is_array($rootFolder->Folders->Folder)){
					foreach($rootFolder->Folders->Folder as $entry){
						$result['entry'][] = $this->_parseFolder($entry);
					}
				}else{
					$result['entry'][] = $this->_parseFolder($rootFolder->Folders->Folder);
				}
			}

			if(is_object($rootFolder->Folders) && (is_array($rootFolder->Folders->ContactsFolder) || is_object($rootFolder->Folders->ContactsFolder))){
				if(is_array($rootFolder->Folders->ContactsFolder)){
					foreach($rootFolder->Folders->ContactsFolder as $entry){
						$result['entry'][] = $this->_parseFolder($entry);
					}
				}else{
					$result['entry'][] = $this->_parseFolder($rootFolder->Folders->ContactsFolder);
				}
			}
		}
		return $result;
	}

	private function _parseFolder($entry){

		$folder = (array) $entry;
		$folder['FolderId'] = $folder['FolderId']->Id;
		$folder['ParentFolderId'] = $folder['ParentFolderId']->Id;
		$folder['EffectiveRights'] = (array) $folder['EffectiveRights'];

		return $folder;
	}

	public function getContacts($folderId = null, $start = 0, $count = 100){

		$request = new \EWSType_FindItemType();

		$request->ItemShape = new \EWSType_ItemResponseShapeType();
		$request->ItemShape->BaseShape = \EWSType_DefaultShapeNamesType::ALL_PROPERTIES;

		$request->ContactsView = new \EWSType_ContactsViewType();
		//$request->ContactsView->InitialName = 'a';
		//$request->ContactsView->FinalName = 'z';

		/*$request->FractionalPageItemView = new EWSType_FractionalPageViewType();  //с конца пагинация
		 $request->FractionalPageItemView->Denominator = 3;
		 $request->FractionalPageItemView->Numerator = 2;
		 $request->FractionalPageItemView->MaxEntriesReturned = 1;
		 */

		$request->IndexedPageItemView = new \EWSType_IndexedPageViewType();  // пагинация
		$request->IndexedPageItemView->MaxEntriesReturned = $count;
		$request->IndexedPageItemView->BasePoint = \EWSType_BasePointType::BEGINNING;
		$request->IndexedPageItemView->Offset = $start;


		$request->Restriction = new \EWSType_RestrictionType();
		$request->Restriction->IsEqualTo->FieldURI = new \stdClass();
		$request->Restriction->IsEqualTo->FieldURI->FieldURI = \EWSType_UnindexedFieldURIType::ITEM_CLASS;
		$request->Restriction->IsEqualTo->FieldURIOrConstant->Constant->Value = \EWSType_ItemClassType::CONTACT; //DISTRIBUTION_LIST //CONTACT


		$request->ParentFolderIds = new \EWSType_NonEmptyArrayOfBaseFolderIdsType();

		if($folderId === null){
			$request->ParentFolderIds->DistinguishedFolderId = new \EWSType_DistinguishedFolderIdType();
			$request->ParentFolderIds->DistinguishedFolderId->Id = \EWSType_DistinguishedFolderIdNameType::CONTACTS;
		}else{
			// if you know exact folder id, then use this piece of code instead. For example
			$request->ParentFolderIds->FolderId = new \EWSType_FolderIdType();
			$request->ParentFolderIds->FolderId->Id = $folderId;
		}

		$request->Traversal = \EWSType_ItemQueryTraversalType::SHALLOW;

		$response = $this->getExchangeWebServices()->FindItem($request);

		$result = $this->_parseContactsResponse($response);
		return $result;
	}

	private function _parseContactsResponse($response) {
		$result = array();

		if($response
			&& is_object($response)
			&& is_object($response->ResponseMessages)
			&& is_object($response->ResponseMessages->FindItemResponseMessage)
			&& $response->ResponseMessages->FindItemResponseMessage->ResponseClass == 'Success'
			&& is_object($response->ResponseMessages->FindItemResponseMessage->RootFolder)){

			$rootFolder = $response->ResponseMessages->FindItemResponseMessage->RootFolder;


			if(!empty($rootFolder->TotalItemsInView)){
				$result['total'] = $rootFolder->TotalItemsInView;
			}

			if(is_object($rootFolder->Items) && (is_array($rootFolder->Items->Contact) || is_object($rootFolder->Items->Contact))){
				if(is_array($rootFolder->Items->Contact)){
					foreach($rootFolder->Items->Contact as $entry){
						$result['entry'][] = $this->_parseContact($entry);
					}
				}else{
					$result['entry'][] = $this->_parseContact($rootFolder->Items->Contact);
				}
			}

			return $result;
		}
	}

	private function _parseContact($entry){

		$entry = (array) $entry;
		$contact = array(
				'id' => '',
				'LastModifiedTime' => '',
				'Subject' => '',
				'DisplayName' => '',
				'CompanyName' => '',
				'BusinessHomePage' => '',
				'Department' => '',
				'AssistantName' => '',
				'name' => array(),
				'email' => array(),
				'phone' => array(),
				'address' => array()
		);

		if(!empty($entry['ItemId'])){
			$contact['id'] = $entry['ItemId']->Id;
		}

		if(!empty($entry['LastModifiedTime'])){
			$contact['LastModifiedTime'] = $entry['LastModifiedTime'];
		}

		if(!empty($entry['Subject'])){
			$contact['Subject'] = $entry['Subject'];
		}

		if(!empty($entry['DisplayName'])){
			$contact['DisplayName'] = $entry['DisplayName'];
		}

		if(!empty($entry['CompanyName'])){
			$contact['CompanyName'] = $entry['CompanyName'];
		}

		if(!empty($entry['BusinessHomePage'])){
			$contact['BusinessHomePage'] = $entry['BusinessHomePage'];
		}
		if(!empty($entry['Department'])){
			$contact['Department'] = $entry['Department'];
		}
		if(!empty($entry['AssistantName'])){
			$contact['AssistantName'] = $entry['AssistantName'];
		}


		if(!empty($entry['PhysicalAddresses'])){
			$addresses = $entry['PhysicalAddresses']->Entry;
			if(!is_array($addresses)){
				$addresses = array(
						(array)$addresses
				);
			}
			foreach ($addresses as $address){
				$address = (array) $address;
				$rel = $address['Key'];
				if(!empty($rel) && empty($contact['address'][$rel])){
					$contact['address'][$rel] = array(
							'City' => $address['City'],
							'Street' => $address['Street'],
							'State' => $address['State'],
							'CountryOrRegion' => $address['CountryOrRegion'],
							'PostalCode' => $address['PostalCode']
					);
					$fullAddress = array(
							$address['Street'],
							$address['City'],
							$address['State'],
							$address['PostalCode'],
							$address['CountryOrRegion']
					);

					$shortAddress = array(
							$address['Street'],
							$address['City'],
							$address['State'],
							$address['PostalCode'],
							$address['CountryOrRegion']
					);

					$fullAddress = array_map('trim', $fullAddress);
					$fullAddress = array_filter($fullAddress, 'strlen');
					$contact['address'][$rel]['FullAddress'] = join(', ', $fullAddress);
				}
			}
		}


		if(!empty($entry['EmailAddresses'])){
			$emails = $entry['EmailAddresses']->Entry;
			if(!is_array($emails)){
				$emails = array(
						(array)$emails
				);
			}
			foreach ($emails as $email){
				$email = (array) $email;
				$rel = $email['Key'];
				if(!empty($rel) && empty($contact['email'][$rel])){
					$contact['email'][$rel] = $email['_'];
				}
			}
		}


		if(!empty($entry['PhoneNumbers'])){
			$phones = $entry['PhoneNumbers']->Entry;
			if(!is_array($phones)){
				$phones = array(
						(array)$phones
				);
			}
			foreach ($phones as $phone){
				$phone = (array) $phone;
				$rel = $phone['Key'];
				if(!empty($rel) && empty($contact['phone'][$rel])){
					$contact['phone'][$rel] = $phone['_'];
				}
			}
		}


		if(!empty($entry['CompleteName'])){
			$name = (array) $entry['CompleteName'];

			if(!empty($name['FirstName'])){
				$contact['name']['FirstName'] = $name['FirstName'];
			}
			if(!empty($name['MiddleName'])){
				$contact['name']['MiddleName'] = $name['MiddleName'];
			}
			if(!empty($name['LastName'])){
				$contact['name']['LastName'] = $name['LastName'];
			}
			if(!empty($name['FullName'])){
				$contact['name']['FullName'] = $name['FullName'];
			}

		}
		return $contact;
	}
}





