<?php

namespace Wildix\Auth\Applications\Abstractions;

use Api\Support\Interfaces\ArrayableInterface;
use Wildix\Auth\Applications\Interfaces\ModelInterface;
use Wildix\Core\BaseModel;

/**
 * Class Model
 */
abstract class Model extends BaseModel implements ArrayableInterface, ModelInterface {

    const FIELD_ID      = 'id';
    const FIELD_NAME    = 'name';
    const FIELD_SECRET  = 'secret';
    const FIELD_CREATED = 'created';

    const FIELDS_EDITABLE = [
        self::FIELD_NAME,
    ];

    const FIELDS_SECURE = [
        self::FIELD_ID,
        self::FIELD_SECRET,
        self::FIELD_CREATED,
    ];

    const PREFIX_NAME = '';

    protected $_primary = self::FIELD_ID;

    public function __construct(?array $properties) {
        if (!empty($properties)) {
            $allFields  = array_merge(static::FIELDS_EDITABLE, static::FIELDS_SECURE);
            $properties = array_intersect_key($properties, array_flip($allFields));
        }

        parent::__construct($properties);

        if (empty($this->_data[self::FIELD_ID])) {
            $this->generateSecureFields();
        }
    }

    public function getId(): string {
        return $this->getProperty(self::FIELD_ID);
    }

    /**
     * Get application name
     *
     * @return string
     */
    public function getName(): string {
        return $this->_data[self::FIELD_NAME] ?? '';
    }

    /**
     * Set application name
     *
     * @param string $name Application name.
     *
     * @return self
     */
    public function setName(string $name): ModelInterface {
        $this->_data[self::FIELD_NAME] = $name;

        return $this;
    }

    /**
     * Get application secret key.
     *
     * @return string
     */
    public function getSecret(): string {
        return $this->_data[self::FIELD_SECRET] ?? '';
    }

    /**
     * Get timestamp create application
     *
     * @return integer
     */
    public function getCreated(): int {
        return $this->_data[self::FIELD_CREATED] ?? 0;
    }

    /**
     * Generate application ID and secret key.
     *
     * @return void
     */
    public function generateSecureFields(): void {
        $appId  = static::PREFIX_NAME . preg_replace('/[^a-z0-9]/u', '', mb_strtolower($this->getName()));
        $appId .= '-' . preg_replace('/[^0-9]/', '', microtime());

        $this->_data[self::FIELD_ID]      = $appId;
        $this->_data[self::FIELD_SECRET]  = $this->generateSecretKey();
        $this->_data[self::FIELD_CREATED] = time();
    }

    protected function generateSecretKey(): string {
        return \Wildix\Generator\StringGenerator::random(64);
    }
}
