<?php
declare(strict_types=1);

namespace Wildix\Auth\Applications\Interfaces;

use Logger\Log;
use Wildix\Auth\Applications\OAuth2\Services\Service as OAuth2Service;
use Wildix\Auth\Applications\OAuth2\Storage\FileStorage as OAuth2Storage;
use Wildix\Auth\Applications\SimpleToken\Services\Service as SimpleTokenService;
use Wildix\Auth\Applications\SimpleToken\Storage\FileStorage as SimpleTokenStorage;
use Wildix\DependencyInjection\Container;

/**
 * Class DiConfig
 */
final class DiConfig implements \Wildix\DependencyInjection\ConfigInterface {

    public static function configure(Container $container): void {
        $container->singleton(
            OAuth2ServiceInterface::class,
            function (Container $container) {
                $storage = new OAuth2Storage();
                return new OAuth2Service(
                    $storage,
                    $container->get(Log::class)
                );
            }
        );
        $container->singleton(
            SimpleTokenServiceInterface::class,
            function (Container $container) {
                $storage = new SimpleTokenStorage();
                return new SimpleTokenService(
                    $storage,
                    $container->get(Log::class)
                );
            }
        );
    }
}
