<?php

namespace Wildix\Auth\Applications\Interfaces;

use Wildix\Auth\Applications\OAuth2\Objects\Applications;
use Wildix\Auth\Applications\OAuth2\Objects\Model;
use Wildix\Auth\Applications\OAuth2\Requests\Request;
use Wildix\InvalidDataException;

/**
 * Class OAuth2ServiceInterface
 */
interface OAuth2ServiceInterface {

    /**
     * Get application list.
     *
     * @return Applications
     */
    public function getItems(): Applications;

    /**
     * Get application item.
     *
     * @param string $appId Application ID.
     *
     * @return ModelInterface|null
     */
    public function getItem(string $appId): ?ModelInterface;

    /**
     * Create application
     *
     * @param Request $data Input app data.
     *
     * @return Model
     * @throws \Wildix\InvalidDataException Invalid data.
     */
    public function create(Request $data): Model;

    /**
     * Update application
     *
     * @param string  $appId Application ID.
     * @param Request $data  Input app data.
     *
     * @return Model
     * @throws \Wildix\InvalidDataException Invalid data.
     */
    public function update(string $appId, Request $data): Model;

    /**
     * Delete application
     *
     * @param string $appId Application ID.
     *
     * @return void
     * @throws InvalidDataException Invalid data.
     */
    public function remove(string $appId): void;
}
