<?php

namespace Wildix\Auth\Applications\OAuth2\Requests;

use Api\Support\DTOValidate\DTOValidate;
use Api\Support\Interfaces\ArrayableInterface;
use Wildix\Auth\Applications\OAuth2\Objects\Model;

/**
 * Class Request
 */
class Request extends DTOValidate implements ArrayableInterface {

    public $name           = '';
    public $redirectUri    = [];
    public $accessTokenTtl = Model::DEFAULT_TTL;

    public function getName(): string {
        return $this->name;
    }

    public function getRedirectUri(): array {
        return !empty($this->redirectUri) ? array_filter((array)$this->redirectUri) : [];
    }

    public function getAccessTokenTtl(): int {
        return $this->accessTokenTtl;
    }

    public function toArray(): array {
        return [
            Model::FIELD_NAME         => $this->getName(),
            Model::FIELD_REDIRECT_URI => $this->getRedirectUri(),
            Model::FIELD_ACCESS_TTL   => $this->getAccessTokenTtl(),
        ];
    }

    public function rules(): array {
        return [
            Model::FIELD_NAME         => [
                'string',
                'required',
            ],
            Model::FIELD_REDIRECT_URI => ['array'],
            Model::FIELD_ACCESS_TTL => [
                'integer',
                [
                    'in',
                    Model::ALLOWED_TTL,
                ],
            ],
        ];
    }

    protected function customValidation(): array {
        $errors = [];

        $this->_validator->reset();
        // stage 2, validate array of URLs
        $this->_validator->rule(
            'url',
            Model::FIELD_REDIRECT_URI
        );

        $uri = $this->getRedirectUri();
        foreach ($uri as $idx => $item) {
            $tmpErrors = $this->_validator->validateData([Model::FIELD_REDIRECT_URI => $item], [Model::FIELD_REDIRECT_URI]);
            if ($tmpErrors) {
                if (empty($errors[Model::FIELD_REDIRECT_URI])) {
                    $errors = $errors + $tmpErrors;
                }

                $errors[Model::FIELD_REDIRECT_URI]['rows'][] = [
                    'key'   => $idx,
                    'value' => $item,
                ];
            }
        }

        return $errors;
    }
}
