<?php

namespace Wildix\Auth\Applications\OAuth2\Storage;

use Wildix\Auth\Applications\Abstractions\AbstractFileStorage;
use Wildix\Auth\Applications\Interfaces\ApplicationsInterface;
use Wildix\Auth\Applications\Interfaces\StorageInterface;
use Wildix\Auth\Applications\OAuth2\Objects\Applications;
use Wildix\Auth\Applications\OAuth2\Objects\Model;

/**
 * Class FileStorage
 */
class FileStorage extends AbstractFileStorage implements StorageInterface {

    const APP_CONFIG_FILE = '/rw2/etc/api_keys_pair/oauth2_apps.ini';

    protected function fromStorageFormat(array $items): ApplicationsInterface {
        return new Applications(
            array_map(
                function ($item) {
                    $fieldUri    = Model::FIELD_REDIRECT_URI;
                    $fieldOrigin = Model::FIELD_ORIGINS;

                    $item[$fieldUri]    = !empty($item[$fieldUri]) ? explode('|', $item[$fieldUri]) : [];
                    $item[$fieldOrigin] = !empty($item[$fieldOrigin]) ? explode('|', $item[$fieldOrigin]) : [];

                    return new Model($item);
                },
                $items
            )
        );
    }

    protected function toStorageFormat(array $items): array {
        $data = [];

        $fieldUri    = Model::FIELD_REDIRECT_URI;
        $fieldOrigin = Model::FIELD_ORIGINS;

        foreach ($items as $key => $item) {
            $item[$fieldUri]    = implode('|', $item[$fieldUri]);
            $item[$fieldOrigin] = implode('|', $item[$fieldOrigin]);
            $data[$key]         = $item;
        }

        return $data;
    }
}
