<?php

namespace Wildix\Auth\Kerberos;

/**
 * The Negotiate module. Allows for password-less, secure login by Kerberos with Negotiate.
 */
class Negotiate {

    private $_logger   = null;
    private $_kerberos = null;

    /**
     * Negotiate constructor.
     *
     * @param \KRB5NegotiateAuth $krbNegotiateAuth Instance of KRB5NegotiateAuth.
     */
    public function __construct(\KRB5NegotiateAuth $krbNegotiateAuth) {
        $this->_kerberos = $krbNegotiateAuth;
        $this->_logger   = \Logger\LoggerFactory::getInstance();
    }

    /**
     * Auth user via Kerberos / Negotiate protocol.
     *
     * @return false|string Return user name on success or false otherwise.
     */
    public function auth() {
        $user = false;

        try {
            $reply = $this->_kerberos->doAuthentication();
        } catch (\Exception $ex) {
            $this->_logger->error(__LINE__, 'Cannot authenticate user via Kerberos: ' . $ex->getMessage() . '. With error code: ' . $ex->getCode());
            return false;
        }

        if ($reply) {
            // success! krb TGS received
            $user = $this->_kerberos->getAuthenticatedUser();
        }

        return $user;
    }

    /**
     * Get Negotiate headers
     *
     * @return array
     */
    public function getNegotiateHeaders() {
        return array(
            'HTTP/1.1 401 Unauthorized',
            'WWW-Authenticate: Negotiate',
        );
    }
}
