<?php
declare(strict_types=1);

namespace Wildix\Auth\OAuth2;

use Logger\Log;
use Wildix\Auth\Applications\Interfaces\OAuth2ServiceInterface as OAuth2ApplicationServiceInterface;
use Wildix\Colleagues\Colleagues;

/**
 * Class DiConfig
 */
final class DiConfig implements \Wildix\DependencyInjection\ConfigInterface {

    public static function configure(\Wildix\DependencyInjection\Container $container): void {
        $container->singleton(
            Storage::class,
            function (\Wildix\DependencyInjection\Container $container) {
                return new Storage(
                    $container->get(Log::class)
                );
            }
        );
        $container->singleton(
            Generator::class,
            function (\Wildix\DependencyInjection\Container $container) {
                return new Generator(
                    $container->get(\User::class)
                );
            }
        );
        $container->singleton(
            OAuth2ServiceInterface::class,
            function (\Wildix\DependencyInjection\Container $container) {
                return new OAuth2Service(
                    $container->get(OAuth2ApplicationServiceInterface::class),
                    $container->get(Storage::class),
                    $container->get(Generator::class),
                    $container->get(Colleagues::class),
                    $container->get(\User::class),
                    $container->get(Log::class)
                );
            }
        );
    }
}
