<?php

namespace Wildix\Auth\OAuth2;

/**
 * Class OAuth2Exception
 */
class OAuth2Exception extends \Exception {

    const ERROR_INVALID_REQUEST           = 'invalid_request';
    const ERROR_UNAUTHORIZED_CLIENT       = 'unauthorized_client';
    const ERROR_ACCESS_DENIED             = 'access_denied';
    const ERROR_UNSUPPORTED_RESPONSE_TYPE = 'unsupported_response_type';
    const ERROR_INVALID_SCOPE             = 'invalid_scope';
    const ERROR_SERVER_ERROR              = 'server_error';
    const ERROR_TEMPORARILY_UNAVAILABLE   = 'temporarily_unavailable';
    const ERROR_INVALID_CLIENT            = 'invalid_client';
    const ERROR_INVALID_GRANT             = 'invalid_grant';
    const ERROR_UNSUPPORTED_GRANT_TYPE    = 'unsupported_grant_type';
    const ERROR_INVALID_URI               = 'invalid_uri';
    const ERROR_INVALID_TOKEN             = 'invalid_token';

    protected $_errorTypes = [
        self::ERROR_INVALID_REQUEST,
        self::ERROR_UNAUTHORIZED_CLIENT,
        self::ERROR_ACCESS_DENIED,
        self::ERROR_UNSUPPORTED_RESPONSE_TYPE,
        self::ERROR_INVALID_SCOPE,
        self::ERROR_SERVER_ERROR,
        self::ERROR_TEMPORARILY_UNAVAILABLE,
        self::ERROR_INVALID_CLIENT,
        self::ERROR_INVALID_GRANT,
        self::ERROR_UNSUPPORTED_GRANT_TYPE,
        self::ERROR_INVALID_URI,
        self::ERROR_INVALID_TOKEN,
    ];

    /**
     * OAuth exception type
     *
     * @var string $_type
     */
    protected $_type = '';

    /**
     * OAuth exception state
     *
     * @var string $_state
     */
    protected $_state = '';

    public function __construct(string $message = '', string $type = '', int $code = 400, string $state = '', \Throwable $previous = null) {
        if (!in_array($type, $this->_errorTypes)) {
            $type = self::ERROR_SERVER_ERROR;
        }

        $this->_type  = $type;
        $this->_state = $state;

        parent::__construct($message, $code, $previous);
    }

    /**
     * Get exception type
     *
     * @return string
     */
    public function getType(): string {
        return $this->_type;
    }

    /**
     * Get exception state
     *
     * @return string
     */
    public function getState(): string {
        return $this->_state;
    }

    /**
     * Custom error response format by standard RFC6749
     * https://tools.ietf.org/html/rfc6749#section-4.2.2.1
     *
     * @return array
     */
    public function getFormattedError() {
        $response = [
            'error'             => $this->getType(),
            'error_description' => $this->getMessage(),
        ];

        $state = $this->getState();
        if (!empty($state)) {
            $response['state'] = $state;
        }

        return $response;
    }
}
