<?php

namespace Wildix\Auth\OAuth2;

use Wildix\Auth\Applications\OAuth2\Objects\Model;

/**
 * Class OAuth2Service
 */
interface OAuth2ServiceInterface {
    /**
     * Handle authorization request
     *
     * @param array $data Input data.
     *
     * @return void
     * @throws OAuth2Exception Validation error.
     */
    public function handleAuthorizationRequest(array $data): void;

    /**
     * Handle authorization grant request
     *
     * @param array $data Input data.
     *
     * @return Model
     * @throws OAuth2Exception Validation error.
     */
    public function handleAuthorizationGrantRequest(array $data): Model;

    /**
     * Handle confirm request
     *
     * @param array $data Input data.
     *
     * @return boolean
     * @throws OAuth2Exception Validation error.
     */
    public function handleGrantConfirmRequest(array $data): bool;

    /**
     * Handle access token request
     *
     * @param array $inputData Input data.
     *
     * @return array
     * @throws OAuth2Exception Validation error.
     */
    public function handleAccessTokenRequest(array $inputData): array;

    /**
     * Redirect after grant response
     *
     * @param boolean $grantConfirm Grant confirm status.
     *
     * @return void
     * @throws OAuth2Exception Validation error.
     */
    public function redirectAfterGrant(bool $grantConfirm): void;

    /**
     * Get application by ID.
     *
     * @param string $clientId Application ID.
     *
     * @return Model
     * @throws OAuth2Exception Validation error.
     */
    public function getAppById(string $clientId): Model;

    /**
     * Redirect to grant URL.
     *
     * @return void
     * @throws OAuth2Exception Validation error.
     */
    public function redirectToGrantForm(): void;

    /**
     * Generate grant URL
     *
     * @param array $params Request params.
     *
     * @return string
     */
    public function generateGrantUrl(array $params): string;

    /**
     * Redirect to URL
     *
     * @param string $url Url address.
     *
     * @return void
     */
    public function redirectToUrl(string $url): void;

    public function isOauthLogged(): bool;

    /**
     * Get OAuth2 data from session
     *
     * @return array|null
     */
    public function getSessionData(): ?array;
}
