<?php
declare(strict_types=1);

namespace Wildix\Auth\ServiceAuth;

/**
 * Class DiConfig
 */
final class DiConfig implements \Wildix\DependencyInjection\ConfigInterface {

    public static function configure(\Wildix\DependencyInjection\Container $container): void {
        $container->singleton(
            KeysCache::class,
            function () {
                return new KeysCache();
            }
        );
        $container->singleton(
            PublicKeyRepository::class,
            function (\Wildix\DependencyInjection\Container $container) {
                return new PublicKeyRepository(
                    $container->get(\Wildix\Services\AbstractServiceAuth::class),
                    $container->get(KeysCache::class),
                    $container->get(\Logger\Log::class)
                );
            }
        );
        $container->singleton(
            ServiceAuthenticatorFactory::class,
            function (\Wildix\DependencyInjection\Container $container) {
                $pbxSerial = \Models\PBX::getInstance()->getSerial();

                return new ServiceAuthenticatorFactory(
                    $pbxSerial,
                    $container->get(PublicKeyRepository::class),
                    $container->get(\Logger\Log::class)
                );
            }
        );
    }
}
