<?php

namespace Wildix\Auth\SimpleToken;

use Logger\Log;
use Wildix\Auth\Applications\SimpleToken\Objects\Model;
use Wildix\Auth\Applications\SimpleToken\Storage\FileStorage;

/**
 * Class SimpleTokenService
 */
class SimpleTokenService implements SimpleTokenServiceInterface {

    /**
     * Application storage class
     *
     * @var FileStorage $_storage
     */
    private $_storage;

    /**
     * Logger class
     *
     * @var Log $_log
     */
    private $_log;

    public function __construct(FileStorage $storage, Log $logger) {
        $this->_storage = $storage;
        $this->_log     = $logger;
    }

    /**
     * Get simple token application
     *
     * @param string $token Simple token.
     *
     * @return Model
     *
     * @throws SimpleTokenException Simple token not found.
     */
    public function getSimpleTokenApp(string $token): Model {
        $apps = $this->_storage->getItems()->all();
        foreach ($apps as $app) {
            if ($app->getSecret() === $token) {
                return $app;
            }
        }

        throw new SimpleTokenException();
    }

    /**
     * Check token is simple
     *
     * @param string $token Token string.
     *
     * @return boolean
     */
    public static function isSimpleToken(string $token): bool {
        return strpos($token, Model::TOKEN_PREFIX) === 0;
    }
}
