<?php

namespace Wildix\Auth\SmsService;

use Firebase\JWT\SignatureInvalidException;
use Logger\Log;
use Wildix\Utils\JWT;

/**
 * Class SmsServiceAuthenticator
 */
class SmsServiceAuthenticator {

    const JWT_AUD = 'PBX';
    const ALG = 'HS256';
    /**
     * Logged manager
     *
     * @var Log
     */
    protected $_logger;

    private $payload;

    /**
     * Constructor for SmsServiceAuthenticator
     *
     * @param Log $logger Logged manager.
     */
    public function __construct(Log $logger) {
        $this->_logger = $logger;
        JWT::$leeway   = 600;
    }

    /**
     * Check a JWT token and authenticate a Wildix service by it.
     *
     * @param string $encodedToken Token string.
     *
     * @return boolean
     */
    public function authenticate(string $encodedToken): ?string {
        $status = true;
        $key    = md5(\Models\PBX::getInstance()->getPbxKey());
        try {
            $this->payload = (array)JWT::decode($encodedToken, $key, [self::ALG]);
        } catch (SignatureInvalidException $e) {
            $this->_logger->error(
                __LINE__,
                sprintf('[SmsServiceAuthenticator] Token %s. %s', $encodedToken, $e->getMessage())
            );
            $status = false;
        } catch (\Exception $e) {
            $this->_logger->error(
                __LINE__,
                sprintf(
                    '[SmsServiceAuthenticator] Token %s validation error: %s',
                    $encodedToken,
                    $e->getMessage()
                )
            );
            $status = false;
        }
        $this->_logger->info(
            __LINE__,
            sprintf('[SmsServiceAuthenticator] Status %s ', $status ? 'success' : 'failure')
        );

        return ($status && $this->_isTokenValid()) ? $this->payload['iss'] ?? null : null;
    }

    private function _isTokenValid(): bool {
        $check = $this->payload['aud'] === self::JWT_AUD;
        if (!$check) {
            $this->_logger->error(
                __LINE__,
                '[SmsServiceAuthenticator] JWT AUD validation error'
            );
        }

        return $check;
    }
}
