<?php

namespace Wildix\Auth\TwoFactor;

use PHPGangsta_GoogleAuthenticator as GoogleAuthenticator;

/**
 * Class AbstractAuthenticator
 */
abstract class AbstractAuthenticator {

    /**
     * Code generator for authentication through second factor.
     *
     * @var GoogleAuthenticator;
     */
    private $_codeGenerator;

    /**
     * AbstractAuthenticator constructor.
     *
     * @param GoogleAuthenticator $codeGenerator Code generator for second factor.
     */
    public function __construct(GoogleAuthenticator $codeGenerator) {
        $this->_codeGenerator = $codeGenerator;
    }

    /**
     * Send authentication code to the user second factor.
     *
     * @param \Wildix\Colleagues\Colleague $user Owner of second factor.
     *
     * @return void
     */
    public function sendCodeTo2ndFactor(\Wildix\Colleagues\Colleague $user) {
        $secondFactorSettings = (array)$user->getSettings()->getTwoFactor();

        $code = $this->_codeGenerator->getCode($secondFactorSettings['secret']);
        $this->transferCodeToUser($code, $user);
    }

    /**
     * Delivers the authentication code to the recipient.
     *
     * @param string                       $code Authentication code.
     * @param \Wildix\Colleagues\Colleague $user Recipient.
     *
     * @throws Exception\TransportException If has failed in transfer procedure.
     * @return void
     */
    abstract protected function transferCodeToUser($code, \Wildix\Colleagues\Colleague $user);
}
