<?php

namespace Wildix\Auth\TwoFactor;

use PHPGangsta_GoogleAuthenticator as GoogleAuthenticator;
use Wildix\Notifications\Email\Interfaces\EmailManagerInterface;

/**
 * Class EmailAuthenticator
 */
class EmailAuthenticator extends AbstractAuthenticator {

    /**
     * Transport for send emails.
     *
     * @var EmailManagerInterface
     */
    private $_transport;
    /**
     * Current PBX domain.
     *
     * @var string
     */
    private $_currentPbxDomain;

    /**
     * EmailAuthenticator constructor.
     *
     * @param GoogleAuthenticator   $codeGenerator    Code generator for second factor.
     * @param EmailManagerInterface $transport        Transport for send emails.
     * @param string                $currentPbxDomain Current PBX domain.
     */
    public function __construct(GoogleAuthenticator $codeGenerator, EmailManagerInterface $transport, $currentPbxDomain) {
        parent::__construct($codeGenerator);

        $this->_transport        = $transport;
        $this->_currentPbxDomain = $currentPbxDomain;
    }

    /**
     * Delivers the authentication code to the recipient.
     *
     * @param string                       $code Authentication code.
     * @param \Wildix\Colleagues\Colleague $user Recipient.
     *
     * @throws Exception\TransportException If has failed in transfer procedure.
     * @return void
     */
    protected function transferCodeToUser($code, \Wildix\Colleagues\Colleague $user) {
        $params = array(
            'type' => 'default',
            'subject' => 'PBX :: Two Factor Authentication :: Code',
            'to' => $user->getEmail(),
            'body' => sprintf('Code - %s | PBX - %s', $code, $this->_currentPbxDomain),
        );

        try {
            $this->_transport->send($params);
        } catch (\Exception $e) {
            throw new Exception\TransportException('Failed send email with authentication code', 0, $e);
        }
    }
}
