<?php

namespace Wildix\Auth\TwoFactor;

use PHPGangsta_GoogleAuthenticator as GoogleAuthenticator;

/**
 * Class SmsAuthenticator
 */
class SmsAuthenticator extends AbstractAuthenticator {

    /**
     * Mock of transport instance.
     *
     * @var \Models\Astman
     */
    private $_transportSms;
    /**
     * Current PBX domain.
     *
     * @var string
     */
    private $_currentPbxDomain;

    /**
     * SmsAuthenticator constructor.
     *
     * @param GoogleAuthenticator $codeGenerator    Code generator for second factor.
     * @param \Models\Astman      $transportSms     Transport for send SMS.
     * @param string              $currentPbxDomain Current PBX domain.
     */
    public function __construct(GoogleAuthenticator $codeGenerator, \Models\Astman $transportSms, $currentPbxDomain) {
        parent::__construct($codeGenerator);

        $this->_transportSms     = $transportSms;
        $this->_currentPbxDomain = $currentPbxDomain;
    }

    /**
     * Delivers the authentication code to the recipient.
     *
     * @param string                       $code Authentication code.
     * @param \Wildix\Colleagues\Colleague $user Recipient.
     *
     * @throws Exception\TransportException If has failed in transfer procedure.
     * @return void
     */
    protected function transferCodeToUser($code, \Wildix\Colleagues\Colleague $user) {
        $now     = new \DateTime();
        $message = sprintf('Code - %s | PBX - %s', $code, $this->_currentPbxDomain);

        try {
            $this->_transportSms->sendSMS('pbx', $user->getMobilePhone(), $message, $now);
        } catch (\Exception $e) {
            throw new Exception\TransportException('Failed send sms with authentication code', 0, $e);
        }
    }
}
