<?php
namespace Wildix\Calendar;

use Wildix\Databases\CalendarDB;
use Wildix\Exception;

class Settings extends \Singleton {

    const TABLE_NAME = 'settings';

    const SETTINGS_APP_OUTLOOK           = 1;
    const SETTINGS_APP_OFFICE365_OUTLOOK = 2;

    const SETTINGS_FIELD_APP   = 'app';
    const SETTINGS_FIELD_OWNER = 'owner';
    const SETTINGS_FIELD_KEY   = 'key';
    const SETTINGS_FIELD_VALUE = 'value';

    private $_tableFields = '`app`, `owner`, `key`, `value`';


    private function isValidData($data, \Wildix\Colleagues\Colleague $colleague = null, $queryType) {
        if ($queryType == CalendarDB::INSERT_QUERY) {
            if (empty($data['key'])) {
                return array(
                        'code' => '0',
                        'message' => 'The key cannot be empty'
                );
            }
        } else if ($queryType == CalendarDB::UPDATE_QUERY) {
        }

        return true;
    }

    /**
     *
     * @var array
     */
    private $_keyMap = array();

    /**
     *
     * @param  string $key
     * @return string
     */
    private function getRealKey($key) {
        if (isset($this->_keyMap[$key])) {
            return $this->_keyMap[$key];
        }
        return $key;
    }


    public function getOutlookSettings(\Wildix\Colleagues\Colleague $colleague = null) {
        return $this->getSettings(self::SETTINGS_APP_OUTLOOK, $colleague);
    }
    /**
     *
     * @param  integer                      $app
     * @param  \Wildix\Colleagues\Colleague $colleague
     * @return array
     */

    public function getSettings($app, \Wildix\Colleagues\Colleague $colleague = null) {
        $settings = array();

        $query = 'SELECT ' . $this->_tableFields . '
                    FROM `' . self::TABLE_NAME . '`
                    ' . $this->createWhere($app, $colleague, CalendarDB::SELECT_QUERY) . ';';

        $rows = CalendarDB::getInstance()->query($query);

        if ($rows) {
            while ($row = $rows->fetchArray(SQLITE3_ASSOC)) {
                if ($row && !empty($row)) {
                    $settings[$row['key']] = $row['value'];
                }
            }
        }
        return $settings;
    }

    public function addSettings($settings, \Wildix\Colleagues\Colleague $colleague, $app) {
        $result = [];
        CalendarDB::getInstance()->beginTransaction();
        foreach ($settings as $key => $value) {
            $tmp = [
                'app' => $app,
                'key' => $key,
                'value' => $value,
            ];

            $result[] = $this->addSetting($tmp, $colleague);
        }

        CalendarDB::getInstance()->endTransaction();

        // todo add rollback
        return $result;
    }


    /**
     *
     * @param  array                        $setting
     * @param  \Wildix\Colleagues\Colleague $colleague
     * @return integer
     */
    public function addSetting($setting, \Wildix\Colleagues\Colleague $colleague) {
        $setting = array_map('trim', $setting);

        $isValid = $this->isValidData($setting, $colleague, CalendarDB::INSERT_QUERY);
        if ($isValid !== true) {
            throw new Exception($isValid['message'], $isValid['code']);
        }

        if ($colleague) {
            $setting[self::SETTINGS_FIELD_OWNER] = $colleague->getID();
        }

        $keys   = array();
        $values = array();
        foreach ($setting as $key => $value) {
            $keys[]   = '`' . $this->getRealKey($key) . '`';
            $values[] = '\'' . CalendarDB::getInstance()->realEscapeString($value) . '\'';
        }

        $query = sprintf('INSERT OR REPLACE INTO `%s` (%s) Values (%s)', self::TABLE_NAME, join(', ', $keys), join(', ', $values));

        $result = CalendarDB::getInstance()->exec($query);
        if ($result === true) {
            return $setting[self::SETTINGS_FIELD_KEY];
        }

        return $result;
    }

    /**
     *
     * @param  array                        $settings
     * @param  \Wildix\Colleagues\Colleague $colleague
     * @return integer
     */
    public function deleteSettings($settings, \Wildix\Colleagues\Colleague $colleague = null, $app) {
        $keys = "'" . join("', '", array_keys($settings)) . "'";

        $query = 'DELETE FROM `' . self::TABLE_NAME . '`
                                ' . $this->createWhere($app, $colleague, CalendarDB::DELETE_QUERY) . ' AND `key` IN(' . $keys . ') ;';

        $result = CalendarDB::getInstance()->exec($query);
        if ($result === true) {
            $result = CalendarDB::getInstance()->getCountChangesRows();
        }
        return $result;
    }

    /**
     *
     * @param  integer                      $app
     * @param  \Wildix\Colleagues\Colleague $colleague
     * @param  string                       $queryType
     * @return string
     */
    private function createWhere($app, \Wildix\Colleagues\Colleague $colleague = null, $queryType = null) {
        $colleague = is_object($colleague) ? $colleague : null;

        $where = array();

        $where[] = '`' . $this->getRealKey(self::SETTINGS_FIELD_APP) . '` = ' . $app;

        if ($colleague) {
            $where[] = '`' . $this->getRealKey(self::SETTINGS_FIELD_OWNER) . '` = ' . $colleague->getID();
        }

        if (count($where) > 0) {
            return 'WHERE ' . join(' AND ', $where);
        }
        return '';
    }
}
