<?php
namespace Wildix;

class CallFiles extends \Singleton{

    const FILES_PATH      = '/var/spool/callweaver/outgoing/';

    private function getFileId(){
        $fileId = rand(10000, 999999);
        return $fileId;
    }

    private function getPatchToCallFile($type, $fileId){
        return self::FILES_PATH.strtolower($type).'_'.$fileId.'.call';
    }

    public function getCallById($type, $fileId){
        $type = strtolower($type);
        $filePath = self::FILES_PATH.$type.'_'.$fileId.'.call';
        if(file_exists($filePath)){
            $date = new \DateTime();
            $date->setTimestamp(filemtime($filePath));
            $call = array(
                    'id'=>$fileId,
                    'postpone' => $date->format('d/m/Y H:i')
            );

            switch ($type) {
                case 'alarmclocks': $explodedId = explode('_', $fileId);
                                    $call['owner'] = $explodedId[0];
                                    $call['number'] = $explodedId[1];
                                    $content = file_get_contents($filePath);
                                    if(preg_match('/.*Context: ([^\n\r]+).*/', $content, $matches)){
                                        $call['dialplan'] = trim($matches[1]);
                                    }
                    break;
                default:
                    break;
            }
            return $call;
        }
        return false;
    }

    public function removeCallById($type, $fileId){
        $filePath = self::FILES_PATH.strtolower($type).'_'.$fileId.'.call';
        if(file_exists($filePath)){
            if(!unlink($filePath)){
                return false;
            }
        }
        return true;
    }


    public function makePlayback($exten, $name, $patch, \DateTime $postpone = null){
        $exten=str_replace(array(' ', '-', '(', ')'), '', $exten);

        $call="Channel: SIP/".$exten."\n";
        $call.="Application: Playback\n";
        $call.="Data: ".$patch."\n";
        $call.="CallerID: \"Playback\" <".$name.">";

        $fileId = $exten.'_'.$this->getFileId();
        $patchToCallFile = $this->getPatchToCallFile('Playback', $fileId);

        if(file_put_contents($patchToCallFile, $call) !== false){
            if($postpone){
                if(touch($patchToCallFile, $postpone->getTimestamp())){
                    return $fileId;
                }
            }else{
                return $fileId;
            }
        }

        return false;
    }

    public function makeAlarmClock(\Wildix\Colleagues\Colleague $owner = null, $dstNumber, $context, \DateTime $postpone = null, $fileId = null){
        $exten=str_replace(array(' ', '-', '(', ')'), '', $exten);

        $call="Channel: Local/{$dstNumber}@{$context}\n";  // 333@alarmclock
        $call.="MaxRetries: 10\n";
        $call.="RetryTime: 5\n";
        $call.="WaitTime: 100\n";
        $call.="Context: {$context}\n";  //alarmclock
        $call.="Extension: alarm\n";  // alarm
        $call.="Priority: 1\n";
        $call.="CallerID: \"Alarm Room {$dstNumber}\" <{$dstNumber}>";

        if(!$fileId){
            $fileId = $owner->getID() .'_'.$dstNumber.'_'.$this->getFileId();
        }

        $patchToCallFile = $this->getPatchToCallFile('AlarmClocks', $fileId);

        if(file_put_contents($patchToCallFile, $call) !== false){
            if($postpone){
                if(touch($patchToCallFile, $postpone->getTimestamp())){
                    return $fileId;
                }
            }else{
                return $fileId;
            }
        }
        return false;
    }

    public function getAlarmClocks(\Wildix\Colleagues\Colleague $owner = null, $destination=null){
        $patern = "alarmclocks_";
        if($owner){
            $patern.=$owner->getID().'_';
        }else{
            $patern.='[0-9]*_';
        }

        if($destination){
            $patern.=$destination.'_';
        }else{
            $patern.='[^_]*_';
        }

        $patern.='[^\.]*\.call';

        $result = array();
        foreach (glob(self::FILES_PATH.$patern) as $filename) {
            $id = str_replace('.call', '', str_replace(self::FILES_PATH.'alarmclocks_', '', $filename));
            $result[] = $this->getCallById('alarmclocks', $id);
        }
        return $result;
    }

    private function sanitizeCallFileParam($param) {
        return trim(str_replace(array('#', ';', '"'), '', $param));
    }

    public function makeCall($srcNumber, $dstNumber, $dstCidName, $dstCidNumber, \DateTime $postpone = null){
        $srcNumber=str_replace(array(' ', '-', '(', ')'), '', $srcNumber);
        $dstNumber=str_replace(array(' ', '-', '(', ')'), '', $dstNumber);
        $dstCidName = self::sanitizeCallFileParam($dstCidName);
        $dstCidNumber = self::sanitizeCallFileParam($dstCidNumber);
        $call="Channel: SIP/{$srcNumber}\n";
        $call.="Application: Transfer\n";
        $call.="Data: SIP/{$dstNumber}\n";
        $call.="CallerID: \"{$dstCidName}\" <{$dstCidNumber}>";

        $fileId = $srcNumber.'_'.$this->getFileId();
        $patchToCallFile = $this->getPatchToCallFile('Call', $fileId);

        if(file_put_contents($patchToCallFile, $call) !== false){
            if($postpone){
                if(touch($patchToCallFile, $postpone->getTimestamp())){
                    return $fileId;
                }
            }else{
                return $fileId;
            }
        }

        return false;
    }

	public function makeLocalCall($srcNumber, $srcContext, $dstNumber, $dstContext, $dstCidName, $dstCidNumber, \DateTime $postpone = null){

	    $srcNumber=str_replace(array(' ', '-', '(', ')'), '', $srcNumber);
	    $dstNumber=str_replace(array(' ', '-', '(', ')'), '', $dstNumber);

	    $call="Channel: Local/{$srcNumber}@{$srcContext}\n";
	    $call.="Extension: {$dstNumber}\n";
	    $call.="Context: {$dstContext}\n";
	    $call.="Priority: 1\n";
	    $call.="CallerID: \"{$dstCidName}\" <{$dstCidNumber}>";

	    $fileId = $srcNumber.'_'.$this->getFileId();
        $patchToCallFile = $this->getPatchToCallFile('LocalCall', $fileId);

        if(file_put_contents($patchToCallFile, $call) !== false){
            if($postpone){
                if(touch($patchToCallFile, $postpone->getTimestamp())){
                    return $fileId;
                }
            }else{
                return $fileId;
            }
        }
        return false;
	}

    public function makeMobilityCall($extension, $mobilityNumber, $userGroupDn, $destNumber, $context, $language='en', \DateTime $postpone = null){

		$userGroupDn = str_replace(',', ';', $userGroupDn);

		$externalLinePrefix = \Models\PBX::getInstance()->getExternalLinePrefix();
		$callerID = $extension;
		$mobilityCIDRewrite = $destNumber;

		if(strlen($destNumber) > 7 && $externalLinePrefix !='' && strpos($destNumber, $externalLinePrefix) === 0){
			$mobilityCIDRewrite = substr($destNumber, strlen($externalLinePrefix));
		}

		$call="Channel: Local/{$extension}@mobility\n";
		$call.="MaxRetries: 0\n";
		$call.="WaitTime: 60\n";
		$call.="Context: {$context}\n";
		$call.="Extension: {$destNumber}\n";
		$call.="Priority: 1\n";
		$call.="CallerID: {$callerID}\n";
		$call.="Set: SIPDOMAIN=127.0.0.1\n";
		$call.="Set: APPCALLBACK={$extension}\n";
		$call.="Set: MOBILITY_OPTS={$mobilityNumber}||-1|{$context}|{$language}|{$userGroupDn}\n";
		$call.="Set: mobilityCIDRewrite=$mobilityCIDRewrite";

        $fileId = $this->getFileId();
        $patchToCallFile = $this->getPatchToCallFile('MobilityCall', $fileId);

        if(file_put_contents($patchToCallFile, $call) !== false){
            if($postpone){
                if(touch($patchToCallFile, $postpone->getTimestamp())){
                    return $fileId;
                }
            }else{
                return $fileId;
            }
        }
        return false;
	}

	public function makeRecord($exten, $filename, $patch, \DateTime $postpone = null){
	    $exten=str_replace(array(' ', '-', '(', ')'), '', $exten);
	    $patch=str_replace(array(" ", "-", "(", ")", ",", "\"", "'", "#", "~", "@", "%", "^", "+", "*", "!", "$", "&"), '', $patch);

	    $call="Channel: Local/$exten@pbxsound\n";
	    $call.="Extension: pbxrecord*{$patch}\n";
	    $call.="Context: pbxservices\n";
	    $call.="Priority: 1\n";
	    $call.="CallerID: \"{$filename}\" <Record>\n";
	    $call.="Set: RECORDOWNER={$exten}";

	    $fileId = $exten.'_'.$this->getFileId();
        $patchToCallFile = $this->getPatchToCallFile('Record', $fileId);

        if(file_put_contents($patchToCallFile, $call) !== false){
            if($postpone){
                if(touch($patchToCallFile, $postpone->getTimestamp())){
                    return $fileId;
                }
            }else{
                return $fileId;
            }
        }

        return false;
	}

	public function makeJoinToConference($number, $conferenceId, $conferenceName, \DateTime $postpone = null){

	    $call="Channel: Local/{$number}@internalcalls\n";
	    $call.="Application: ConfBridge\n";
	    $call.="Data: {$conferenceId}\n";
	    $call.="CallerID: \"{$conferenceName}\" <conference*{$conferenceId}>";

	    $fileId = $number.'_'.$this->getFileId();
        $patchToCallFile = $this->getPatchToCallFile('JoinToConference', $fileId);

	    if(file_put_contents($patchToCallFile, $call) !== false){
            if($postpone){
                if(touch($patchToCallFile, $postpone->getTimestamp())){
                    return $fileId;
                }
            }else{
                return $fileId;
            }
        }
        return false;
	}
}
