<?php

namespace Wildix;

/**
 *    CallRecordings class.
 */
class CallRecordings {

    const DIR = '/dev/shm/var/spool/callweaver/monitor';

    /**
     * Logger class.
     *
     * @var \Syslog Log.
     */
    private $_log;

    /**
     * CallRecordings constructor.
     *
     * @param \Syslog|null $log Logger class.
     */
    public function __construct(\Syslog $log = null) {
        $this->_log = $log ? $log : new \Syslog('CallRecordings');
    }

    /**
     * Delete call recordings older than provided period.
     *
     * @param integer $time Period while we store the call recordings.
     *
     * @return void
     * @throws \Exception Folder cannot be removed.
     */
    public function deleteAllCallRecordingsAfter($time) {
        $period  = 'month';
        $newDate = new \DateTime();
        $newDate->modify('-' . $time . ' ' . $period);

        $result = $this->getFolders();

        foreach ($result as $folder) {
            preg_match('/^20[0-9]{2}\.[0-9]{2}\.[0-9]{2}/', $folder, $matches);
            if (!empty($matches[0])) {
                $folderName = self::DIR . '/' . $matches[0];
                if (filemtime($folderName) < $newDate->format('U')) {
                    $cmd = '/bin/rm -r ' . $folderName;
                    exec($cmd, $out, $result);
                    if ($result !== 0) {
                        throw new Exception('Cannot remove this folder: ' . $folderName);
                    }
                }
            }
        }
    }

    private function getFolders(): array {
        $items = preg_grep('/.(gz|db)$/', scandir(self::DIR), PREG_GREP_INVERT);
        return $items ?: [];
    }

    /**
     * Delete call recordings from storage.
     *
     * @param array $recordings Records.
     *
     * @return void
     */
    public function deleteCallRecordings(array $recordings) {
        foreach ($recordings as $record) {
            try {
                $this->_deleteRecordingFileFromStorage($record['file']);
                $this->_log->info(__LINE__, sprintf('Removed recordings file %s', $record['file']));
            } catch (\Exception $e) {
                $this->_log->error(__LINE__, $e->getMessage());
            }
        }
    }

    /**
     * Delete recording file from storage.
     *
     * @param string $file File name.
     *
     * @return void
     * @throws \Exception Exception.
     */
    private function _deleteRecordingFileFromStorage(string $file) {
        if ($file === '') {
            return;
        }

        $cmd = '/bin/rm ' . self::DIR . DIRECTORY_SEPARATOR . $file;
        exec($cmd, $out, $result);
        if ($result !== 0) {
            throw new Exception(sprintf('Cannot remove recordings file  %s', $file));
        }
    }
}
