<?php
declare(strict_types=1);

namespace Wildix\Colleagues;

/**
 * Class DiConfig
 */
final class DiConfig implements \Wildix\DependencyInjection\ConfigInterface {

    public static function configure(\Wildix\DependencyInjection\Container $container): void {
        $container->singleton(
            Colleagues::class,
            static function (\Wildix\DependencyInjection\Container $container): Colleagues {
                return Colleagues::getInstance();
            }
        );
        $container->singleton(
            Groups::class,
            static function (\Wildix\DependencyInjection\Container $container): Groups {
                $ldap             = $container->get(\WMS_Ldap::class);
                $currentPbxSerial = $ldap->getEntry(\WMS_Ldap::PBX, '(pbxSerial=' . $container->get(\Models\PBX::class)->getSerial() . ')', ['dn']);

                if (empty($currentPbxSerial['dn'])) {
                    throw new \RuntimeException('Failed to get current PBX from LDAP for building ACL\Groups service.');
                }

                $validator = $container->get(\Wildix\Validator::class);
                $validator->setLdap($ldap);

                $groupsRepository = Groups::getInstance();
                $groupsRepository->setBaseDn($ldap->getConnectParams()['basedn']);
                $groupsRepository->setCurrentPbxDn($currentPbxSerial['dn']);
                $groupsRepository->setLdap($ldap);
                $groupsRepository->setColleagues($container->get(Colleagues::class));
                $groupsRepository->setLicense($container->get(\Wildix\License::class));
                $groupsRepository->setValidator($validator);

                return $groupsRepository;
            }
        );
        $container->singleton(
            Validator::class,
            static function (\Wildix\DependencyInjection\Container $container): Validator {
                $groups          = $container->get(\Wildix\Colleagues\Groups::class);
                $wildixValidator = $container->get(\Wildix\Validator::class);

                return new \Wildix\Colleagues\Validator($wildixValidator, $groups->getGroups());
            }
        );
        $container->singleton(
            ColleagueFactory::class,
            static function (\Wildix\DependencyInjection\Container $container): ColleagueFactory {
                $ldap = \WMS_Ldap::getInstance();

                $groups                = $container->get(Groups::class);
                $validator             = $container->get(Validator::class);
                $phoneNumberNormalizer = $container->get(\Wildix\Normalizer\PhoneNumberNormalizer::class);
                $pbx                   = $container->get(\Models\PBX::class);

                $connectParams = $ldap->getConnectParams();
                $currentPBX    = $ldap->getEntry(\WMS_Ldap::PBX, '(pbxSerial=' . $pbx->getSerial() . ')', ['pbxSerial', 'dn']);

                return new ColleagueFactory(
                    $validator,
                    $phoneNumberNormalizer,
                    $connectParams['basedn'],
                    $currentPBX['dn'] ?? '',
                    $groups->getAvailableGroupDn()
                );
            }
        );
    }
}
