<?php
namespace Wildix\Colleagues;

/**
 * Class Group
 */
class Group {

    public const DN           = 'dn';
    public const ORGANIZATION = 'o';
    public const ID           = 'gid';
    public const NAME         = 'cn';
    public const WCGRP        = 'wcgrp';
    public const OWNER        = 'owner';
    public const ACL_WG2G     = 'wg2gAcl';
    public const ACL_WG2E     = 'wg2eAcl';

    private $_dn;
    private $_organization;
    private $_gid;
    private $_name;
    private $_wcgrp;
    private $_owner;
    private $_wgToGacl;
    private $_wgToEacl;

    public function __construct(?array $properties) {
        if (is_array($properties)) {
            $this->_dn           = $properties[self::DN] ?? null;
            $this->_organization = $properties[self::ORGANIZATION] ?? null;
            $this->_gid          = $properties[self::ID] ?? null;
            $this->_name         = $properties[self::NAME] ?? null;
            $this->_wcgrp        = $properties[self::WCGRP] ?? null;
            $this->_owner        = $properties[self::OWNER] ?? null;
            $this->_wgToGacl     = $properties[self::ACL_WG2G] ?? null;
            $this->_wgToEacl     = $properties[self::ACL_WG2E] ?? null;
        }
    }

    public function getDn(): string {
        return $this->_dn ?? '';
    }

    public function getID(): ?string {
        return $this->_gid;
    }

    public function getName(): string {
        return $this->_name ?? '';
    }

    public function getWcgrp(): string {
        return $this->_wcgrp ?? '';
    }

    public function getGroupAsArray(array $fields = null): array {
        $data = [
            self::DN => $this->getDn(),
            self::ORGANIZATION => $this->_organization,
            self::ID => $this->getID(),
            self::NAME => $this->getName(),
            self::WCGRP => $this->getWcgrp(),
            self::OWNER => $this->_owner,
            self::ACL_WG2G => $this->_wgToGacl,
            self::ACL_WG2E => $this->_wgToEacl,
        ];

        if (!isset($fields)) {
            return $data;
        }

        return array_filter(
            $data,
            static function (string $field) use ($fields): bool {
                return in_array($field, $fields);
            },
            ARRAY_FILTER_USE_KEY
        );
    }

    public static function getFields(): array {
        return [
            self::DN,
            self::ID,
            self::NAME,
            self::WCGRP,
        ];
    }
}
