<?php

namespace Wildix\ContactCenter;

/**
 * Class ContactCenter
 */
class ContactCenter {

    private $_callWeaver = null;

    /**
     * Contact center constructor.
     *
     * @param \Wildix\CallweaverManager $callweaver Callweaver instance.
     */
    public function __construct(\Wildix\CallweaverManager $callweaver) {
        $this->_callWeaver = $callweaver;
        $this->_callWeaver->connect();
    }

    public function enable($extension, $callGroups, $paused) {
        $dynamicUserCallGroups = $this->_getDynamicCallGroups($extension);

        foreach ($callGroups as $callGroup) {
            if (!array_key_exists($callGroup['id'], $dynamicUserCallGroups)) {
                $this->_callWeaver->QueueAdd($callGroup['id'], 'Local/' . $extension . '@internalcalls', 1, $paused);
            } else {
                unset($dynamicUserCallGroups[$callGroup['id']]);
            }
        }

        $this->_removeFromCallGroups($extension, array_keys($dynamicUserCallGroups));
    }

    public function disable($extension) {
        $dynamicUserCallGroups = $this->_getDynamicCallGroups($extension);

        $this->_removeFromCallGroups($extension, array_keys($dynamicUserCallGroups));
    }

    private function _getDynamicCallGroups($extension) {
        $userCallGroups = $this->_callWeaver->getCallGroupsByExtension($extension);
        if (isset($userCallGroups['dynamic'])) {
            $dynamicUserCallGroups = $userCallGroups['dynamic'];
        } else {
            $dynamicUserCallGroups = array();
        }

        return $dynamicUserCallGroups;
    }

    private function _removeFromCallGroups($extension, $ids) {
        if (!is_array($ids)) {
            return;
        }
        foreach ($ids as $groupId) {
            $this->_callWeaver->QueueRemove($groupId, 'Local/' . $extension . '@internalcalls');
        }
    }
}
