<?php
namespace Wildix\Core;

use Controllers\Controller;
use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;

/**
 * Class AbstractCrudController
 */
abstract class AbstractCrudController extends Controller {

    protected $_service;

    /**
     * Get items
     *
     * @param Request  $request
     * @param Response $response
     *
     * @return Response
     */
    public function getItems(Request $request, Response $response): Response {
        $records = [];
        $items   = $this->_service()->getItems();
        foreach ($items as $item) {
            $records[] = $this->_service()->buildItem($item);
        }
        return $this->resultList($records, $response);
    }

    /**
     * Create
     *
     * @param Request  $request
     * @param Response $response
     *
     * @return Response
     */
    public function create(Request $request, Response $response): Response {
        $this->getLogger()->info(__LINE__, sprintf('Create item in class %s', get_class($this)));
        $this->_service()->create($request->getParsedBody());
        return $this->success($response);
    }

    /**
     * Update
     *
     * @param Request  $request
     * @param Response $response
     * @param array    $args
     *
     * @return Response
     */
    public function update(Request $request, Response $response, array $args): Response {
        $this->getLogger()->info(__LINE__, sprintf('Update item %s in class %s', $args['id'], get_class($this)));
        $this->_service()->update($args['id'], $request->getParsedBody());
        return $this->success($response);
    }

    /**
     * Remove
     *
     * @param Request  $request
     * @param Response $response
     * @param array    $args
     *
     * @return Response
     */
    public function remove(Request $request, Response $response, array $args): Response {
        $this->getLogger()->info(__LINE__, sprintf('Delete item %s in class %s', $args['id'], get_class($this)));
        $this->_service()->remove($args['id']);
        return $this->success($response);
    }

    /**
     * @return mixed
     */
    protected function _service() {
        return $this->getContainer()->get($this->_service);
    }
}
