<?php
namespace Wildix\Core;

/**
 * Class BaseModel
 */
abstract class BaseModel {

    protected $_data;
    protected $_id;
    protected $_primary = 'id';

    public function __construct(?array $properties) {
        if (is_array($properties)) {
            $this->_data = array_map(
                function ($value) {
                    return is_string($value) ? trim($value) : $value;
                },
                $properties
            );
            $this->_id   = $properties[$this->_primary] ?? null;
        }
    }

    public function getId() {
        return $this->_id;
    }

    public function getAsArray(array $fields = null): array {
        if (empty($fields)) {
            return $this->_data;
        }
        return array_intersect_key($this->_data, array_flip($fields));
    }

    protected function getProperty($name, $default = null) {
        if (!empty($this->_data) && isset($this->_data[$name])) {
            return $this->_data[$name];
        }

        return $default;
    }

    protected function setProperty($name, $value): void {
        if ($this->_data === null) {
            $this->_data = [];
        }

        $this->_data[$name] = $value;
    }
}
