<?php

namespace Wildix\Databases;

/**
 * Class AvatarCache
 */
class AvatarCache extends Database {
    public const CACHE_DB = '/tmp/wms_cache/avatar.db';

    private const CACHE_TABLE = 'avatar_cache';
    private const FIELD_TIME  = 'time';

    private const DEFAULT_DATE = '-1 day';

    public static function getInstance($path = null) {
        return parent::getInstance($path ?? self::CACHE_DB);
    }

    public function clearCacheByDate(string $date = null) {
        if ($this->_hasTable()) {
            $statement = $this->prepare(sprintf('DELETE FROM %s WHERE %s < :time', self::CACHE_TABLE, self::FIELD_TIME));
            $timestamp = new \DateTime($date ?? self::DEFAULT_DATE);
            $statement->bindValue(':time', $timestamp->format('Y-m-d H:i:s'));
            $statement->execute();
            $this->exec('VACUUM');
        }
    }

    public function clearAllCache(): void {
        if ($this->_hasTable()) {
            $this->exec(sprintf('DELETE FROM %s', self::CACHE_TABLE));
            $this->exec('VACUUM');
        }
    }

    private function _hasTable(): bool {
        $res = $this->getRows('SELECT name FROM sqlite_master', 'name');
        return isset($res[self::CACHE_TABLE]);
    }
}
