<?php
namespace Wildix\Databases;

/**
 * CalendarDB Class
 */
class CalendarDB extends Database {

    const TABLE_EVENTS   = 'events';
    const TABLE_SETTINGS = 'settings';

    public static function getInstance($path = null) {
        $path = Database::WILDIX_CALENDAR_DB;
        return parent::getInstance($path);
    }

    public function __construct($path) {
        if (!file_exists($path)) {
            exec('/usr/sbin/init_calendardb');
        }
        $result = parent::__construct($path);

        return $result;
    }

    public function createDb() {
        $this->beginTransaction();

        $this->createTable(self::TABLE_EVENTS);
        $this->exec('CREATE INDEX IF NOT EXISTS `idx_' . self::TABLE_EVENTS . '_owner` ON `' . self::TABLE_EVENTS . '` (`owner`);');
        $this->exec('CREATE INDEX IF NOT EXISTS `idx_' . self::TABLE_EVENTS . '_dateStart` ON `' . self::TABLE_EVENTS . '` (`dateStart`);');
        $this->exec('CREATE INDEX IF NOT EXISTS `idx_' . self::TABLE_EVENTS . '_dateEnd` ON `' . self::TABLE_EVENTS . '` (`dateEnd`);');
        $this->createTable(self::TABLE_SETTINGS);

        $this->endTransaction();
    }

    private function createTable($table) {
        $query = '';
        switch ($table) {
            case self::TABLE_EVENTS:
                $query = 'CREATE TABLE IF NOT EXISTS `' . self::TABLE_EVENTS . '` (
                    `id` varchar(255) PRIMARY KEY,
                    `type` INTEGER NOT NULL default 1,
                    `owner` INTEGER NOT NULL,
                    `name` varchar(255) NOT NULL,
                    `dateStart` DATETIME NOT NULL,
                    `dateEnd` DATETIME NOT NULL,
                    `status` varchar(255) NOT NULL default \'Busy\',
                    `importance` varchar(255) NOT NULL default \'Normal\',
                    `private` INTEGER NOT NULL default 0,
                    `processed` INTEGER NOT NULL default 0,
                    `options` TEXT NOT NULL default \'\',
                    `app` INTEGER NOT NULL default 1
                ) WITHOUT ROWID;';
                break;
            case self::TABLE_SETTINGS:
                    $query = 'CREATE TABLE IF NOT EXISTS `' . self::TABLE_SETTINGS . '` (
                    `app` INTEGER NOT NULL default 1,
                    `owner` INTEGER NOT NULL,
                    `key` varchar(255) NOT NULL,
                    `value` varchar(255) NOT NULL default \'\',
                    PRIMARY KEY (`app`, `owner`, `key`)
                ) WITHOUT ROWID;';
                break;
            default:
                // unknown table
                break;
        }
        if (!empty($query)) {
            return $this->exec($query);
        }
        return true;
    }
}
