<?php
namespace Wildix\Databases;

/**
 * DEVDB Class
 */
class DEVDB extends Database {

    const SYSTEM_QUICK_DIAL_PATTERNS = 'QUICK_DIAL_PATTERNS';
    const SYSTEM_JITTER_MIN          = 'JITTER_MIN';
    const SYSTEM_JITTER_NOM          = 'JITTER_NOM';
    const SYSTEM_JITTER_MAX          = 'JITTER_MAX';

    const TABLE_SYSTEM        = 'system';
    const TABLE_AUTOPROV      = 'autoprov';
    const TABLE_WAIR_USERS    = 'wair_users';
    const TABLE_WAIR_NETWORKS = 'wair_networks';
    const TABLE_WAIR_GATEWAYS = 'wair_gateways';

    public static function getInstance($path = null) {
        $path = Database::WILDIX_DEVDB;
        return parent::getInstance($path);
    }

    private $_systemVariables = null;
    public function getSystemVariable($name = null, $default = null) {
        if ($this->_systemVariables == null) {
            $this->_systemVariables = array();
            // check variable
            $result = $this->query('SELECT `variable`, `value` FROM `system`');
            while ($row = $result->fetchArray(SQLITE3_ASSOC)) {
                $this->_systemVariables[$row['variable']] = $row['value'];
            }
        }

        if ($name !== null) {
            if (isset($this->_systemVariables[$name])) {
                return $this->_systemVariables[$name];
            }
            return $default;
        }
        return null;
    }

    public function setSystemVariables($variables) {
        if (is_array($variables)) {
            $this->exec('BEGIN TRANSACTION;');
            foreach ($variables as $key => $value) {
                $result = $this->setSystemVariable($key, $value);
            }
            $this->exec('COMMIT;');
            return true;
        }
        return false;
    }

    public function setSystemVariable($variable, $value) {
        $query = 'INSERT OR REPLACE INTO `system`
                (`variable`, `value`)
                VALUES
                ("' . $this->realEscapeString($variable) . '", "' . $this->realEscapeString($value) . '")';
        return $this->exec($query);
    }

    public function createTable($table) {
        $query = '';
        switch ($table) {
            case self::TABLE_SYSTEM:
                $query = 'CREATE TABLE IF NOT EXISTS `system` (
                `variable` varchar(20) PRIMARY KEY,
                `value` varchar(50));';
                break;
            case self::TABLE_AUTOPROV:
                $query = 'CREATE TABLE IF NOT EXISTS `autoprov` (
                `id` INTEGER PRIMARY KEY AUTOINCREMENT,
                `param` varchar(40),
                `value` varchar(128),
                `flag` varchar(2),
                `mac` varchar(12),
                `token` varchar(32));';
                break;
            case self::TABLE_WAIR_USERS:
                $query = 'CREATE TABLE IF NOT EXISTS `wair_users` (
                `slot_id` INTEGER,
                `uid` INTEGER,
                `mac` varchar(12),
                `ipei` varchar(10) default \'FFFFFFFFFF\' NOT NULL);';
                break;
            case self::TABLE_WAIR_NETWORKS:
                $query = 'CREATE TABLE IF NOT EXISTS `wair_networks` (
                `id` INTEGER PRIMARY KEY AUTOINCREMENT,
                `name` varchar(128) NOT NULL,
                `code` varchar(4) default \'\',
                `sipproxy` varchar(255)  default \'\' NOT NULL,
                `primarybase` varchar(255)  default \'\' NOT NULL,
                `autodecttree` int(1) default \'1\' NOT NULL,
                `sync_plus_via_ethernet` int(1) default 0 NOT NULL);';
                break;
            case self::TABLE_WAIR_GATEWAYS:
                $query = 'CREATE TABLE IF NOT EXISTS `wair_gateways` (
                `mac` varchar(12),
                `network_id` INTEGER NOT NULL,
                `type` INTEGER);';
                break;
            default:
                $this->getLog()->error(__LINE__, 'Unknown table name ' . $table);
                break;
        }
        if (!empty($query)) {
            return $this->exec($query);
        }
        return true;
    }

    public function exec($sql): bool {
        $this->getLog()->info(
            __LINE__,
            sprintf('Exec query for devdb: %s', $sql)
        );

        return parent::exec($sql);
    }
}
