<?php
namespace Wildix\Databases;

/**
 * QueueDB Class
 */
class QueueDB extends Database {

    const SCHEMA_JOBS = Database::SCHEMA_PATH . 'queue/jobs.sql';
    const PATH_DIR_DB = '/rw2/var/queue';

    public static function getInstance($path = null) {
        $path = Database::WILDIX_QUEUEDB;
        return parent::getInstance($path);
    }

    public function __construct($path) {
        if (!file_exists($path)) {
            $this->createDir();
        }
        $result = parent::__construct($path);

        return $result;
    }

    public function createDb() {
        $schema = self::SCHEMA_JOBS;

        if (!empty($schema) && file_exists($schema)) {
            $sql = file_get_contents($schema);
            if ($sql !== false) {
                return $this->exec($sql);
            }
        }
        return true;
    }

    public function getItems() {
        return $this->getRows('SELECT * FROM `jobs` ORDER BY `created_at` ASC');
    }

    public function updateRetryCountJob($attempt, $id) {
        $query = 'UPDATE `jobs` SET `retry_count` = ' . $this->realEscapeString($attempt) . ' WHERE `id` = ' . $this->realEscapeString($id);
        return $this->exec($query);
    }

    public function updateCreatedAtToCurrentTimeJob($id) {
        $query = 'UPDATE `jobs` SET `created_at` = CURRENT_TIMESTAMP WHERE `id` = ' . $this->realEscapeString($id);
        return $this->exec($query);
    }

    public function addJob($type, $params) {
        $query = 'INSERT INTO `jobs` (`type`, `params`)
                    VALUES (\'' . $this->realEscapeString($type) . '\', \'' . $this->realEscapeString($params) . '\')';
        return $this->exec($query);
    }

    public function delJobByField($data) {
        if (empty($data)) {
            return false;
        }
        foreach ($data as $item => $key) {
            $field = $this->realEscapeString($item);
            $value = $this->realEscapeString($key);
        }

        $query = 'DELETE FROM `jobs` WHERE `' . $field . '` = "' . $value . '";';
        return $this->exec($query);
    }

    private function createDir() {
        if (file_exists(self::PATH_DIR_DB)) {
            return false;
        }

        if (!mkdir(self::PATH_DIR_DB, 0777, true)) {
            return false;
        }

        if (!chown(self::PATH_DIR_DB, 'wms')) {
            return false;
        }

        return true;
    }
}
