<?php
namespace Wildix\Databases;

/**
 * WMSDB Class
 */
class WMSDB extends Database {

    const SYSTEM_EXTERNAL_LINE_PREFIX = 'PREFIX_EXTLINE';
    const SYSTEM_SMTP_SETTINGS        = 'SMTP';

    const TABLE_CALL_GROUPS_USERS = 'call_groups_members';
    const TABLE_CALL_GROUPS       = 'call_groups';
    const TABLE_PAGING_GROUPS     = 'paging';
    const TABLE_PAGING_MEMBERS    = 'paging_members';
    const TABLE_RULES_LINKS       = 'dialplan_links';
    const TABLE_IVR               = 'ivr_tree';
    const TABLE_TIME_TABLES       = 'timetable_main';
    const TABLE_TIME_SETTING      = 'timetable_additional';
    const TABLE_SWITCHES          = 'wmsswitches';
    const DIALPLAN_RULE_NAME      = 'dialplan_rulenames';
    const TABLE_PSTN_TRUNKS       = 'pstn_trunks';
    const TABLE_TRUNKS            = 'trunks';

    /**
     * Function that returns instance of WMSDB class.
     *
     * @param string $path Path to datebase.
     *
     * @return static
     */
    public static function getInstance($path = null) {
        $path = Database::WILDIX_WMSDB;
        return parent::getInstance($path);
    }

    private $_systemVariables = null;
    public function getSystemVariable($name) {
        if ($this->_systemVariables == null) {
            $this->_systemVariables = array();
            // check variable
            $result = $this->query('SELECT `variable`, `value` FROM `system`');
            while ($row = $result->fetchArray(SQLITE3_ASSOC)) {
                $this->_systemVariables[$row['variable']] = $row['value'];
            }
        }

        if (isset($this->_systemVariables[$name])) {
            return $this->_systemVariables[$name];
        }
        return null;
    }

    public function setSystemVariable($variable, $value) {
        $query = 'INSERT OR REPLACE INTO `system` (`variable`, `value`)
                    VALUES (\'' . $this->realEscapeString($variable) . '\', \'' . $this->realEscapeString($value) . '\')';
        return $this->exec($query);
    }

    public function getCountGsmTrunks(): int {
        return (int)$this->querySingle("SELECT COUNT(*) as `count` FROM `pstn_trunks` WHERE `technology`='gsm'");
    }

    /**
     * Retrive SIP, BRI, PRI, GSM, FXO trunk names.
     *
     * @return array trunk names
     */
    public function getTrunksNamesList() {
        $names = array();

        $linesPerDevice = array(
                'bri' => 2,
                'pri' => 1,
                'gsm' => 1,
                'fxo' => 1,
        );
        // Table pstn_trunks used for GSM/UMTS, FXO trunks
        // Table trunks used for SIP trunks
        $sql = "SELECT username, 'trunk' AS technology, 1 AS ports, settings_pbx
                FROM trunks
                UNION
                SELECT username, technology, ports, settings_pbx
                FROM pstn_trunks";

        $result = $this->query($sql);
        while ($row = $result->fetchArray(SQLITE3_ASSOC)) {
            if (!$row['username'] || !$row['technology'] || !$row['ports']) {
                continue;
            }
            if ($row['technology'] == 'trunk') {
                $settingsPbx = @json_decode($row['settings_pbx'], true);
                // Sip trunks must return TrunkName instead AuthLogin due to TrunkName present in call information in toChannel & fromChannel
                if ($settingsPbx !== null && $settingsPbx['peername']) {
                    $names[] = $settingsPbx['peername'];
                } else {
                    $names[] = $row['username'];
                }
            } else if (in_array($row['technology'], array_keys($linesPerDevice))) {
                $gwLines = $linesPerDevice[$row['technology']];
                if ($row['technology'] == 'bri' && $row['ports'] == 4) {
                    $gwLines = 1;
                }

                for ($p = 0; $p < $row['ports']; $p++) {
                    for ($l = 0; $l < $gwLines; $l++) {
                        if ($row['technology'] == 'fxo') {
                            $names[] = sprintf('%s_%s', $row['username'], $p);
                        } else {
                            $names[] = sprintf('%s_%s_%s', $row['username'], $p, $l);
                        }
                    }
                }
            }
        }
        return $names;
    }
}
