<?php
declare(strict_types=1);

namespace Wildix\DependencyInjection;

/**
 * Class Container
 */
final class Container extends \Wildix\Slim\Set {
    public function get(string $key, mixed $default = null):mixed {
        if (!$this->has($key)) {
            $this->_addService($key);
        }

        return parent::get($key, $default);
    }

    /**
     * Adding a service configuration to the current container.
     *
     * @param string $serviceName Service for which should add a configuration.
     *
     * @return void
     * @throws ConfigNotFoundException if the configuration for the service does not found.
     */
    private function _addService(string $serviceName): void {
        [$serviceClass] = explode(':', $serviceName);

        $serviceParts = explode('\\', $serviceClass);
        array_pop($serviceParts);
        $serviceConfigurator = '\\' . implode('\\', $serviceParts) . '\DiConfig';

        // Remove extra slashes for DiConfig class which has a root namespace
        $serviceConfigurator = str_replace('\\\\', '\\', $serviceConfigurator);

        if (!class_exists($serviceConfigurator) || !\in_array(ConfigInterface::class, class_implements($serviceConfigurator))) {
            throw new ConfigNotFoundException($serviceName);
        }

        \call_user_func($serviceConfigurator . '::configure', $this);
    }
}
