<?php
declare(strict_types=1);

namespace Wildix\Devices;

use Logger\Log;
use Models\PBX;
use PHPGangsta_GoogleAuthenticator as GoogleAuthenticator;
use Services\LuaService;
use Services\TProxyService;
use Wildix\Colleagues\Colleagues;
use Wildix\DependencyInjection\ConfigInterface;
use Wildix\DependencyInjection\Container;
use Wildix\SipProxy;
use Wildix\System\HttpProxy;
use Wildix\System\Upgrade\UpgradeSettings;

/**
 * Class DiConfig
 */
class DiConfig implements ConfigInterface {

    public static function configure(Container $container): void {
        $container->singleton(
            Devices::class,
            function (Container $container) {
                $devices = Devices::getInstance();
                $devices->setGoogleAuthenticator($container->get(GoogleAuthenticator::class));
                $devices->setColleagues($container->get(Colleagues::class));
                $devices->setPbx($container->get(PBX::class));
                $devices->setLog($container->get(Log::class));
                $devices->setLuaService($container->get(LuaService::class));
                $devices->setHttpProxy($container->get(HttpProxy::class));
                $devices->setSipProxy($container->get(SipProxy::class));
                $devices->setUpgradeSettings($container->get(UpgradeSettings::class));
                $devices->setTproxyService($container->get(TProxyService::class));
                return $devices;
            }
        );
    }
}
