<?php
namespace Wildix\Devices\Networks;

use Wildix\Devices\Device;

/**
 * Class GatewaysService
 */
class GatewaysService {

    private $_storage;

    public function __construct(NetworkStorage $storage) {
        $this->_storage = $storage;
    }

    /**
     * Get gateways list.
     *
     * @param boolean $available Available.
     *
     * @return array
     */
    public function getItems(bool $available = true): array {
        if ($available) {
            $res = $this->_storage()->getAvailableGateways();
        } else {
            $res = $this->_storage()->getGateways();
        }

        return $res;
    }

    /**
     * Build item
     *
     * @param Device $item Item.
     *
     * @return array
     */
    public function buildItem(Device $item): array {
        return [
            'mac' => $item->getMac(),
            'isMaster' => false,
            'address' => $item->getIpAddress(),
            'model' => $item->getModel()
        ];
    }

    /**
     * Network data storage.
     *
     * @return NetworkStorage
     */
    private function _storage(): NetworkStorage {
        return $this->_storage;
    }
}
