<?php

namespace Wildix\Devices;

/**
 * Class Vendors
 */
class Vendors {
    const SNOM        = 'Snom';
    const THOMSON     = 'Thomson';
    const AASTRA      = 'Aastra';
    const MOIMSTONE   = 'Moimstone';
    const WILDIX      = 'Wildix';
    const GRANDSTREAM = 'Grandstream';
    const PATTON      = 'Patton';
    const PORTECH     = 'Portech';
    const UNKNOWN     = 'Unknown';
    const WIZYCONF    = 'Wizyconf';
    const DAYSAVER    = 'daysaver';

    const FXS_FAMILY  = [
        'FXSR2', 'W02FXSR2', 'W02FXSR3', 'W24FXSR3', 'W04FXSR3', 'W04FXS', 'W08FXS', 'W08FXSR2', 'W16FXS', 'W24FXS', 'W24FXSR2', 'W04FXO', 'W04FXOR3',
    ];
    const WPR2_FAMILY = [
        'WP410R2', 'WP410R3', 'WP480R2', 'WP480GR2', 'WP480GR3', 'WP490R2', 'WP490GR2', 'WP490GCR2', 'WP490GR3', 'WP490GR4', 'WP480GR4',
    ];
    const WPA_FAMILY  = [
        'W-PA', 'W01GSM', 'W-PA2',
    ];

    private const AVAILABLE_TONE_ZONE_MODELS = [
        'W01FXSR2', 'W02FXSR2', 'W02FXSR3', 'W24FXSR3', 'W04FXSR3', 'W04FXS', 'W08FXS', 'W08FXSR2', 'W16FXS', 'W24FXS', 'W24FXSR2', 'W04FXO',
    ];

    private const AVAILABLE_SNMP_MODELS = [
        'WP400', 'WP410R2', 'WP480', 'WP490', 'WP500',
    ];

    private const MODELS_NEED_REBOOT = [
        'W04FXOR3', 'W02FXSR3', 'W24FXSR3', 'W04FXSR3',
    ];

    const MODELS_ALLOW_ASSIGN = [
        'phone',
        'wp400',
        'wp480g',
        'wp490g',
        'wp410',
        'wp410r2',
        'wp410r3',
        'wp480',
        'wp480r2',
        'wp480gr2',
        'wp480gr3',
        'wp480gr4',
        'wp490',
        'wp490r2',
        'wp490gr2',
        'wp490gcr2',
        'wp490gr3',
        'wp490gr4',
        'wp500',
        'wp600',
        'w01fxs',
        'w01fxsr2',
        'w-pa',
        'wizyconf',
        'welcomeconsole',
        'workforce',
        'start',
        'w-pa2',
    ];

    const NO_SECURE = 'http://';
    const SECURE    = 'https://';

    const ACTION_JSON = '/?action=setaps';
    const ACTION_XML  = '/?action=setaps&config=xml';

    const DEVICE_MODELS = [
            [
                'modelLine' => 'Phone',
                'start' => '001565110000',
                'end' => '00156511FFFF',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
            [
                'modelLine' => 'Phone',
                'start' => '001565140000',
                'end' => '00156514FFFF',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
            [
                'modelLine' => 'Phone',
                'start' => '001565160000',
                'end' => '00156516FFFF',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
            [
                'modelLine' => 'Phone',
                'start' => '0015651DAB60',
                'end' => '0015651DAB6F',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
             // WP R2
            [
                'modelLine' => 'Phone R2',
                'start' => '9C7514020000',
                'end' => '9C751402FFFF',
                'protocol' => self::SECURE,
                'action' => self::ACTION_JSON
            ],
             // WP R2
            [
                'modelLine' => 'Phone R2',
                'start' => '9C7514040000',
                'end' => '9C751406FFFF',
                'protocol' => self::SECURE,
                'action' => self::ACTION_JSON
            ],
             // WP
            [
                'modelLine' => 'Phone',
                'start' => '9C7514000000',
                'end' => '9C75140FFFFF',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
             // W01FXS
            [
                'modelLine' => 'W01FXS',
                'start' => '9C7514100000',
                'end' => '9C75141FFFFF',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
             // W01FXSR2 || W02FXSR2
            [
                'modelLine' => 'FXSR2',
                'start' => '9C751432B200',
                'end' => '9C751432FFFF',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
             // W02FXSR3
            [
                'modelLine' => 'FXSR3',
                'start' => '9C7514310000',
                'end' => '9C7514314FFF',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
             // MGW - Welltech (4 port GW's)
            [
                'modelLine' => 'MGW',
                'start' => '9C7514320000',
                'end' => '9C751432B1FF',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
             // ??? Mediatrix
            [
                'modelLine' => 'MGW1',
                'start' => '0090F8000000',
                'end' => '0090F8FFFFFF',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
             // W24FXSR2
            [
                'modelLine' => 'FXSR2',
                'start' => '9C7514370000',
                'end' => '9C751437FFFF',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
             // W01GSM
            [
                'modelLine' => 'W01GSM',
                'start' => '9C7514330000',
                'end' => '9C751433FFFF',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_XML
            ],
             // W-AIR BASE
            [
                'modelLine' => 'W-AIR',
                'start' => '9C7514340000',
                'end' => '9C7514342FFF',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
             // W-AIR BASE-SB
            [
                'modelLine' => 'W-AIR SB',
                'start' => '9C7514343000',
                'end' => '9C7514344FFF',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
            // W-AIR BASE-SP
            [
                'modelLine' => 'W-AIR',
                'start' => '9C7514345000',
                'end' => '9C7514346FFF',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
            // W-AIR BASE
            [
                'modelLine' => 'W-AIR',
                'start' => '9C7514347000',
                'end' => '9C7514347FFF',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
             // W-AIR outdoor BASE
            [
                'modelLine' => 'W-AIR',
                'start' => '00087B000000',
                'end' => '00087BFFFFFF',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
             // W-PA
            [
                'modelLine' => 'W-PA',
                'start' => '9C7514381000',
                'end' => '9C7514381FFF',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
             // sample W-PA
            [
                'modelLine' => 'W-PA',
                'start' => '0C383E1FBD06',
                'end' => '0C383E1FBD06',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
             // sample W-PA bridge mode support
            [
                'modelLine' => 'W-PA',
                'start' => '00A834682560',
                'end' => '00A83468256F',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
             // Wizyconf
            [
                'modelLine' => 'Wizyconf',
                'start' => '9C7514400000',
                'end' => '9C7514400FFF',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
             // Wizyconf test lab
            [
                'modelLine' => 'Wizyconf',
                'start' => '00e04c680000',
                'end' => '00e04c680FFF',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
            // W04FXOR3 test lab
            [
                'modelLine' => 'Wildix FXOR3',
                'start' => 'f8a03d000000',
                'end' => 'f8a03dffffff',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
            // W04FXOR3
            [
                'modelLine' => 'Wildix FXOR3',
                'start' => '9C7514310000',
                'end' => '9C751431FFFF',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
            // W-AIR SBR2
            [
                'modelLine' => 'W-AIR SBR2',
                'start' => '9C7514410000',
                'end' => '9C7514411FFF',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
            // W-AIR SBR2 test lab
            [
                'modelLine' => 'W-AIR SBR2',
                'start' => '00087B100000',
                'end' => '00087B1FFFFF',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
            // W-PA2
            [
                'modelLine' => 'W-PA2',
                'start' => '9C7514382000',
                'end' => '9C7514382FFF',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
            // W-PA2 test lab
            [
                'modelLine' => 'W-PA2',
                'start' => '00d84a03ecf0',
                'end' => '00d84a03ecff',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
            // W-AIR SP and W-AIR SP Outdoor
            [
                'modelLine' => 'W-AIR',
                'start' => '9C7514430000',
                'end' => '9C7514431FFF',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
            ],
        ];

    /**
     * Return devices info types.
     *
     * @return array
     */
    public static function getDeviceMacs() {
        return array(
            'hardphones' => array(
                // 001d29, Doro AB
                self::SNOM        => array(
                    '000413',
                    '001d29',
                    ),
                self::THOMSON     => array(
                    '000e50', '00147f', '0018f6', '0007c3', '000e80', '001095', '0011e3', '00189b',
                    '0019df', '001d68', '001e69', '009064', '0090d0', '001f9f', '002417',
                ),
                self::AASTRA      => array(
                    '0010bc',
                    '00085d',
                    ),
                self::MOIMSTONE   => array('0011a9'),
                // Yealink
                self::WILDIX      => array(
                    '001565',
                    '9c7514',
                    ),
                self::GRANDSTREAM => array('000b82'),
            ),
            'gateways'   => array(
                self::PATTON  => array(
                    '00a0ba',
                    '00c04e',
                    ),
                // Medaitrix
                self::WILDIX  => array('0090f8'),
                // Medaitrix
                self::PORTECH => array('00037e'),
            ),
        );
    }

    /**
     * Return device by mac address
     *
     * @param string $mac Mac address.
     *
     * @return array
     */
    public static function getDeviceByMac(string $mac) {
        $shMac = strtolower(substr(\Wildix\System\Network::delim2mac($mac), 0, 6));

        $result = array(
            'type' => 'pc',
            'vendor' => self::UNKNOWN,
        );

        $deviceMacs = self::getDeviceMacs();

        foreach ($deviceMacs['hardphones'] as $vendor => $prefix) {
            if (in_array($shMac, $prefix) !== false) {
                return array(
                    'type' => 'phone',
                    'vendor' => $vendor,
                    'prefix' => $prefix,
                );
            }
        }

        foreach ($deviceMacs['gateways'] as $vendor => $prefix) {
            if (in_array($shMac, $prefix) !== false) {
                return array(
                    'type' => 'gateway',
                    'vendor' => $vendor,
                    'prefix' => $prefix,
                );
            }
        }

        return $result;
    }

    public static function getDeviceInfoByMac(string $mac, string $server = '') :array {
        $mac   = str_replace(':', '', $mac);
        $model = [
                'modelLine' => self::UNKNOWN,
                'start' => '',
                'end' => '',
                'protocol' => self::NO_SECURE,
                'action' => self::ACTION_JSON
        ];

        foreach (self::DEVICE_MODELS as $item) {
            $cmpStart = compareMAC($mac, $item['start']);
            $cmpEnd   = compareMAC($mac, $item['end']);
            if ($cmpStart >= 0 && $cmpEnd <= 0 && $cmpStart !== false && $cmpEnd !== false) {
                $model = $item;
            }
        }
        $model['mac'] = $mac;

        if ($model['modelLine'] === self::UNKNOWN) {
            $model['url'] = 'Unable to provision this device type';
        } else {
            $model['url'] = $model['protocol'] . $server . $model['action'];
        }

        return $model;
    }

    public static function isAllowMultipleUsers(string $model) :bool {
        return in_array(strtoupper($model), self::FXS_FAMILY);
    }

    public static function hasToneZone(string $model) :bool {
        return in_array(strtoupper($model), self::AVAILABLE_TONE_ZONE_MODELS);
    }

    public static function hasSnmp(string $model) :bool {
        return in_array(strtoupper($model), self::AVAILABLE_SNMP_MODELS);
    }

    public static function isNeedsToReboot(string $model): bool {
        return in_array(strtoupper($model), self::MODELS_NEED_REBOOT, true);
    }
}
