<?php


namespace Wildix\Dialplan;

/**
 * Class ApplicationFactory
 */
class ApplicationFactory {

    private $_appConfigPath = BASEPATH . 'dialplan/applications/';

    private $_apps = [
        'Answer' => [
            'group' => 'CallControl',
            'config' => 'CallControl__Answer.json'
        ],
        'AuthenticateUser' => [
            'group' => 'CallControl',
            'config' => 'CallControl__AuthenticateUser.json'
        ],
        'CorrectOutgoingNumber' => [
            'group' => 'CallControl',
            'config' => 'CallControl__CorrectOutgoingNumber.json'
        ],
        'DialHuntGroup' => [
            'group' => 'CallControl',
            'config' => 'CallControl__DialHuntGroup.json'
        ],
        'DialPhone' => [
            'group' => 'CallControl',
            'config' => 'CallControl__DialPhone.json'
        ],
        'DialRemotePbx' => [
            'group' => 'CallControl',
            'config' => 'CallControl__DialRemotePbx.json'
        ],
        'DialTrunk' => [
            'group' => 'CallControl',
            'config' => 'CallControl__DialTrunk.json'
        ],
        'Hangup' => [
            'group' => 'CallControl',
            'config' => 'CallControl__Hangup.json'
        ],
        'LookUpCidNameInPhonebook' => [
            'group' => 'ContactsBlacklists',
            'config' => 'ContactsBlacklists__LookUpCidNameInPhonebook.json'
        ],
        'LookUpDestCidNameInPhonebook' => [
            'group' => 'ContactsBlacklists',
            'config' => 'ContactsBlacklists__LookUpDestCidNameInPhonebook.json'
        ],
        'MobilityExtensionLookUp' => [
            'group' => 'ContactsBlacklists',
            'config' => 'ContactsBlacklists__MobilityExtensionLookUp.json'
        ],
        'GenerateDtmf' => [
            'group' => 'Dtmf',
            'config' => 'Dtmf__GenerateDtmf.json'
        ],
        'GenerateFlashHook' => [
            'group' => 'Dtmf',
            'config' => 'Dtmf__GenerateFlashHook.json'
        ],
        'GoToIfFaxDetected' => [
            'group' => 'JumpsConditions',
            'config' => 'JumpsConditions__GoToIfFaxDetected.json'
        ],
        'Goto' => [
            'group' => 'JumpsConditions',
            'config' => 'JumpsConditions__Goto.json'
        ],
        'GotoIf' => [
            'group' => 'JumpsConditions',
            'config' => 'JumpsConditions__GotoIf.json'
        ],
        'GotoIf3SwitchIsOnOrBlinking' => [
            'group' => 'JumpsConditions',
            'config' => 'JumpsConditions__GotoIf3SwitchIsOnOrBlinking.json'
        ],
        'GotoIfBusyCongested' => [
            'group' => 'JumpsConditions',
            'config' => 'JumpsConditions__GotoIfBusyCongested.json'
        ],
        'GotoIfCallType' => [
            'group' => 'JumpsConditions',
            'config' => 'JumpsConditions__GotoIfCallType.json'
        ],
        'GotoIfGroupCount' => [
            'group' => 'JumpsConditions',
            'config' => 'JumpsConditions__GotoIfGroupCount.json'
        ],
        'GotoIfSwitchIsOn' => [
            'group' => 'JumpsConditions',
            'config' => 'JumpsConditions__GotoIfSwitchIsOn.json'
        ],
        'GotoIfUserStatus' => [
            'group' => 'JumpsConditions',
            'config' => 'JumpsConditions__GotoIfUserStatus.json'
        ],
        'Timetable' => [
            'group' => 'JumpsConditions',
            'config' => 'JumpsConditions__Timetable.json'
        ],
        'VerifyCaller' => [
            'group' => 'JumpsConditions',
            'config' => 'JumpsConditions__VerifyCaller.json'
        ],
        'CustomApp' => [
            'group' => 'Other',
            'config' => 'Other__CustomApp.json'
        ],
        'FastAGI' => [
            'group' => 'Other',
            'config' => 'Other__FastAGI.json'
        ],
        'Callback' => [
            'group' => 'Services',
            'config' => 'Services__Callback.json'
        ],
        'Conference' => [
            'group' => 'Services',
            'config' => 'Services__Conference.json'
        ],
        'Directory' => [
            'group' => 'Services',
            'config' => 'Services__Directory.json'
        ],
        'FaxToEmail' => [
            'group' => 'Services',
            'config' => 'Services__FaxToEmail.json'
        ],
        'FeatureIntercom' => [
            'group' => 'Services',
            'config' => 'Services__FeatureIntercom.json'
        ],
        'FeaturePaging' => [
            'group' => 'Services',
            'config' => 'Services__FeaturePaging.json'
        ],
        'MuxMon' => [
            'group' => 'Services',
            'config' => 'Services__MuxMon.json'
        ],
        'Queue' => [
            'group' => 'Services',
            'config' => 'Services__Queue.json'
        ],
        'VoiceMail' => [
            'group' => 'Services',
            'config' => 'Services__VoiceMail.json'
        ],
        'VoiceMailMain' => [
            'group' => 'Services',
            'config' => 'Services__VoiceMailMain.json'
        ],
        'Set' => [
            'group' => 'SetApps',
            'config' => 'SetApps__Set.json'
        ],
        'AsrIvr' => [
            'group' => 'SoundsIvr',
            'config' => 'SoundsIvr__AsrIvr.json'
        ],
        'Background' => [
            'group' => 'SoundsIvr',
            'config' => 'SoundsIvr__Background.json'
        ],
        'IVR' => [
            'group' => 'SoundsIvr',
            'config' => 'SoundsIvr__IVR.json'
        ],
        'Playback' => [
            'group' => 'SoundsIvr',
            'config' => 'SoundsIvr__Playback.json'
        ],
        'WaitExten' => [
            'group' => 'SoundsIvr',
            'config' => 'SoundsIvr__WaitExten.json'
        ],
    ];

    private $_appsCache = [];

    /**
     * Logger class.
     *
     * @var \Logger\Log $_logger
     */
    private $_logger;

    /**
     * Dialplan Formatter.
     *
     * @var DialplanFormatter $_formatter
     */
    private $_formatter;

    /**
     * ApplicationFactory constructor.
     *
     * @param \Logger\Log       $logger     Logger class.
     * @param DialplanFormatter $formatter  Formatter class.
     * @param string            $configPath Patch to configs folder.
     *
     * @return void
     */
    public function __construct(
        \Logger\Log $logger,
        DialplanFormatter $formatter,
        string $configPath = ''
    ) {
        if ($configPath && is_dir($configPath)) {
            $this->_appConfigPath = $configPath;
        }

        $this->_formatter = $formatter;
        $this->_logger    = $logger;
    }

    /**
     * Create application by name.
     *
     * @param string $appName Application name.
     *
     * @return null|ApplicationModel
     */
    public function createApp(string $appName): ?ApplicationModel {
        if (array_key_exists($appName, $this->_appsCache)) {
            return $this->_appsCache[$appName];
        }

        $config = $this->_readAppConfig($appName);
        if (!$config) {
            return null;
        }

        $app = new \Wildix\Dialplan\ApplicationModel($config, $this->_formatter);
        $this->_appsCache[$appName] = $app;

        return $app;
    }

    /**
     * Read app config from JSON file.
     *
     * @param string $appName Application name.
     *
     * @return boolean|array
     */
    private function _readAppConfig(string $appName) {
        if (!array_key_exists($appName, $this->_apps)) {
            $this->_logger->error(__LINE__, sprintf('Not found dialplan app %s', $appName));
            return false;
        }

        $path = $this->_appConfigPath . $this->_apps[$appName]['config'];
        if (!is_file($path) || !is_readable($path)) {
            $this->_logger->error(__LINE__, sprintf('Not found config file for app %s', $appName));
            return false;
        }

        $config = json_decode(file_get_contents($path), true);
        if (!$config) {
            $this->_logger->error(__LINE__, sprintf('Wrong format config file for app %s', $appName));
            return false;
        }
        $config['group'] = $this->_apps[$appName]['group'];

        return $config;
    }

    /**
     * Return list of dialplan applications.
     *
     * @return array
     */
    public function getAppList(): array {
        return array_keys($this->_apps);
    }
}
