<?php

namespace Wildix\Dialplan;

/**
 * Class ApplicationModel
 */
class ApplicationModel {

    protected $_name;

    protected $_group;

    protected $_dialplanAppName;

    protected $_dialplanOutput;

    protected $_dialplanOutputSet;

    protected $_parameter;

    /**
     * Formatter.
     *
     * @var DialplanFormatter $_formatter
     */
    private $_formatter;

    /**
     * ApplicationModel constructor.
     *
     * @param array             $config    Application config.
     * @param DialplanFormatter $formatter Dialplan formatter.
     *
     * @return void
     */
    public function __construct(array $config, DialplanFormatter $formatter) {
        $this->_formatter = $formatter;

        $this->setData($config);
    }

    /**
     * Set data to model.
     *
     * @param array $data Model data.
     *
     * @return void
     */
    private function setData(array $data): void {
        $this->_name              = $data['name'] ?? '';
        $this->_group             = $data['group'] ?? '';
        $this->_dialplanAppName   = $data['dialplanappname'] ?? '';
        $this->_dialplanOutput    = $data['dialplanoutput'] ?? '';
        $this->_dialplanOutputSet = $data['dialplanoutputSet'] ?? $data['dialplanoutput'] ?? '';
        $this->_parameter         = $data['parameter'] ?? [];
    }

    /**
     * Get dialplan name.
     *
     * @return string
     */
    public function getName(): string {
        return $this->_name;
    }

    /**
     * Get dialplan group.
     *
     * @return string
     */
    public function getGroup(): string {
        return $this->_group;
    }

    /**
     * Get dialplan application name.
     *
     * @return string
     */
    public function getDialplanAppName(): string {
        return $this->_dialplanAppName;
    }

    /**
     * Get template for output.
     *
     * @return string
     */
    public function getTemplateForOutput(): string {
        return $this->_dialplanOutput;
    }

    /**
     * Get template for DB.
     *
     * @return string
     */
    public function getTemplateForDb(): string {
        return $this->_dialplanOutputSet;
    }

    /**
     * Get dialplan config params.
     *
     * @param boolean $enableMapping Enable param name mapping.
     *
     * @return array
     */
    public function getParams(bool $enableMapping = true): array {
        $params = [];
        foreach ($this->_parameter as $item) {
            if ($enableMapping) {
                $item['name'] = $this->_formatter->convertParamNameConfigToApi($this->getName(), $item['name']);
            }

            $params[$item['name']] = $item;
        }

        return $params;
    }

    /**
     * Get params list without hidden param.
     *
     * @param boolean $enableMapping Enable param name mapping.
     *
     * @return array
     */
    public function getActiveParamsList(bool $enableMapping = true): array {
        $activeParams = [];
        foreach ($this->getParams($enableMapping) as $item) {
            if ($item['type'] === 'hidden' && (!isset($item['defaultval']) || (isset($item['defaultval']) && $item['defaultval'] !== '{rand}'))) {
                continue;
            }
            $activeParams[] = $item['name'];
        }

        return $activeParams;
    }
}
