<?php

namespace Wildix\Dialplan;

/**
 * Class ApplicationsService
 */
class ApplicationService {

    /**
     * Application factory.
     *
     * @var ApplicationFactory
     */
    private $_appFactory;

    public function __construct(
        \Wildix\Dialplan\ApplicationFactory $appFactory
    ) {
        $this->_appFactory = $appFactory;
    }

    /**
     * Get list of applications.
     *
     * @param boolean $withConfigs Include application configs.
     *
     * @return array
     */
    public function getApplications(bool $withConfigs = false) {
        $result = $this->_appFactory->getAppList();
        if (!$withConfigs) {
            return $result;
        }

        $data = [];
        foreach ($result as $appName) {
            $app = $this->_appFactory->createApp($appName);
            if (!$app) {
                continue;
            }

            $paramsArr       = [];
            $appActiveParams = $app->getActiveParamsList();
            foreach ($app->getParams() as $param) {
                if (in_array($param['name'], $appActiveParams)) {
                    $paramsArr[] = $param;
                }
            }

            $data[$app->getName()] = [
                'name' => $app->getName(),
                'group' => $app->getGroup(),
                'dialplanAppName' => $app->getDialplanAppName(),
                'templateForOutput' => $app->getTemplateForOutput(),
                'templateForDb' => $app->getTemplateForDb(),
                'params' => $paramsArr,
            ];
        }

        return $data;
    }

    /**
     * Get application by name.
     *
     * @param string $appName Application name.
     *
     * @return null|ApplicationModel
     */
    public function getApplication(string $appName): ?ApplicationModel {
        return $this->_appFactory->createApp($appName);
    }
}
