<?php
declare(strict_types=1);
namespace Wildix\Dialplan\CallGroups;

use \Wildix\Core\BaseModel;

/**
 * Class CallGroup
 */
class CallGroup extends BaseModel {

    private $_users = [];
    private $_settings;

    public function __construct(?array $properties) {
        parent::__construct($properties);
        $this->_settings = json_decode($properties['queue_parameters'], true);
    }

    public function getName(): string {
        return (string)$this->getProperty('call_groupname', '');
    }

    public function addUser(string $user): self {
        $this->_users[] = $user;

        return $this;
    }

    public function getUsers(): array {
        return $this->_users;
    }

    public function getSettings(): array {
        $data    = $this->_settings;
        $exitArr = explode(',', (string)$data['joinempty']);
        if (in_array('inuse', $exitArr, true)) {
            $data['exit_all_members_inuse'] = true;
        }
        if (in_array('paused', $exitArr, true)) {
            $data['exit_all_members_paused'] = true;
        }
        if (in_array('ringing', $exitArr, true)) {
            $data['exit_all_members_ringing'] = true;
        }
        if (!isset($data['ringinuse'])) {
            $data['ringinuse'] = true;
        }

        return $data;
    }
}
