<?php
declare(strict_types=1);

namespace Wildix\Dialplan\CallGroups;

use Wildix\CallweaverManager;
use Wildix\Error;
use Wildix\InvalidDataException;

/**
 * Class CallGroupsQueueService
 */
class CallGroupsQueueService {

    private $_storage;

    private $_callWeaver;

    private $_memberFields = [
        'Name',
        'StateInterface',
        'Membership',
        'Penalty',
        'CallsTaken',
        'LastCall',
        'IsInCall',
        'Status',
        'Paused',
        'ActionID',
    ];

    public function __construct(CallGroupsStorage $storage, CallweaverManager $callWeaver) {
        $this->_storage    = $storage;
        $this->_callWeaver = $callWeaver;
    }

    public function getItems(): array {
        return $this->storage()->getItems();
    }

    public function buildItem(CallGroup $item): array {
        $res = [
            'id' => $item->getId(),
            'name' => $item->getName()
        ];

        return $res;
    }

    public function getItem(int $identity, bool $check = false) {
        $item = $this->storage()->getItem($identity);
        if (empty($item) && $check) {
            throw new InvalidDataException(Error::NotFound, [], 404);
        }

        return [
            'id' => $item->getId(),
            'name' => $item->getName(),
            'members' => $this->_getMembersInQueue($identity)
        ];
    }

    private function _getMembersInQueue($queueId):array {
        $data        = [];
        $queueStatus = $this->getCallWeaver()->QueueStatus(['Queue' => $queueId]);
        foreach ($queueStatus['members'] as $member) {
            $info = [];
            foreach ($this->_memberFields as $param) {
                $info[lcfirst($param)] = $member[$param];
            }
            $data[] = $info;
        }

        return $data;
    }

    public function addMember(int $queueId, string $member, int $penalty = 0, int $paused = 0):array {
        return $this->getCallWeaver()->QueueAdd($queueId, $member, $penalty, $paused);
    }

    public function deleteMember(int $queueId, string $member):array {
        return $this->getCallWeaver()->QueueRemove($queueId, $member);
    }

    protected function storage(): CallGroupsStorage {
        return $this->_storage;
    }

    protected function getCallWeaver(): CallweaverManager {
        if (!$this->_callWeaver->isConnected()) {
            $this->_callWeaver->connect();
        }

        return $this->_callWeaver;
    }
}
