<?php
declare(strict_types=1);

namespace Wildix\Dialplan\CallGroups;

use Cache\FileCache;
use Logger\Log;
use PBX;
use Wildix\CallweaverManager;
use Wildix\DependencyInjection\ConfigInterface;
use Wildix\DependencyInjection\Container;
use Wildix\Dialplan\CallGroups\Config\CallGroupsEntitiesConfig;
use Wildix\Dialplan\CallGroups\Config\CallGroupsRulesConfig;
use Wildix\License;

/**
 * Class DiConfig
 */
final class DiConfig implements ConfigInterface {

    public static function configure(Container $container): void {
        $container->singleton(
            CallGroupsStorage::class,
            function () {
                return new CallGroupsStorage();
            }
        );

        $container->singleton(
            ConfigFiles::class,
            function () {
                $entriesConfig = new CallGroupsEntitiesConfig();
                $rulesConfig   = new CallGroupsRulesConfig();
                return new ConfigFiles($entriesConfig, $rulesConfig);
            }
        );

        $container->singleton(
            CallGroupsService::class,
            function (Container $container) {
                return new CallGroupsService(
                    $container->get(CallGroupsStorage::class),
                    PBX::getInstance(),
                    $container->get(ConfigFiles::class),
                    (int)$container->get(License::class)->getLimitations('calls'),
                    $container->get(Log::class),
                    $container->get(FileCache::class)
                );
            }
        );

        $container->singleton(
            CallGroupsQueueService::class,
            function (Container $container) {
                return new CallGroupsQueueService(
                    $container->get(CallGroupsStorage::class),
                    $container->get(CallweaverManager::class)
                );
            }
        );
    }
}
