<?php
namespace Wildix\Dialplan;

use Wildix\Settings\ConfigFile;

/**
 * Class ExtensionsVariables
 */
class ExtensionsVariables extends ConfigFile {

    const INTERNATIONAL_PREFIX   = 'GINTERNATIONAL_PREFIX';
    const NATIONAL_PREFIX        = 'GNATIONAL_PREFIX';
    const COUNTRY_CODE           = 'GCOUNTRY_CODE';
    const INTDIAL_TIMEOUT        = 'GINTDIAL_TIMEOUT';
    const PARK_TIMEOUT           = 'GPARK_TIMEOUT';
    const FAXLANG                = 'GFAXLANG';
    const RECORD_FORMAT          = 'GRECORD_FORMAT';
    const REC_NOTIFY             = 'GREC_NOTIFY';
    const REC_ATTACH             = 'GREC_ATTACH';
    const CTICONNECT3_PHONEBOOKS = 'GCTICONNECT3_PHONEBOOKS';
    const ATTACH_FORMAT_VM       = 'GATTACH_FORMAT_VM';
    const ATTACH_FORMAT_REC      = 'GATTACH_FORMAT_REC';
    const END_OF_DIGIT           = 'GEOD';
    const BUTTON_SOUND           = 'GBUTTON_SOUND';
    const DYNAMIC_FEATURES       = 'DYNAMIC_FEATURES';
    const MOBILITY_PRESENCE      = 'MOBILITY_PRESENCE';
    const DEBUG_LUA              = 'DEBUG_LUA';
    const DESCRIBE_VOICEMAIL     = 'DESCRIBE_VOICEMAIL';
    const USER_VARIABLES         = 'GUSER_VARIABLES';

    const EXTENSIONS_VARIABLES_CONF = '/etc/callweaver/extensions-variables.conf';

    const COMPARE_VARIABLES_CONF = '#include "/etc/companies.d/*/variables.conf"';

    const CUSTOM_INCLUDE = '#include';

    protected $_config;

    public function __construct() {
        parent::__construct(self::EXTENSIONS_VARIABLES_CONF);
    }

    public function get($param = null, $section = null) {
        if ($this->_config === null) {
            $this->_config = [];

            $iniContent = is_readable(self::EXTENSIONS_VARIABLES_CONF) ? file_get_contents(self::EXTENSIONS_VARIABLES_CONF) : false;

            if ($iniContent) {
                $iniContent = preg_replace('/^#/', ';', $iniContent);
                $iniContent = preg_replace('/ => /', ' = ', $iniContent);
                $iniContent = preg_replace('/^[ \t]*=.*/m', '', $iniContent);

                $this->_config = $this->parseNotIniFormat($iniContent);
            }
        }

        $sectionContent = $this->_config;

        if ($param !== null || $section !== null) {
            if ($section !== null) {
                if (isset($this->_config[$section])) {
                    $sectionContent = $this->_config[$section];
                } else {
                    $sectionContent = null;
                }
            }
            if ($param !== null) {
                if ($sectionContent && isset($sectionContent[$param])) {
                    return $sectionContent[$param];
                } else {
                    return null;
                }
            }
        }

        return $sectionContent;
    }

    public function set($param, $value, $section = null) {
        if ($this->_config === null) {
            $this->get();
        }

        if ($section === null) {
            $this->_config[$param] = $value;
        } else {
            $this->_config[$section][$param] = $value;
        }
        return $this;
    }

    public function setData(array $data) {
        $this->_config = $data;
    }

    public function save() {
        $toFile     = self::COMPARE_VARIABLES_CONF . PHP_EOL;
        $parameters = $this->get();

        $lastKey = array_key_last($parameters);
        foreach ($parameters as $key => $value) {
            $toFile .= ($this->isInclude($key)) ? $key : $key . '=' . $value;
            if ($lastKey !== $key) {
                $toFile .= PHP_EOL;
            }
        }

        $fp = @fopen(self::EXTENSIONS_VARIABLES_CONF, 'w');
        if ($fp) {
            fputs($fp, $toFile);
            fclose($fp);
            return true;
        }

        return false;
    }

    public function isInclude($data) {
        $isInclude = strpos($data, '#include');
        return $isInclude !== false ?? true;
    }
}
