<?php
declare(strict_types=1);

namespace Wildix\Dialplan\FeatureCodes;

use Wildix\Exception;
use Services\LuaService;

/**
 * Class FeatureCodesStorage
 */
class FeatureCodesStorage {
    public const FILE_CONF       = PATH_TO_CW_CONF . 'features.conf';
    public const FILE_RES_FUTURE = PATH_TO_CW_CONF . 'res_features.lua';
    public const FILE_LOCK       = '/tmp/extensions.lock';
    public const PREFERENCES     = ['PREFIX'];
    public const FEATURES        = [
    'STATUS', 'BCF', 'UCF', 'FCF', 'CW', 'MEXT', 'TOUT', 'CALLBLOCK', 'ROAD', 'MOBCONFIRMATION',
    ];
    // phpcs:disable Generic.Files.LineLength.MaxExceeded
    public const SERVICES = [
    'VMACCESS', 'DIRECTORY', 'LOGIN', 'PERSONALRECORD', 'PBXRECORD', 'SBARGE', 'PBARGE', 'CBARGE', 'SENDDOC', 'FAXRELAY', 'PAGING', 'HIDECID', 'SWITCH', '3SWITCH', 'STIME', 'PICKUP', 'CONTINUITYCALL', 'QCALL', 'CGMANAGER', 'INTERCOM', 'SHORTNUM', 'CONFERENCE', 'ECHO', 'WHOTELALARM', 'WHOTELMUR', 'IDENTITY', 'WHOTELINSPECT', 'WHOTELBAR',
    ];
    // phpcs:enable Generic.Files.LineLength.MaxExceeded
    public const IN_CALL_FEATURES = [
    'blindxfer', 'atxfer', 'disconnect', 'a_callrec', 'a_callrecpause', 'a_callswitch',
    ];
    public const GROUPS           = [
    'preferences', 'features', 'inCallFeatures', 'services',
    ];

    private const DEFAULT         = [
        'STATUS' => [
            'access' => '60',
            'direct' => '_60!',
            'change' => true
        ],
        'BCF' => [
            'access' => '61',
            'direct' => '_61!',
            'change' => '',
        ],
        'UCF' => [
            'access' => '62',
            'direct' => '_62!',
            'change' => '',
        ],
        'FCF' => [
            'access' => '63',
            'direct' => '_63!',
            'change' => '',
        ],
        'CW' => [
            'access' => '64',
            'direct' => '_64!',
            'change' => true,
        ],
        'MEXT' => [
            'access' => '75',
            'direct' => '_75*!',
            'change' => '',
        ],
        'TOUT' => [
            'access' => '65',
            'direct' => '_65!',
            'change' => '',
        ],
        'CALLBLOCK' => [
            'access' => '72',
            'direct' => '_72*!',
            'change' => true,
        ],
        'ROAD' => [
            'access' => '68',
            'direct' => '_68*!',
            'change' => true,
        ],
        'MOBCONFIRMATION' => [
            'access' => '69',
            'direct' => '_69*!',
            'change' => true,
        ],
        'VMACCESS' => [
            'access' => '81',
            'direct' => '_81!',
            'change' => '',
        ],
        'DIRECTORY' => [
            'access' => '82',
            'direct' => '_82!',
            'change' => '',
        ],
        'LOGIN' => [
            'access' => '99',
            'direct' => '_99!',
            'change' => '',
        ],
        'PERSONALRECORD' => [
            'access' => '84',
            'direct' => '_84!',
            'change' => '',
        ],
        'PBXRECORD' => [
            'access' => '74',
            'direct' => '_74!',
            'change' => '',
        ],
        'CBARGE' => [
            'access' => '85',
            'direct' => '_85!',
            'change' => '',
        ],
        'SBARGE' => [
            'access' => '86',
            'direct' => '_86!',
            'change' => '',
        ],
        'PBARGE' => [
            'access' => '87',
            'direct' => '_87!',
            'change' => '',
        ],
        'SENDDOC' => [
            'access' => '89',
            'direct' => '_89!',
            'change' => '',
        ],
        'FAXRELAY' => [
            'access' => '90',
            'direct' => '_90!',
            'change' => '',
        ],
        'PAGING' => [
            'access' => '91',
            'direct' => '_91!',
            'change' => '',
        ],
        'HIDECID' => [
            'access' => '92',
            'direct' => '_92!',
            'change' => '',
        ],
        'SWITCH' => [
            'access' => '93',
            'direct' => '_93!',
            'change' => '',
        ],
        '3SWITCH' => [
            'access' => '94',
            'direct' => '_94!',
            'change' => '',
        ],
        'STIME' => [
            'access' => '95',
            'direct' => '_95!',
            'change' => '',
        ],
        'PICKUP' => [
            'access' => '88',
            'direct' => '_88!',
            'change' => '',
        ],
        'CONTINUITYCALL' => [
            'access' => '*5',
            'direct' => '_5!',
            'change' => '',
        ],
        'QCALL' => [
            'access' => '79',
            'direct' => '_79!',
            'change' => '',
        ],
        'CGMANAGER' => [
            'access' => '97',
            'direct' => '_97!',
            'change' => '',
        ],
        'INTERCOM' => [
            'access' => '96',
            'direct' => '_96!',
            'change' => '',
        ],
        'CONFERENCE' => [
            'access' => '98',
            'direct' => '_98!',
            'change' => '',
        ],
        'ECHO' => [
            'access' => '76',
            'change' => '',
        ],
        'SHORTNUM' => [
            'access' => '80',
            'direct' => '_80!',
            'change' => '',
        ],
        'PREANSWER' => [
            'gotovm' => '1',
            'gotoprivat' => '2',
            'gotointercom' => 4,
            'gotocc' => '5',
            'change' => '',
        ],
        'IDENTITY' => [
            'access' => '78',
            'change' => '',
        ],
        'WHOTELINSPECT' => [
            'access' => '774',
            'direct' => '_774!',
            'change' => '[01]'
        ],
        'WHOTELBAR' => [
            'access' => '772',
            'direct' => '_772!',
            'change' => '',
        ],
        'WHOTELMUR' => [
            'access' => '771',
            'direct' => '_771!',
            'change' => '[01]'
        ],
        'WHOTELALARM' => [
            'access' => '773',
            'direct' => '_773!',
            'change' => '',
        ],
    ];
    private const FEATURES_MAP    = ['blindxfer', 'atxfer', 'disconnect'];
    private const APPLICATION_MAP = ['a_callrec', 'a_callrecpause', 'a_callswitch'];

    private $_luaService;
    private $_configFile;
    private $_isInstalled;

    public function __construct(LuaService $luaService, FeatureConfigFile $configFile, bool $isInstalled) {
        $this->_luaService  = $luaService;
        $this->_configFile  = $configFile;
        $this->_isInstalled = $isInstalled;
    }

    private function _getLuaService(): LuaService {
        return $this->_luaService;
    }

    private function _getConfig(): FeatureConfigFile {
        return $this->_configFile;
    }

    public function getSettings(): array {
        $res     = [];
        $default = self::DEFAULT;
        $config  = $this->_getConfig()->get();
        $items   = array_merge($default, $this->_getLuaService()->getFeatures());

        foreach ($items as $key => $item) {
            if (isset($item['access'])) {
                $res[$key] = $item['access'];
            }
        }

        foreach (self::FEATURES_MAP as $item) {
            $res[$item] = $config['featuremap'][$item];
        }

        foreach (self::APPLICATION_MAP as $item) {
            $res[$item] = explode(',', $config['applicationmap'][$item])[0];
        }

        return $res;
    }

    public function setSettings(array $data): void {
        $data = array_merge($this->getSettings(), $data);
        arsort($data, SORT_NUMERIC);
        $this->updateConfig($data);
        $this->updateSettings($data);
    }

    private function updateConfig($data): void {
        $this->_getConfig()->setData($data);
        $this->_getConfig()->save();
    }

    private function updateSettings(array $values): void {
        $success = false;
        $prefix  = $values['PREFIX'];
        $items   = array_diff_key($values, array_flip(self::IN_CALL_FEATURES), array_flip(['BTX', 'ATX', 'DIS', 'REC', 'PREANSWER', 'PREFIX']));

        $glFeatures  = $this->buildGlobalFeatures($items, $prefix);
        $pbxFeatures = $this->buildPbxFeatures($items, $prefix);
        $pbxServices = $this->buildPbxServices($items, $prefix);
        $content     = $glFeatures . $pbxFeatures . $pbxServices;

        if (file_exists(self::FILE_LOCK)) {
            $handle = fopen(self::FILE_LOCK, 'r+');
            if (flock($handle, LOCK_EX)) {
                $success = file_put_contents(self::FILE_RES_FUTURE, $content);
                flock($handle, LOCK_UN);
            }
            fclose($handle);
        } else {
            $success = file_put_contents(self::FILE_RES_FUTURE, $content);
        }

        if (!$success) {
            throw new Exception('Can not save features');
        }
    }

    private function buildGlobalFeatures(array $values, string $prefix = ''): string {
        $output    = [];
        $preAnswer = [];

        foreach (self::DEFAULT['PREANSWER'] as $key => $value) {
            $preAnswer[] = sprintf('["%s"] = "%s"', $key, $value);
        }

        foreach ($values as $key => $value) {
            $endStr = '}';
            if (isset(self::DEFAULT[$key]['direct'])) {
                $endStr = sprintf(',["direct"] = "_%s*!"}', $value);
            }
            $output[] = sprintf('["%s"] = {["access"] = "%s"%s', $key, $value, $endStr);
        }
        $output[] = sprintf('["PREFIX"] = {["access"] = "%s"}', $prefix);
        $output[] = sprintf('["PREANSWER"] = {%s}', implode(',', $preAnswer));

        return sprintf('gl_features = {%s}' . PHP_EOL . PHP_EOL, implode(', ', $output));
    }

    private function buildPbxFeatures(array $values, string $prefix = ''): string {
        $output = [];
        $items  = array_intersect_key($values, array_flip(self::FEATURES));

        $patternOne   = '["%s"] = function() return require_once"services":start_call("%s"); end;';
        $patternTwo   = '["_%s*!"] = function() return require_once"services":start_call("%s"); end;';
        $patternThree = '["_%s%s"] = function() return require_once"services":start_call("%s",%s); end;';

        foreach ($items as $key => $value) {
            $ext      = str_replace(['n', 'x', 'z'], ['[n]', '[x]', '[z]'], strtolower($key));
            $value    = $prefix . $value;
            $output[] = sprintf($patternOne, strtolower($key), $key);
            $output[] = sprintf($patternOne, $value, $key);

            if (isset(self::DEFAULT[$key]['direct'])) {
                $output[] = sprintf($patternTwo, $ext, $key);
                $output[] = sprintf($patternTwo, $value, $key);

                if (empty(self::DEFAULT[$key]['change'])) {
                    $output[] = sprintf($patternThree, $value, '!', $key, strlen($value));
                } else if ($key === 'STATUS') {
                    $output[] = sprintf($patternThree, $value, '[0-2]', $key, strlen($value));
                } else {
                    $output[] = sprintf($patternThree, $value, '[013]', $key, strlen($value));
                }
            }
        }

        return sprintf('extensions["pbxfeatures"] = {%s}' . PHP_EOL . PHP_EOL, implode(PHP_EOL, $output));
    }
    // phpcs:disable Generic.Files.LineLength.MaxExceeded
    private function buildPbxServices(array $values, string $prefix = ''): string {
        $res      = [];
        $services = self::SERVICES;
        if (!$this->_isInstalled) {
            $services = array_filter(
                $services,
                function ($item) {
                    return !in_array($item, ['WHOTELINSPECT', 'WHOTELBAR']);
                }
            );
        }
        $res[] = '["story"] = function() return require_once"services":start_call("STORY"); end;';
        $res[] = '["_briX!"] = function() return require_once"services":start_call("PSTN_TRUNK_OCCUPATION"); end;';
        $res[] = '["_priX!"] = function() return require_once"services":start_call("PSTN_TRUNK_OCCUPATION"); end;';
        $res[] = '["_gsmX!"] = function() return require_once"services":start_call("PSTN_TRUNK_OCCUPATION"); end;';
        $res[] = '["_f[x]oX.X"] = function() return require_once"services":start_call("PSTN_TRUNK_OCCUPATION"); end;';
        $res[] = '["_gpickup*!"] = function() return require_once"services":start_call("GPICKUP"); end;';
        $res[] = '["_cg_."] = function() return require_once"services":start_call("QCALL",3); end;';
        $res[] = '["_co[n]f*!"] = function() return require_once"services":start_call("CONFERENCE"); end;';
        $res[] = '["_vm*."] = function() return require_once"services":start_call("VMTRANSFER"); end;';
        $res[] = '["*wair*"] = function() return require_once"services":start_call("CONTINUITYCALL"); end;';

        $items = array_intersect_key($values, array_flip($services));

        foreach ($items as $key => $value) {
            $ext   = str_replace(['n', 'x', 'z'], ['[n]', '[x]', '[z]'], strtolower($key));
            $value = $prefix . $value;
            if (strtoupper($key) === 'IDENTITY') {
                $res[] = sprintf('["%s"] = function() return require_once"services":start_call("%s"); end;', $value, $key);
                $res[] = sprintf('["_%s!"] = function() return require_once"services":start_call("%s",%s); end;', $value, $key, strlen($value));
                continue;
            }

            $res[] = sprintf('["%s"] = function() return require_once"services":start_call("%s"); end;', strtolower($key), $key);
            $res[] = sprintf('["%s"] = function() return require_once"services":start_call("%s"); end;', $value, $key);

            if (isset(self::DEFAULT[$key]['direct'])) {
                $change = self::DEFAULT[$key]['change'];

                if (empty($change)) {
                    $res[] = sprintf('["_%s*!"] = function() return require_once"services":start_call("%s"); end;', $ext, $key);
                    $res[] = sprintf('["_%s*!"] = function() return require_once"services":start_call("%s"); end;', $value, $key);
                    $res[] = sprintf('["_%s!"] = function() return require_once"services":start_call("%s",%s); end;', $value, $key, strlen($value));
                } else {
                    $res[] = sprintf('["_%s*%s"] = function() return require_once"services":start_call("%s"); end;', $ext, $change, $key);
                    $res[] = sprintf('["_%s*%s"] = function() return require_once"services":start_call("%s"); end;', $value, $change, $key);
                    $res[] = sprintf('["_%s%s"] = function() return require_once"services":start_call("%s",%s); end;', $value, $change, $key, strlen($value));
                }
                if ($key === 'QCALL') {
                    $res[] = sprintf('["_%s!"] = function() return require_once"services":start_call("QPICKUP",%s); end;', $value . $items['PICKUP'], strlen($value . $items['PICKUP']));
                    $res[] = sprintf('["_%s*%s!"] = function() return require_once"services":start_call("QPICKUP",%s); end;', $value, $items['PICKUP'], strlen($value . '*' . $items['PICKUP']));
                    $res[] = sprintf('["_%s!"] = function() return require_once"services":start_call("QPICKUP",%s); end;', $items['PICKUP'] . $value, strlen($items['PICKUP'] . $value));
                    $res[] = sprintf('["_%s*%s!"] = function() return require_once"services":start_call("QPICKUP",%s); end;', $items['PICKUP'], $value, strlen($items['PICKUP'] . '*' . $value));
                }
            }
        }
        return sprintf('extensions["pbxservices"] = {%s}' . PHP_EOL . PHP_EOL, implode(PHP_EOL, $res));
    }
    // phpcs:enable Generic.Files.LineLength.MaxExceeded
}
