<?php
declare(strict_types=1);

namespace Wildix\Dialplan\FeatureCodes;

use Wildix\Settings\ConfigFile;

/**
 * Class FeatureConfigFile
 */
class FeatureConfigFile extends ConfigFile {

    const GENERAL_SECTION        = 'general';
    const TRANSFER_DIGIT_TIMEOUT = 'transferdigittimeout';
    const CONTEXT                = 'context';
    const TRANSFER_INTER_DIGIT_TIMEOUT = 'transferinterdigittimeout';

    public const CALL_SWITCH = '%s,self,Macro,autocallswitch';
    public const CALL_REC    = '%s,caller,Macro,autocallrec';
    public const CALL_PAUSE  = '%s,caller,Macro,autocallrecpause';
    private const EQUAL_KEYS = ['parkhints', 'courtesytone', 'xfersound', 'xferfailsound', 'adsipark', 'pickupexten', 'featuredigittimeout', 'atxferdropcall', 'atxfernoanswertimeout'];

    public function setData(array $data) {
        $config = $this->get();

        $config['featuremap']['blindxfer']          = $data['blindxfer'];
        $config['featuremap']['disconnect']         = $data['disconnect'];
        $config['featuremap']['atxfer']             = $data['atxfer'];
        $config['applicationmap']['a_callrec']      = sprintf(self::CALL_REC, $data['a_callrec']);
        $config['applicationmap']['a_callrecpause'] = sprintf(self::CALL_PAUSE, $data['a_callrecpause']);
        $config['applicationmap']['a_callswitch']   = sprintf(self::CALL_SWITCH, $data['a_callswitch']);

        parent::setData($config);
    }
    // phpcs:disable Squiz.Strings.DoubleQuoteUsage.ContainsVar
    public function save() {
        $content = '';
        foreach ($this->get() as $sectionName => $section) {
            $content .= "\n[$sectionName]\n";
            foreach ($section as $key => $value) {
                if (in_array($key, self::EQUAL_KEYS)) {
                    $content .= "$key = $value\n";
                } else {
                    $content .= "$key => $value\n";
                }
            }
        }

        file_put_contents($this->getPath(), $content);
    }
    // phpcs:enable Squiz.Strings.DoubleQuoteUsage.ContainsVar
}
