<?php

namespace Wildix\Dialplan\GeneralSettings;

use \PBX;
use Wildix\Dialplan\ExtensionsVariables;
use \Wildix\DependencyInjection\Container;
use \Wildix\DependencyInjection\ConfigInterface;
use Wildix\Dialplan\FeatureCodes\FeatureConfigFile;
use Wildix\Dialplan\FeatureCodes\FeatureCodesStorage;

/**
 * Class DiConfig
 */
final class DiConfig implements ConfigInterface {
    public static function configure(Container $container): void {
        $container->singleton(
            GeneralSettingsService::class,
            function () {
                $server              = PBX::getInstance();
                $featureConfig       = new FeatureConfigFile(FeatureCodesStorage::FILE_CONF);
                $voiceMailConfig     = new VoiceMailConfigFile();
                $trunkNotification   = new TrunkNotificationConfig();
                $extensionsVariables = new ExtensionsVariables();

                $storage = new GeneralSettingsStorage(
                    $featureConfig,
                    $voiceMailConfig,
                    $trunkNotification,
                    $extensionsVariables
                );

                return new GeneralSettingsService($storage, $server);
            }
        );
    }
}
