<?php
namespace Wildix\Dialplan;

use PBX;
use Wildix\Databases\WMSDB;
use Wildix\Dialplan\Switches\SwitchesService;
use Wildix\Dialplan\TimeTables\TimeTablesService;

class IncomingCalls {

    const DIALPLAN_LINK        = 1;
    const TRUNK_LINK           = 2;
    const CALL_GROUP_LINK      = 3;
    const HUNT_GROUP_LINK      = 5;
    const PBX_LINK             = 6;
    const PAGE_GROUP           = 7;
    const SWITCH_LINK          = 8;
    const TIMETABLE_LINK       = 9;
    const PHONEBOOK_LINK       = 10;
    const IVR_LINK             = 11;
    const RULES_LINKS_TABLE    = 'dialplan_links';
    const RULES_INCLUDES_TABLE = 'dialplan_rules_includes';
    const RULES_TABLE          = 'dialplan_rules';
    const RULES_NAME_TABLE     = 'dialplan_rulenames';

    private $maxMembersInPenaltyGroup = 10;
    private $err;
    private $applicationspath;
    private $rulenamesTable     = 'dialplan_rulenames';
    private $rulesTable         = 'dialplan_rules';//
    private $rulesIncludesTable = 'dialplan_rules_includes';//

    private $timeTables;
    private $switchesService;
    private $pbx;

    public function __construct(
        string $applicationsPath,
        TimeTablesService $timeTables,
        SwitchesService $switchesService,
        PBX $pbx
    ) {
        global $wmsErr;
        $this->applicationspath = $applicationsPath;
        $this->timeTables       = $timeTables;
        $this->switchesService  = $switchesService;
        $this->pbx              = $pbx;
        $this->err              = $wmsErr;
    }

    function get_application($appname){
        $filename = '';
        foreach (array('CallControl','ContactsBlacklists','JumpsConditions','Other','Services','SetApps','Dtmf','SoundsIvr') as $grp){
            $t_filename = $this->applicationspath.$grp.'__'.$appname.'.json';
            if (is_file($t_filename) && is_readable($t_filename)){
                $filename = $t_filename;
            }
        }
        if ($filename == ''){
            return false;
        }

        $json = file_get_contents($filename);
        if (!$json) {
            return false;
        }
        $appArr = json_decode($json,true);
        // translation of formvals
        $appArr['formval'] = _t('inccalls.'.$appname);
        foreach ($appArr['parameter'] as $key=>$value){
            if (isset($value['formval']) && '' != $value['formval']){
                $appArr['parameter'][$key]['formval'] = _t('inccalls.'.$value['formval']);
            }
            if (isset($value['formvalafter']) && '' != $value['formvalafter']){
                $appArr['parameter'][$key]['formvalafter'] = _t('inccalls.'.$value['formvalafter']);
            }
            if (isset($value['form_n_val']) && '' != $value['form_n_val']){
                $appArr['parameter'][$key]['form_n_val'] = $value['form_n_val'];
            }
        }
        return $appArr;
    }

    function get_dialplan_content($rule_id){
        $result = array();
        $query  = "SELECT * FROM `$this->rulesTable` WHERE rule_id='".$rule_id."' ORDER BY number, priority;";

        if ($rows = WMSDB::getInstance()->query($query)) {
            while($row = $rows->fetchArray(SQLITE3_ASSOC)){
                $result[(string)$row['number']]['priorities'][$row['priority']] = $row;
            }
            $rows->finalize();
        }


        $return = array();
        foreach ($result as $exten => $vals){
            $tmp = array('exten' => (string)$exten,'expanded' => 0,/*'exmatch'=>$vals['exmatch'],*/'priorities' => $vals['priorities']);

            $return[] = $tmp;
        }

        return $return;
    }

    function get_dialplan_includes($rule_id){
        $result = array();
        $query = "SELECT include_rule_id FROM `$this->rulesIncludesTable` WHERE rule_id='".$rule_id."' ORDER BY priority;";

        if ($rows = WMSDB::getInstance()->query($query)) {
            while($row = $rows->fetchArray(SQLITE3_ASSOC)){
                $result[] = $row['include_rule_id'];
            }
            $rows->finalize();
        }

        return $result;
    }

    function escape($str){
        $trans = array(" " => "%20");
        return strtr($str, $trans);
    }

    function selectfrom_timetables(){
        $res   = [];
        $items = $this->timeTables->getItems();
        foreach ($items as $item) {
            $res[$item->getId()] = $item->getName();
        }

        return $res;
    }

    function selectfrom_wmsswitches(){
        $res   = [];
        $items = $this->switchesService->getItems();
        foreach ($items as $item) {
            if (!$item->isTreeType()) {
                $res[$item->getId()] = $item->getName();
            }
        }
        return $res;
    }

    function selectfrom_wms3switches(){
        $res   = [];
        $items = $this->switchesService->getItems();
        foreach ($items as $item) {
            if ($item->isTreeType()) {
                $res[$item->getId()] = $item->getName();
            }
        }

        return $res;
    }

    function selectfrom($from, $api = false){
        $outstring = '';
        $items = [];
        if (!in_array($from,array('query_db_types','hg_strategies','classes_of_calls'))) {
            $outstring = '<option value="">-</option>';
            $items[] = ['key' => '-', 'value' => ''];
        }
        if ( ! method_exists($this,'selectfrom_'.$from)){
            if ($api) {
                return array_values($items);
            }
            return $outstring;
        }
        $outarr = call_user_func(array($this,'selectfrom_'.$from));
        if ( ! is_array($outarr)) return $outstring;
        if ($from == 'set_vals') {
            // we return array here
            $outstring = [];
            $items = [];
            foreach ($outarr as $name => $arr){
                $t_outstring = '';
                if(!in_array($name,array('directrtp','timeout', 'itc'))){
                    $t_outstring = '<option value="">-</option>';
                    $items[$name][] = ['key' => '-', 'value' => ''];
                }
                foreach ($arr as $value){
                    $t_outstring .= '<option value="'.$value.'">'.$value.'</option>';
                    $items[$name][] = ['key' => $value, 'value' => $value];
                }
                $outstring[$name] = $t_outstring;
            }
        } elseif (in_array($from,array('sounds','companies','contexts','set_keys','phonebooks','timetables','wmsswitches','wms3switches','page_groups','call_groups','hunt_groups','classes_of_calls','hg_strategies','remote_pbxes','query_db_types', 'trunks', 'causecodes'))){
            foreach ($outarr as $key => $value){
                $outstring .= '<option value="'.$key.'">'.$value.'</option>';
                $items[] = ['key' => $value, 'value' => $key];
            }
        } else {
            foreach ($outarr as $value) {
                $outstring .= '<option value="'.$value.'">'.$value.'</option>';
                $items[] = ['key' => $value, 'value' => $value];
            }
        }

        if($api){
            return $items;
        }
        return $outstring;
    }

    function get_options_form($appname,$input_obj){
        $options = $input_obj['option'];

        $output = '
<form id="'.$appname.'_'.$input_obj['name'].'_form">
<table>
<tr>
<td colspan="3">'._t('inccalls.'.$appname).' '._t('inccalls.'.$input_obj['name']).':</td>
</tr>';

        if (isset($input_obj['kind']) && $input_obj['kind'] == 'selectone'){
            $optid = $appname.'_'.$input_obj['name'].'_form_'.$input_obj['name'];
            $output .= '<tr><td><select id="'.$optid.'">';
            foreach ($options as $object){
                switch ($object['type']) {
                    case 'option':
                        $optid = $appname.'_'.$input_obj['name'].'_form_'.$object['name'];
                        $output .= '<option id="__'.$optid.'" value="'.$object['name'].'">'._t('inccalls.'.$object['description']).'</option>';
                        break;
                }
            }
            $output .= '</select></td></tr>';
        }else {
            foreach ($options as $object){
                $output .= '<tr>';
                switch ($object['type']) {
                    case 'checkbox':
                        $optid = $appname.'_'.$input_obj['name'].'_form_'.$object['name'];
                        $output .= '<td width="15px">'.$object['name'].'</td>';
                        //$output .= '<td>&nbsp;</td>';
                        $output .= '<td  width="15px"><input type="checkbox" id="__'.$optid.'"  style="margin-left:0px;"/><input type="hidden" id="'.$optid.'"/></td>';
                        $output .= '<td>'._t('inccalls.'.$object['description']).'</td>';
                        break;

                    case 'text':
                        $size = 'size="10"';
                        if (isset($object['size'])) $size = 'size="'.$object['size'].'"';
                        $optid = $appname.'_'.$input_obj['name'].'_form_'.$object['name'];
                        $output .= '<td>'.$object['name'].'</td>';
                        $output .= '<td><input '.$size.' type="text" id="'.$optid.'"/></td>';
                        $output .= '<td>'._t('inccalls.'.$object['description']).'</td>';
                        break;

                    default:
                        break;
                }
                $output .= '</tr>';
            }
        }
        $output .= '</table>
</form>';

        //echo $output;

        return array('form' => $output, 'schema' => $options);
    }

    private function get_incoming_dialplan_db2fs(){
        $outarr = array();

        $contexts = array();
        $contexts['-1'] = 'pbxfeatures';
        $contexts['-2'] = 'pbxservices';
        $contexts['-3'] = 'internalcalls';
        $contexts['-4'] = 'pbxinternal';

        $sql = "SELECT id, rulename as context FROM `$this->rulenamesTable` ORDER BY context;";
        if ($rows = WMSDB::getInstance()->query($sql)) {
            while($row = $rows->fetchArray(SQLITE3_ASSOC)){
                $contexts[$row['id']] = $row['context'];
            }
            $rows->finalize();
        }

        $sql = "SELECT rn.id AS drule_id,
                rn.rulename AS context,
                r.number AS exten,
                r.priority AS priority,
                r.dialplanappname AS app,
                r.parameters AS appdata
                FROM `$this->rulesTable` AS r
                LEFT JOIN `$this->rulenamesTable` AS rn ON (rn.id=r.rule_id)
                ORDER BY context, exten, priority;";

        if ($rows = WMSDB::getInstance()->query($sql)) {
            while($tmp = $rows->fetchArray(SQLITE3_ASSOC)){

                $contexts[$tmp['drule_id']] = $tmp['context'];
                $exten = $tmp['exten'];

                if (preg_match('/[XNZ\[\]\.\!]/', $exten)) {
                    $exten = '_'.$exten;
                }
                if(!$outarr[$tmp['drule_id']]){
                    $outarr[$tmp['drule_id']] = array();
                }
                if(!$outarr[$tmp['drule_id']][$exten]){
                    $outarr[$tmp['drule_id']][$exten] = array();
                }

                if ($tmp['app'] == 'CustomApp' && !empty($tmp['appdata'])) {
                    $escape = array('\\' => '\\\\', '"' => '\\"');
                    $tmp['appdata'] = strtr($tmp['appdata'], $escape);
                    $outarr[$tmp['drule_id']][$exten][] = '		require_once"services":start_call("app-custom","'.$tmp['appdata'].'");';
                    continue;
                }

                $appArgs = empty($tmp['appdata'])?array():explode(',',$tmp['appdata']);

                if(in_array($tmp['app'],array('Background','Playback','SendDTMF'))){
                    $outarr[$tmp['drule_id']][$exten][] = '		app.'.$tmp['app'].'('.join(',',$appArgs).');';
                    continue;
                }

                if ($tmp['app'] == 'Answer') {
                    $outarr[$tmp['drule_id']][$exten][] = '		app.Answer(",nocdr");';
                    continue;
                }

                if ($tmp['app'] == 'WaitExten') {
                    $outarr[$tmp['drule_id']][$exten][] = '		app.WaitExten('.join(',',$appArgs).');';
                    continue;
                }

                if ($tmp['app'] == 'app-dial-internalcall' || $tmp['app'] == 'app-queue' || $tmp['app'] == 'app-dial-trunk' || $tmp['app'] == 'app-dial-hunt-group') {
                    $appArgs[] = 1;
                }

                if ($tmp['app'] == 'app-set' && isset($appArgs[0]) && $appArgs[0] == '"CDR(tags)"') {
                    $tags = sizeof($appArgs) > 1 ? trim(join(',', array_slice($appArgs, 1)), "\"") : "";
                    if (!empty($tags)) {
                        $outarr[$tmp['drule_id']][$exten][] = '		require_once"services":start_call("'.$tmp['app'].'","CDR(tags)","tags:' . $tags . '");';
                    }
                } else {
                    $outarr[$tmp['drule_id']][$exten][] = '		require_once"services":start_call("'.$tmp['app'].'"' . (!empty($appArgs)?','.join(',',$appArgs):'') . ');';
                }
            }
            $rows->finalize();
        }

        /**
         * WMS-4496 - delete # from dial the user / intercom app
         */
        foreach($outarr as $context_id => $content) {
            if (array_key_exists("i",$content)){
                continue;
            }
            $isWaitDigRuleExist = false;
            foreach ($content as $exten => $rules) {
                foreach($rules as $rule){
                    if (strpos($rule,"app-playback-waitDigits")!==false || strpos($rule,"app.WaitExten")!==false ){
                        $isWaitDigRuleExist = true;
                    }
                }
            }
            if ($isWaitDigRuleExist){
                $outarr[$context_id]["i"]=array(
                    '		i_exten = channel.INVALID_EXTEN:get() or ""
                if "#" == string.sub(i_exten, -1) then
                        require_once"services":start_call("app-goto-general",string.sub(i_exten, 1, #i_exten - 1),channel.CONTEXT:get() or "","1","");
                else
                        require_once"services":start_call("app-hangup","","1");
                end'
                );
            }
        }

        foreach($outarr as $context_id => $content){
            foreach($content as $exten => $rules){
                $key_update = false;
                $rules_cnt = count($rules);
                if($rules_cnt > 0){
                    $key = $rules_cnt - 1;
                    if(strpos($rules[$key],'"app-dial-internalcall",') || strpos($rules[$key],'"app-queue",') || strpos($rules[$key],'"app-dial-trunk",') || strpos($rules[$key],'"app-dial-hunt-group",')){
                        $key_update = $key;
                    }
                }
                if($key_update !== false){
                    $outarr[$context_id][$exten][$key_update] = substr($outarr[$context_id][$exten][$key_update],0, -3).'0);';
                }
            }
        }

        $sql = 'SELECT rule_id, include_rule_id FROM `'.$this->rulesIncludesTable.'` ORDER BY priority;';
        $includes = array();
        if ($rows = WMSDB::getInstance()->query($sql)) {
            while($row = $rows->fetchArray(SQLITE3_ASSOC)){
                if (isset($contexts[$row['rule_id']]) && isset($contexts[$row['include_rule_id']])){
                    if(!isset($includes[$row['rule_id']])){
                        $includes[$row['rule_id']] = array();
                    }
                    $includes[$row['rule_id']][] = $contexts[$row['include_rule_id']];
                }
            }
            $rows->finalize();
        }

        $lua_script = '';
        foreach ($contexts as $context_id => $context__name){
            if(!isset($includes[$context_id])){
                $includes[$context_id] = array();
            }
            if(!isset($outarr[$context_id]) || !isset($outarr[$context_id]['s'])){
                //$includes[$context_id][] = 'invalid';
            }

            if ($context_id > 0 && strcasecmp($context__name, 'ctivideo') !== 0){
                $lua_script .= PHP_EOL;
                $lua_script .= 'extensions["'.$contexts[$context_id]. '"] = {'.PHP_EOL;
                if (isset($outarr[$context_id])){
                    foreach ($outarr[$context_id] as $exten => $rules){
                        $lua_script .= '	["'. str_replace('"', '\"', $exten) .'"] = function (c, e)'.PHP_EOL;
                        foreach($rules as $rule){
                            $lua_script .= $rule.PHP_EOL;
                        }
                        $lua_script .= '	end;'.PHP_EOL;
                    }
                }
                if(!empty($includes[$context_id])){
                    $lua_script .= "	include = {";
                    foreach($includes[$context_id] as $include){
                        $lua_script .= '"'.$include.'",';
                    }
                    $lua_script = substr($lua_script,0,-1);
                    $lua_script .= "};".PHP_EOL;
                }
                $lua_script .= '}'.PHP_EOL;
            }
        }
        return $lua_script;
    }

    public function set_extensions_incomingcalls(){
        $to_file = $this->get_incoming_dialplan_db2fs();
        $fp = fopen('/tmp/extensions-incomingcalls.lua','w');
        if ($to_file != '') fputs($fp,$to_file);
        fclose($fp);

        $lockFile = "/tmp/extensions.lock";
        if(file_exists($lockFile)){
            $handle = fopen($lockFile, "r+");
            if(flock($handle, LOCK_EX)){
                rename('/tmp/extensions-incomingcalls.lua', PATH_TO_CW_CONF.'extensions-incomingcalls.lua');
                flock($handle,LOCK_UN);
            }else{
                logger('Error flock file '.$lockFile,__FUNCTION__,__LINE__);
            }
            fclose($handle);
        }else{
            logger('Not file for lock '.$lockFile,__FUNCTION__,__LINE__);
            rename('/tmp/extensions-incomingcalls.lua', PATH_TO_CW_CONF.'extensions-incomingcalls.lua');
        }

        //make sure that old dialplan file is empty
        $fp = fopen(PATH_TO_CW_CONF.'extensions-incomingcalls.conf','w');
        fclose($fp);
        $this->pbx->put_cli_reload('pbx_lua');
    }

    function getAll(){
        $result = array();
        $query = "SELECT id AS dplan_id, rulename, ruledescription, subrule_id FROM {$this->rulenamesTable} ORDER BY rulename;" ;

        if ($rows = WMSDB::getInstance()->query($query)) {
            while($tmp = $rows->fetchArray(SQLITE3_ASSOC)){
                $tmp['dialplan_content'] = $this->get_dialplan_content($tmp['dplan_id']);
                $tmp['dialplan_includes'] = $this->get_dialplan_includes($tmp['dplan_id']);
                if (in_array($tmp['rulename'], ['main','users','kite', 'classound'], true)) {
                    $tmp['ruledescription'] = _t('dialplan.rule.'.$tmp['rulename']);
                }
                if ($tmp['dplan_id'] == '-1'){
                    array_unshift($result, $tmp); // pushing [main] to the top
                } else {
                    $result[] = $tmp;
                }
            }
            $rows->finalize();
        }

        return $result;
    }

    function getAllNameFromBackup(){
        $result = array();

        $sql = "SELECT name FROM sqlite_master WHERE type='table' AND name='_bkp_".$this->rulenamesTable."';";

        if ($rows = WMSDB::getInstance()->query($sql)) {
            $row = $rows->fetchArray(SQLITE3_ASSOC);
            $rows->finalize();
            if(!$row['name']){
                return $result;
            }
        }else{
            return $result;
        }


        $sql = "SELECT id, rulename as name, ruledescription as desc FROM _bkp_".$this->rulenamesTable." ORDER BY rulename;";
        if ($rows = WMSDB::getInstance()->query($sql)) {
            while($row = $rows->fetchArray(SQLITE3_ASSOC)){
                $result[] = $row;
            }
            $rows->finalize();
        }


        return $result;
    }

    function restoreBackup($ids){
        $bkp = $this->getAllNameFromBackup();

        $names = array();
        $ids_flip = array_flip($ids);
        foreach($bkp as $val){
            if(array_key_exists($val['id'], $ids_flip)){
                $names[$val['id']] = $val['name'];
            }
        }
        if(empty($names)){
            throw new \Wildix\InvalidDataException('Rule name not found');
        }
        // delete the coincident dialplans named
        $sql = "SELECT id FROM ".$this->rulenamesTable." WHERE rulename IN ('".implode("','", $names)."');";
        $del = array();
        if ($rows = WMSDB::getInstance()->query($sql)) {
            while($row = $rows->fetchArray(SQLITE3_ASSOC)){
                $del[] = $row['id'];
            }
            $rows->finalize();
        }


        if(count($del)){
            WMSDB::getInstance()->exec("DELETE FROM `".self::RULES_LINKS_TABLE."` WHERE `object_from_id` IN ('".implode("','", $del)."');");
            WMSDB::getInstance()->exec("DELETE FROM `".$this->rulenamesTable."` WHERE `id` IN ('".implode("','", $del)."');");
            WMSDB::getInstance()->exec("DELETE FROM `".$this->rulesTable."` WHERE `rule_id` IN ('".implode("','", $del)."');");
            WMSDB::getInstance()->exec("DELETE FROM `".$this->rulesIncludesTable."` WHERE `rule_id` IN ('".implode("','", $del)."');");
        }

        // restore backup in original table
        // select auto increment for rulenames id
        $tmp = array();
        $sql = "select seq from sqlite_sequence WHERE name = '".$this->rulenamesTable."';";
        if ($rows = WMSDB::getInstance()->query($sql)) {
            $tmp = $rows->fetchArray(SQLITE3_ASSOC);
            $rows->finalize();
        }

        $ai =  intval($tmp['seq']);
        $link_id = array();

        foreach($names as $id=>$name){
            $ai++;
            $link_id[$id] = $ai;

            $query = "INSERT INTO `".$this->rulenamesTable."` (`id`,`rulename`,`ruledescription`,`subrule_id`)
				  		  SELECT '".$ai."',`rulename`,`ruledescription`,`subrule_id` FROM `_bkp_".$this->rulenamesTable."` WHERE `id` = '".$id."'";
            WMSDB::getInstance()->exec($query);

            $query = "INSERT INTO `".self::RULES_LINKS_TABLE."` (`object_from_type`,`object_from_id`,`object_to_type`,`object_to_id`)
				  	  	  SELECT `object_from_type`,'".$ai."',`object_to_type`,`object_to_id`
				  	  	  FROM `_bkp_".self::RULES_LINKS_TABLE."` WHERE `object_from_id` = '".$id."';";
            WMSDB::getInstance()->exec($query);

            $query = "INSERT INTO `".$this->rulesTable."` (`rule_id`,`number`,`exmatch`,`priority`,`application`,`parameters`,`dialplanappname`)
				  	  	  SELECT '".$ai."',`number`,`exmatch`,`priority`,`application`,`parameters`,`dialplanappname`
				  	   	  FROM `_bkp_".$this->rulesTable."` WHERE `rule_id` = '".$id."';";
            WMSDB::getInstance()->exec($query);

        }

        // restore include table
        $incl = array();
        $sql = "SELECT id, include_rule_id FROM _bkp_".$this->rulesIncludesTable." WHERE include_rule_id > 0;";
        if ($rows = WMSDB::getInstance()->query($sql)) {
            while($row = $rows->fetchArray(SQLITE3_ASSOC)){
                $id = $link_id[$row['include_rule_id']] ? $link_id[$row['include_rule_id']] : '';
                $incl[$id][] = $row['id'];
            }
            $rows->finalize();
        }

        if(count($incl)){
            foreach($incl as $new=>$old){
                $query = "UPDATE `_bkp_".$this->rulesIncludesTable."` SET include_rule_id = '".$new."' WHERE id IN ('".implode("','", $old)."');";
                WMSDB::getInstance()->exec($query);
            }
        }

        foreach($link_id as $old=>$new){
            $query = "INSERT INTO `".$this->rulesIncludesTable."` (`rule_id`,`priority`,`include_rule_id`)
				  	      SELECT '".$new."',`priority`,`include_rule_id`
				  	      FROM `_bkp_".$this->rulesIncludesTable."` WHERE `rule_id` = '".$old."';";
            WMSDB::getInstance()->exec($query);
        }

        // end include table

        $this->dropBackupTableDialplan();

        $this->set_extensions_incomingcalls();

        return $this->getApplicationsCache();
    }

    function dropBackupTableDialplan(){
        $query = "DROP TABLE IF EXISTS `_bkp_".self::RULES_LINKS_TABLE."`";
        WMSDB::getInstance()->exec($query);

        $query = "DROP TABLE IF EXISTS `_bkp_".$this->rulenamesTable."`";
        WMSDB::getInstance()->exec($query);

        $query = "DROP TABLE IF EXISTS `_bkp_".$this->rulesTable."`";
        WMSDB::getInstance()->exec($query);

        $query = "DROP TABLE IF EXISTS `_bkp_".$this->rulesIncludesTable."`";
        WMSDB::getInstance()->exec($query);
    }

    function createBackupTableDialplan($ids){
        $this->dropBackupTableDialplan();

        $query = "CREATE TABLE `_bkp_".self::RULES_LINKS_TABLE."` as SELECT * FROM `".self::RULES_LINKS_TABLE."` WHERE `object_from_id` IN ('".implode("','", $ids)."');";
        WMSDB::getInstance()->exec($query);

        $query = "CREATE TABLE `_bkp_".$this->rulenamesTable."` as SELECT * FROM `".$this->rulenamesTable."` WHERE `id` IN ('".implode("','", $ids)."');";
        WMSDB::getInstance()->exec($query);

        $query = "CREATE TABLE `_bkp_".$this->rulesTable."` as SELECT * FROM `".$this->rulesTable."` WHERE `rule_id` IN ('".implode("','", $ids)."');";
        WMSDB::getInstance()->exec($query);

        $query = "CREATE TABLE `_bkp_".$this->rulesIncludesTable."` as SELECT * FROM `".$this->rulesIncludesTable."` WHERE `rule_id` IN ('".implode("','", $ids)."');";
        WMSDB::getInstance()->exec($query);
    }

    function getApplicationsCache(){
        $result = array();
        $query = "SELECT DISTINCT application FROM `$this->rulesTable` ORDER BY application;";
        if ($rows = WMSDB::getInstance()->query($query)) {
            while($row = $rows->fetchArray(SQLITE3_ASSOC)){
                $result[$row['application'] ] = $row['application'];
            }
            $rows->finalize();
        }

        $result['Goto'] = 'Goto';

        $return = array('apps'=>array(),'selectfrom'=>array(),'optionsforms'=>array());

        foreach ($result as $appname){
            $got_application = $this->get_application($appname);
            if (!is_array($got_application)) continue;

            $return['apps'][$appname] = $got_application;

            foreach ($got_application['parameter'] AS $param){
                if (isset($param['selectfrom'])){
                    if (! isset($return['selectfrom'][$param['selectfrom']])) $return['selectfrom'][$param['selectfrom']] = $this->selectfrom($param['selectfrom']);
                }
                if ($param['type'] == 'optionsstring'){
                    if (! isset($return['optionsforms'][$appname][$param['name']])) $return['optionsforms'][$appname][$param['name']] = $this->get_options_form($appname,$param);
                }
            }
        }
        return $return;
    }

    public function set_dialplan($d_id,$d_name,$d_description,$d_content,$d_includes){
        // validation
        $errors = array();
        $queries = array();

        $wmsDb = WMSDB::getInstance();
        $result = array();
        $d_id = $d_id=='new'?$d_id:(int)$d_id;

        $sql = "SELECT COUNT(rulename) AS present FROM `$this->rulenamesTable`
                 WHERE rulename='".$wmsDb->realEscapeString($d_name)."' AND id<>'$d_id';";
        if ($rows = $wmsDb->query($sql)) {
            $result = $rows->fetchArray(SQLITE3_ASSOC);
            $rows->finalize();
        }

        if ($result['present']){
            $errors["edit_dplan_name"] = _t('strings.AlreadyPresent');
        }

        if (!empty($errors)) return $errors;

        if ($d_id == 'new') {
            // insert new
            try {
                $query = "INSERT INTO `$this->rulenamesTable` (rulename, ruledescription) VALUES ('".$wmsDb->realEscapeString($d_name)."', '".$wmsDb->realEscapeString($d_description)."');";

                $wmsDb->exec($query);

                $d_id = WMSDB::getInstance()->getLastInsertId();
            } catch (Exception $e) {
                $errors["system_error"] = $e->getMessage();
                return $errors;
            }
        } else {
            try {
                $wmsDb->exec("UPDATE `$this->rulenamesTable` SET ruledescription='".$wmsDb->realEscapeString($d_description)."' WHERE id='$d_id';");
            } catch (Exception $e) {
                $errors["system_error"] = $e->getMessage();
                return $errors;
            }
        }


        $queries[] = "DELETE FROM `$this->rulesTable` WHERE rule_id = '$d_id';";
        $queries[] = "DELETE FROM `$this->rulesIncludesTable` WHERE rule_id = '$d_id';";
        $queries[] = "DELETE FROM `".self::RULES_LINKS_TABLE."` WHERE object_from_type = ".self::DIALPLAN_LINK." and object_from_id = '$d_id';";


        $search = array('\\','"',';');
        $replace = array('\\\\','\\"','\\;');
        $links = array(
            IncomingCalls::DIALPLAN_LINK => array(),
            IncomingCalls::HUNT_GROUP_LINK => array(),
            IncomingCalls::PBX_LINK => array(),
            IncomingCalls::TRUNK_LINK => array(),
            IncomingCalls::PAGE_GROUP => array(),
            IncomingCalls::CALL_GROUP_LINK => array(),
            IncomingCalls::SWITCH_LINK => array(),
            IncomingCalls::TIMETABLE_LINK => array(),
            IncomingCalls::PHONEBOOK_LINK => array(),
            IncomingCalls::IVR_LINK => array()
        );
        foreach ($d_content as $exten) {
            $prior_cnt = 0;
            foreach ($exten['priorities'] as $priority){
                $appname = $priority['application'];
                $app_obj = $this->get_application($priority['application']);
                if (isset($app_obj['dialplanoutputSet'])){
                    $priority['parameters'] = $app_obj['dialplanoutputSet'];
                }else{
                    $priority['parameters'] = $app_obj['dialplanoutput'];
                }
                $this->getLinkTo($links, $appname, $priority['rule_params']);
                if (isset($priority['rule_params'])){
                    foreach ($priority['rule_params'] as $key => $val){
                        if ($val == '-'){
                            $val = '';
                        }
                        if ($appname == 'VoiceMail' && $key == 'destination' && strncmp ($val, 'email:', 6) == 0) {
                            $val = substr($val, 6);
                            $val = str_replace($search, $replace, $val); // \ becomes \\ then ; becomes \; (backslash replacement must be the first one)
                        }elseif($appname == 'Set' && $key == 'set_l_key'){
                            switch($val){
                                case 'tags': $val = 'CDR(tags)'; break;
                                case 'language': $val = 'LANGUAGE()'; break;
                                case 'calltype': $val = '__CALLTYPE'; break;
                                case 'mohclass': $val = 'MUSICCLASS()'; break;
                                case 'ringtone': $val = 'RINGTONE()'; break;
                                case 'srtp_security': $val = 'SECURITY'; break;
                                case 'sip_codecs': $val = 'SIP_CODECS'; break;
                                case 'cidname': $val = 'CALLERID(name)'; break;
                                case 'cidnumber': $val = 'CALLERID(number)'; break;
                                case 'trunk_caller_num': $val = '__TRUNK_CALLER_NUM'; break;
                                case 'directrtp': $val = 'DIRECTRTP'; break;
                                case 'timeout': $val = 'TIMEOUT'; break;
                                case 'itc': $val = 'ITC'; break;
                            }
                        }elseif($appname == 'VoiceMailMain' && $key == 'options' && $val == ''){
                            $val = 'c'; // option to pin check
                        }elseif($appname != 'CustomApp'){
                            $val = str_replace($search, $replace, $val); // \ becomes \\ then ; becomes \; (backslash replacement must be the first one)
                            if ($appname == 'FaxToEmail' && $key == 'destination') {
                                // Replace space(s) or/and commas with pipe if application is FaxToEmail and the parameter is destination
                                $val = preg_replace('/\s*[,|\s]\s*/', '|', $val);
                            } else {
                                $val = str_replace(',', '\,', $val); // , becomes \,
                            }
                        }
                        $priority['parameters'] = str_replace('_{_'.$key.'_}', $val, $priority['parameters']);
                    }
                }

                if ($appname === 'AsrIvr') {
                    $priority['parameters'] = '"i"';
                }

                $priority['parameters'] = str_replace("'","''",$priority['parameters']);
                $priority['dialplanappname'] = $app_obj['dialplanappname'];

                $t_ddot_pos = strpos($exten['exten'],':');
                $t_sp_pos = strpos($exten['exten'],' ');
                if ($t_ddot_pos !== false || $t_sp_pos !== false){
                    if ($t_ddot_pos !== false && $t_sp_pos !== false){
                        if ($t_ddot_pos < $t_sp_pos)
                            $pos = $t_ddot_pos;
                        else
                            $pos = $t_sp_pos;
                    }elseif ($t_ddot_pos !== false){
                        $pos = $t_ddot_pos;
                    }elseif ($t_sp_pos !== false){
                        $pos = $t_sp_pos;
                    }
                    $exten['exten'] = substr($exten['exten'],0,$pos);
                }

                $extenEscaped = WMSDB::getInstance()->realEscapeString($exten['exten']);
                $queries[] = "INSERT INTO `$this->rulesTable` (rule_id, number, priority, application, parameters, dialplanappname) VALUES ('$d_id','{$extenEscaped}','$prior_cnt','{$priority['application']}','{$priority['parameters']}','{$priority['dialplanappname']}');";
                $prior_cnt++;
            }
        }

        $inclides_ids = array();
        foreach ($d_includes as $row){
            if($row['druleid']){
                $inclides_ids[] = $row['druleid'];
            }
        }
        $inclides_ids = array_unique($inclides_ids);

        $prior_cnt = 0;
        foreach ($inclides_ids as $inclide_id){
            $queries[] = "INSERT INTO `$this->rulesIncludesTable` (rule_id, priority, include_rule_id) VALUES ('$d_id','$prior_cnt','$inclide_id');";
            $prior_cnt++;
        }

        foreach($links as $type => $ids){
            $ids = array_keys($ids);
            foreach($ids as $id){
                $queries[] = "INSERT INTO `".self::RULES_LINKS_TABLE."` (object_from_type, object_from_id,object_to_type,object_to_id)VALUES(".self::DIALPLAN_LINK.",$d_id,$type,\"$id\")";
            }
        }

        $db = WMSDB::getInstance();

        try {
            $db->beginTransaction();

            foreach ($queries as $query) {
                $db->exec($query);
            }

            $db->endTransaction();
        } catch (Exception $e) {
            try {
                $db->rollbackTransaction();
            } catch (Exception $e) {
                $errors["system_error"] = $e->getMessage();
                return $errors;
            }

            $errors["system_error"] = $e->getMessage();
            return $errors;
        }

        $this->set_extensions_incomingcalls();

        return true;
    }

    private function getLinkTo(&$links, $appname, $parameters){
        switch($appname){
            case 'CorrectOutgoingNumber':
                $links[self::DIALPLAN_LINK][$parameters['context']] = 1;
                break;
            case 'DialHuntGroup':
                $links[self::HUNT_GROUP_LINK][$parameters['hunt_group']] = 1;
                break;
            case 'DialRemotePbx':
                $links[self::PBX_LINK][$parameters['pbx']] = 1;
                break;
            case 'DialTrunk':
                $links[self::TRUNK_LINK][$parameters['trunk']] = 1;
                break;
            case 'FeaturePaging':
                $links[self::PAGE_GROUP][$parameters['dest']] = 1;
                break;
            case 'Queue':
                $links[self::CALL_GROUP_LINK][$parameters['queuename']] = 1;
                break;
            case 'Goto':
                $links[self::DIALPLAN_LINK][$parameters['context']] = 1;
                break;
            case 'GotoIf3SwitchIsOnOrBlinking':
                $links[self::SWITCH_LINK][$parameters['switchname']] = 1;
                $links[self::DIALPLAN_LINK][$parameters['context_on']] = 1;
                $links[self::DIALPLAN_LINK][$parameters['context_bl']] = 1;
                break;
            case 'GotoIfBusyCongested':
                $links[self::DIALPLAN_LINK][$parameters['context']] = 1;
                break;
            case 'GoToCallCostLimit':
                $links[self::DIALPLAN_LINK][$parameters['context']] = 1;
                break;
            case 'GotoIfCallType':
                $links[self::DIALPLAN_LINK][$parameters['context']] = 1;
                break;
            case 'GoToIfFaxDetected':
                $links[self::DIALPLAN_LINK][$parameters['context']] = 1;
                break;
            case 'GotoIfGroupCount':
                $links[self::DIALPLAN_LINK][$parameters['context']] = 1;
                break;
            case 'GotoIfSwitchIsOn':
                $links[self::SWITCH_LINK][$parameters['switchname']] = 1;
                $links[self::DIALPLAN_LINK][$parameters['context']] = 1;
                break;
            case 'Timetable':
                $links[self::TIMETABLE_LINK][$parameters['timetablename']] = 1;
                $links[self::DIALPLAN_LINK][$parameters['context']] = 1;
                break;
            case 'VerifyCaller':
                $links[self::DIALPLAN_LINK][$parameters['context']] = 1;
                break;
            case 'LookUpCidNameInPhonebook':
            case 'LookUpDestCidNameInPhonebook':
                $links[self::PHONEBOOK_LINK][$parameters['phonebook']] = 1;
                break;
            case 'IVR':
                $links[self::IVR_LINK][$parameters['ivrname']] = 1;
                break;
        }
    }

    /**
     * Call Groups
     */
    public function getAllCallGroups(){
        $result = array();

        $query = "SELECT id AS cgroup_id, call_groupname, queue_parameters FROM call_groups ORDER BY call_groupname;";
        if ($rows = WMSDB::getInstance()->query($query)) {
            while($row = $rows->fetchArray(SQLITE3_ASSOC)){
                $row['group_members'] = array();
                $row['queue_parameters'] = json_decode($row['queue_parameters'], true);
                $exitArr = explode(',', $row['queue_parameters']['joinempty']);
                if (in_array('inuse', $exitArr)) {
                    $row['queue_parameters']['exit_all_members_inuse'] = 'yes';
                }
                if (in_array('paused', $exitArr)) {
                    $row['queue_parameters']['exit_all_members_paused'] = 'yes';
                }
                if (in_array('ringing', $exitArr)) {
                    $row['queue_parameters']['exit_all_members_ringing'] = 'yes';
                }
                if (!isset($row['queue_parameters']['ringinuse'])) {
                    $row['queue_parameters']['ringinuse'] = 'yes';
                }
                $result[$row['cgroup_id']] = $row;
            }
            $rows->finalize();
        }

        $query = "SELECT call_group_id, group_member FROM call_groups_members;";
        if ($rows = WMSDB::getInstance()->query($query)) {
            while($row = $rows->fetchArray(SQLITE3_ASSOC)){
                $result[$row['call_group_id']]['group_members'][] = $row['group_member'];
            }
            $rows->finalize();
        }

        return array_values($result);
    }

    private function get_queues_db2fs(){
        $queues = array();
        $queues_names = array();
        $queues_params = array();
        $final_members_arr = array();
        $tmp_rules = array();

        $query = "SELECT id, call_groupname, queue_parameters FROM call_groups ORDER BY call_groupname;";
        if ($rows = WMSDB::getInstance()->query($query)) {
            while($tmp = $rows->fetchArray(SQLITE3_ASSOC)){
                $queues_names[$tmp['id']] = $tmp['id'];
                $queue_params = array();
                $tmp['queue_parameters'] = json_decode($tmp['queue_parameters'],true);
                foreach ($tmp['queue_parameters'] as $ok => $ov){
                    if ($ov !== '') $queues[$tmp['id']][] = $ok .'='.$ov;
                    if ($ok == 'strategy' || $ok == 'timeout') $queue_params[$ok] = $ov;
                }

                if (!isset($queue_params['strategy']) || $queue_params['strategy'] == ''){
                    $queue_params['strategy'] = 'ringall';
                }
                if (!isset($queue_params['timeout']) || $queue_params['timeout'] == ''){
                    $queue_params['timeout'] = 15;
                }
                $queues_params[$tmp['id']] = $queue_params;

            }
            $rows->finalize();
        }

        $all_members_arr = array();

        $query = "SELECT call_group_id, group_membername FROM call_groups_members ORDER BY id;";
        if ($rows = WMSDB::getInstance()->query($query)) {
            while($tmp = $rows->fetchArray(SQLITE3_ASSOC)){
                if (isset($queues_names[$tmp['call_group_id']])){
                    $all_members_arr[$tmp['call_group_id']][] = $tmp['group_membername'];
                    if (! isset($final_members_arr[$tmp['call_group_id']])) {
                        $final_members_arr[$tmp['call_group_id']] = array();
                    }
                }
            }
            $rows->finalize();
        }

        foreach ($all_members_arr as $group_id => $members){
            $count_members = array_count_values($members);
            foreach ($members as $member){
                if (isset($count_members[$member]) && $count_members[$member] > 1){
                    $final_members_arr[$group_id][] = $member.'|1';
                }else{
                    $final_members_arr[$group_id][] = $member;
                }
            }
            if (isset($queues_params[$group_id]) && $queues_params[$group_id]['strategy'] == 'ringall'){
                $final_members_arr[$group_id] = array_unique($final_members_arr[$group_id]);
            }
        }

        foreach ($final_members_arr as $group_id => $members) {
            $is_ringall = isset($queues_params[$group_id]) && $queues_params[$group_id]['strategy'] == 'ringall';
            $is_wringall = isset($queues_params[$group_id]) && $queues_params[$group_id]['strategy'] == 'wringall';
            $penalty = 1;
            $n = 0;
            $timeout = $queues_params[$group_id]['timeout'];
            if($is_ringall && count($members) > $this->maxMembersInPenaltyGroup){
                $queues[$group_id][] = 'defaultrule='.$group_id;
            }

            foreach ($members as $member){
                if($is_ringall && ++$n > $this->maxMembersInPenaltyGroup){
                    $n = 0;
                    $tmp_rules[$group_id][] = 'penaltychange => '.($timeout*$penalty - 2).','.($penalty+1).','.($penalty+1);
                    ++$penalty;
                }
                /**
                 * WMS-5083
                 *
                 * @todo Need refactoring this class and save in database only member extension.
                 */
                if ($is_wringall && preg_match("~\/(\d+)@internalcalls~", $member, $math)) {
                    $queues[$group_id][] = 'member => SIP/' . $math[1].',1';
                } else {
                    $queues[$group_id][] = 'member => '.$member.','.$penalty;
                }
            }
        }

        $entities = array();
        foreach ($queues as $cgroup_id => $rows){
            $entities[] = '['.$queues_names[$cgroup_id].']';
            foreach ($rows as $row){
                $entities[] = $row;
            }
            $entities[] = '';
        }
        $entities[] = '';

        $rules = array();
        foreach ($tmp_rules as $cgroup_id => $rows){
            $rules[] = '['.$queues_names[$cgroup_id].']';
            foreach ($rows as $row){
                $rules[] = $row;
            }
            $rules[] = '';
        }
        $rules[] = '';

        return array('entities' => $entities, 'rules' => $rules);
    }

    function queues_reload(){
        $this->pbx->Command('reload app_queue.so');
    }

    public function set_queues_conf(){
        $confs = $this->get_queues_db2fs();
        $fp = fopen(PATH_TO_CW_CONF.'queues-entities.conf','w');
        fputs($fp,implode("\n",$confs['entities']));
        fclose($fp);

        $fp = fopen(PATH_TO_CW_CONF.'queuerules.conf','w');
        fputs($fp,implode("\n",$confs['rules']));
        fclose($fp);
        // reloading config
        $this->queues_reload();
    }

}
