<?php
declare(strict_types=1);

namespace Wildix\Dialplan\Ivr;

use \Wildix\DependencyInjection\Container;
use \Wildix\DependencyInjection\ConfigInterface;
use Wildix\Dialplan\ContextRepository;
use Wildix\Sounds\SoundsService;
use Wildix\Sounds\Storage;

/**
 * Class DiConfig
 */
final class DiConfig implements ConfigInterface {

    public static function configure(Container $container): void {
        $container->singleton(
            IvrValidator::class,
            function (Container $container) {
                $validator = new IvrValidator();

                $contexts = $container->get(ContextRepository::class)->getContexts();
                $validator->setContexts(array_values($contexts));

                $soundStorage = new Storage(SoundsService::REAL_PATH);
                $validator->setSoundStorage($soundStorage);

                return $validator;
            }
        );

        $container->singleton(
            IvrService::class,
            function () {
                $storage = new IvrStorage();
                return new IvrService($storage);
            }
        );
    }
}
