<?php
namespace Wildix\Dialplan\PagingGroups;

use Wildix\Dialplan\BaseDialplansService;
use Wildix\Error;
use Wildix\Validator;

/**
 * Class PagingGroupsService
 */
class PagingGroupsService extends BaseDialplansService {

    const MAX_COUNT = 100;

    public function __construct($storage) {
        $this->_storage = $storage;
    }

    public function create(array $data = []): void {
        $this->validate($data);
        $data = $this->_prepareToSave($data, $this->getAvailableId());
        $this->storage()->create($data);
    }

    public function update(int $identity, array $data = []): void {
        $this->getItem($identity, true);
        $this->validate($data, $identity);
        $data = $this->_prepareToSave($data, $identity);
        $this->storage()->update($identity, $data);
    }

    public function buildItem(PagingGroup $item) {
        return [
            'id' => $item->getId(),
            'title' => $item->getName(),
            'members' => $item->getUsers()
        ];
    }

    private function _prepareToSave(array $data, int $id): array {
        return [
            'id' => $id,
            'name' => $data['title'],
            'members' => array_unique($data['members'])
        ];
    }

    protected function makeValidator(array $data): Validator {
        $validator = new Validator($data);
        $validator->rule('required', ['title', 'members']);
        $validator->rule('regex', ['title'], '/^[0-9a-zA-Z-._]*$/')->reason(Error::getMessage(Error::IncorrectFormat));
        $validator->rule('array', ['members']);
        return $validator;
    }

    public function clearUserByExtension(string $extension): void {
        $this->_storage->clearUserByExtension($extension);
    }
}
