<?php

namespace Wildix\Dialplan\PagingGroups;

use Wildix\Databases\WMSDB;

/**
 * Class PagingGroupsStorage
 */
class PagingGroupsStorage {

    const DIALPLAN_LINK = 1;
    const LINK_GROUP    = 7;

    private const GET_ITEMS = 'SELECT * FROM ' . WMSDB::TABLE_PAGING_GROUPS;

    private $_db;

    private function _db(): WMSDB {
        if (!$this->_db) {
            $this->_db = WMSDB::getInstance();
        }
        return $this->_db;
    }

    public function getItems(): array {
        return $this->_db()->getRows(self::GET_ITEMS, null, PagingGroup::class);
    }

    public function getItem(int $identity): ?PagingGroup {
        $item = $this->_db()->first(self::GET_ITEMS . ' WHERE id=' . $identity);
        if ($item) {
            $item = new PagingGroup($item);
        }
        return $item;
    }

    public function create(array $data): void {
        $this->_db()->beginTransaction();
        $this->_db()->insert(
            WMSDB::TABLE_PAGING_GROUPS,
            [
            'id' => $data['id'],
            'name' => $data['name'],
            ]
        );
        $this->_insertUsers($data['id'], $data['members']);
        $this->_db()->endTransaction();
    }

    public function update(int $identity, array $data): void {
        $this->_db()->beginTransaction();
        $this->_clearUsers($identity);
        $this->_db()->exec(sprintf('UPDATE %s SET name="%s" WHERE id=%d', WMSDB::TABLE_PAGING_GROUPS, $data['name'], $identity));
        $this->_insertUsers($identity, $data['members']);
        $this->_db()->endTransaction();
    }

    public function remove(int $identity): void {
        $this->_db()->beginTransaction();
        $this->_clearUsers($identity);
        $this->_db()->exec(sprintf('DELETE FROM %s WHERE id=%d', WMSDB::TABLE_PAGING_GROUPS, $identity));
        $this->_db()->endTransaction();
    }

    public function getLinked($identity): array {
        // phpcs:disable Generic.Files.LineLength.TooLong
        $res = $this->_db()->getRows(
            sprintf(
                'SELECT rn.rulename FROM %s as rl LEFT JOIN %s as rn ON rn.id=rl.object_from_id WHERE rl.object_from_type=%s AND rl.object_to_type=%s AND rl.object_to_id=%d',
                WMSDB::TABLE_RULES_LINKS,
                WMSDB::DIALPLAN_RULE_NAME,
                self::DIALPLAN_LINK,
                self::LINK_GROUP,
                $identity
            )
        );
        // phpcs:enable Generic.Files.LineLength.TooLong
        return $res ? array_column($res, 'rulename') : [];
    }

    public function loadRelations(array $groups = []): array {
        $items = [];

        foreach ($groups as $group) {
            $items[$group->getId()] = $group;
        }

        $users = $this->_getUsers(array_keys($items));

        foreach ($users as $user) {
            if (isset($items[$user['paging_id']])) {
                $items[$user['paging_id']]->addUser($user['group_member']);
            }
        }

        return array_values($items);
    }

    private function _getUsers(array $ids = []): array {
        $items = [];
        if ($ids) {
            $items = $this->_db()->getRows(sprintf('SELECT * FROM %s WHERE paging_id IN (%s)', WMSDB::TABLE_PAGING_MEMBERS, implode(', ', $ids)));
        }
        return $items;
    }

    private function _clearUsers(int $groupId) {
        $this->_db()->exec(sprintf('DELETE FROM %s WHERE paging_id=%d', WMSDB::TABLE_PAGING_MEMBERS, $groupId));
    }

    private function _insertUsers(int $groupId, array $members): void {
        foreach ($members as $member) {
            $this->_db()->insert(
                WMSDB::TABLE_PAGING_MEMBERS,
                [
                'paging_id' => $groupId,
                'group_member' => $member
                ]
            );
        }
    }

    public static function getForUser($ext): array {
        return WMSDB::getInstance()->getRows(
            sprintf(
                'SELECT paging.name, paging.id FROM %s LEFT JOIN %s on (paging.id = paging_members.paging_id) WHERE paging_members.group_member=\'%s\'',
                WMSDB::TABLE_PAGING_GROUPS,
                WMSDB::TABLE_PAGING_MEMBERS,
                $ext
            )
        );
    }

    public function clearUserByExtension(string $extension): void {
        $this->_db()->exec(sprintf('DELETE FROM %s WHERE group_member=\'%s\'', WMSDB::TABLE_PAGING_MEMBERS, $extension));
    }
}
