<?php
namespace Wildix\Dialplan;

use Wildix\Exception;
use Wildix\InvalidDataException;

/**
 * Class Rules
 */
class Rules {
    public const TMP_BACKUP_DIR = '/tmp/dialplan/';

    public function export($rulesIds): array {
        $rulesIdsArr = \Services\Helpers::explodeIdsByDelimiter((string)$rulesIds);
        if (empty($rulesIdsArr)) {
            throw new InvalidDataException('Not found dialplans for export');
        }

        $hostname = trim(file_get_contents('/etc/hostname'));
        $filename = 'dialplan_' . date('Y.m.d_H.i.s') . '_' . $hostname . '_' . WMS_VERSION . '_' . \Models\PBX::getInstance()->getSerial() . '.bkp';

        exec('echo "nohup php /usr/sbin/wms_dialplan_backup ' . $filename . ' ' . implode(',', $rulesIdsArr) . ' 1>/dev/null 2>/dev/null &" | /bin/sh');

        return ['filename' => $filename];
    }

    /**
     * Checks if the backup file is created
     *
     * @param string $exportedFile Dialplan rules backup filename.
     *
     * @return array
     *
     * @throws Exception If backup file size less than 100
     */
    public function pingExport(string $exportedFile): array {
        $pingFile = self::TMP_BACKUP_DIR . $exportedFile;
        $result   = [
            'file'   => $exportedFile,
            'status' => 'yes'
        ];

        if (!file_exists($pingFile)) {
            $result['status'] = 'no';
        } else if (filesize($pingFile) < 100) {
            // If small size, then the backup is not created, even empty database
            throw new Exception(\Wildix\Error::ErrorCreatingBackup);
        }

        return $result;
    }
}
