<?php

namespace Wildix\Dialplan;

/**
 * Class RulesValidator
 */
class RulesValidator {

    /**
     * Validate rule param value.
     *
     * @param ApplicationModel $app        Application.
     * @param string           $paramName  Parameter name.
     * @param string           $paramValue Parameter value.
     *
     * @return boolean
     */
    public function validate(ApplicationModel $app, string $paramName, string $paramValue): bool {
        $params = $app->getParams(false);
        if (!array_key_exists($paramName, $params)) {
            return false;
        }
        $paramConfig = $params[$paramName];

        if (in_array($paramName, ['options', 'flags']) && !empty($paramConfig['option']) && $paramValue) {
            return $this->validateOptionsField($paramConfig, $paramValue);
        }

        return true;
    }

    /**
     * Validate allowed values in option params.
     *
     * @param array  $paramConfig Parameter config.
     * @param string $paramValue  Checked value.
     *
     * @return boolean
     */
    private function validateOptionsField(array $paramConfig, string $paramValue): bool {
        $validValues = array_column($paramConfig['option'], 'name');
        foreach (str_split($paramValue) as $value) {
            if (!in_array($value, $validValues)) {
                return false;
            }
        }

        return true;
    }
}
