<?php
namespace Wildix\Dialplan\Switches;

use Wildix\Dialplan\BaseDialplansService;
use Wildix\Error;
use Wildix\Validator;

/**
 * Class SwitchesService
 */
class SwitchesService  extends BaseDialplansService {

    const TREE_TYPE = '3switch';
    const NORM_TYPE = 'switch';

    public function getItems(): array {
        return $this->storage()->getItems();
    }

    public function create(array $data = []): void {
        $this->getList((boolean)$data['isTreeType']);
        $this->validate($data);
        $data['id'] = $this->getAvailableId();
        $this->storage()->create($data);
        $type = $data['isTreeType'] ? self::TREE_TYPE : self::NORM_TYPE;
        $this->setState($type, $data['id'], $data['state']);
    }

    public function update(int $identity, array $data = []): void {
        $item               = $this->getItem($identity, true);
        $data['isTreeType'] = $item->isTreeType();
        $this->getList($item->isTreeType());
        $this->validate($data, $identity);
        $this->storage()->update($identity, $data);
        $type = $item->isTreeType() ? self::TREE_TYPE : self::NORM_TYPE;
        $this->setState($type, $identity, $data['state']);
    }

    public function buildItem(SwitchEntity $item) {
        return [
            'id' => $item->getId(),
            'title' => $item->getName(),
            'isTreeType' => $item->isTreeType(),
            'state' => $item->getState()
        ];
    }

    protected function makeValidator(array $data): Validator {
        $validator = new Validator($data);
        $validator->rule('required', ['title', 'state', 'isTreeType']);
        $validator->rule('regex', ['title'], '/^[0-9a-zA-Z-._]*$/')->reason(Error::getMessage(Error::IncorrectFormat));
        $validator->rule('boolean', ['isTreeType']);
        $validator->rule('integer', ['state']);
        $validator->rule('min', ['state'], 0);
        if (isset($data['isTreeType'])) {
            $validator->rule('max', ['state'], $data['isTreeType'] ? 2 : 1);
        }

        return $validator;
    }

    protected function getList($type = ''): array {

        if (empty($this->items)) {
            foreach ($this->storage()->getItems() as $item) {
                $this->items[$item->getId()] = $item->isTreeType() === $type ? $item->getName() : '';
            }
        }

        return $this->items;
    }
}
