<?php

namespace Wildix\Dialplan\Switches;

use Wildix\Databases\WMSDB;

/**
 * Class SwitchesStorage
 */
class SwitchesStorage {

    const DIALPLAN_LINK      = 1;
    private const LINK_GROUP = 8;

    private const GET_ITEMS = 'SELECT * FROM ' . WMSDB::TABLE_SWITCHES;

    private $_db;

    private function _db(): WMSDB {
        if (!$this->_db) {
            $this->_db = WMSDB::getInstance();
        }
        return $this->_db;
    }

    public function getItems(): array {
        return $this->_db()->getRows(self::GET_ITEMS, null, SwitchEntity::class);
    }

    public function getItem(int $identity): ?SwitchEntity {
        $item = $this->_db()->first(self::GET_ITEMS . ' WHERE id=' . $identity);
        if ($item) {
            $item = new SwitchEntity($item);
        }
        return $item;
    }

    public function create(array $data): void {
        $this->_db()->beginTransaction();
        $this->_db()->insert(WMSDB::TABLE_SWITCHES, $this->_prepareToSave($data));
        $this->_db()->endTransaction();
    }

    public function update(int $identity, array $data): void {
        $data = $this->_prepareToSave($data);
        $this->_db()->beginTransaction();
        $this->_db()->exec(sprintf('UPDATE %s SET switchname="%s", state=%d WHERE id=%d', WMSDB::TABLE_SWITCHES, $data['switchname'], $data['state'], $identity));
        $this->_db()->endTransaction();
    }

    public function remove(int $identity): void {
        $this->_db()->beginTransaction();
        $this->_db()->exec(sprintf('DELETE FROM %s WHERE id=%d', WMSDB::TABLE_SWITCHES, $identity));
        $this->_db()->endTransaction();
    }

    public function getLinked($identity): array {
        // phpcs:disable Generic.Files.LineLength.TooLong
        $res = $this->_db()->getRows(
            sprintf(
                'SELECT rn.rulename FROM %s as rl LEFT JOIN %s as rn ON rn.id=rl.object_from_id WHERE rl.object_from_type=%s AND rl.object_to_type=%s AND rl.object_to_id=%d',
                WMSDB::TABLE_RULES_LINKS,
                WMSDB::DIALPLAN_RULE_NAME,
                self::DIALPLAN_LINK,
                self::LINK_GROUP,
                $identity
            )
        );
        // phpcs:enable Generic.Files.LineLength.TooLong
        return $res ? array_column($res, 'rulename') : [];
    }

    /**
     * Prepare data to save
     *
     * @param array $data Data.
     *
     * @return array
     */
    private function _prepareToSave(array $data): array {
        return [
            'id' => $data['id'],
            'switchname' => $data['title'],
            'swtype' => $data['isTreeType'] ? SwitchEntity::TREE_TYPE : SwitchEntity::TWO_TYPE,
            'state' => $data['state'],
            'description' => ''
        ];
    }
}
