<?php


namespace Wildix;

/**
 * Class Dictionaries
 */
class Dictionaries {

    private $_dictionaries = [
        'contextsNames',
        'contexts',
    ];

    /**
     * Context repository.
     *
     * @var \Wildix\Dialplan\ContextRepository $_contextRepository
     */
    private $_contextRepository;

    /**
     * Dictionaries constructor.
     *
     * @param \Wildix\Dialplan\ContextRepository $_contextRepository Context repository.
     */
    public function __construct(
        \Wildix\Dialplan\ContextRepository $_contextRepository
    ) {
        $this->_contextRepository = $_contextRepository;
    }

    /**
     * Get dictionary by name.
     *
     * @param string $name Dictionary name.
     *
     * @return array|null
     */
    public function getDictionary(string $name): ?array {
        if (!in_array($name, $this->_dictionaries)) {
            return null;
        }
        $funcName = '_' . $name;

        return $this->$funcName();
    }

    /**
     * Return contexts.
     *
     * @return array
     * @throws \Exception Error.
     */
    private function _contexts() {
        return $this->_contextRepository->getContexts();
    }

    /**
     * Return contexts names.
     *
     * @return array
     * @throws \Exception Error.
     */
    private function _contextsNames() {
        return $this->_contextRepository->getNames();
    }
}
