<?php

namespace Wildix\Generator;

/**
 * Class String
 */
class StringGenerator {
    /**
     * Generate random string
     *
     * @param integer $minLength    Generated string with length equal or grate then this value.
     * @param boolean $onlyAlphaNum Use only alphabetical, numeric and asterisk for generation.
     * @param boolean $noAsterisk   Don't use asterisk for generation.
     *
     * @return string
     */
    public static function random($minLength = 10, $onlyAlphaNum = false, $noAsterisk = false) {
        // 0~9 , A~Z , a~z and "%!@#*"
        $characters = 'abcdefghijklmnopqrstuvwxyz%!@#*ABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890%!@#*';

        if ($noAsterisk) {
            $characters = 'abcdefghijklmnopqrstuvwyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890';
        } else if ($onlyAlphaNum) {
            $characters = 'abcdefghijklm*nopqrstuvw*yzABCDEFGHIJKLMN*OPQRSTUVWXY*Z1234567890*';
        }

        $string = '';
        $strlen = 0;

        $max = strlen($characters) - 1;
        while ($strlen < $minLength) {
            $string .= $characters[random_int(0, $max)];
            $strlen  = strlen($string);
        }

        if (!$noAsterisk) {
            if (!preg_match('/\d/', $string)) {
                $string .= substr(str_shuffle('7890'), 0, 1);
            }
            if (!preg_match('/[a-z]/', $string)) {
                $string .= substr(str_shuffle('ghij'), 0, 1);
            }
            if (!preg_match('/[A-Z]/', $string)) {
                $string .= substr(str_shuffle('IJKL'), 0, 1);
            }
        }
        if (!$onlyAlphaNum && !$noAsterisk && !preg_match('/[\W]/', $string)) {
            $string .= substr(str_shuffle('%!@#'), 0, 1);
        }

        return $string;
    }
}
