<?php
declare(strict_types=1);

namespace Wildix\HttpSecurity;

use Wildix\Auth\Applications\Interfaces\OAuth2ServiceInterface;
use Wildix\DependencyInjection\ConfigInterface;
use Wildix\DependencyInjection\Container;
use Wildix\Settings\ConfigFile;
use Wildix\Validator;

/**
 * Class DiConfig
 */
final class DiConfig implements ConfigInterface {

    public static function configure(Container $container): void {
        $container->singleton(
            Repository::class,
            function () {
                $storage = new ConfigFile(Repository::STORAGE_PATH);
                return new Repository($storage);
            }
        );

        $container->singleton(
            Service::class,
            function (Container $container) {
                return new Service(
                    $container->get(Validator::class),
                    $container->get(Repository::class),
                    $container->get(OAuth2ServiceInterface::class),
                    env('DEFAULT_ORIGINS', [])
                );
            }
        );
    }
}
