<?php
namespace Wildix\HttpSecurity;

use Wildix\Settings\ConfigFile;
use Wildix\Error;
use Wildix\Exception;
use Wildix\InvalidDataException;

/**
 * Class Repository
 */
class Repository {

    const STORAGE_PATH = '/rw2/etc/pbx/http-security.conf';
    /**
     * Instance of ConfigFile.
     *
     * @var ConfigFile
     */
    private $_storage;

    /**
     * Repository constructor.
     *
     * @param ConfigFile   $storage         A storage for persist settings data.
     */
    public function __construct(ConfigFile $storage) {
        $this->_storage = $storage;
    }

    /**
     * Get settings data in storage and return instance of settings.
     *
     * @return ModelSettings
     */
    public function getSettings() {
        $data = $this->_storage->get();

        if (is_array($data)) {
            if(!$data[ModelSettings::FIELD_ORIGIN] || $data[ModelSettings::FIELD_ORIGIN] == "") {
                $data[ModelSettings::FIELD_ORIGIN] = array();
            } else {
                $data[ModelSettings::FIELD_ORIGIN] = explode(',', $data[ModelSettings::FIELD_ORIGIN]);
            }
        } else {
            $data = array();
        }

        return new ModelSettings($data);
    }

    /**
     * Saves the settings in the storage.
     *
     * @param Settings $settings Instance of settings for saving.
     *
     * @return void
     */
    public function save(ModelSettings $settings) {
        $data = $settings->toArray();
        $data[ModelSettings::FIELD_ORIGIN] = implode(',', $data[ModelSettings::FIELD_ORIGIN]);
        foreach($data as $key=>$val) {
            $this->_storage->set($key, $val);
        }
        return $this->_storage->save();
    }
}
