<?php

namespace Wildix\Import;

/**
 * Class Import
 */
class Import extends \Wildix\Services\AbstractService {

    const TOKEN_VALID           = 1;
    const NO_ACCESS_TOKEN       = 2;
    const NO_ID_TOKEN           = 3;
    const TOKEN_EXPIRED         = 4;
    const REFRESH_TOKEN_EXPIRED = 5;

    private $_kite;
    private $_integrationApp;
    private $_integrationAppKey;
    private $_integrationAppUrl;

    public function __construct(\Wildix\Services\Kite $kite, $logLevel = \Syslog::ERROR) {
        parent::__construct($logLevel);

        $this->disableBasicAuth();
        $this->disableSslVerify();

        $this->setConnectTimeout(5);

        $this->_kite = $kite;
    }

    public function setIntegrationAppCredentials($key, $url) {
        $this->_integrationAppKey = $key;
        $this->_integrationAppUrl = $url;
    }

    public function getIntegrationApp($param) {
        if ($this->_integrationApp === null) {
            $this->_integrationApp = $this->_kite->getIntegrationApp($this->_integrationAppKey, $this->_integrationAppUrl);
        }

        return $this->_integrationApp[$param];
    }

    protected function sendRequest($type, $url, $params = null, $formData = false, $headers = null) {
        if (!is_array($params)) {
            $params = array();
        }

        if (empty($headers)) {
            $headers = array('Accept: application/json');
        }

        $this->getLog()->info(__LINE__, $type . ': ' . $url);
        // @codingStandardsIgnoreLine
        $this->getLog()->info(__LINE__, 'Params: ' . print_r($params, true));
        // @codingStandardsIgnoreLine
        $this->getLog()->debug(__LINE__, 'Headers: ' . print_r($headers, true));

        $response = $this->makeRequest($type, $url, $params, $formData, $headers);

        if ($response['result'] === false) {
            throw new \Wildix\Services\Exception\ServiceException($response['error']['reason'], 'CONNECTION_ERROR');
        }

        // @codingStandardsIgnoreLine
        $this->getLog()->debug(__LINE__, 'Dirty response: ' . print_r($response, true));

        $result = $this->parse($response);

        // @codingStandardsIgnoreLine
        $this->getLog()->info(__LINE__, 'Response: ' . print_r($result, true));
        return $result;
    }
}
