<?php

namespace Wildix\Integration;

/**
 * Class CrmSettings
 */
class CrmSettings {
    const CRM_SETTINGS_STORAGE     = 'CRM_SETTINGS';
    const CRM_NEW_CALL_CALLBACK    = 'newCallCallback';
    const CRM_CALL_UPDATE_CALLBACK = 'callUpdateCallback';
    const CRM_CALL_END_CALLBACK    = 'callEndCallback';
    const CRM_VERIFY_CERTIFICATE   = 'verifyCertificate';
    const CRM_BASIC_AUTH_LOGIN     = 'basicAuthLogin';
    const CRM_BASIC_AUTH_PASSWORD  = 'basicAuthPassword';

    /**
     * A storage for settings.
     *
     * @var \Wildix\Databases\WMSDB
     */
    private $_storage;

    private $_settings;

    private $_defaultSettings = array(
        self::CRM_NEW_CALL_CALLBACK => '',
        self::CRM_CALL_UPDATE_CALLBACK => '',
        self::CRM_CALL_END_CALLBACK => '',
        self::CRM_VERIFY_CERTIFICATE => false,
        self::CRM_BASIC_AUTH_LOGIN => '',
        self::CRM_BASIC_AUTH_PASSWORD => '',
    );

    /**
     * Settings constructor.
     *
     * @param \Wildix\Databases\WMSDB $storage A storage for settings.
     */
    public function __construct(\Wildix\Databases\WMSDB $storage) {
        $this->_storage = $storage;
    }

    public function getSettings($force = false) {
        if ($this->_settings === null || $force === true) {
            $settings = json_decode($this->_storage->getSystemVariable(self::CRM_SETTINGS_STORAGE), true);
            if ($settings === null) {
                $settings = array();
            }

            $this->_settings = array_merge($this->_defaultSettings, $settings);
        }
        return $this->_settings;
    }

    private function validateSettings(array $params) {
        $form = new \Wildix\Validator(
            $params,
            array(self::CRM_VERIFY_CERTIFICATE)
        );

        $form->rule(
            'boolean',
            array(self::CRM_VERIFY_CERTIFICATE)
        );

        if (!$form->validate()) {
            throw new \Wildix\InvalidDataException('Validation error', $form->errors());
        }
    }

    public function setSettings($settings) {
        $this->validateSettings($settings);

        $this->_storage->setSystemVariable('CRM_SETTINGS', json_encode($settings));

        return $this->getSettings(true);
    }

    /**
     * Checks if Callback URLs has parameters.
     *
     * @return boolean
     */
    public function hasSettings(): bool {
        $settings = $this->getSettings(true);

        return $settings[self::CRM_NEW_CALL_CALLBACK] !== ''
            || $settings[self::CRM_CALL_UPDATE_CALLBACK] !== ''
            || $settings[self::CRM_CALL_END_CALLBACK] !== '';
    }
}
