<?php
declare(strict_types=1);

namespace Wildix\Integration\XBees\Interfaces;

use Aws\Sdk;
use Models\PBX;
use Wildix\DependencyInjection\ConfigInterface;
use Wildix\DependencyInjection\Container;
use Wildix\Integration\XBees\Repository\AwsRepository;
use Wildix\Integration\XBees\Repository\WimRepository;
use Wildix\Integration\XBees\Service\AwsService;
use Wildix\Integration\XBees\Service\WimService;
use Wildix\Services\GlobalConfig;

/**
 * Class DiConfig
 */
final class DiConfig implements ConfigInterface {

    public static function configure(Container $container): void {
        $container->singleton(
            AwsRepositoryInterface::class,
            function (Container $container) {
                $awsSdk = new Sdk();
                return new AwsRepository(
                    $container->get(GlobalConfig::class),
                    $container->get(PBX::class),
                    $awsSdk
                );
            }
        );

        $container->singleton(
            AwsServiceInterface::class,
            function (Container $container) {
                return new AwsService(
                    $container->get(AwsRepositoryInterface::class)
                );
            }
        );

        $container->singleton(
            WimServiceInterface::class,
            function (Container $container) {
                return new WimService(
                    $container->get(AwsServiceInterface::class),
                    $container->get(WimRepositoryInterface::class)
                );
            }
        );

        $container->singleton(
            WimRepositoryInterface::class,
            function () {
                return new WimRepository(env('SERVICE_WIM_URI'));
            }
        );
    }
}
