<?php

namespace Wildix\Integration\XBees\Repository;

use Wildix\Error;
use Wildix\Exception;
use Wildix\Integration\XBees\Interfaces\WimRepositoryInterface;
use Wildix\Services\AbstractService;

/**
 * Class WimRepository
 */
class WimRepository extends AbstractService implements WimRepositoryInterface {

    private $_wimUri;

    public function __construct(string $wimUri) {
        parent::__construct();

        $this->_wimUri = $wimUri;
    }

    public function getData(string $token): array {
        $url = sprintf('%s/blendr/token', $this->getWimUri());

        $this->disableBasicAuth();
        $response = $this->makeRequest(
            'GET',
            $url,
            null,
            false,
            [sprintf('Authorization: Bearer %s', $token)]
        );

        $result = json_decode($response['result'], true);

        if (!$result || !isset($result['token']) || !isset($result['portal'])) {
            throw new Exception(Error::CantFetchDataFromWIM, 503);
        }

        return $result;
    }

    private function getWimUri(): string {
        return $this->_wimUri;
    }
}
