<?php
declare(strict_types=1);

namespace Wildix\Microsoft;

use Cache\FileCache;
use Logger\Log;
use Wildix\Calendar\CalendarService;
use Wildix\Databases\WMSDB;
use Wildix\DependencyInjection\ConfigInterface;
use Wildix\DependencyInjection\Container;
use Wildix\Normalizer\PhoneNumberNormalizer;
use Wildix\Phonebooks\PhonebooksService;
use Wildix\Services\Kite;
use Wildix\System\Systemd;

/**
 * Class DiConfig
 */
final class DiConfig implements ConfigInterface {

    public static function configure(Container $container): void {
        $container->singleton(
            Office365Service::class,
            function (Container $container) {
                $baseUri = env('MICROSOFT_AUTHORIZE_DOMAIN');

                return new Office365Service(
                    $container->get(WMSDB::class),
                    $container->get(FileCache::class),
                    $container->get(Kite::class),
                    $baseUri,
                    $container->get(CalendarService::class),
                    $container->get(PhonebooksService::class),
                    $container->get(Systemd::class . ':SyncOffice365EventsTimer'),
                    $container->get(Systemd::class . ':SyncOffice365PhonebooksTimer'),
                    $container->get(Log::class)
                );
            }
        );
        $container->singleton(
            ImportContactOffice365::class,
            function (Container $container) {
                return new ImportContactOffice365($container->get(PhoneNumberNormalizer::class));
            }
        );
    }
}
