<?php

namespace Wildix\Microsoft;

use Beta\Microsoft\Graph\Model as BetaModel;
use Wildix\Phonebooks\ImportContactAbstract;

/**
 * Class ImportContact
 */
class ImportContactOffice365 extends ImportContactAbstract {

    // phpcs:ignore
    public function parseContact($contact): array {
        // phpcs:ignore
        /** @var BetaModel\Contact  $contact */

        // hack for null value of birthday
        // sdk incorrect return current date
        $birthday = null;
        if (!empty($contact->getProperties()['birthday'])) {
            $birthday = $contact->getBirthday();
        }

        $result = [
            'id'       => $contact->getId(),
            'created'  => $contact->getCreatedDateTime()->format(DATE_RFC3339),
            'modified' => $contact->getLastModifiedDateTime()->format(DATE_RFC3339),
            'birthday' => $birthday ? $birthday->format('Y-m-d') : '',
            'nickname' => $contact->getNickName() ?? '',
            'notes'    => $contact->getPersonalNotes() ?? '',
            'name'     => [
                'FirstName'   => $contact->getGivenName() ?? '',
                'MiddleName'  => $contact->getMiddleName() ?? '',
                'LastName'    => $contact->getSurname() ?? '',
                'Title'       => $contact->getTitle() ?? '',
                'DisplayName' => $contact->getDisplayName() ?? '',
            ],
            'website'  => '',
            'email'    => [],
            'phone'    => [],
        ];

        $emails = $contact->getEmailAddresses() ?? [];
        foreach ($emails as $key => $value) {
            $result['email'][($key + 1)] = $value['address'];
        }

        $websites = $contact->getWebsites() ?? [];
        if ($websites) {
            $result['website'] = $websites[0]['address'];
        }

        $phones = $contact->getPhones() ?? [];
        $phArr  = [];
        foreach ($phones as $phone) {
            $type = ucfirst($phone['type']);

            if (empty($phArr[$type])) {
                $phArr[$type] = [1 => $phone['number']];
            } else {
                $count = count($phArr[$type]);
                $phArr[$type][($count + 1)] = $phone['number'];
            }
        }
        foreach (['Home', 'Business', 'Mobile'] as $type) {
            if (!empty($phArr[$type])) {
                $n = 0;
                foreach ($phArr[$type] as $key => $val) {
                    $n++;
                    $result['phone'][$type . $n] = $val;
                }
            }
        }

        $jobTitle = $contact->getJobTitle();
        if (!empty($jobTitle)) {
            $result['JobTitle'] = $jobTitle;
        }

        $companyName = $contact->getCompanyName();
        if (!empty($companyName)) {
            $result['company'] = $companyName;
        }

        $department = $contact->getDepartment();
        if (!empty($department)) {
            $result['department'] = $department;
        }

        $profession = $contact->getProfession();
        if (!empty($profession)) {
            $result['profession'] = $profession;
        }

        $assistantName = $contact->getAssistantName();
        if (!empty($assistantName)) {
            $result['AssistantName'] = $assistantName;
        }

        $manager = $contact->getManager();
        if (!empty($manager)) {
            $result['Manager'] = $manager;
        }

        $spouseName = $contact->getSpouseName();
        if (!empty($spouseName)) {
            $result['SpouseName'] = $spouseName;
        }

        $generation = $contact->getGeneration();
        if (!empty($generation)) {
            $result['Generation'] = $generation;
        }

        $officeLocation = $contact->getOfficeLocation();
        if (!empty($officeLocation)) {
            $result['OfficeLocation'] = $officeLocation;
        }

        $addressMap = [
            'home' => 'HomeAddress',
            'business' => 'BusinessAddress',
        ];
        $addresses  = $contact->getPostalAddresses() ?? [];
        foreach ($addresses as $address) {
            $addressKey = array_key_exists($address['type'], $addressMap) ? $addressMap[$address['type']] : 'OtherAddress';

            $result[$addressKey] = [
                'street'          => $address['street'] ?? '',
                'city'            => $address['city'] ?? '',
                'state'           => $address['state'] ?? '',
                'countryOrRegion' => $address['countryOrRegion'] ?? '',
                'postalCode'      => $address['postalCode'] ?? '',
            ];
        }

        return $result;
    }
}
