<?php

namespace Wildix\Notifications\Email;

use Logger\Log;
use Wildix\Core\Http;
use Wildix\Notifications\Email\Objects\EmailData;

class ApiEmailSender implements Interfaces\EmailSenderInterface {

    private $_serviceUrl;
    private $_logger;

    public function __construct(string $serviceUrl, Log $logger) {
        $this->_serviceUrl = $serviceUrl;
        $this->_logger     = $logger;
    }

    public function send(EmailData $data): void {
        $data->attachments = $this->processAttachments($data->getAttachments());

        $response = Http::clientWithPbxAuth()
            ->post(
                sprintf('%s/api/v1/mail/', $this->getServiceUrl()),
                [
                    'json' => $data->toArray()
                ]
            );

        $messageId = json_decode($response->getBody()->getContents(), true)['result']['messageId'];

        $this->getLogger()->info(__LINE__, sprintf('Email sent. Message Id: %s', $messageId));
    }

    private function processAttachments(array $attachments): array {
        $result = [];

        foreach ($attachments as $attachment) {
            $presignedUrlData = $this->createPresignedUrl()['result'];
            $this->uploadFile($presignedUrlData['url'], $attachment);

            $result[] = ['filename' => basename($attachment), 'fileKey' => $presignedUrlData['fileKey']];
        }

        return $result;
    }

    private function createPresignedUrl(): array {
        $response = Http::clientWithPbxAuth()
            ->post(
                sprintf('%s/api/v1/url/', $this->getServiceUrl())
            );

        return json_decode($response->getBody()->getContents(), true);
    }

    private function uploadFile(string $url, string $file): void {
        $body = fopen($file, 'r');
        Http::client()->put($url, ['body' => $body]);
    }

    private function getServiceUrl(): string {
        return $this->_serviceUrl;
    }

    private function getLogger(): Log {
        return $this->_logger;
    }
}
