<?php

namespace Wildix\Notifications\Email;

use Wildix\Notifications\Email\Factories\EmailDataFactory;
use Wildix\Notifications\Email\Interfaces\EmailManagerInterface;
use Wildix\Notifications\Email\Interfaces\EmailSenderInterface;
use Wildix\Notifications\Email\Interfaces\EmailTemplateProcessorInterface;

class EmailManager implements EmailManagerInterface {

    private $_sender;
    private $_templateProcessor;

    public function __construct(EmailSenderInterface $sender, EmailTemplateProcessorInterface $templateProcessor) {
        $this->_templateProcessor = $templateProcessor;
        $this->_sender            = $sender;
    }

    public function send(array $data): void {
        $emailData = EmailDataFactory::make($this->getTemplateProcessor()->process($data));

        $this->getSender()->send($emailData);
    }

    private function getSender(): EmailSenderInterface {
        return $this->_sender;
    }

    private function getTemplateProcessor(): EmailTemplateProcessorInterface {
        return $this->_templateProcessor;
    }
}
