<?php

namespace Wildix\Notifications\Email\Factories;

use Wildix\Notifications\Email\Objects\EmailData;

class EmailDataFactory {
    public static function make(array $data): EmailData {
        $emailData = [];

        $emailData['html']    = $data['body'] ?? '';
        $emailData['subject'] = $data['subject'] ?? '';
        $emailData['from']    = $data['from'] ?? '';

        $emailData['attachments'] = [];

        $data['to'] = $data['to'] ?? [];

        if (!is_array($data['to'])) {
            $emailData['to'] = explode(',', $data['to']);
        }

        if (isset($data['attach']) && is_array($data['attach'])) {
            foreach ($data['attach'] as $attach) {
                if (file_exists($attach)) {
                    $emailData['attachments'][] = $attach;
                }
            }
        } else if (isset($data['attach']) && file_exists($data['attach'])) {
            $emailData['attachments'][] = $data['attach'];
        }

        if (!empty($data['replyto'])) {
            $emailData['replyTo'] = $data['replyto'];
        }

        if (!empty($data['text'])) {
            $emailData['text'] = $data['text'];
        }

        if (!empty($data['cc'])) {
            $emailData['cc'] = is_array($data['cc']) ? $data['cc'] : explode(',', $data['cc']);
        }

        if (!empty($data['bcc'])) {
            $emailData['bcc'] = is_array($data['bcc']) ? $data['bcc'] : explode(',', $data['bcc']);
        }

        return new EmailData($emailData);
    }
}
