<?php

namespace Wildix\Notifications\Email\Interfaces;

use Models\PBX;
use Wildix\DependencyInjection\ConfigInterface;
use Wildix\DependencyInjection\Container;
use Wildix\Dialplan\ExtensionsVariables;
use Wildix\License;
use Wildix\Notifications\Email\ApiEmailSender;
use Wildix\Notifications\Email\EmailManager;
use Wildix\Notifications\Email\EmailTemplateProcessor;
use Wildix\Notifications\Email\SmtpEmailSender;
use Wildix\Services\SpeechToText;
use Wildix\Smtp;
use Wildix\WhiteLabel;

final class DiConfig implements ConfigInterface {
    public static function configure(Container $container): void {
        $container->singleton(
            EmailTemplateProcessorInterface::class,
            function () use ($container) {
                $describeVoiceMail = $container->get(ExtensionsVariables::class)->get(ExtensionsVariables::DESCRIBE_VOICEMAIL) ?? '';
                $pbxDomain         = $container->get(PBX::class)->getDomain();

                return new EmailTemplateProcessor(
                    $container->get(License::class),
                    $describeVoiceMail,
                    $container->get(SpeechToText::class),
                    $container->get(WhiteLabel::class),
                    $pbxDomain
                );
            }
        );

        $container->singleton(
            EmailManagerInterface::class,
            function () use ($container) {
                $smtp   = $container->get(Smtp::class);
                $sender = $smtp->isDefaultConfig() ? ApiEmailSender::class : SmtpEmailSender::class;

                return new EmailManager(
                    $container->get($sender),
                    $container->get(EmailTemplateProcessorInterface::class)
                );
            }
        );
    }
}
