<?php

namespace Wildix\Notifications\Email\Objects;

use Api\Support\DTOValidate\DTOValidate;
use Api\Support\Interfaces\ArrayableInterface;

class EmailData extends DTOValidate implements ArrayableInterface {

    public $from = '';

    public $to  = [];
    public $cc  = [];
    public $bcc = [];
    public $subject;
    public $text = '';
    public $html;
    public $replyTo     = '';
    public $attachments = [];

    public function rules(): array {
        return [
            'to' => [
                'array',
                'required',
            ],
            'cc' => 'array',
            'bcc' => 'array',
            'subject' => [
                'string',
                'required',
            ],
            'text' => 'string',
            'html' => [
                'string',
                'required',
            ],
            'replyTo' => 'string',
            'attachments' => 'array'
        ];
    }

    public function getTo(): array {
        return $this->to;
    }

    public function getCc(): array {
        return $this->cc;
    }

    public function getBcc(): array {
        return $this->bcc;
    }

    public function getSubject(): string {
        return $this->subject;
    }

    public function getText(): string {
        return $this->text;
    }

    public function getHtml(): string {
        return $this->html;
    }

    public function getReplyTo(): string {
        return $this->replyTo;
    }

    public function getAttachments(): array {
        return $this->attachments;
    }

    public function getFrom(): string {
        return $this->from;
    }

    public function toArray(): array {
        $result = [
            'to' => $this->getTo(),
            'subject' => $this->getSubject(),
            'html' => $this->getHtml(),
            'attachments' => $this->getAttachments()
        ];

        if ($this->getReplyTo()) {
            $result['replyTo'] = $this->getReplyTo();
        }

        if ($this->getCc()) {
            $result['cc'] = $this->getCc();
        }

        if ($this->getBcc()) {
            $result['bcc'] = $this->getBcc();
        }

        if ($this->getText()) {
            $result['text'] = $this->getText();
        }

        return $result;
    }
}
