<?php
declare(strict_types=1);

namespace Wildix\PBXes\Network;

use Wildix\System\Ntp;


/**
 * Class Client.
 */
class Client {

    /**
     * Ntp class.
     *
     * @var Ntp $_ntp
     */
    private $_ntp;

    /**
     * Ntp class.
     *
     * @var \aclpbx $_aclpbx
     */
    private $_aclpbx;

    /**
     * User class.
     *
     * @var \User $_user
     */
    private $_user;

    /**
     * WMS_Ldap class.
     *
     * @var \WMS_Ldap $_wmsLdap
     */
    private $_wmsLdap;

    public function __construct(Ntp $ntp, \aclpbx $aclpbx, \WMS_Ldap $wmsLdap, \User $user) {
        $this->_ntp     = $ntp;
        $this->_aclpbx  = $aclpbx;
        $this->_wmsLdap = $wmsLdap;
        $this->_user    = $user;
    }
    public function configuringNtpServer(array $data): void {
        if ($data['SERVER1'] === '' && $data['SERVER2'] === '') {
            return;
        }
        $this->_ntp->setConfig(['SERVER1' => $data['SERVER1'], 'SERVER2' => $data['SERVER2']]);
    }

    public function usersSyncDisableRecurrent(): void {
        $this->_aclpbx->users_sync_disable_recurrent_sync();
    }

    /**
     * Fix auth after replace password from master for the same login.
     *
     * @return void
     */
    public function fixAuth(): void {
        $this->_wmsLdap::closeInstance();
        // update password in session only for user admin
        $currentUser = $this->_user;
        if (!$currentUser->isRoot()) {
            return;
        }
        $userFromMaster = $this->_wmsLdap->getEntryFromMaster($this->_wmsLdap::PERSONS, '(cn=admin)', array('userPassword'));
        if (is_array($userFromMaster) && array_key_exists('userPassword', $userFromMaster)) {
            $currentUser->updateSessionPassword($userFromMaster['userPassword']);
            // WMS-4431 when 40k users, next request 'get slave state' will break auth, this is a fix
            $currentUser->updateSessionCache(time() + $currentUser::DEFAULT_UPDATE_SESSION_CACHE_TIME);
        }
    }
}
