<?php
declare(strict_types=1);

namespace Wildix\PBXes\Network;

use Logger\Log;
use Services\KamailioService;
use Services\LdapService;
use Services\TProxyService;
use Wildix\CallweaverManager;
use Wildix\Databases\AvatarCache;
use Wildix\DependencyInjection\ConfigInterface;
use Wildix\DependencyInjection\Container;
use Wildix\Ejabberd;
use Wildix\PBXes\PBXes;
use Wildix\Settings\ConfigFile;
use Wildix\System\Dhcp\ServerManager;
use Wildix\System\LdapRadius;
use Wildix\System\Ntp;

/**
 * Class DiConfig
 */
final class DiConfig implements ConfigInterface {

    public static function configure(Container $container): void {
        $container->singleton(
            \WMS_Ldap::class,
            static function (): \WMS_Ldap {
                return \WMS_Ldap::getInstance();
            }
        );

        $container->singleton(
            \User::class,
            static function () {
                return \User::getInstance();
            }
        );

        $container->singleton(
            NetworkServices::class,
            function (Container $container) {
                $server            = $container->get(Server::class);
                $client            = $container->get(Client::class);
                $ntp               = $container->get(Ntp::class);
                $wmsLdap           = $container->get(\WMS_Ldap::class);
                $PBXes             = $container->get(PBXes::class);
                $kamailioService   = $container->get(KamailioService::class);
                $ejabberd          = $container->get(Ejabberd::class);
                $ldapService       = $container->get(LdapService::class);
                $avatarCacheDB     = $container->get(AvatarCache::class);
                $serverManager     = $container->get(ServerManager::class);
                $callweaverManager = $container->get(CallweaverManager::class);
                $netRepository     = $container->get(NetRepository::class);
                $ldapRepository    = $container->get(LdapRepository::class);
                $tProxyService     = $container->get(TProxyService::class);
                $ldapRadius        = $container->get(LdapRadius::class);
                return new NetworkServices(
                    $server,
                    $client,
                    $ntp,
                    $wmsLdap,
                    $PBXes,
                    $kamailioService,
                    $ejabberd,
                    $ldapService,
                    $avatarCacheDB,
                    $serverManager,
                    $callweaverManager,
                    $netRepository,
                    $ldapRepository,
                    $tProxyService,
                    $ldapRadius
                );
            }
        );

        $container->singleton(
            Server::class,
            function (Container $container) {
                $PBXes   = $container->get(PBXes::class);
                $wmsLdap = $container->get(\WMS_Ldap::class);
                $log     = $container->get(Log::class);
                return new Server($PBXes, $wmsLdap, $log);
            }
        );

        $container->singleton(
            Client::class,
            function (Container $container) {
                $aclpbx  = new \aclpbx();
                $ntp     = $container->get(Ntp::class);
                $wmsLdap = $container->get(\WMS_Ldap::class);
                $user    = $container->get(\User::class);
                return new Client($ntp, $aclpbx, $wmsLdap, $user);
            }
        );

        $container->singleton(
            NetRepository::class,
            function (Container $container) {
                $storage = new ConfigFile(NetRepository::STORAGE_PATH_NET);
                return new NetRepository($storage);
            }
        );

        $container->singleton(
            LdapRepository::class,
            function (Container $container) {
                $storage = new ConfigFile(LdapRepository::STORAGE_PATH_LDAP);
                return new LdapRepository($storage);
            }
        );
    }
}
