<?php
declare(strict_types=1);

namespace Wildix\PBXes\Network;

use Logger\Log;
use Services\Helpers;
use Wildix\PBXes\PBX;
use Wildix\PBXes\PBXes;

/**
 * Class Server.
 */
class Server {

    /**
     * PBXes class.
     *
     * @var PBXes $_PBXes
     */
    private $_PBXes;

    /**
     * WMS_Ldap class.
     *
     * @var \WMS_Ldap $_wmsLdap
     */
    private $_wmsLdap;

    /**
     * Log service.
     *
     * @var Log
     */
    private $_log;

    public function __construct(PBXes $PBXes, \WMS_Ldap $wmsLdap, Log $log) {
        $this->_PBXes   = $PBXes;
        $this->_wmsLdap = $wmsLdap;
        $this->_log     = $log;
    }

    public function insertPbxToLdap(array $data): void {
        $entry    = $this->_PBXes->getPBXBySerial($data['serial']);
        $property = [
            PBX::HOSTNAME  => $data['hostname'],
            PBX::IP        => $data['masterIp'],
            PBX::IS_MASTER => $data['pbxIsMaster']
        ];

        $this->_PBXes->updatePBXProperty($property, $entry);
    }

    public function isHostAvailable(string $host, int $port = 443, float $timeout = 5): bool {
        $errno    = null;
        $errstr   = null;
        $resource = fsockopen($host, $port, $errno, $errstr, $timeout);
        if (is_resource($resource)) {
            fclose($resource);
            return true;
        }

        return false;
    }

    public function getVersion(): string {
        $pbxFilter = '(|(pbxIsMaster=1))';
        $search    = $this->_wmsLdap->getEntries($this->_wmsLdap::PBX, $pbxFilter, ['description']);

        $version = $search && key_exists('description', $search[0]) ? Helpers::makePbxVersionByDescription($search[0]['description']) : '';

        if ($version === '') {
            $this->_log->error(__LINE__, 'The unable to determine the server version');
        }

        return $version ? sprintf('%s.%s', explode('.', $version)[0], explode('.', $version)[1]) : '';
    }
}
