<?php
namespace Wildix\PBXes;

class PBXes extends \Singleton
{
    private $_pbxes = array();
	public function getPBXByDN($pbxdn) {
	    if(!isset($this->_pbxes[$pbxdn])){
	        $this->_pbxes[$pbxdn] = $this->getPBXByProperty(PBX::DN, $pbxdn);
	    }
	    return $this->_pbxes[$pbxdn];
	}

    public function getPBXByID($pbxid) {
        return $this->getPBXByProperty(PBX::ID, $pbxid);
    }

    public function getPBXByName($name) {
        return $this->getPBXByProperty(PBX::NAME, $name);
    }

    public function getPBXByIp($ip) {
        return $this->getPBXByProperty(PBX::IP, $ip);
    }

    public function getPBXBySerial($serial) {
        return $this->getPBXByProperty(PBX::SERIAL, $serial);
    }

    public function getPBXByDomain($domain) {
        return $this->getPBXByProperty(PBX::DOMAIN, $domain);
    }

    public function getPBXes($name=null, $value=null){
    	return $this->getPBXesByProperty($name, $value);
    }

    private function getPBXByProperty($name, $value) {
    	$pbx = null;
    	if($name == PBX::DN){
    		$pbx = \WMS_Ldap::getInstance()->getEntryByDn($value, PBX::getPBXFields());
    	}else{
	    	$pbx = \WMS_Ldap::getInstance()->getEntry(
	            \WMS_Ldap::PBX,
	            "({$name}={$value})",
	            PBX::getPBXFields()
	        );
    	}

        if ($pbx && !empty($pbx) && is_array($pbx)) {
            return new PBX($pbx);
        }

        return null;
    }

    private function getPBXesByProperty($name, $value = ''){
        $filter = '';
        if (is_array($value)) {
            $filter = "(|({$name}=".join(")({$name}=", $value).'))';
        }else if(!empty($name)){
            $filter = "({$name}={$value})";
        }

        $ldapPBXes = \WMS_Ldap::getInstance()->getEntries(
                \WMS_Ldap::PBX,
                $filter,
                PBX::getPBXFields()
        );

        if ($ldapPBXes && !empty($ldapPBXes) && is_array($ldapPBXes)) {
            $pbxes = array();
            foreach ($ldapPBXes as $key => $pbx){
                $pbxes[] = new PBX($pbx);
            }
            return $pbxes;
        }
        return null;
    }

	public function updatePBXProperty($prop, \Wildix\PBXes\PBX $pbx){
    	$result = \WMS_Ldap::getInstance()->update($pbx->getDN(), $prop);
    	if(!is_bool($result)){
    		throw new \Wildix\Exception($result.': '.print_r($prop, true));
    	}
    	return $result;
    }
}
