<?php
namespace Wildix\Phonebooks;

use Services\Helpers;

class Contact
{
    const ID                = 'id';
    const SOURCE_ID         = 'source_id';
    const NAME              = 'name';
    const EMAIL             = 'email';
    const EXTENSION         = 'extension';
    const PHONE             = 'phone';
    const OFFICE            = 'office';
    const HOME              = 'home';
    const HOME_MOBILE       = 'home_mobile';
    const FAX               = 'fax';
    const MOBILE            = 'mobile';
    const ORGANIZATION      = 'organization';
    const PICTURE           = 'picture';
    const SHORTCUT          = 'shortcut';
    const PHONEBOOK_ID      = 'phonebook_id';
    const GROUP_ID      	= 'group_id';
    const TYPE              = 'type';
    const NOTE              = 'note';
    const ADDRESS           = 'address';
    const VAT_ID            = 'vat_id';
    const NAME_PREFIX       = 'name_prefix';
    const DOCUMENT_TYPE     = 'document_type';
    const DOCUMENT_ID       = 'document_id';
    const DOCUMENT_RELEASED = 'document_released';
    const DOCUMENT_FROM     = 'document_from';
    const PIN               = 'pin';
    const CREDIT            = 'credit';
    const HASH              = 'hash';
    const COUNTRY           = 'country';
    const DATE_BIRTH        = 'date_birth';
    const BORN_IN           = 'born_in';
    const POSTAL_CODE       = 'postal_code';
    const CITY              = 'city';
    const PROVINCE          = 'province';
    const LICENSE_PLATE     = 'license_plate';
    const LAST_UPDATE       = 'last_update';
    const RINGTONE       	= 'ringtone';
    const OWNER_ID       	= 'owner_id';

    const NAME_MIN_LENGTH = 2;

    const ALLOWED_FIELDS = [
        self::ID,
        self::SOURCE_ID,
        self::NAME,
        self::EMAIL,
        self::EXTENSION,
        self::PHONE,
        self::OFFICE,
        self::HOME,
        self::HOME_MOBILE,
        self::FAX,
        self::MOBILE,
        self::ORGANIZATION,
        self::PICTURE,
        self::SHORTCUT,
        self::PHONEBOOK_ID,
        self::GROUP_ID,
        self::TYPE,
        self::NOTE,
        self::ADDRESS,
        self::VAT_ID,
        self::NAME_PREFIX,
        self::DOCUMENT_TYPE,
        self::DOCUMENT_ID,
        self::DOCUMENT_RELEASED,
        self::DOCUMENT_FROM,
        self::PIN,
        self::CREDIT,
        self::HASH,
        self::COUNTRY,
        self::DATE_BIRTH,
        self::DATE_BIRTH,
        self::BORN_IN,
        self::POSTAL_CODE,
        self::CITY,
        self::PROVINCE,
        self::LICENSE_PLATE,
        self::LAST_UPDATE,
        self::RINGTONE,
        self::OWNER_ID,
    ];

    private $_data = null;
    private $_id   = null;

    public function __construct($properties = null) {
        if (is_array($properties)) {
            $this->_data = array_map('trim', $properties);
        }else{
            $this->_data = array(
                    self::NAME => '',
                    self::COUNTRY => ''
            );
        }

        if(!empty($properties[self::ID])){
            $this->_id = $properties[self::ID];
        }else{
            $this->_id = null;
        }
    }

    public function updateWithData($data){
        $this->_data = array_merge($this->_data, $data);
        return true;
    }


    public function getID() {
        return $this->_id;
    }

    public function getSourceID() {
    	return $this->getProperty(self::SOURCE_ID);
    }

    public function getName() {
        return $this->getProperty(self::NAME);
    }

    public function getEmail() {
        return $this->getProperty(self::EMAIL);
    }

    public function getExtension() {
    	return $this->getProperty(self::EXTENSION);
    }

    public function getPhone() {
        return $this->getProperty(self::PHONE);
    }

    public function getOfficePhone() {
    	return $this->getProperty(self::OFFICE);
    }

    public function getHomePhone() {
    	return $this->getProperty(self::HOME);
    }

    public function getHomeMobile() {
    	return $this->getProperty(self::HOME_MOBILE);
    }

    public function getFax() {
        return $this->getProperty(self::FAX);
    }

    public function getMobile() {
        return $this->getProperty(self::MOBILE);
    }

    public function getOrganisation() {
        return $this->getProperty(self::ORGANIZATION);
    }

    public function getPicture() {
        return Helpers::makePictureUrl($this->getProperty(self::PICTURE), $this->getExtension(), $this->getName());
    }

    public function getShortcut() {
        return $this->getProperty(self::SHORTCUT);
    }

    public function getPhonebookID() {
        return $this->getProperty(self::PHONEBOOK_ID);
    }

    public function getGroupID() {
    	return $this->getProperty(self::GROUP_ID);
    }

    public function getType() {
        return $this->getProperty(self::TYPE);
    }

    public function getNote() {
        return $this->getProperty(self::NOTE);
    }

    public function getAddress() {
        return $this->getProperty(self::ADDRESS);
    }

    public function getVatID() {
        return $this->getProperty(self::VAT_ID);
    }

    public function getNamePrefix() {
        return $this->getProperty(self::NAME_PREFIX);
    }

    public function getDocumentType() {
        return $this->getProperty(self::DOCUMENT_TYPE);
    }

    public function getDocumentID() {
        return $this->getProperty(self::DOCUMENT_ID);
    }

    public function getPin() {
        return $this->getProperty(self::PIN);
    }

    public function getCredit() {
        return $this->getProperty(self::CREDIT);
    }

    public function getHash() {
        return $this->getProperty(self::HASH);
    }

    public function getCountry() {
        return $this->getProperty(self::COUNTRY);
    }

    public function getDateBirth() {
        return $this->getProperty(self::DATE_BIRTH);
    }

    public function getBornIn() {
        return $this->getProperty(self::BORN_IN);
    }

    public function getPostalCode() {
        return $this->getProperty(self::POSTAL_CODE);
    }

    public function getCity() {
        return $this->getProperty(self::CITY);
    }

    public function getProvince() {
        return $this->getProperty(self::PROVINCE);
    }

    public function getLicensePlate() {
        return $this->getProperty(self::LICENSE_PLATE);
    }

    public function getDocumentReleased() {
        return $this->getProperty(self::DOCUMENT_RELEASED);
    }

    public function getDocumentFrom() {
        return $this->getProperty(self::DOCUMENT_FROM);
    }

    public function getLastUpdate() {
        return $this->getProperty(self::LAST_UPDATE);
    }

    public function getRingtone() {
    	return $this->getProperty(self::RINGTONE);
    }

    public function getOwnerId() {
        return $this->getProperty(self::OWNER_ID);
    }

    protected function getProperty($name) {
        if ($this->_data && !empty($this->_data) && isset($this->_data[$name])) {
            return $this->_data[$name];
        }
        return null;
    }

    public function getAsArray($fields = null){
        $this->_data[self::PICTURE] = $this->getPicture();

        if(empty($fields)){
            return $this->_data;
        }
        return array_intersect_key($this->_data, array_flip($fields));
    }
}
