<?php
namespace Wildix\Phonebooks;

use Wildix\Exception;

class Phonebook
{
    const ID              = 'id';
    const NAME            = 'name';
    const TYPE            = 'type';
    const HASH            = 'hash';
    const OWNER_ID        = 'owner_id';
    const SYNC            = 'sync_set';
    const SYNC_INTERVAL   = 'sync_interval';
    const SYNC_PARAMS     = 'sync_params';


    const TYPE_PERSONAL   = 1;
    const TYPE_GLOBAL     = 2;
    const TYPE_COLLEAGUE  = 3;


    private $_data = null;
    private $_id = null;

    public function __construct($properties = null) {
        if (is_array($properties)) {
            $this->_data = array_map('trim', $properties);
        }else{
            $this->_data = array(
                    self::ID => null,
                    self::NAME => '',
                    self::TYPE => self::TYPE_PERSONAL,
                    self::HASH => '',
                    self::OWNER_ID => 0,
                    self::SYNC => 0,
                    self::SYNC_INTERVAL => 0,
                    self::SYNC_PARAMS => ''
            );
        }

        if(!empty($properties[Phonebook::ID])){
            $this->_id = $properties[Phonebook::ID];
        }else{
            $this->_id = null;
        }
    }

    public function updateWithData($data){
        $this->_data = array_merge($this->_data, $data);
        return true;
    }

    public function getID() {
        return $this->_id;
    }

    public function getName() {
        return $this->getProperty(Phonebook::NAME);
    }

    public function setName($value) {
        if(empty($value)){
            throw new Exception('The name cannot be empty');
        }
        return $this->setProperty(Phonebook::NAME, $value);
    }

    public function getType() {
        return $this->getProperty(Phonebook::TYPE);
    }

    public function setType($value) {
        if(!in_array($value, array(self::TYPE_PERSONAL,
                                    self::TYPE_GLOBAL,
                                    self::TYPE_COLLEAGUE))){
            throw new Exception('The type can be 1 (PERSONAL), 2 (GLOBAL) or 3 (COLLEAGUE)');
        }
        return $this->setProperty(Phonebook::TYPE, $value);
    }

    public function getHash() {
        return $this->getProperty(Phonebook::HASH);
    }

    public function setHash($value) {
        return $this->setProperty(Phonebook::HASH, $value);
    }

    public function getOwner() {
        return $this->getProperty(Phonebook::OWNER_ID);
    }

    public function setOwner($value) {
        return $this->setProperty(Phonebook::OWNER_ID, $value);
    }

    public function getSync() {
        return $this->getProperty(Phonebook::SYNC);
    }

    public function setSync($value) {
        return $this->setProperty(Phonebook::SYNC, $value);
    }

    public function getSyncInterval() {
        return $this->getProperty(Phonebook::SYNC_INTERVAL);
    }

    public function setSyncInterval($value) {
        return $this->setProperty(Phonebook::SYNC_INTERVAL, $value);
    }

    public function getSyncParams() {
        return $this->getProperty(Phonebook::SYNC_PARAMS);
    }

    public function setSyncParams($value) {
        return $this->setProperty(Phonebook::SYNC_PARAMS, $value);
    }

    protected function getProperty($name) {
        if ($this->_data && !empty($this->_data) && isset($this->_data[$name])) {
            return $this->_data[$name];
        }

        return null;
    }

    protected function setProperty($name, $value) {
        if($this->_data == null){
            $this->_data = array();
        }
        $this->_data[$name] = $value;
        return $this;
    }

    public function getAsArray($fields = null){
        if(empty($fields)){
            return $this->_data;
        }
        return array_intersect_key($this->_data, array_flip($fields));
    }
}
