<?php

namespace Wildix\Phonebooks\Sync;

/**
 * Class SyncSettings
 */
class SyncSettings {

    private $_data = [
        'global' => [
            'backend' => 'office365',
            'remove_users' => 'no',
            'erase_values' => 'no',
        ],
        'office365_settings' => [
            'phonebook' => '',
            'msUserId' => '',
            'userId' => '',
            'updateTime' => '',
            'deltaLink' => '',
        ],
        'office365_map' => [
            'source_id' => 'id',
            'name_prefix' => 'nameTitle',
            'username' => 'name | company',
            'office' => 'phoneBusiness1',
            'home' => 'phoneHome1',
            'home_mobile' => 'phoneHome2',
            'email' => 'email1 | email2 | email3',
            'fax' => 'phoneBusiness2',
            'mobile' => 'phoneMobile1',
            'organization' => 'company',
            'address' => 'addressWork | addressHome | addressOther',
            'postal_code' => 'postcodeHome | postcodeWork',
            'city' => 'cityHome | cityWork',
            'province' => 'regionHome | regionWork',
            'note' => 'notes',
        ],
    ];

    public function __construct($data = []) {
        if (is_string($data)) {
            $data = json_decode($data, true);
        }

        if ($data && !empty($data)) {
            $this->_data = array_merge($this->_data, $data);
        }
    }

    public function asArray(): array {
        return $this->_data;
    }

    public function getBackend(): string {
        return $this->_data['global']['backend'];
    }

    public function getSettings(): array {
        return $this->_data[$this->getBackend() . '_settings'];
    }

    public function setSettings(array $settings): self {
        $this->_data[$this->getBackend() . '_settings'] = $settings;
        return $this;
    }

    public function getMapping(): array {
        return $this->_data[$this->getBackend() . '_map'];
    }

    public function getPhonebookId(): string {
        return $this->getSettings()['phonebook'];
    }

    public function getDeltaLink(): string {
        return $this->getSettings()['deltaLink'];
    }

    public function setDeltaLink(string $link): self {
        $this->_data[$this->getBackend() . '_settings']['deltaLink'] = $link;
        return $this;
    }

    public function getUpdateTime(): string {
        return $this->getSettings()['updateTime'];
    }

    public function setUpdateTime(): self {
        $this->_data[$this->getBackend() . '_settings']['updateTime'] = time();
        return $this;
    }

    public function getMsUserId(): string {
        return $this->getSettings()['msUserId'];
    }

    public function getUserId() {
        return $this->getSettings()['userId'];
    }
}
