<?php


namespace Wildix\Services;

use Wildix\Utils\JWK;

/**
 * Class Aws
 */
class Aws extends AbstractService {

    /**
     * Get AWS public keys
     *
     * @param string $publicKeyUrl Public key URL.
     *
     * @return array
     *
     * @throws Exception\ServiceException Invalid tokens data.
     */
    public function getAwsPublicKeys(string $publicKeyUrl): array {
        $keySet = $this->sendRequest('GET', $publicKeyUrl);

        $keysData = JWK::parseKeySet($keySet);

        $result = [];
        foreach ($keysData as $kid => $pubKey) {
            $keyData = \openssl_pkey_get_details($pubKey);
            if (isset($keyData['key'])) {
                $result[$kid] = $keyData['key'];
            }
        }

        return $result;
    }

    protected function parse($data) {
        $decodedResult = json_decode($data, true);

        if (!$decodedResult || !is_array($decodedResult) || !isset($decodedResult['keys'])) {
            throw new Exception\ServiceException($data, 'RESPONSE_DECODE_ERROR');
        }

        return $decodedResult;
    }
}
