<?php
namespace Wildix\Services;

use Wildix\Exception;

/**
 * Provide an interface to the wildix backtrace service
 */
class Backtrace extends AbstractService {

    private $_backtraceLink;

    /**
     * Backtrace constructor.
     *
     * @param string $_backtraceLink Param link.
     */
    public function __construct(string $_backtraceLink) {
        parent::__construct();
        $this->_backtraceLink = $_backtraceLink;
    }


    /**
     * Add Callweaver Backtrace.
     *
     * @param array $params Params to send.
     *
     * @throws \Wildix\Services\Exception\ServiceException If request failed.
     * @return boolean|mixed
     */
    public function addCallweaverBacktrace(array $params) {
        $response = $this->sendRequest('POST', $this->_backtraceLink . '/api/v1/Callweaver/Trace/', $params);
        if ($response) {
            return $response;
        }
        return false;
    }

    /**
     * Send dump file to backtrace.
     *
     * @param string $fileUri Path of zip file.
     *
     * @return mixed
     * @throws Exception If invalid path with zip archive.
     */
    public function sendDumpToBacktrace($fileUri) {
        if (empty($fileUri) || !file_exists($fileUri) || !stristr($fileUri, '.zip')) {
            throw new Exception('InvalidData', 400);
        }

        $file     = curl_file_create($fileUri);
        $response = $this->sendRequest(
            'POST',
            $this->_backtraceLink . '/api/v1/PBX/Dump/',
            ['dump_archive' => $file],
            true
        );

        return $response;
    }
}
