<?php
declare(strict_types=1);

namespace Wildix\Services;

use Logger\Log;
use Wildix\DependencyInjection\ConfigInterface;
use Wildix\DependencyInjection\Container;
use Wildix\License;

/**
 * Class DiConfig
 */
final class DiConfig implements ConfigInterface {

    public static function configure(Container $container): void {
        $container->singleton(
            SSL::class,
            function () {
                $sslApiURL = env('SERVICE_SSL_URI');
                return new SSL($sslApiURL);
            }
        );

        $container->singleton(
            CheckIP::class,
            function () {
                return new CheckIP();
            }
        );

        $container->{VideoConference::class} = function () {
            return new VideoConference(Log::WARNING, env('SERVICE_CONFERENCE_URI'));
        };

        $container->singleton(
            GroupChat::class,
            function (Container $container) {
                $_defaultConfig = [
                    GroupChat::GROUP_CHAT_ENABLED => \Wildix\Validator::isTrue(env('SERVICE_GROUP_CHAT_ENABLED')) ? 'yes' : 'no',
                    GroupChat::GROUP_CHAT_DOMAIN  => parse_url(env('SERVICE_GROUP_CHAT_URI'), PHP_URL_HOST),
                    GroupChat::SMS_ENABLED => \Wildix\Validator::isTrue(env('SERVICE_SMS_ENABLED')) ? 'yes' : 'no',
                    GroupChat::SMS_DOMAIN => parse_url(env('SERVICE_SMS_URI'), PHP_URL_HOST),
                ];
                return new GroupChat($container->get(License::class), $_defaultConfig, Log::WARNING, null);
            }
        );

        $container->singleton(
            Portal::class,
            function () {
                 return new Portal(Log::INFO, env('SERVICE_PORTAL_API_URI'), env('SERVICE_UPGRADE_PORTAL_URI'));
            }
        );

        $container->singleton(
            PhoneBridge::class,
            function (Container $container) {
                return new PhoneBridge($container->get(Log::class), env('SERVICE_PHONEBRIDGE_URI'));
            }
        );

        $container->singleton(
            SpeechToText::class,
            function () {
                return new SpeechToText(env('SERVICE_SPEECH_TO_TEXT_URI'));
            }
        );

        $container->singleton(
            Backtrace::class,
            function () {
                return new Backtrace(env('SERVICE_BACKTRACE_URI'));
            }
        );

        $container->singleton(
            TextToSpeech::class,
            function () {
                return new TextToSpeech(env('SERVICE_TEXT_TO_SPEECH_URI'));
            }
        );

        $container->singleton(
            Aws::class,
            function (Container $container) {
                return new Aws($container->get(Log::class));
            }
        );

        $container->singleton(
            GlobalConfig::class,
            function () {
                return new GlobalConfig(Log::INFO, env('SERVICE_CONFIGS_URI') . '/');
            }
        );

        $container->singleton(
            AbstractServiceAuth::class,
            function () {
                return new AbstractServiceAuth(Log::INFO);
            }
        );

        $container->singleton(
            WizyWebinar::class,
            function () {
                return new WizyWebinar(Log::INFO, env('SERVICE_WIZYWEBINAR_URI'));
            }
        );

        $container->singleton(
            Kite::class,
            function () {
                return new Kite(Log::INFO);
            }
        );
    }
}
