<?php

namespace Wildix\Services;

use Logger\Log;
use Logger\LoggerFactory;
use \Services\Helpers;

class Header extends \Singleton {

    const DEFAULT_PATH = '/rw2/etc/pbx/headers.json';
    const CUSTOM_PATH  = '/rw2/etc/pbx/headers.custom.json';

    private const KEY    = 'key';
    private const VALUE  = 'value';
    private const ENABLE = 'enable';

    public function send() :void {
        foreach ($this->getEnableItems() as $header) {
            header($header[self::KEY] . ': ' . $header[self::VALUE]);
        }
    }

    public function createCustomFile() {
        return file_exists(self::CUSTOM_PATH) && touch(self::CUSTOM_PATH);
    }

    private function getEnableItems() :array {
        return array_filter(
            $this->getItems(),
            function ($header) {
                return $header[self::ENABLE];
            }
        );
    }

    private function getItems() :array {
        return $this->merge($this->getDefaultItems(), $this->getCustomItems());
    }

    private function merge(array $headers, array $customHeaders) :array {
        if (!$headers) {
            return [];
        }

        foreach ($customHeaders as $customHeader) {
            $index = array_search($customHeader[self::KEY], array_column($headers, self::KEY));

            if (is_int($index)) {
                $headers[$index] = [
                    self::KEY => $customHeader[self::KEY],
                    self::VALUE => $customHeader[self::VALUE] ?? $headers[$index][self::VALUE],
                    self::ENABLE => $customHeader[self::ENABLE]
                ];
            } else {
                if (isset($customHeader[self::VALUE]) && $customHeader[self::VALUE]) {
                    $headers[] = $customHeader;
                }
            }
        }

        return $headers;
    }

    private function getDefaultItems() :array {
        return $this->getItemsByPath(self::DEFAULT_PATH);
    }

    private function getCustomItems() :array {
        return array_filter(
            $this->getItemsByPath(self::CUSTOM_PATH),
            function ($header) {
                $isExistKey    = isset($header[self::KEY]) && $header[self::KEY];
                $isValidEnable = isset($header[self::ENABLE]) && is_bool($header[self::ENABLE]);
                return $isExistKey && $isValidEnable;
            }
        );
    }

    private function getItemsByPath(string $path) :array {
        return json_decode(Helpers::fileGetContent($path), true) ?? [];
    }
}
