<?php
namespace Wildix\Services;

/**
 * Class Kite
 */
class Kite extends AbstractService {

    const INFUSIONSOFT_INTEGRATION_APP_KEY = 'infusionsoftIntegrationApp';

    const GOOGLE_INTEGRATION_APP_URL        = 'https://:domain/api/pbx/GoogleIntagrationApp/:serial';
    const MICROSOFT_INTEGRATION_APP_URL     = 'https://:domain/api/pbx/MicrosoftIntagrationApp/:serial';
    const OFFICE365_INTEGRATION_APP_URL     = 'https://:domain/api/pbx/Office365IntegrationApp/:serial';
    const ZOHO_PRODUCTS_INTEGRATION_APP_URL = 'https://:domain/api/pbx/ZohoProductsIntegrationApp/:serial';
    const INFUSIONSOFT_INTEGRATION_APP_URL  = 'https://:domain/api/pbx/InfusionsoftIntegrationApp/:serial';
    const EMAIL_TRANSCRIPT_URL              = 'https://:domain/api/pbx/emailTranscript/:serial';

    protected function parse($data) {
        return json_decode($data, true);
    }

    private function getUrl($url) {
        $url = str_replace(':domain', \Models\PBX::getInstance()->getKiteConf('domain'), $url);
        $url = str_replace(':serial', \Models\PBX::getInstance()->getSerial(), $url);
        return $url;
    }

    public function getIntegrationApp($appCacheKey, $appUrl) {
        $cfg = \Cache\FileCache::getInstance()->get($appCacheKey);

        if ($cfg) {
            return $cfg;
        }

        $cfg = $this->sendRequest('GET', $this->getUrl($appUrl));

        if ($cfg && !empty($cfg['expire'])) {
            \Cache\FileCache::getInstance()->set($appCacheKey, $cfg, $cfg['expire']);
        }

// @codingStandardsIgnoreStart
        $this->getLog()->info(__LINE__, $appCacheKey . ': ' . print_r($cfg, true));
// @codingStandardsIgnoreEnd
        return $cfg;
    }

    public function getGoogleIntegrationApp() {
        return $this->getIntegrationApp('googleIntegrationApp', self::GOOGLE_INTEGRATION_APP_URL);
    }

    public function getMicrosoftIntagrationApp() {
        return $this->getIntegrationApp('microsoftIntegrationApp', self::MICROSOFT_INTEGRATION_APP_URL);
    }

    public function getOffice365IntegrationApp() {
        return $this->getIntegrationApp('office365IntegrationApp', self::OFFICE365_INTEGRATION_APP_URL);
    }

    public function getZohoProductsIntegrationApp() {
        return $this->getIntegrationApp('zohoProductsIntegrationApp', self::ZOHO_PRODUCTS_INTEGRATION_APP_URL);
    }

    public function sendEmailTranscript($emails, $messages) {
        $params = array(
            'emails'   => $emails,
            'messages' => $messages,
        );

        $this->sendRequest('POST', $this->getUrl(self::EMAIL_TRANSCRIPT_URL), $params);

        return true;
    }
}
