<?php

namespace Wildix\Services;

use Wildix\Services\Exception\ServiceException;

/**
 * Class Location
 */
class Location extends \Wildix\Services\AbstractService {

    /**
     * Make formatted data from service
     *
     * @param array $data Raw data from service.
     *
     * @return array
     */
    private function formattedData(array $data) {
        $defaultData = array(
            'latitude' => '',
            'longitude' => '',
            'city' => '',
            'region_name' => '',
            'country_name' => ''
        );

        $result = array();

        if (!empty($data['location'])) {
            $result['latitude']  = $data['location']['latitude'];
            $result['longitude'] = $data['location']['longitude'];
        }
        if (!empty($data['city']['names']['en'])) {
            $result['city'] = $data['city']['names']['en'];
        }
        if (!empty($data['subdivisions'][0]['names']['en'])) {
            $result['region_name'] = $data['subdivisions'][0]['names']['en'];
        }
        if (!empty($data['country']['names']['en'])) {
            $result['country_name'] = $data['country']['names']['en'];
        }
        return array_merge($defaultData, $result);
    }

    /**
     * Make request to server and get data
     *
     * @param string $type HTTP request type.
     * @param string $url  URL server address.
     *
     * @return mixed Return an array in case of success or null otherwise.
     */
    public function makeServerRequest($type, $url) {
        $result = null;
        try {
            $response = $this->makeRequest($type, $url, [], null, array('Accept: application/json'));
            $result   = $this->parse($response['result']);
            $result   = $this->formattedData($result);
        } catch (ServiceException $exception) {
            $this->getLog()->error(__LINE__, 'Server responded with error: ' . $exception->getMessage());
        }
        return $result;
    }
}
