<?php

namespace Wildix\Services;

/**
 * Class PBX
 */
class PBX extends AbstractService {

    const NET_CONF = '/rw2/etc/pbx/net.conf';

    const DEFAULT_PORT = 443;

    /**
     * PBX URL
     *
     * @var string
     */
    private $_url;
    /**
     * Use http proxy
     *
     * @var boolean
     */
    protected $_useHttpProxy = false;

    /**
     * PBX class.
     *
     * @var \Wildix\PBXes\PBX $_pbx
     */
    private $_pbx;

    /**
     * Sip peeer prune request data.
     *
     * @var array
     */
    private $_sipPeerPruneRequestData;

    /**
     * Remove user request data.
     *
     * @var array
     */
    private $_removeUserRequestData;

    /**
     * PBX constructor.
     *
     * @param \Wildix\PBXes\PBX $pbx      Instance of PBX.
     * @param integer           $logLevel Default 5.
     */
    public function __construct(\Wildix\PBXes\PBX $pbx, $logLevel = 5) {
        parent::__construct($logLevel);

        $this->_pbx       = $pbx;
        $customSecurePort = $this->_pbx->getPublicPort() ? $this->_pbx->getPublicPort() : self::DEFAULT_PORT;

        $this->_url = 'https://' . $this->getServerIp() . ':' . $customSecurePort . '/api/v1/PBX/WmsNetwork';

        $this->_removeUserRequestData   = [
            'action' => '/removeUser',
            'method' => 'DELETE'
        ];
        $this->_sipPeerPruneRequestData = [
            'action' => '/sipPeerPrune',
            'method' => 'GET'
        ];
        $this->disableBasicAuth();
        $this->disableSslVerify();
    }

    /**
     * Remove user from this PBX
     *
     * @param integer $userId User ID.
     *
     * @throws \Wildix\Services\Exception\ServiceException If request failed.
     * @return void
     */
    public function removeUser($userId) {
        $this->sendRequest($this->_removeUserRequestData['method'], $this->_url . $this->_removeUserRequestData['action'], array('userId' => $userId));
    }

    /**
     * Clear sip peer cache
     *
     * @param string $extension User extension.
     *
     * @throws Exception\ServiceException If request failed.
     * @return void
     */
    public function sipPeerPrune(string $extension) {
        $this->sendRequest($this->_sipPeerPruneRequestData['method'], $this->_url . $this->_sipPeerPruneRequestData['action'], array('extension' => $extension));
    }

    private function getServerIp() {
        $netParams = parse_ini_file(self::NET_CONF, false, INI_SCANNER_RAW);

        return $this->_pbx->getIsMaster() ? $netParams['SRV_IP'] : $this->_pbx->getIp();
    }

    protected function parse($data) {
        return $data;
    }
}
