<?php

namespace Wildix\Services;

/**
 * Class SSL Provide an interface to the Wildix SSL service
 */
class SSL extends AbstractService {

    private $_sslApiURL;

    /**
     * SSL constructor.
     *
     * @param string $_sslApiURL Url.
     */
    public function __construct(string $_sslApiURL) {
        parent::__construct();
        $this->_sslApiURL = $_sslApiURL . '/api/v1/Certificate';
    }

    /**
     * Returns certificate and private key.
     *
     * @param array   $domains Domains list.
     * @param boolean $forced  Force update of certificate.
     *
     * @return array
     * @throws \Wildix\Services\Exception\ServiceException When request failed.
     */
    public function getCertificate(array $domains, bool $forced = false): array {
        $params['domains'] = $domains;
        $params['forced']  = $forced;

        $this->setTimeout(300);

        $response    = $this->sendRequest('GET', $this->_sslApiURL, $params);
        $certificate = isset($response['certificate']) ? $response['certificate'] : null;

        if (\is_array($certificate) && !empty($certificate['privateKey']) && !empty($certificate['fullchainPem'])) {
            $this->getLog()->info(__LINE__, 'Certificate successfully received');

            return [
                'privateKey' => $certificate['privateKey'],
                'fullchainPem' => $certificate['fullchainPem'],
            ];
        }

        $errorMessage = 'No certificate information found in the response';

        $this->getLog()->error(__LINE__, $errorMessage . ' Info: ' . json_encode(['responseData' => $response, 'params' => $params], JSON_PRETTY_PRINT));
        throw new \Wildix\Services\Exception\ServiceException($errorMessage);
    }
}
