<?php
namespace Wildix\Services;

/**
 * Provide an interface to the Wildix STT service
 */
class SpeechToText extends AbstractService {

    private $_voiceMailUrl;

    /**
     * SpeechToText constructor.
     *
     * @param string $_voiceMailUrl Url.
     */
    public function __construct(string $_voiceMailUrl) {
        parent::__construct();
        $this->_voiceMailUrl = $_voiceMailUrl . '/api/v1/Voicemail';
    }

    public function getTextFromVoiceMail(
        $filePath,
        $language = 'en-GB',
        $encoding = 'LINEAR16',
        $hertz = '8000',
        $alternatives = 1
    ) {
        // php 5.5+
        if (function_exists('curl_file_create')) {
            $cFile = curl_file_create($filePath);
        } else {
            $cFile = '@' . realpath($filePath);
        }

        $params = array(
            'file' => $cFile,
            'language' => $language,
            'encoding' => $encoding,
            'hertz' => $hertz,
            'maxAlternatives' => $alternatives,
        );

        try {
            $result = $this->sendRequest('POST', $this->_voiceMailUrl, $params, true);
        } catch (Exception\ServiceException $e) {
            return false;
        }

        if (isset($result[0])) {
            return $result[0]['transcript'];
        }

        return false;
    }
}
