<?php
namespace Wildix\Services;

/**
 * Provide an interface to the wildix TTS service
 */
class TextToSpeech extends AbstractService {

    private $_getAudioUrl;

    /**
     * TextToSpeech constructor.
     *
     * @param string $_getAudioUrl Url.
     */
    public function __construct(string $_getAudioUrl) {
        parent::__construct();
        $this->_getAudioUrl = $_getAudioUrl . '/api/v2/Audio/';
    }

    /**
     * Try to download audio from tts service or throw error.
     *
     * @param array $params Parameters for query.
     *
     * @return boolean|mixed
     *
     * @throws Exception\ServiceException If get error from tts service.
     */
    public function getAudio(array $params) {
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, true);
        curl_setopt($ch, CURLOPT_USERAGENT, 'Wildix PBX (' . WMS_VERSION_FULL . ')');
        curl_setopt($ch, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
        curl_setopt($ch, CURLOPT_USERPWD, \Models\PBX::getInstance()->getSerial() . ':' . \Models\PBX::getInstance()->getPbxKey());
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 3);
        curl_setopt($ch, CURLOPT_TIMEOUT, 120);
        curl_setopt($ch, CURLOPT_AUTOREFERER, true);
        curl_setopt($ch, CURLOPT_URL, $this->_getAudioUrl . '?' . http_build_query($params));
        curl_setopt($ch, CURLOPT_HTTPHEADER, ['Accept: audio/*']);
        $audioFile = curl_exec($ch);

        $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);

        if ($audioFile && (int)$httpCode === 200) {
            return $audioFile;
        }

        // try to extract error from not ok response
        $this->parse($audioFile);
    }
}
