<?php

namespace Wildix\Settings\Env;

use Wildix\Settings\ConfigFile;

/**
 * Class EnvConfig
 */
class EnvConfig extends ConfigFile {

    private const CONFIG_DEFAULT_FILE = '/rw2/etc/env.ini';
    private const CONFIG_CUSTOM_FILE  = '/rw2/etc/env.custom.ini';

    private const FORCED_CUSTOM_FIELDS = ['SERVICE_SMS_ENABLED'];

    public function __construct() {
        parent::__construct(self::CONFIG_CUSTOM_FILE);

        if (file_exists(self::CONFIG_DEFAULT_FILE)) {
            $this->setDefault($this->parseIniFile(self::CONFIG_DEFAULT_FILE));
        }
    }

    protected function parseIniFile(string $file) {
        return parse_ini_file($file, true, INI_SCANNER_TYPED);
    }

    public function get($param = null, $section = null) {
        $custom = file_exists(self::CONFIG_CUSTOM_FILE) ? $this->parseIniFile(self::CONFIG_CUSTOM_FILE) : [];

        if ($this->_config === null) {
            $this->_config = array_merge(
                $this->getDefault(),
                $custom
            );
        }

        if ($param !== null) {
            if ($this->_config && isset($this->_config[$param]) && (!in_array($param, self::FORCED_CUSTOM_FIELDS) || isset($custom[$param]))) {
                return $this->_config[$param];
            } else {
                return null;
            }
        }

        return $this->_config;
    }

    protected function prepareContent() {
        $content    = '';
        $parameters = $this->get();
        $default    = $this->getDefault();

        foreach ($parameters as $key => $value) {
            if (!isset($default[$key]) || $default[$key] !== $value || in_array($key, self::FORCED_CUSTOM_FIELDS, true)) {
                $content .= $this->createContentRow($key, $value, $this->_delimiter);
            }
        }

        return $content;
    }
}
