<?php
namespace Wildix;

/**
 * Class SipRtp
 */
class SipRtp extends \Singleton {

    const CONFIG_GENERAL_SIP = '/etc/callweaver/sip-wms.conf';

    const DEFAULT_EXPIRY = 'defaultexpiry';
    const RTP_END        = 'rtpend';
    const CONTEXT        = 'context';
    const LANGUAGE       = 'language';
    const TONE_ZONE      = 'tonezone';

    private $_logLevel = 0;
    private $_log      = null;

    private function getLog() {
        if ($this->_log === null) {
            $this->_log = new \Syslog('\Wildix\SipRtp', $this->_logLevel);
        }
        return $this->_log;
    }

    private $_generalSip = null;

    public function getGeneralSip($param = null) {
        if (!$this->_generalSip) {
            $this->_generalSip = array(
                'defaultexpiry' => '600',
                'rtpend' => '',
                'tos' => '184',
                'tos_sip' => '184',
                'language' => 'it',
            );
            if (is_readable(self::CONFIG_GENERAL_SIP)) {
                $tmp = parse_ini_file(self::CONFIG_GENERAL_SIP, true, INI_SCANNER_RAW);
                if (is_array($tmp)) {
                    $this->_generalSip = array_merge($this->_generalSip, $tmp);
                }
            }
        }
        if ($param !== null) {
            if (isset($this->_generalSip[$param])) {
                return $this->_generalSip[$param];
            } else {
                return null;
            }
        } else {
            return $this->_generalSip;
        }
    }

    public function setGeneralSip($data) {
        if (is_writeable(self::CONFIG_GENERAL_SIP)) {
            if (write_ini_file(self::CONFIG_GENERAL_SIP, $data, true)) {
                return true;
            }
        }
        return false;
    }
}
