<?php
declare(strict_types=1);

namespace Wildix\Sms;

use Wildix\Colleagues\Colleagues;
use Wildix\DependencyInjection\Container;
use Wildix\Dialplan\CallGroups\CallGroupsService;
use Wildix\Dialplan\DialplanService;
use Wildix\Dialplan\RulesService;

/**
 * Class DiConfig
 */
final class DiConfig implements \Wildix\DependencyInjection\ConfigInterface {

    public static function configure(Container $container): void {
        $container->singleton(
            SmsService::class,
            function (Container $container) {
                $colleagues   = $container->get(Colleagues::class);
                $dialplan     = $container->get(DialplanService::class);
                $rulesService = $container->get(RulesService::class);
                $validator    = $container->get(\Wildix\Validator::class);
                $callGroups   = $container->get(CallGroupsService::class);
                return new SmsService($colleagues, $dialplan, $rulesService, $validator, $callGroups);
            }
        );

        $container->singleton(
            SmsViaGsmService::class,
            function (Container $container) {
                $user = PHP_SAPI === 'cli' ? null : $container->get(\User::class);

                return new SmsViaGsmService($user);
            }
        );
    }
}
