<?php
namespace Wildix\Smtp;

/**
 * Class SmtpValidator
 */
class SmtpValidator
{

    /**
     * Validation errors.
     *
     * @var array $_errors
     */
    private $_errors = [];

    private $_allowedTimeout = [
        2,
        5,
        10,
        15,
        20,
        60,
    ];

    private $_allowedAuthTypes = [
        'off',
        'on',
        'login',
        'plain',
        'cram-md5',
        'digest-md5',
        'gssapi',
        'ntlm',
    ];

    /**
     * Get errors.
     *
     * @return array
     */
    public function getErrors(): array {
        return $this->_errors;
    }

    /**
     * Validate SMTP settings.
     *
     * @param array $data SMTP settings.
     *
     * @return boolean
     */
    public function validateSmptSettings(array $data): bool {
        $form = new \Wildix\Validator(
            $data,
            [
                'is_default_settings',
                'auth',
                'domain',
                'from',
                'host',
                'user',
                'password',
                'port',
                'timeout',
                'tls',
                'tlsStartTls',
            ]
        );

        $form->rules(
            [
                'boolean' => [
                    ['is_default_settings'],
                    ['tls'],
                    ['tlsStartTls'],
                ],
                'ipPort' => [['port']],
                'in' => [
                    [
                        'timeout',
                        $this->_allowedTimeout,
                    ],
                    [
                        'auth',
                        $this->_allowedAuthTypes,
                    ],
                ],
                'email' => [['from']],
                'domainOrIp' => [
                    ['host'],
                    ['domain'],
                ],
                'required' => [
                    ['port'],
                    ['auth'],
                    ['timeout'],
                ],
            ]
        );

        if (!$form->validate()) {
            $this->_errors = $form->errors();
            return false;
        }

        return true;
    }

    /**
     * Validate SMTP ping data.
     *
     * @param array $data SMTP ping data.
     *
     * @return boolean
     */
    public function validateSmptPingRequest(array $data): bool {
        $form = new \Wildix\Validator(
            $data,
            [
                'mailto',
                'from',
                'body',
            ]
        );
        $form->rules(
            [
                'email' => [
                    ['mailto'],
                    ['from'],
                ],
                'required' => [
                    ['mailto'],
                    ['from'],
                    ['body'],
                ],
            ]
        );

        if (!$form->validate()) {
            $this->_errors = $form->errors();
            return false;
        }

        return true;
    }
}
