<?php
declare(strict_types=1);

namespace Wildix\System\Dhcp;

/**
 * Class DiConfig
 */
final class DiConfig implements \Wildix\DependencyInjection\ConfigInterface {

    public static function configure(\Wildix\DependencyInjection\Container $container): void {
        $container->singleton(
            \WMS_Ldap::class,
            function () {
                return \WMS_Ldap::getInstance();
            }
        );

        $container->singleton(
            \Wildix\System\Dhcp\ServerManager::class,
            function (\Wildix\DependencyInjection\Container $container) {
                $network   = \Wildix\System\Network::getInstance();
                $storage   = \Wildix\Databases\WMSDB::getInstance();
                $validator = new \Wildix\System\Dhcp\Validator;
                $converter = $container->get(\Wildix\System\Dhcp\Converter::class);
                $wmsLdap   = $container->get(\WMS_Ldap::class);
                $logger    = $container->get(\Logger\Log::class);

                $dhcpServer = new \Wildix\System\Dhcp\Server($network, $storage, $converter, $wmsLdap, $logger);
                $dhcpLeases = new \Wildix\System\Dhcp\Leases($logger);

                return new \Wildix\System\Dhcp\ServerManager($dhcpServer, $dhcpLeases, $network, $validator, $logger);
            }
        );

        $container->singleton(
            \Wildix\System\Dhcp\Converter::class,
            function () {
                return new \Wildix\System\Dhcp\Converter();
            }
        );
    }
}
