<?php
declare(strict_types=1);

namespace Wildix\System;

use Logger\Log;
use Models\PBX;
use Services\TProxyService;
use Wildix\DependencyInjection\ConfigInterface;
use Wildix\DependencyInjection\Container;
use Wildix\Settings\ConfigFile;
use Wildix\System\Ntp\NtpConfig;
use WMS_Ldap;

final class DiConfig implements ConfigInterface {

    public static function configure(Container $container): void {
        $container->singleton(
            SystemService::class,
            function () {
                return new SystemService();
            }
        );
        $container->singleton(
            Systemd::class . ':RSyslog',
            function () {
                return new Systemd('rsyslog');
            }
        );
        $container->singleton(
            ADSingleSignOnService::class,
            function (Container $container): ADSingleSignOnService {
                $config = new ConfigFile(ADSingleSignOnService::CONFIG_FILE);

                return new ADSingleSignOnService($config);
            }
        );
        $container->singleton(
            Ntp::class,
            function (): Ntp {
                if (!file_exists(Ntp::INI_FILE)) {
                    touch(Ntp::INI_FILE);
                }
                $service       = new Ntp();
                $ntpIniFile    = new ConfigFile(Ntp::INI_FILE);
                $ntpConfigFile = new NtpConfig(Ntp::CONFIG_FILE);
                $service->setIniFile($ntpIniFile);
                $service->setConfigFile($ntpConfigFile);

                return $service;
            }
        );
        $container->singleton(
            HttpProxy::class,
            function (): HttpProxy {
                return new HttpProxy();
            }
        );
        $container->singleton(
            FileSystem::class,
            function (): FileSystem {
                return FileSystem::getInstance();
            }
        );
        $container->singleton(
            Snmp::class,
            function (): Snmp {
                return new Snmp();
            }
        );
        $container->singleton(
            Systemd::class . ':TurnServer',
            function () {
                return new Systemd('turnserver');
            }
        );
        $container->singleton(
            Systemd::class . ':SyncOffice365EventsTimer',
            function () {
                return new Systemd('sync-office365-events.timer');
            }
        );
        $container->singleton(
            Systemd::class . ':SyncOffice365PhonebooksTimer',
            function () {
                return new Systemd('sync-office365-phonebooks.timer');
            }
        );
        $container->singleton(
            Systemd::class . ':nginx',
            function () {
                return new Systemd('nginx');
            }
        );
        $container->singleton(
            LdapRadius::class,
            function (Container $container) {
                $wmsLdap = $container->get(WMS_Ldap::class);
                $pbx     = $container->get(PBX::class);
                $log     = $container->get(Log::class);
                $tProxy  = $container->get(TProxyService::class);
                return new LdapRadius($wmsLdap, $pbx, $tProxy, $log);
            }
        );
        $container->singleton(
            TraceService::class,
            function (Container $container) {
                return new TraceService($container->get(Log::class));
            }
        );
        $container->singleton(
            QueueMetrics::class,
            function () {
                return new QueueMetrics();
            }
        );
        $container->singleton(
            RemoteSupport::class,
            function () {
                return RemoteSupport::getInstance();
            }
        );
        $container->singleton(
            Location::class,
            function () {
                $config = new ConfigFile(Location::GEO_LOCATION_CONFIG_PATH);

                return new Location($config);
            }
        );
        $container->singleton(
            Network::class,
            function () {
                return Network::getInstance();
            }
        );
    }
}
