<?php

namespace Wildix\System;

/**
 * Class FileSystem
 */
class FileSystem extends \Singleton {

    public $logFile = '/tmp/fs_errors.log';

    public function checkFileSystem() {
        $output = '';
        if (file_exists($this->logFile)) {
            $output = file_get_contents($this->logFile);
        }

        if (!empty($output)) {
            return true;
        }
        return false;
    }

    /**
     * Returns available space on disk.
     *
     * @return float Disk space in bytes.
     */
    public function getFreeDiskSpace(): float {
        return disk_free_space('/') ?: 0;
    }

    /**
     * Move existing backups to share
     *
     * @access public
     * @return string "OK" or string for get translation of error
     * @author Igor Kuts <igor.kuts@wildix.com>
     */
    public function moveBackupsToShare() {
        exec('/usr/sbin/move_backups_to_share', $out, $ret);
        switch ((int)$ret) {
            case 0:
                $return = 'OK';
                break;

            case 1:
                $return = 'backup.err.failed';
                break;

            case 2:
                $return = 'backup.err.notenoughspace';
                break;

            default:
                $return = 'backup.err.unknown';
                break;
        }
        return $return;
    }

    /**
     * Get logFile
     *
     * @return string
     */
    public function getLogFile(): string {
        return $this->logFile;
    }
}
