<?php
namespace Wildix\System;

use Wildix\Error;
use Wildix\Exception;

/**
 * Class QueueMetrics
 */
class QueueMetrics extends \Syslog {

    const FILE_CONFIG = '/rw2/etc/pbx/qlogger.conf';

    /**
     * QueueMetrics constructor.
     */
    public function __construct() {
        parent::__construct('Wildix\System\QueueMetrics', 0);
    }

    /**
     * Get settings.
     *
     * @return array
     */
    public function getSettings() {
        $parameters = array(
            'enable'   => false,
            'host'     => '127.0.0.1',
            'login'    => 'queuemetrics',
            'password' => 'javadude',
            'database' => 'queuemetrics',
        );

        if (!file_exists(self::FILE_CONFIG)) {
            return $parameters;
        }

        $config = array();

        foreach (file(self::FILE_CONFIG) as $item) {
            if (preg_match('/(.+)=\'(.+)\'/', $item, $matches)) {
                $config[$matches[1]] = str_replace("'\''", "'", $matches[2]);
            } else if (preg_match('/(.+)="(.+)"/', $item, $matches)) {
                $config[$matches[1]] = stripcslashes(str_replace("'\''", "'", $matches[2]));
            } else if (preg_match('/(.+)=(.+)/', $item, $matches)) {
                $config[$matches[1]] = str_replace("'\''", "'", $matches[2]);
            }
        }

        $parameters['host']     = $config['HOST'];
        $parameters['database'] = $config['DBNAME'];
        $parameters['login']    = $config['USER'];
        $parameters['password'] = $config['PASS'];

        $output = exec('crontab -l -u wms | sed -ne /runner/p;');

        if (trim($output) !== '') {
            $parameters['enable'] = true;
        }

        return $parameters;
    }

    /**
     * Method sets settings.
     *
     * @param array $parameters Parameters array.
     *
     * @return boolean
     */
    public function setSettings(array $parameters) {
        $validate = $this->_validate($parameters);

        if ($validate !== true) {
            return $validate;
        }

        // /etc/callweaver/logger.conf [general] queue_log = yes
        $fileRunner = '/rw2/var/qloader/runner';
        $fileLogger = '/etc/callweaver/logger.conf';

        if (!file_exists($fileLogger)) {
            return false;
        }

        exec('crontab -u wms -l | sed /qloader/d | crontab -u wms -; sed -i "/queue_log/c queue_log = no" ' . $fileLogger . ';');

        if ($parameters) {
            $command  = 'sed -i "s|var/log/asterisk|var/log/callweaver|g" ' . $fileRunner . ';';
            $command .= ' (crontab -u wms -l; echo "55 23 * * * ' . $fileRunner . ' > /dev/null 2>&1") | crontab -u wms -;';
            $command .= ' sed -i "/queue_log/c queue_log = yes" ' . $fileLogger . ';';

            $toFile[] = 'HOST=' . escapeshellarg($parameters['host']);
            $toFile[] = 'DBNAME=' . escapeshellarg($parameters['database']);
            $toFile[] = 'USER=' . escapeshellarg($parameters['login']);
            $toFile[] = 'PASS=' . escapeshellarg($parameters['password']);

            if (!file_put_contents(self::FILE_CONFIG, implode(PHP_EOL, $toFile) . PHP_EOL)) {
                $this->error(__LINE__, 'Can not write to ' . self::FILE_CONFIG);
            }

            if ($parameters['enable'] === true) {
                exec($command);
            }
        }

        if ($parameters['enable'] === true) {
            // let's (re)execute runner to update entries
            exec('nohup ' . $fileRunner . ' >/dev/null 2>&1 &');
        } else {
            exec('nohup /etc/init.d/qloader stop');
        }

        \Wildix\CallweaverManager::getInstance()->reloadModule('logger');

        return true;
    }

    private function _validate($values) {
        $form = new \Wildix\Validator($values, array('host', 'login', 'password', 'database'));

        $form->rule('required', array('host', 'login', 'password', 'database'));

        if (!$form->validate()) {
            throw new Exception(Error::FieldRequired);
        }

        try {
            $dbh = new \PDO('mysql:dbname=' . $values['database'] . ';host=' . $values['host'], $values['login'], $values['password']);
        } catch (\PDOException $e) {
            throw new Exception(Error::ConnectDbError, 400);
        }

        unset($dbh);

        return true;
    }
}
