<?php

namespace Wildix\System\RemoteSyslogSettings;

use Wildix\Error;
use Wildix\InvalidDataException;
use Wildix\Validator;

/**
 * Class Factory
 */
class Factory {

    /**
     * Rules for validate data.
     *
     * @var array
     */
    private static $_validationRules = array(
        'optional' => Settings::FIELD_PORT,
        'boolean' => Settings::FIELD_ENABLED,
        'lengthMin' => array(array(Settings::FIELD_FILTER, 3)),
        'in' => array(
                 array(
                     Settings::FIELD_TRANSPORT,
                     array(
                         Settings::TRANSPORT_TCP,
                         Settings::TRANSPORT_UDP,
                         ),
                     ),
                 array(
                  Settings::FIELD_FORMAT,
                  array(Settings::FORMAT_RSYSLOG_FORWARD,
                      Settings::FORMAT_RSYSLOG_TRADITIONAL_FORWARD,
                      Settings::FORMAT_RSYSLOG_SYSLOG_PROTOCOL_23,
                      ),
                 ),
        ),
        'required' => array(
                       array(Settings::FIELD_FILTER),
                       array(Settings::FIELD_TRANSPORT),
                       array(Settings::FIELD_FORMAT),
                       array(Settings::FIELD_HOST),
        ),
        'min' => array(array(Settings::FIELD_PORT, 1)),
        'max' => array(array(Settings::FIELD_PORT, 65535)),
    );

    /**
     * Instance of validator.
     *
     * @var Validator
     */
    private $_validator;

    /**
     * Factory constructor.
     *
     * @param Validator $validator A validator for user data validation.
     */
    public function __construct(Validator $validator) {
        $this->_validator = $validator;
        $this->_validator->rules(self::$_validationRules);
    }

    /**
     * Create a new instance of Settings.
     *
     * @param array $data Settings data.
     *
     * @return Settings
     * @throws InvalidDataException If the data is not valid.
     */
    public function create(array $data) {
        $errors = $this->_validator->validateData($data, Settings::$fields);

        if (count($errors) > 0) {
            throw new InvalidDataException(Error::getMessage(Error::VALIDATION_ERROR), $errors);
        }

        return new Settings($data);
    }
}
