<?php

namespace Wildix\TaskQueue;

use Wildix\InvalidDataException;

/**
 * Class QueueItem
 */
class QueueItem {
    const FIELD_ID          = 'id';
    const FIELD_TYPE        = 'type';
    const FIELD_PARAMS      = 'params';
    const FIELD_CREATED_AT  = 'created_at';
    const FIELD_RETRY_COUNT = 'retry_count';

    const PARAM_CREATED     = 'created';
    const PARAM_RETRY_COUNT = 'retry_count';

    const DATE_FORMAT = 'Y-m-d H:i:s';

    private $_id;
    private $_type;
    private $_params;
    private $_createdAt;
    private $_retryCount;

    /**
     * QueueItem constructor.
     *
     * @param array $item Queue item.
     *
     * @throws InvalidDataException Invalid item.
     */
    public function __construct(array $item) {
        if (isset($item[self::FIELD_ID])) {
            $this->_id = $item[self::FIELD_ID];
        } else {
            throw new InvalidDataException('Empty item id.');
        }
        if (isset($item[self::FIELD_TYPE])) {
            $this->_type = $item[self::FIELD_TYPE];
        } else {
            throw new InvalidDataException('Empty item type.');
        }
        if (isset($item[self::FIELD_PARAMS])) {
            $this->_params = json_decode($item[self::FIELD_PARAMS], true);
            if ($this->_params === null) {
                throw new InvalidDataException('Invalid item params.');
            }
        } else {
            throw new InvalidDataException('Empty item params.');
        }
        if (isset($item[self::FIELD_CREATED_AT])) {
            $this->_createdAt = date_create_from_format(self::DATE_FORMAT, $item[self::FIELD_CREATED_AT])->getTimestamp();
        } else {
            throw new InvalidDataException('Invalid item created date.');
        }
        if (isset($item[self::FIELD_RETRY_COUNT])) {
            $this->_retryCount = $item[self::FIELD_RETRY_COUNT];
        } else {
            throw new InvalidDataException('Invalid item retry count.');
        }
    }

    /**
     * Return item id
     *
     * @return integer
     */
    public function getId() {
        return $this->_id;
    }

    /**
     * Return item type
     *
     * @return string
     */
    public function getType() {
        return $this->_type;
    }

    /**
     * Return array of params
     *
     * @return array
     */
    public function getParams() {
        return $this->_params;
    }

    /**
     * Return created date
     *
     * @return mixed
     */
    public function getCreatedAt() {
        return $this->_createdAt;
    }

    /**
     * Return count of retry times
     *
     * @return integer
     */
    public function getRetryCount() {
        return $this->_retryCount;
    }
}
