<?php
declare(strict_types=1);

namespace Wildix\TlsSecurity;

use Logger\Log;
use Wildix\DependencyInjection\ConfigInterface;
use Wildix\DependencyInjection\Container;
use Wildix\Settings\ConfigFile;
use Wildix\Settings\Env\EnvConfig;
use Wildix\Validator;

/**
 * Class DiConfig
 */
final class DiConfig implements ConfigInterface {

    public static function configure(Container $container): void {
        $container->singleton(
            Repository::class,
            function (Container $container) {
                $storage = new ConfigFile(Repository::STORAGE_PATH);
                $logger  = $container->get(Log::class);
                return new Repository($storage, $logger);
            }
        );

        $container->singleton(
            Service::class,
            function (Container $container) {
                return new Service(
                    $container->get(Repository::class),
                    $container->get(EnvConfig::class),
                    $container->get(Validator::class)
                );
            }
        );
    }
}
