<?php

namespace Wildix\TlsSecurity;

use Wildix\Validator;

/**
 * Class ModelSettings
 */
class ModelSettings {
    const TLS_1   = 'TLS1_VERSION';
    const TLS_1_2 = 'TLS1_2_VERSION';

    const SSL_VERSION_FIELD = 'ssl_min_proto_version';

    const DEFAULT_TLS_VERSION = self::TLS_1_2;

    private $_data;

    public function __construct(array $params) {
        $this->_data = $this->prepareParams($params);
    }

    public function toArray(): array {
        return [
            'enabled' => $this->isDeprecatedTlsVersion()
        ];
    }

    public function getSslVersion(): string {
        return $this->_data[self::SSL_VERSION_FIELD] ?? self::DEFAULT_TLS_VERSION;
    }

    public function isDeprecatedTlsVersion(): bool {
        return $this->getSslVersion() !== self::DEFAULT_TLS_VERSION;
    }

    private function prepareParams(array $params): array {
        if (isset($params['enabled'])) {
            $params[self::SSL_VERSION_FIELD] = (Validator::isTrue($params['enabled']) ? self::TLS_1 : self::DEFAULT_TLS_VERSION);
            unset($params['enabled']);
        }

        return $params;
    }
}
