<?php
namespace Wildix\TlsSecurity;

use Logger\Log;
use Wildix\Exception;
use Wildix\Settings\ConfigFile;

/**
 * Class Repository
 */
class Repository {

    const STORAGE_PATH = '/etc/wildix/tproxy_wms_proto_version.conf';

    private $_storage;

    private $_logger;

    public function __construct(ConfigFile $storage, Log $logger) {
        $this->_storage = $storage;
        $this->_logger  = $logger;
    }

    private function storage(): ConfigFile {
        return $this->_storage;
    }

    private function logger(): Log {
        return $this->_logger;
    }

    public function get(): ModelSettings {
        $data = $this->storage()->get();

        return new ModelSettings($data);
    }

    public function save(ModelSettings $data, bool $isAutoMode): ModelSettings {
        $tlsVersion    = $data->isDeprecatedTlsVersion() ? ModelSettings::TLS_1 : ModelSettings::DEFAULT_TLS_VERSION;
        $tlsVersionEnv = $this->storage()->get(ModelSettings::SSL_VERSION_FIELD);

        $this->storage()->set(ModelSettings::SSL_VERSION_FIELD, $tlsVersion);

        if ($this->storage()->save() === false) {
            throw new Exception('Error while saving');
        }

        if ($tlsVersionEnv !== $tlsVersion) {
            $this->logger()->info(
                __LINE__,
                sprintf(
                    'Option \'Enable TLS 1.0, TLS 1.1 (deprecated)\' is %s %s',
                    ($data->isDeprecatedTlsVersion() ? 'enabled' : 'disabled'),
                    ($isAutoMode ? 'automatically' : 'manually')
                )
            );
        }

        return $data;
    }
}
