<?php

namespace Wildix\TlsSecurity;

use Wildix\Error;
use Wildix\InvalidDataException;
use Wildix\Settings\Env\EnvConfig;
use Wildix\Validator;

/**
 * Class Service
 */
class Service {

    private $_tProxyRepository;
    private $_envConfig;
    private $_validator;

    public function __construct(Repository $tProxyRepository, EnvConfig $envConfig, Validator $validator) {
        $this->_tProxyRepository = $tProxyRepository;
        $this->_envConfig        = $envConfig;
        $this->_validator        = $validator;
    }

    private function tProxyRepository(): Repository {
        return $this->_tProxyRepository;
    }

    private function envConfig(): EnvConfig {
        return $this->_envConfig;
    }

    private function validator(): Validator {
        return $this->_validator;
    }

    public function get(): array {
        return $this->tProxyRepository()->get()->toArray();
    }

    public function save(array $params, bool $isAutoMode = false): array {
        $this->validateParams($params);
        $tlsModel = new ModelSettings($params);

        $this->updateEnvConfig($tlsModel);

        $result = $this->tProxyRepository()->save($tlsModel, $isAutoMode)->toArray();

        $this->restartTproxy();

        return $result;
    }

    private function restartTproxy(): void {
        exec('sudo /etc/init.d/tproxyd restart > /dev/null &');
    }

    private function updateEnvConfig(ModelSettings $tlsModel): void {
        $this->envConfig()->set(strtoupper(ModelSettings::SSL_VERSION_FIELD), $tlsModel->getSslVersion());
        $this->envConfig()->save();
    }

    private function validateParams($params): void {
        $this->validator()->rule('boolean', 'enabled');
        $this->validator()->rule('required', 'enabled');
        $errors = $this->validator()->validateData(['enabled' => $params['enabled']], ['enabled']);

        if ($errors) {
            throw new InvalidDataException(Error::getMessage(Error::VALIDATION_ERROR), $errors);
        }
    }
}
