<?php

namespace Wildix\Trunks\PstnTrunks;

use Wildix\Devices\Vendors;

/**
 * Class Service
 */
class Service {

    private $_storage;

    public function __construct(Storage $storage) {
        $this->_storage = $storage;
    }

    /**
     * Trunks storage.
     *
     * @return Storage
     */
    private function _storage(): Storage {
        return $this->_storage;
    }

    public function getItems(): array {
        $trunks = $this->_storage()->getItems();

        return $this->_modifyTech($trunks);
    }

    public function buildItem(Trunk $item) {
        return [
            Trunk::FIELD_USERNAME => $item->getUsername(),
            Trunk::FIELD_PORTS => $item->getPorts(),
            Trunk::FIELD_TECHNOLOGY => $item->getTechnology()
        ];
    }

    /**
     * Modify technology for bri/pri trunks
     *
     * @param array $trunks Trunks.
     *
     * @return array
     *
     * @throws \Exception Database error
     */
    private function _modifyTech(array $trunks) : array {
        $trunkDeviceMap = $this->_storage()->getTrunkIdDeviceMap(array_keys($trunks));

        array_walk(
            $trunks,
            function ($trunk) use ($trunkDeviceMap) {
                $tech = $trunk->getTechnology();

                if ($tech === 'bri' || $tech === 'pri') {
                    $trunk->setTechnology('other');
                    if (!empty($trunkDeviceMap[$trunk->getId()]['device'])) {
                        $device = json_decode($trunkDeviceMap[$trunk->getId()]['device'], true);
                        if (!empty($device['vendor']) && $device['vendor'] === Vendors::WILDIX) {
                            $trunk->setTechnology($tech);
                        }
                    }
                }
            }
        );

        return $trunks;
    }
}
