<?php

namespace Wildix\Trunks\PstnTrunks;

use Wildix\Databases\DEVDB;
use Wildix\Databases\WMSDB;

/**
 * Class Storage
 */
class Storage {

    /**
     * WMS database
     *
     * @var WMSDB
     */
    private $_db;

    /**
     * DEV database
     *
     * @var DEVDB
     */
    private $_devDb;

    /**
     * Storage constructor.
     *
     * @param WMSDB $_db    WMSDB.
     * @param DEVDB $_devDb DEVDB.
     */
    public function __construct(WMSDB $_db, DEVDB $_devDb) {
        $this->_db    = $_db;
        $this->_devDb = $_devDb;
    }

    /**
     * WMS database getter
     *
     * @return WMSDB
     */
    private function _db(): WMSDB {
        return $this->_db;
    }

    /**
     * DEV database getter
     *
     * @return DEVDB
     */
    private function _devDb(): DEVDB {
        return $this->_devDb;
    }

    /**
     * Get trunks
     *
     * @return array
     *
     * @throws \Exception Database error
     */
    public function getItems() {
        return $this->_db()->getRows('SELECT * FROM ' . WMSDB::TABLE_PSTN_TRUNKS, Trunk::ID, Trunk::class);
    }

    /**
     * Get trunk id and device map
     *
     * @param array $trunkIds List of trunk ids.
     *
     * @return array
     *
     * @throws \Exception Database error
     */
    public function getTrunkIdDeviceMap(array $trunkIds) {
        $query = sprintf(
            "SELECT a1.value AS trunkid, a2.value AS device FROM %s AS a1 
                LEFT JOIN %s AS a2 ON (a1.mac = a2.mac AND a2.param = 'device') 
                LEFT JOIN %s AS a3 ON (a1.mac = a3.mac AND a3.param = 'status') 
             WHERE a1.value IN (%s) AND a1.param='trunkid'",
            DEVDB::TABLE_AUTOPROV,
            DEVDB::TABLE_AUTOPROV,
            DEVDB::TABLE_AUTOPROV,
            implode(',', array_map('intval', $trunkIds))
        );

        return $this->_devDb()->getRows($query, 'trunkid');
    }
}
