<?php

namespace Wildix\Utils;

use Firebase\JWT\JWT as FirebaseJWT;
use UnexpectedValueException;

/**
 * Class JWT
 */
class JWT extends FirebaseJWT {

    /**
     * Unpack JWT token and return head and payload.
     *
     * @param string $jwt JWT token.
     *
     * @return array
     * @throws UnexpectedValueException Provided JWT was invalid
     */
    public static function unpack(string $jwt): array {
        $tks = \explode('.', $jwt);
        if (\count($tks) != 3) {
            throw new UnexpectedValueException('Wrong number of segments');
        }
        // phpcs:disable
        [$headb64, $bodyb64, $cryptob64] = $tks;
        if (null === ($header = static::jsonDecode(static::urlsafeB64Decode($headb64)))) {
            throw new UnexpectedValueException('Invalid header encoding');
        }
        if (null === $payload = static::jsonDecode(static::urlsafeB64Decode($bodyb64))) {
            throw new UnexpectedValueException('Invalid claims encoding');
        }
        if (false === ($sig = static::urlsafeB64Decode($cryptob64))) {
            throw new UnexpectedValueException('Invalid signature encoding');
        }
        // phpcs: enable

        return [
            'head'    => (array)$header,
            'payload' => (array)$payload,
        ];
    }
}