<?php
require_once('../init.php');

/**
 * @var \Wildix\DependencyInjection\Container $diContainer
 * @var boolean|null                          $oath2Mode
 */

$diContainer = new \Wildix\DependencyInjection\Container();

if (isset($oath2Mode) && $oath2Mode === true) {
    /**
     * @var \Wildix\Auth\OAuth2\OAuth2ServiceInterface $service
     */
    $service = $diContainer->get(\Wildix\Auth\OAuth2\OAuth2ServiceInterface::class);
    if ($service->isOauthLogged()) {
        $service->redirectToGrantForm();
        exit;
    }
}

function isLocalIP($ip){
	/*$ipLong = ip2long($ip);
	 if (($ipLong > ip2long("10.0.0.0") && $ipLong < ip2long("10.255.255.255")) ||
		 ($ipLong > ip2long("172.16.0.0") && $ipLong < ip2long("172.31.255.255")) ||
		 ($ipLong > ip2long("192.168.0.0") && $ipLong < ip2long("192.168.255.255"))){
		 return true;
	 }*/
	if(!filter_var($ip, FILTER_VALIDATE_IP, FILTER_FLAG_NO_PRIV_RANGE)){
		return true;
	}
	return false;
}

function isSupportedBrowser(){

	if(empty($_COOKIE['iWantThisBrowser'])){

		$agent = $_SERVER['HTTP_USER_AGENT'];
		if(strpos($agent, 'Chrome') === false
			&& strpos($agent, 'Safari') === false
			&& strpos($agent, 'Firefox') === false
			&& strpos($agent, 'Mozilla') === false
			&& strpos($agent, 'MSIE') === false
			&& strpos($agent, 'Opera') === false){
			// another not supported
			return false;
		}else if(strpos($agent, 'Edge') !== false){
			return false;
		}else if(strpos($agent, 'MSIE') !== false){
			// not supported IE 6,7,8,9 and Edge
			if(strpos($agent, 'MSIE 6.0') !== false
				|| strpos($agent, 'MSIE 7.0') !== false
				|| strpos($agent, 'MSIE 8.0') !== false
				|| strpos($agent, 'MSIE 9.0') !== false){

				return false;
			}
		}
	}

	return true;
}

function isSupportedProtocol(){
	if(empty($_SERVER['HTTPS'])
		&& empty($_COOKIE['iWantHttp'])
		&& !isLocalIP($_SERVER['REMOTE_ADDR'])){

		return false;
	}
	return true;
}

function isHttpsRequired(){
    if(empty($_SERVER['HTTPS']) && !empty($_COOKIE['httpsOnly'])){
        return true;
    }
    return false;
}

/**
 * Return login name from token
 *
 * Jwt payload wait
 * {
 * "exp": 1652159154,
 * "login": "adriano.alvarez@wildix.com",
 * "ip": "213.231.25.164",
 * "time": 1652072754
 * }
 *
 * @param string $jwt Jwt token (json encoded).
 *
 * @return string
 */
function getLoginFromToken(string $jwt): string {
    $login = '';
    try {
        $token = \Wildix\Utils\JWT::unpack($jwt);
        $login = $token['payload']['loginAs'] ?? '';
    } catch (Exception $e) {}

    return $login;
}

if(User::getInstance()->isLogged() && empty($oath2Mode)) {
    header('location: ../');
    exit;
}else if(!isSupportedBrowser()){
	header('location: ../not_supported_browser/');
    exit;
}else if(isHttpsRequired()){
	header('location: ../force_https/');
    exit;
}else if(!isSupportedProtocol()){
	header('location: ../use_https/');
    exit;
}

?>
<html>
<head>

<title>Authorization required</title>
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
<meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
<link rel="shortcut icon" href="../<?=\Wildix\WhiteLabel::getInstance()->getFavicon();?>" type="image/x-icon">
<link href="../css/jquery.loadmask.css" rel="stylesheet" type="text/css">

<script type="text/javascript" src="../js/jquery-3.2.0.min.js?<?=WMS_VERSION;?>"></script>
<script type="text/javascript" src="../js/jquery.loadmask.js"></script>
<script type="text/javascript" src="../js/jquery.countdown360.js"></script>

<link href="../css/wildix-font.css?<?=WMS_VERSION;?>" rel="stylesheet" type="text/css">
<link href="../css/wildix-icons.css?<?=WMS_VERSION;?>" rel="stylesheet" type="text/css">
<link href="../collaboration/dist/auth/style.css?<?=WMS_VERSION;?>" rel="stylesheet" type="text/css" />
<?php
$custom_css = \Wildix\WhiteLabel::getInstance()->getCss();
if(!empty($custom_css)){
    echo '<link href="../'.$custom_css.'" rel="stylesheet" type="text/css">'.PHP_EOL;
}
?>

<?php if (isset($oath2Mode) && $oath2Mode === true) { ?>
<script>
    const oauth2Mode = true;
    const oauth2GrantUrl = '<?=$oauth2GrantUrl?>';
</script>
<?}?>

<script defer src="https://statics.teams.cdn.office.net/sdk/v1.10.0/js/MicrosoftTeams.min.js" integrity="sha384-6oUzHUqESdbT3hNPDDZUa/OunUj5SoxuMXNek1Dwe6AmChzqc6EJhjVrJ93DY/Bv" crossorigin="anonymous"></script>

<script type="text/javascript" src="authorization.js?<?=WMS_VERSION;?>" data-chromeapp="1"></script>
</head>

<body>

    <section class="page-wrapper authorization">

        <?php include_once '../authorization/header.php'; ?>

        <main class="page-wrapper__body">

            <div class="authorization__wrapper main-wrapper">

                <div class="form-auth">

                    <form class="form-auth__body" onsubmit="if(!auth()){return false;}" method="post">

                        <div class="form-auth__wrap form-wrap window-info">
                            <div class="form-item field-caption-top">
                                <input class="form-auth-field form-field form-field__user" type="text" value="" placeholder="" id="user-auth" required="required"/>
                                <label class="field-caption-top__label">Login</label>
                            </div>
                            <div class="form-item form-item_password field-caption-top">
                                <input class="form-auth-field form-field form-field__password" type="password" value="" placeholder="" id="password-auth" required="required"/>
                                <label class="field-caption-top__label">Password</label>
                                <button class="btn-show-password" type="button" title="">
                                    <i class="fa fa-icon-password-hide image_password"></i>
                                </button>
                            </div>

                            <div class="form-error flex-container">
                                <div class="form-error__message"></div>
    <!--                            <div class="btn-forgot-password">-->
    <!--                                <button class="btn-forgot-password__link tooltip" tooltip="Forgot the password?" flow="down" type="button" title="">-->
    <!--                                    Forgot the password-->
    <!--                                </button>-->
    <!--                            </div>-->
                            </div>

                            <div class="form-auth__bottom flex-container">
                                <div class="form-auth__checkboxes">
                                    <div class="remember-me flex-container form-item">
                                        <input class="remember-me__field checkbox-normal" id="remember" type="checkbox" name="remember">
                                        <label class="remember-me__label" for="remember" title="Remember me">Remember me</label>
                                    </div>
                                    <?php if (env('CALL_CONTROL_FEATURE', false)) : ?>
                                    <div class="call-control flex-container form-item">
                                        <input class="call-control__field checkbox-normal" id="call-control" type="checkbox" name="call-control">
                                        <label class="call-control__label" for="call-control" title="Use collaboration as Call control">Call Control only</label>
                                    </div>
                                    <?php endif; ?>
                                </div>
                                <button class="form-auth__submit btn-submit btn-usual" type="submit" title="Login">Login</button>
                            </div>
                        </div>

                        <div class="login-with flex-container">
                            <div class="login-with__caption">Login with</div>
                            <button type="button" title="Google Single Sign-On" class="btn-circle btn-sing-on btn-sing-on-google">
                                <i class="fa fa-icon-google-sign-on"></i>
                            </button>
                            <button type="button" title="Office 365 Sign-On" class="btn-circle btn-sing-on btn-sing-on-office365">
                                <i class="fa fa-icon-sing-on-office365"></i>
                            </button>
                        </div>
                    </form>

                    <form class="form-two-factor" method="post" onsubmit="if(!auth(true)){return false;}" >

                        <div class="form-wrap window-info">

                            <div class="form-two-factor__top">
                                <h3 class="form-two-factor__title">Two-factor authentication</h3>
                                <h5 class="form-two-factor__subtitle  description">
                                </h5>
                            </div>

                            <div class="flex-container form-two-factor__bottom">
                                <div class="form-item field-caption-top">
                                    <input class="form-field form-field__code" type="text"  placeholder=""  required="required"/>
                                    <label class="field-caption-top__label">Enter code</label>
                                </div>
                                <div class="countdown"></div>
                                <button class="btn-usual btn_submit  submit" type="submit" title="Login">Login</button>
                            </div>

                            <div class="form-error flex-container">
                                <div class="form-error__message"></div>
                            </div>
                        </div>
                    </form>

                </div>

            </div>

        </main>

    </section>
<?php
$loginFromPortalToken = getLoginFromToken((string)($_POST['portalToken'] ?? ''));
if ($loginFromPortalToken !== '') { ?>
    <input type="hidden" id="portalToken" value="<?= htmlspecialchars($_POST['portalToken']); ?>" />
    <input type="hidden" id="portalUserLogin" value="<?= htmlspecialchars($loginFromPortalToken); ?>" />
<?php } ?>
</body>
</html>
