<?php

use Session\Session;

!file_exists('auth.php') ? require '../auth.php' : require 'auth.php';

if (!WMS_Permissions::getInstance()->is_allowed('page', 'settings__utilites__backup') || ($_SERVER['REQUEST_METHOD'] !== 'GET' && !Session::isValidCsrfToken())) {
    die(_t('strings.permissionsDenied'));
}

require_once 'classes/backuper/backuper.class.php';
require_once 'classes/multipbx.class.php';

@unlink('/tmp/wmsrestore.out');

if (isset($_POST['applyBackup']) && $_POST['applyBackup'] == 'on') {
    backuper::apply($_POST['name'], $_POST['network']);
    die(json_encode(array('onSuccess' => 'true')));
}

@unlink('/tmp/wmsrestore.out');
?>
<html>
<head>
<meta http-equiv="Content-type" content="text/html;charset=UTF-8" />
<style>
body {
    font-family: Helvetica,sans-serif;
    font-size: 13px;
    text-align: center;
    padding: 0 0 30px;
    position: relative;
}
.err {
    color:red;
}
.endop, .sound {
    color: green;
    text-overflow: ellipsis;
    overflow: hidden;
    display: block;
}
.proc {
    background: url('../images/preloader-gray.gif') no-repeat;
    padding-left: 20px;
    color: blue;
}
.actions {
    position: absolute;
    right: 0;
    bottom: 0;
}
.actions button {
    font-size: 12px;
    margin: 0 8px 0 0;
}
.info {
    color: #2f79a7;
    font-weight: bold;
}
.name {
    overflow: hidden;
    text-overflow: ellipsis;
    max-width: 100%;
    display: block;
    position: relative;
    font-weight: bold;
}
.name:after {
    content: '?';
    position: absolute;
    right: 0;
    top: 0;
}
.mess {
    text-align: left;
    text-overflow: clip;
    overflow: hidden;
    max-width: 90%;
}
</style>
<meta name="X-CSRF-Token" content="<?=Session::getCsrfToken();?>">
<script src="../js/prototype.js?<?=WMS_VERSION;?>"></script>
<script src="../js/effects.js?<?=WMS_VERSION;?>"></script>
<script src="../js/wms.js?<?=WMS_VERSION;?>"></script>
<script>
// --- Show window --- //
var win = parent.win;
    win.setSize(580, 260);
    win.setTitle('<?=_t('backup.ApplyBackup');?>');
    win.showCenter(true);
// ------------------- //
function wclose() {
    parent.win.hide();
}

function wreboot(){
    fetch('/api/v1/PBX/System/Reboot/', {method: 'PUT'})
        .then(() => {
            parent.location.href = '../reboot';
        })
        .catch((e) => {
            console.error(e);
        });
}

window.onload=function() {
    ChangeButtons();
}

function apply_backup(timeout) {
    document.getElementById('confirm').hide();
    document.getElementById('close').hide();
    var net_check = document.getElementById('network-checkbox').checked;
    var filename = '<?=htmlspecialchars($_REQUEST['name'])?>';
    var oXHRInfo;
    $('showinfo').innerHTML = '<span class="proc"><?=_t('strings.BeginningProcedure');?></span><br>';
    if (filename != '') {
        new Ajax.Request('../backuper/apply_backup.php', {
            method: 'post',
            parameters : $H({
                name: filename,
                network: net_check,
                applyBackup: 'on'
            }).toQueryString(),
            onSuccess: function(response) {
            }
        });
        return setTimeout(function() {
            oXHRInfo = new Ajax.PeriodicalUpdater('showinfo', '../backuper/index.php', {
                method: 'post',
                parameters: $H({
                    get_apply_info: 'on'
                }).toQueryString(),
                frequency: 4, decay: 1,
                onSuccess: (function(response) {
                    if (response.responseText.indexOf('class="endop') != -1) {
                        var txt = response.responseText.gsub('proc', 'endop');
                        $('showinfo').innerHTML = txt;
                        document.getElementById('close').show();
                        document.getElementById('reboot').show();
                        oXHRInfo.stop();
                    } else if (response.responseText.indexOf('class="sound') != -1) {
                        var txt = response.responseText.gsub('proc', 'sound');
                        $('showinfo').innerHTML = txt;
                        document.getElementById('done').show();
                        oXHRInfo.stop();
                    }
                }).bind(this)
            });
        }.bind(this), timeout);
    }
}
</script>
</head>
<body>
<?php
$multipbx = new multipbx();
$mode     = $multipbx->get_mode();

$additionalInfo = '';
if ($mode == '2') {
    $additionalInfo = _t('backup.msg.restoreOnMaster');
} else if ($mode == '1') {
    $additionalInfo = _t('backup.msg.restoreOnSlave');
}

$checkArch = backuper::check_archive($_REQUEST['name'], true);

if (!in_array($checkArch, array('sound', 'wms'))) {
    if ($checkArch == 'WRONG_FORMAT') {
        $err = _t('backup.err.OldBackup');
    } else {
        $err = _t('backup.err.UnknownError');
    }
}
?>

<div id="showinfo">
    <?php if (isset($err)) { ?>
        <span  class="err"><?php echo $err; ?>!</span>
        <div class="actions">
            <button type="button" id="close" class="but20 butt_window_bottom" onclick="wclose()"><?= _t('buttons.Cancel') ?></button>
        </div>
    <?php } else {
    if (!empty($additionalInfo)) {
        echo '<span style="text-align:left;padding:15px 15px 15px 15px;">' . $additionalInfo . '</span><br/>';
    }
    ?>
    <span class="info"><?php echo _t('backup.msg.RestoreSystemFrom'); ?>:</span>
    <br/>
    <span class="name" title="<?= htmlspecialchars($_REQUEST['name']) ?>">
        <?= htmlspecialchars($_REQUEST['name']); ?>
    </span>
    <div style="margin-top: 7px;">
        <input type="checkbox" id="network-checkbox" style="position: relative; top: 3px;">
        <label for="network-checkbox"> restore network</label>
    </div>

    <?php } ?>
</div>
<div class="actions">
    <button type="button" id="confirm" class="but20 butt_window_bottom" onclick="apply_backup(3000)"><?= _t('buttons.Yes') ?></button>
    <button type="button" style="display: none" id="reboot" class="but20 butt_window_bottom" onclick="wreboot()"><?= _t('backup.btn.Reboot') ?></button>
    <button type="button" id="close" class="but20 butt_window_bottom" onclick="wclose()"><?= _t('buttons.Cancel') ?></button>
    <button type="button" style="display: none" id="done" class="but20 butt_window_bottom" onclick="wclose()"><?=_t('buttons.Ok');?></button>
</div>
</body>
</html>
