<?php
(file_exists('auth.php')) ? require 'auth.php' : require '../auth.php';

if (!WMS_Permissions::getInstance()->is_allowed('page', 'settings__utilites__backup')) {
    die(_t('strings.permissionsDenied'));
}

require_once 'classes/backuper/backuper.class.php';

$err                = '';
$reset_pbx_filename = '/var/lib/wms/callweaver.conf.tar.gz';
$reset_box_filename = '/var/lib/wms/reset.conf.tar.gz';

$check_arch = backuper::check_reset($reset_pbx_filename);
if ($check_arch !== true) {
    $error = true;
    if ($check_arch == 'NOT_EXISTS') {
        $err = _t('strings.doesNotExist', $reset_pbx_filename);
    } else if ($check_arch == 'NOT_READABLE') {
        $err = _t('strings.isNotReadable', $reset_pbx_filename);
    } else if ($check_arch == 'BPATH_NOT_WRITABLE') {
        $err = _t('strings.isNotWriteable', BASEPATH);
    } else if ($check_arch == 'WRONG_FORMAT') {
        $err = _t('backup.err.CannotReadArchive', $reset_pbx_filename);
    } else {
        $err = _t('backup.err.UnknownError');
    }
}
$check_arch = backuper::check_reset($reset_box_filename);
if ($check_arch !== true) {
    $error = true;
    if ($check_arch == 'NOT_EXISTS') {
        $err = _t('strings.doesNotExist', $reset_box_filename);
    } else if ($check_arch == 'NOT_READABLE') {
        $err = _t('strings.isNotReadable', $reset_box_filename);
    } else if ($check_arch == 'BPATH_NOT_WRITABLE') {
        $err = _t('strings.isNotWriteable', BASEPATH);
    } else if ($check_arch == 'WRONG_FORMAT') {
        $err = _t('backup.err.CannotReadArchive', $reset_box_filename);
    } else {
        $err = _t('backup.err.UnknownError');
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $res = '';
    $reset_ret = backuper::reset();
    if ($reset_ret == 0) {
        $res = 'Success';
    } else if ($reset_ret == 1) {
        $res = _t('backup.msg.RemoveErrors') . PHP_EOL;
    } else {
        $res = _t('backup.err.CannotExecuteScript', 'wmsreset') . PHP_EOL;
    }
    header("Content-Type: application/json\n");
    die(json_encode(['result' => $res]));
}
?>
<html>
<head>
<meta http-equiv="Content-type" content="text/html;charset=UTF-8" />
<style>
body {
    font-family: Helvetica,sans-serif;
    font-size: 13px;
    text-align: center;
    padding: 0 0 30px;
    position: relative;
}
table.backup-dialog { width: 500px; border: 1px solid #DDD; margin: 0 auto}
.tablehead {
    background:#D8D8DA url(../images/sprite.png) repeat-x scroll 0 0;
    height:20px;
    font-size:12px;
    color:#000;
    font-weight:normal;
    cursor: default;
}
.actions {
    position: absolute;
    right: 0;
    bottom: 0;
}
.actions button {
    font-size: 12px;
    margin: 0 8px 0 0;
}
.backup-dialog tbody td {
    text-align: center;
    padding: 3px;
    font-size: 13px;
    font-weight: bolder;
    font-family: Arial,Helvetica,sans-serif;
}
.proc {
    background: url(../images/preloader-gray.gif) no-repeat;
    padding-left: 20px;
    color: blue;
}
</style>
<script src="../js/prototype.js?<?=WMS_VERSION;?>"></script>
<script src="../js/effects.js?<?=WMS_VERSION;?>"></script>
<script src="../js/wms.js?<?=WMS_VERSION;?>"></script>
<script>
// --- Show window --- //
var win = parent.win;
    win.setSize(520, 200);
    win.setTitle('WMS [<?=_t('backup.ApplyReset');?>]');
// ------------------- //
function wclose() {
    parent.win.hide();
}
window.onload=function() {
    ChangeButtons();
}

function wreboot(){
    fetch('/api/v1/PBX/System/Reboot/', {method: 'PUT'})
        .then(() => {
            parent.location.href = '../reboot';
        })
        .catch((e) => {
            console.error(e);
        });
}

function dsm() {
    $('loading').show();
    $('actions').hide();
    fetch('/backuper/apply_reset.php', {method: 'POST'})
        .then(res => res.json())
        .then(({result}) => {
            if (result === 'Success') {
                wreboot();
            } else {
                document.getElementById('message').textContent = result;
                document.getElementById('confirm').remove();
            }
        })
        .catch(e => console.warn(e))
        .finally(() => $('loading').show());
}
</script>
</head>
<body>
<?php if (!empty($error)) { ?>
    <div style='background-color:#FFD400;height:20px;width:100%;font-weight:bold'>
        <?= $err ?>
    </div>
<?php } else { ?>
    <table class='backup-dialog'>
        <thead>
            <tr class='tablehead'>
                <td style='font-size: 14px; color: red; text-align: center' >Warning!</td>
            </tr>
        </thead>
        <tbody>
            <tr>
                <td id="message">
                    <?= _t('backup.msg.CreateBackup') ?>
                    <br/>
                    <?= _t('backup.ConfirmReset') ?>
                </td>
            </tr>
        </tbody>
    </table>
    <span id="loading" style="display: none" class="proc"><?=_t('strings.BeginningProcedure');?></span><br>

    <div id="actions" class="actions">
        <button type="button" id="confirm" class="but20 butt_window_bottom" onclick="dsm()"><?= _t('buttons.Yes') ?></button>
        <button type="button" id="close" class="but20 butt_window_bottom" onclick="wclose()"><?= _t('buttons.Cancel') ?></button>
    </div>
<?php } ?>
</body>
</html>
