<?php
/*
 * Addressbook/CardDAV server example
 * This server features CardDAV support
 *
 */
error_reporting(E_ALL ^ E_NOTICE);
ini_set('display_errors', 'on');
ini_set('memory_limit','200M');

require_once '../api/init.php';
require_once 'classes/class_phonebooks.php';
require_once 'classes/CustomAuthBackend.php';
require_once 'classes/CustomDAVACLPrincipalBackend.php';
require_once 'classes/CustomCardDavBackend.php';
require_once 'classes/CustomCardDavDirectory.php';

function isOSXAddressBook(){
    return preg_match("/(macOS|Mac OS X).*?AddressBook/i", $_SERVER['HTTP_USER_AGENT']) > 0;
}

// Make sure this setting is turned on and reflect the root url for your WebDAV server.
// This can be for example the root / or a complete path to your server script
$baseUri = '/';

// Backends
$authBackend      = new CustomAuthBackend();
$principalBackend = new CustomDAVACLPrincipalBackend();
$carddavBackend   = new CustomCardDavBackend();


// Setting up the directory tree //
$nodes = array(
        new Sabre\DAVACL\PrincipalCollection($principalBackend),
        //new Sabre\CalDAV\CalendarRootNode($authBackend, $caldavBackend),
        new Sabre\CardDAV\AddressBookRoot($principalBackend, $carddavBackend),
        new CustomCardDavDirectory($carddavBackend)
);

// The object tree needs in turn to be passed to the server class
$server = new Sabre\DAV\Server($nodes);
$server->setBaseUri($baseUri);

// Plugins
$server->addPlugin(new Sabre\DAV\Auth\Plugin($authBackend,'SabreDAV'));
$server->addPlugin(new Sabre\DAV\Browser\Plugin());
//$server->addPlugin(new Sabre\CalDAV\Plugin());
$server->addPlugin(new Sabre\CardDAV\Plugin());
$server->addPlugin(new Sabre\DAVACL\Plugin());

// And off we go!
$server->exec();
