<?php

/**
 *
 * Custom Authontification
 */

class CustomAuthBackend extends \Sabre\DAV\Auth\Backend\AbstractBasic {


	/**
	 * Validates a username and password
	 *
	 * This method should return true or false depending on if login
	 * succeeded.
	 *
	 * @param string $username
	 * @param string $password
	 * @return bool
	 */
	protected function validateUserPass($username, $password){
		return true;
	}

	/**
	 * Returns information about the currently logged in username.
	 *
	 * If nobody is currently logged in, this method should return null.
	 *
	 * @return string|null
	 */
	public function getCurrentUser() {
		return str_replace(' ', '_', $this->currentUser);
	}


	/**
	 * Authenticates the user based on the current request.
	 *
	 * If authentication is successful, true must be returned.
	 * If authentication fails, an exception must be thrown.
	 *
	 * @param Sabre\DAV\Server $server
	 * @param string $realm
	 * @throws Sabre\DAV\Exception\NotAuthenticated
	 * @return bool
	 */
	public function authenticate(\Sabre\DAV\Server $server, $realm) {
		$auth = new \Sabre\HTTP\BasicAuth();
		$auth->setHTTPRequest($server->httpRequest);
		$auth->setHTTPResponse($server->httpResponse);
		$auth->setRealm($realm);
		$userpass = $auth->getUserPass();

		if (!$userpass) {
			$auth->requireLogin();
			throw new \Sabre\DAV\Exception\NotAuthenticated('No basic authentication headers were found');
		}

		$user=class_colleagues::getInstance()->getAuthenticatedUser();

		// Authenticates the user
		if (!$user) {
			$auth->requireLogin();
			throw new \Sabre\DAV\Exception\NotAuthenticated('Username or password does not match');
		}
		$this->currentUser = $user['telephoneNumber'];
		return true;
	}

}
