<?php

/**
 * Custom CardDAV backend
 */

class CustomCardDavBackend extends \Sabre\CardDAV\Backend\AbstractBackend {

	/**
	 * The PDO table name used to store addressbooks
	 */
	protected $addressBooksTableName;

	/**
	 * The PDO table name used to store cards
	 */
	protected $cardsTableName;


    public function __construct($addressBooksTableName = 'phonebooks', $cardsTableName = 'contacts') {
        $this->addressBooksTableName = $addressBooksTableName;
        $this->cardsTableName = $cardsTableName;
    }

    /**
     * Returns the list of addressbooks for a specific user.
     *
     * @param string $principalUri
     * @return array
     */
    private $_addressBooks = null;
    public function getAddressBooksForUser($principalUri) {
    	//logger($principalUri, 'getAddressBooksForUser');

    	if (!isset($this->_addressBooks[$principalUri])){

    	    $userName = str_replace('principals/', '', $principalUri);
    	    $colleague = class_colleagues::getInstance()->getColleagueByName($userName, true);
    	    $phoneBooks = class_phonebooks::getInstance()->getAvailablePhoneBooksByColleague($colleague);

    	    if(!isOSXAddressBook()){
    	        $lastUpdateContacts = class_phonebooks::getInstance()->getDateLastUpdateContactsByPhonebook($phoneBooks);

    	        foreach($phoneBooks as $row) {
    	            if($row['name'] == 'LDAP'){
    	                $row['name'] = 'Colleagues';
    	            }
    	            if(!empty($lastUpdateContacts[$row['rid']]['last_update'])){
    	                $this->_addressBooks[$principalUri][] = array(
    	                        'id'  => $row['rid'],
    	                        'uri' => $row['name'],
    	                        'principaluri' => $principalUri,
    	                        '{DAV:}displayname' => $row['name'],
    	                        '{' . \Sabre\CardDAV\Plugin::NS_CARDDAV . '}addressbook-description' => '',
    	                        '{http://calendarserver.org/ns/}getctag' => $row['hash'].''.$lastUpdateContacts[$row['rid']]['last_update'],
    	                        '{' . \Sabre\CardDAV\Plugin::NS_CARDDAV . '}supported-address-data' => new \Sabre\CardDAV\Property\SupportedAddressData(),
    	                );
    	            }
    	        }
    	    }else{
    	        $lastUpdateContact = class_phonebooks::getInstance()->getDateLastUpdateContact();

    	        $hash = '';
    	        foreach($phoneBooks as $phonebook){
    	            $hash.= $phonebook['hash'];
    	        }

    	        if(!empty($lastUpdateContact)){
    	            $this->_addressBooks[$principalUri][] = array(
    	                    'id'  => 'allContacts',
    	                    'uri' => 'Contacts',
    	                    'principaluri' => $principalUri,
    	                    '{DAV:}displayname' => 'Contacts',
    	                    '{' . \Sabre\CardDAV\Plugin::NS_CARDDAV . '}addressbook-description' => '',
    	                    '{http://calendarserver.org/ns/}getctag' => md5($hash).$lastUpdateContact,
    	                    '{' . \Sabre\CardDAV\Plugin::NS_CARDDAV . '}supported-address-data' => new \Sabre\CardDAV\Property\SupportedAddressData(),
    	            );
    	        }
    	    }
    	}
        return $this->_addressBooks[$principalUri];
    }


    /**
     * Updates an addressbook's properties
     *
     * See Sabre\DAV\IProperties for a description of the mutations array, as
     * well as the return value.
     *
     * @param mixed $addressBookId
     * @param array $mutations
     * @see Sabre\DAV\IProperties::updateProperties
     * @return bool|array
     */
    public function updateAddressBook($addressBookId, array $mutations) {
    	//logger($addressBookId, 'updateAddressBook');

    	return true;
    }

    /**
     * Creates a new address book
     *
     * @param string $principalUri
     * @param string $url Just the 'basename' of the url.
     * @param array $properties
     * @return void
     */
    public function createAddressBook($principalUri, $url, array $properties) {
    	//logger($url, 'createAddressBook');

    }

    /**
     * Deletes an entire addressbook and all its contents
     *
     * @param int $addressBookId
     * @return void
     */
    public function deleteAddressBook($addressBookId) {
    	//logger($addressBookId, 'deleteAddressBook');

    }

    /**
     * Returns all cards for a specific addressbook id.
     *
     * This method should return the following properties for each card:
     *   * carddata - raw vcard data
     *   * uri - Some unique url
     *   * lastmodified - A unix timestamp
     *
     * It's recommended to also return the following properties:
     *   * etag - A unique etag. This must change every time the card changes.
     *   * size - The size of the card in bytes.
     *
     * If these last two properties are provided, less time will be spent
     * calculating them. If they are specified, you can also ommit carddata.
     * This may speed up certain requests, especially with large cards.
     *
     * @param mixed $addressbookId
     * @return array
     */
    public function getCards($addressbookId) {
    	//logger($addressbookId, 'getCards');

        $filter = null;
    	if($addressbookId != 'allContacts'){
    		$filter = array(Wildix\Phonebooks\Contact::PHONEBOOK_ID => $addressbookId);
        }
        $contacts = class_phonebooks::getInstance()->getAllAvailableContacts($filter);

        if(is_array($contacts)){
    		foreach($contacts as $key=>$row){
    			if ($key<=10000) {
    				$contacts[$key] = array('id' => $row['rid'], 'carddata' => class_phonebooks::getInstance()->contactToVcard($row), 'uri' => str_replace('/', ' ', $row['rid'].'-'.$row['username']), 'lastmodified'=> $row['last_update']);
    			}else{
    				unset($contacts[$key]);
    			}
    		}
    	}
    	return $contacts;
    }

    /**
     * Returns a specfic card.
     *
     * The same set of properties must be returned as with getCards. The only
     * exception is that 'carddata' is absolutely required.
     *
     * @param mixed $addressBookId
     * @param string $cardUri
     * @return array|false
     */
    public function getCard($addressBookId, $cardUri) {
    	//logger($cardUri, 'getCard');

    	$id = null;
    	if(preg_match('/^(\d+)-.*$/', $cardUri, $matches)){
    		if(!empty($matches[1])){
    			$id = $matches[1];
    		}
    	}

        $contact = null;
        $filter = null;
        if($addressBookId != 'allContacts'){
			if(empty($id)){
				$filter = array(
						Wildix\Phonebooks\Contact::PHONEBOOK_ID => $addressBookId,
						Wildix\Phonebooks\Contact::NAME => $cardUri
				);
			}else{
				$filter = array(
						Wildix\Phonebooks\Contact::PHONEBOOK_ID => $addressBookId,
						Wildix\Phonebooks\Contact::ID => $id
				);
			}
        }else{
        	if(empty($id)){
        		$filter = array(
        				Wildix\Phonebooks\Contact::NAME => $cardUri
        		);
        	}else{
        		$filter = array(
        				Wildix\Phonebooks\Contact::ID => $id
        		);
        		
        	}
        }

        if($filter !== null){
        	$contact = class_phonebooks::getInstance()->getAllAvailableContacts($filter);
        	$contact = $contact[0];
        }
        
    	$vCard = false;
    	if($contact){
    		$vCard = class_phonebooks::getInstance()->contactToVcard($contact);
    	}

        return array('carddata' => $vCard);
    }

    /**
     * Creates a new card.
     *
     * The addressbook id will be passed as the first argument. This is the
     * same id as it is returned from the getAddressbooksForUser method.
     *
     * The cardUri is a base uri, and doesn't include the full path. The
     * cardData argument is the vcard body, and is passed as a string.
     *
     * It is possible to return an ETag from this method. This ETag is for the
     * newly created resource, and must be enclosed with double quotes (that
     * is, the string itself must contain the double quotes).
     *
     * You should only return the ETag if you store the carddata as-is. If a
     * subsequent GET request on the same card does not have the same body,
     * byte-by-byte and you did return an ETag here, clients tend to get
     * confused.
     *
     * If you don't return an ETag, you can just return null.
     *
     * @param mixed $addressBookId
     * @param string $cardUri
     * @param string $cardData
     * @return string|null
     */
    public function createCard($addressBookId, $cardUri, $cardData) {
    	//logger($cardUri, 'createCard');

    	return null;
    }

    /**
     * Updates a card.
     *
     * The addressbook id will be passed as the first argument. This is the
     * same id as it is returned from the getAddressbooksForUser method.
     *
     * The cardUri is a base uri, and doesn't include the full path. The
     * cardData argument is the vcard body, and is passed as a string.
     *
     * It is possible to return an ETag from this method. This ETag should
     * match that of the updated resource, and must be enclosed with double
     * quotes (that is: the string itself must contain the actual quotes).
     *
     * You should only return the ETag if you store the carddata as-is. If a
     * subsequent GET request on the same card does not have the same body,
     * byte-by-byte and you did return an ETag here, clients tend to get
     * confused.
     *
     * If you don't return an ETag, you can just return null.
     *
     * @param mixed $addressBookId
     * @param string $cardUri
     * @param string $cardData
     * @return string|null
     */
    public function updateCard($addressBookId, $cardUri, $cardData) {
    	//logger($cardUri, 'updateCard');

    	return null;
    }

    /**
     * Deletes a card
     *
     * @param mixed $addressBookId
     * @param string $cardUri
     * @return bool
     */
    public function deleteCard($addressBookId, $cardUri) {
    	//logger($cardUri, 'deleteCard');

    	return true;
    }
}
