<?php

class CustomCardDavDirectory implements \Sabre\CardDAV\IDirectory {

	/**
	 * This is an array with addressbook information
	 *
	 * @var array
	 */
	private $addressBookInfo;

	/**
	 * CardDAV backend
	 *
	 * @var Sabre\CardDAV\Backend\Abstract
	 */
	private $carddavBackend;

	/**
	 * Constructor
	 *
	 * @param Sabre\CardDAV\Backend\Abstract $carddavBackend
	 * @param array $addressBookInfo
	 */
	public function __construct(\Sabre\CardDAV\Backend\AbstractBackend $carddavBackend) {
		$this->carddavBackend = $carddavBackend;

		$user=class_colleagues::getInstance()->getAuthenticatedUser();

		$this->addressBookInfo = array(
    				'id'  => 0,
    				'uri' => 'Contacts',
    				'principaluri' => 'principals/'.$user['telephoneNumber'],
    				'{DAV:}displayname' => 'Contacts',
    				'{' . \Sabre\CardDAV\Plugin::NS_CARDDAV . '}addressbook-description' => '',
    				'{http://calendarserver.org/ns/}getctag' => '',
    				'{' . \Sabre\CardDAV\Plugin::NS_CARDDAV . '}supported-address-data' =>
    				new \Sabre\CardDAV\Property\SupportedAddressData(),
    		);
	}

	/**
	 * Creates a new file in the directory
	 *
	 * Data will either be supplied as a stream resource, or in certain cases
	 * as a string. Keep in mind that you may have to support either.
	 *
	 * After succesful creation of the file, you may choose to return the ETag
	 * of the new file here.
	 *
	 * The returned ETag must be surrounded by double-quotes (The quotes should
	 * be part of the actual string).
	 *
	 * If you cannot accurately determine the ETag, you should not return it.
	 * If you don't store the file exactly as-is (you're transforming it
	 * somehow) you should also not return an ETag.
	 *
	 * This means that if a subsequent GET to this new file does not exactly
	 * return the same contents of what was submitted here, you are strongly
	 * recommended to omit the ETag.
	 *
	 * @param string $name Name of the file
	 * @param resource|string $data Initial payload
	 * @return null|string
	 */
	public function createFile($name, $data = null){
		//logger($name, 'createFile');
	}

	/**
	 * Creates a new subdirectory
	 *
	 * @param string $name
	 * @return void
	 */
	public function createDirectory($name){
	    //logger($name, 'createDirectory');
	}

	/**
	 * Returns a specific child node, referenced by its name
	 *
	 * @param string $name
	 * @return \Sabre\DAV\INode
	 */
	public function getChild($name){
		//logger($name, 'getChild');

		$id = null;
		if(preg_match('/^(\d+)-.*$/', $name, $matches)){
			if(!empty($matches[1])){
				$id = $matches[1];
			}
		}

		$contact = null;
		$filter = null;
		if(!empty($id)){
			$filter = array(
					Wildix\Phonebooks\Contact::ID => $id
			);
		}else{
			$filter = array(
					Wildix\Phonebooks\Contact::NAME => $name
			);
		}
		$contacts = class_phonebooks::getInstance()->getAllAvailableContacts($filter);
		$contact = $contacts[0];

		if(empty($contact)){
			throw new \Sabre\DAV\Exception\NotFound('Card not found');
		}

		$card = array('id' => $contact['rid'], 'carddata' => class_phonebooks::getInstance()->contactToVcard($contact), 'uri' => $contact['rid'].'-'.$contact['username'], 'lastmodified'=> $contact['last_update']);

		return new \Sabre\CardDAV\Card($this->carddavBackend, $this->addressBookInfo, $card);
	}

	/**
	 * Returns an array with all the child nodes
	 *
	 * @return \Sabre\DAV\INode[]
	 */
	public function getChildren(){
		//logger('getChildren');
		$cards = array();
		$contacts = class_phonebooks::getInstance()->getAllAvailableContacts();

		if(is_array($contacts)){
			foreach($contacts as $row){
				$cards[] = array('id' => $row['rid'], 'carddata' => class_phonebooks::getInstance()->contactToVcard($row), 'uri' => str_replace('/', ' ', $row['rid'].'-'.$row['username']), 'lastmodified'=> $row['last_update']);
			}
		}
		$children = array();
		foreach($cards as $card) {
			$children[] = new \Sabre\CardDAV\Card($this->carddavBackend, $this->addressBookInfo, $card);
		}
		return $children;
	}

	/**
	 * Checks if a child-node with the specified name exists
	 *
	 * @param string $name
	 * @return bool
	 */
	public function childExists($name){
		//logger($name, 'childExists');
		return true;
	}










	/**
	 * Deleted the current node
	 *
	 * @return void
	 */
	function delete(){
		//echo 'delete<br>';
	}

	/**
	 * Returns the name of the node.
	 *
	 * This is used to generate the url.
	 *
	 * @return string
	 */
	function getName(){
		return 'Contacts';
	}

	/**
	 * Renames the node
	 *
	 * @param string $name The new name
	 * @return void
	 */
	function setName($name){
		//echo 'setName<br>';
	}

	/**
	 * Returns the last modification time, as a unix timestamp
	 *
	 * @return int
	 */
	function getLastModified(){
		return time();
	}
}
