<?php
include_once __DIR__.'/functions.php';
include_once __DIR__.'/class_colleagues.php';

class class_phonebooks {

    private static $_obj = null;

    public static function getInstance(){
        if (self::$_obj == null) {
            self::$_obj = new class_phonebooks();
        }
        return self::$_obj;
    }

    public function getAvailablePhoneBooksByColleague($colleague){
        $result = array();

        $phonebooks = \Wildix\Phonebooks\Phonebooks::getInstance()->getPhonebooks(null, null, null, 0, 1000, Wildix\Phonebooks\Phonebook::NAME, 'ASC', class_colleagues::getInstance()->getObjectApiColleague($colleague));
        foreach ($phonebooks as $key => $phonebook){
        	$result[] = array(
        					"rid"=>$phonebook->getID(),
        					"name"=>$phonebook->getName(),
        					"type"=>$phonebook->getType(),
        					"hash"=>$phonebook->getHash()
        	);
        }
        return $result;
    }

    public function getDateLastUpdateContactsByPhonebook($phonebooks){
        $ids = array();
        foreach ($phonebooks as $phonebook){
            $ids[] = $phonebook['rid'];
        }

        $result = array();
        $query = "SELECT phonebook_id, MAX(last_update) as last_update
                        FROM cti_contacts
                        WHERE phonebook_id in (".join(',',$ids).")
                        GROUP BY phonebook_id;";
        if($rows = \Wildix\Databases\CTIconnectDB::getInstance()->query($query)){
        	while($row = $rows->fetchArray(SQLITE3_ASSOC)){
        		if ($row && !empty($row)) {
        			$result[$row['phonebook_id']] = $row;
        		}
            }
        }
        return $result;
    }

    public function getDateLastUpdateContact(){
        $query = "SELECT MAX(last_update) as last_update
                        FROM cti_contacts
                        LIMIT 1";
        if($rows = \Wildix\Databases\CTIconnectDB::getInstance()->query($query)){
        	$row = $rows->fetchArray(SQLITE3_ASSOC);
            if($row && !empty($row) && !empty($row['last_update'])){
                return $row['last_update'];
            }
        }
        return null;
    }

    public function getAllAvailableContacts($filter=null){
    	$result = array();

        $contacts = \Wildix\Phonebooks\Contacts::getInstance()->getContacts($filter, false, false, 0, 500000, Wildix\Phonebooks\Contact::NAME, 'ASC', \User::getInstance());
        foreach ($contacts as $key => $contact){
        	$result[] = array(
        					"rid"=>$contact->getID(),
        					"source_id"=>$contact->getSourceID(),
        					"username"=>$contact->getName(),
        					"email"=>$contact->getEmail(),
        					"extension"=>$contact->getExtension(),
        					"phone"=>$contact->getPhone(),
        					"office"=>$contact->getOfficePhone(),
        					"home"=>$contact->getHomePhone(),
        					"home_mobile"=>$contact->getHomeMobile(),
        					"fax"=>$contact->getFax(),
        					"mobile"=>$contact->getMobile(),
        					"organization"=>$contact->getOrganisation(),
        					"image_url"=>$contact->getPicture(),
        					"shortcut"=>$contact->getShortcut(),
        					"phonebook_id"=>$contact->getPhonebookID(),
        					"group_id"=>$contact->getGroupID(),
        					"user_class"=>$contact->getType(),
        					"note"=>$contact->getNote(),
        					"address"=>$contact->getAddress(),
        					"vat_id"=>$contact->getVatID(),
        					"name_prefix"=>$contact->getNamePrefix(),
        					"user_passport_type"=>$contact->getDocumentType(),
        					"user_passport_id"=>$contact->getDocumentID(),
        					"pin"=>$contact->getPin(),
        					"credit"=>$contact->getCredit(),
        					"hash"=>$contact->getHash(),
        					"country"=>$contact->getCountry(),
        					"date_birth"=>$contact->getDateBirth(),
        					"born_in"=>$contact->getBornIn(),
        					"postal_code"=>$contact->getPostalCode(),
        					"city"=>$contact->getCity(),
        					"province"=>$contact->getProvince(),
        					"license_plate"=>$contact->getLicensePlate(),
        					"document_released_on"=>$contact->getDocumentReleased(),
        					"document_from"=>$contact->getDocumentFrom(),
        					"last_update"=>$contact->getLastUpdate(),
        					"ringtone"=>$contact->getRingtone()
        	);
        }

        return $result;
    }

    public function contactToVcard($data){

        foreach ($data as $key=>$value){
            $data[$key] = preg_replace("/\r\n|\n\r|\r|\n/", '\n', $value);
        }

        $vcard = '';

        $vcard .= "BEGIN:VCARD\n";
        $vcard .= "VERSION:3.0\n";

        $vcard .= "N:{$data['username']};;;;\n";
        $vcard .= "FN:{$data['username']}\n";

        !empty($data['organization']) && $vcard .= "ORG:" . str_replace('LDAP', 'Colleagues', $data['organization']) . ";\n";

        !empty($data['extension']) && $vcard .= "TEL;type=WORK:{$data['extension']}\n";
        !empty($data['phone']) && $vcard .= "TEL;type=MAIN:{$data['phone']}\n";
        !empty($data['office']) && $vcard .= "TEL;type=WORK:{$data['office']}\n";
        !empty($data['home']) && $vcard .= "TEL;type=HOME:{$data['home']}\n";
        !empty($data['home_mobile']) && $vcard .= "TEL;type=OTHER:{$data['home_mobile']}\n";
        !empty($data['mobile']) && $vcard .= "TEL;type=CELL:{$data['mobile']}\n";
        !empty($data['fax']) && $vcard .= "TEL;type=WORK;type=FAX:{$data['fax']}\n";
        !empty($data['email']) && $vcard .= "EMAIL;type=INTERNET;type=WORK;type=pref:{$data['email']}\n";

        if(!isOSXAddressBook()){
            $data['image_url'] = trim($data['image_url']);
            if(!empty($data['image_url']) && !empty($data['phone']) && preg_match('#^/cticonnect/cticonnect_share/user_avatar_\d+\.png\?\d+$#',$data['image_url'])){
                $shema = 'http';
                if(isset($_SERVER['HTTPS']) && $_SERVER['HTTPS']=='on'){
                    $shema = 'https';
                }
                $vcard .= "PHOTO;TYPE=PNG:{$shema}://{$_SERVER['HTTP_HOST']}/user_avatar/{$data['phone']}.png\n";
            }else if (!empty($data['image_url'])) {
                $vcard .= "PHOTO;VALUE=uri:{$data['image_url']}\n";
            }
        }

        if(!empty($data['note'])){
            $vcard .= "NOTE:" . preg_replace("/\r\n|\n\r|\r|\n/", '\n', strip_tags(br2nl($data['note']))) . "\n";

        }
        if(!empty($data['date_birth'])){
            $vcard .= "BDAY;value=date:{$data['date_birth']} ";
        }

        if(!empty($data['address'])){
            $vcard .= "item1.ADR;type=WORK;type=pref:;;" . preg_replace("/\r\n|\n\r|\r|\n/", '\n', removeNonUtf(strip_tags(br2nl($data['address'])))) . ";{$data['city']};{$data['province']};{$data['postal_code']};{$data['country']}\n"
            . "item1.X-ABADR:us\n";
        }


        if($data['organization'] == "LDAP" && !empty($data['phone'])){
            $vcard .=  "item2.X-JABBER;type=pref:{$data['phone']}@wildix\n"
            . "item2.X-ABLabel:wms\n";
        }


        $vcard .= "UID:{$data['rid']}\n";
        $vcard .= "END:VCARD\n";

        return $vcard;
    }

}
