<?php

use Session\Session;
use Wildix\Core\Notification;

(file_exists('auth.php'))?include('auth.php'):include('../auth.php');

if (
    !WMS_Permissions::getInstance()->is_allowed('page','settings__pbx')
    || (
            (isset($_REQUEST["set"]) || isset($_REQUEST["restart"]) || isset($_REQUEST["reinit"])) && !Session::isValidCsrfToken()
        )
    ) {
    die(_t('strings.permissionsDenied'));
}

if(isset($_REQUEST["page"]) && $_REQUEST["page"] == "cdr"){
    if(isset($_REQUEST["status"])){
        $obj = $_REQUEST["status"];
        switch ($obj){
            case "allstatus":
                $code['status']['general'] = GetAllStatus();
                $code['status']['mssql']   = GetMssqlStatus();
                $code['status']['mysql']   = GetMysqlStatus();
                $code['status']['sqlite3'] = GetSqliteStatus();
                $code['status']['csv']     = GetCSVStatus();
                break;
            default:
                $code = "";
                break;
        }
    }
    if(isset($_REQUEST["get"])){
        $obj = $_REQUEST["get"];
        switch ($obj){
            case "all":
                $code['settings']['all'] = GetAll();
                break;
            default:
                $code = "";
                break;
        }
    }
    if(isset($_REQUEST["set"])){
        $obj = $_REQUEST["set"];
        switch ($obj){
            case "all":
                $code['setted'] = SetSettings($_POST); // now return array()
                $code['status']['general'] = GetAllStatus();
                break;
            default:
                $code = "";
                break;
        }
    }

    if(isset($_REQUEST["restart"])){
        $obj = $_REQUEST["restart"];
        PBX::init_operation('restart');
    }

    if(isset($_REQUEST["reinit"])){
        $obj = $_REQUEST["rereinit"];
        $code = ReinitCDRSQLite();
    }
    die(json_encode(array('code' => $code, 'obj' =>$obj)));
}

function CreateAnswer($code,$obj){ // was used in the previous function, but usage was removed
    return array('obj' => $obj, 'code' => $code);
}

function ReinitCDRSQLite(){
    $settings = \CDR::getInstance()->getSettings();
    $file = rtrim($settings['sqlite3']['dbdir'],'/').'/'.ltrim($settings['sqlite3']['dbfile'],'/');
    if(is_file($file)){
        rename($file, $file . "_bkp");
    }
    syslog(LOG_WARNING, "PHP Warning:  SQLite3() CDR database was recreated. Old DB stored in " . $file . "_bkp");
    $ret = \CDR::getInstance()->SetSqliteDB();
    if($ret === true){
        $userData = WMS_Ldap::getInstance()->getEntry(WMS_Ldap::PERSONS, "(cn=admin)", array('mail'));
        if(isset($userData['mail'])){
            $msg = _t('cdr.db_restored',date('d-m-Y H:i:s'));
            $params = array(
                'body' => $msg,
                'to' => $userData['mail'],
                'subject' =>  \Models\PBX::getInstance()->getDomain() . ' ' . 'SQLite CDR database was recreated'
            );
            Notification::sendEmail($params);
        }
    }
    return is_bool($ret) ? $ret : false;
}

function prepareOut($out){
    $out = str_replace('[0;37;40m','',$out);
    $out = trim(implode("<br/>",$out));
    return $out;
}

function GetAllStatus(){
    $out = PBX::getInstance()->CommandResponce('cdr show status');
    $result = str_replace('Cannot get cdr settings from /etc/callweaver/cdr.conf','',prepareOut($out));
    return $result;
}

function GetMssqlStatus(){
    exec("echo '".implode("\n",PBX::getInstance()->CommandResponce('cdr show status'))."' | grep -Ii 'FreeTDS (MSSQL)\|Total\|TDS CDR\|MSSQL CDR\|Wrote\|Failed\|No such command'", $out);
    $result = prepareOut($out);

    if($result =='FreeTDS (MSSQL)'){
        $result = _t('cdr.EngineEnabled','MSSQL CDR');
    }else if ($result == '' || substr($result,0,15) == 'No such command'){
        $result = _t('cdr.EngineDisabled','MSSQL CDR');
    }
    return $result;
}

function GetMysqlStatus(){
    exec("echo '".implode("\n",PBX::getInstance()->CommandResponce('cdr show status'))."' | grep -Ii 'mysql\|Connected\|Wrote\|Failed\|No such command'", $out);
    $result = prepareOut($out);

    if($result == 'mysql'){
        $out = null;
        exec("echo '".implode("\n",PBX::getInstance()->CommandResponce('cdr mysql status'))."'", $out);
        $result = _t('cdr.EngineEnabled','Mysql CDR')."<br>".prepareOut($out);

    }else if ($result=='' || substr($result,0,15) == 'No such command'){
        $result = _t('cdr.EngineDisabled','Mysql CDR');
    }
    return $result;
}

function GetSqliteStatus(){
    exec("echo '".implode("\n",PBX::getInstance()->CommandResponce('cdr show status'))."' | grep -Ii 'SQLite\|Wrote\|Failed\|No such command' | grep -iv 'SQLite Realtime Driver'", $out);
    $result = prepareOut($out);
    if($result == 'cdr_sqlite3_custom'){
        $result = _t('cdr.EngineEnabled','SQLite CDR');
    }else if ($result=='' || substr($result,0,15) == 'No such command'){
        $result = _t('cdr.EngineDisabled','SQLite CDR');
    }
    return $result;
}

function GetCSVStatus(){
    exec("echo '".implode("\n",PBX::getInstance()->CommandResponce('cdr show status'))."' | grep -Ii 'csv\|Master\|Total\|No such command'", $out);
    $result = prepareOut($out);

    if($result == 'csv'){
        $result = _t('cdr.EngineEnabled','CSV CDR');
    }else if ($result == '' || substr($result,0,15) == 'No such command') {
        $result = _t('cdr.EngineDisabled','CSV CDR');
    }
    return $result;
}

function GetAll(){
    $settings = \CDR::getInstance()->getSettings();
    if (!is_array($settings))
        return false;
    // tds -> mssql
    if(isset($settings['tds'])) $settings['mssql'] = $settings['tds'];

    return array('all'=>$settings);
}

function SetSettings($array) {
    /* CW changes
     * now we have:
     * CSV 		- cdr_csv.so
     * SQLite3 	- cdr_sqlite3_custom.so
     * MySQL 	- cdr_mysql.so
     * MSSQL 	- cdr_tds.so
    */
    $error_msg = array();

    $settings = \CDR::getInstance()->getSettings();
    if (is_array($array['general'])){
        foreach ($array['general'] as $key => $value){
        	$settings['general'][$key] = $value;
        }
    }
    if (is_array($array['mysql'])){
        foreach ($array['mysql'] as $key => $value){
        	$settings['mysql'][$key] = $value;
        }
    }
    if (is_array($array['sqlite3'])){
        foreach ($array['sqlite3'] as $key => $value){
        	$settings['sqlite3'][$key] = $value;
        }
    }
    if (is_array($array['csv'])){
        foreach ($array['csv'] as $key => $value){
        	$settings['csv'][$key] = $value;
        }
    }
    if (is_array($array['mssql'])){
        foreach ($array['mssql'] as $key => $value){
        	$settings['tds'][$key] = $value;
        }
    }
    \CDR::write_cdr_conf($settings);
    // possible options changed after write cdr conf
    $settings = \CDR::getInstance()->getSettings();

    $reset = false;

    if ($settings['tds']['enabled'] == 'yes'){
        if (empty($settings['tds']['password'])) {
            $settings['tds']['enabled'] = 'no';
            $reset                      = true;
            $error_msg[]                = array(
                'subj' => 'mssql',
                'errmsg' => "<font color='#f68263' >" . _t('err.PasswordCanNotBeEmpty') . "</font><br/><br/>" . _t('cdr.EngineDisabled', 'Mssql CDR'),
            );
        } else {
            $res = \CDR::getInstance()->SetMssqlDB();
            if ($res !== true) {
                // if test connection false dont load mssql backend & return error message

                //WMS-1756 not enabled mssql and mysql if not connection to server
                //$reset = true;
                //$settings['tds']['enabled'] = 'no';
                //if ($settings['general']['ctibackend'] == 'tds') $settings['general']['ctibackend'] = '';
                $error_msg[] = array(
                    'subj' => 'mssql',
                    'errmsg' => "<font color='#f68263' >" . $res . "</font><br/><br/>" . _t('cdr.EngineDisabled', 'Mssql CDR')
                );
            }
        }
    }elseif ($settings['general']['ctibackend'] == 'tds'){
    	$settings['general']['ctibackend'] = '';
    }

    if ($settings['mysql']['enabled'] == 'yes'){
        if (empty($settings['mysql']['password'])) {
            $settings['mysql']['enabled'] = 'no';
            $reset                        = true;
            $error_msg[]                  = array(
                'subj' => 'mysql',
                'errmsg' => "<font color='#f68263' >" . _t('err.PasswordCanNotBeEmpty') . "</font><br/><br/>" . _t('cdr.EngineDisabled', 'Mysql CDR'),
            );
        } else {
            // exec, because of slow cdr mysql connection , mysql_query to down WMS-1978
            exec("timeout 30 /usr/sbin/init_cdrdb 'mysql'", $res);
            $res = $res[0];
            if ($res != 1) {
                // if test connection false dont load mysql backend & return error message

                //WMS-1756 not enabled mssql and mysql if not connection to server
                //$reset = true;
                //$settings['mysql']['enabled'] = 'no';
                //if ($settings['general']['ctibackend'] == 'mysql') $settings['general']['ctibackend'] = '';
                $error_msg[] = array(
                    'subj' => 'mysql',
                    'errmsg' => "<font color='#f68263' >" . $res . "</font><br/><br/>" . _t('cdr.EngineDisabled', 'Mysql CDR')
                );
            }
        }
    }elseif ($settings['general']['ctibackend'] == 'mysql'){
    	$settings['general']['ctibackend'] = '';
    }

    if ($settings['sqlite3']['enabled'] == 'yes'){
        $res = \CDR::getInstance()->SetSqliteDB();
        if($res !== true){
            // if test connection false dont load sqlite3 backend & return error message
            $reset = true;
            $settings['sqlite3']['enabled'] = 'no';
            if ($settings['general']['ctibackend'] == 'sqlite3') $settings['general']['ctibackend'] = '';
            $error_msg[] = array(
                'subj'   => 'sqlite3',
                'errmsg' => "<font color='#f68263' >".$res."</font><br/><br/>"._t('cdr.EngineDisabled','SQLite CDR')
            );
        }
    } else if ($settings['general']['ctibackend'] == 'sqlite3') {
    	$settings['general']['ctibackend'] = '';
    }

    if ($settings['general']['ctibackend'] == ''){
    	if ($settings['tds']['enabled'] == 'yes'){
    		$reset = true;
    		$settings['general']['ctibackend'] = 'tds';
    	}else if ($settings['mysql']['enabled'] == 'yes'){
    		$reset = true;
    		$settings['general']['ctibackend'] = 'mysql';
    	}else if ($settings['sqlite3']['enabled'] == 'yes'){
    		$reset = true;
    		$settings['general']['ctibackend'] = 'sqlite3';
    	}
    }

	if ($settings['general']['ctibackend'] != '' && $settings['general']['save_history_base'] != 'yes') {
		$settings['general']['save_history_base'] = 'yes';
		$reset = true;
	}

    if($settings['general']['save_history_base'] == 'yes' && isset($settings['sqlite3']['dbdir']) && $settings['sqlite3']['dbdir'] != ''){
    	$freeSpace = disk_free_space($settings['sqlite3']['dbdir']);
    	if($freeSpace !== false){
    		$freeSpace = $freeSpace/1024/1024;
    		if($freeSpace < 1){
    			$reset = true;
    			$settings['general']['save_history_base'] = 'no';
    			$error = _t('cdr.no_free_space');
    		}
    	}else{
    		// error
    	}
    }

    if(($settings['general']['enable_contact_notes'] == 'yes' || $settings['general']['save_history_base'] == 'yes')
    		&& $settings['general']['ctibackend'] == ''){
    	$settings['general']['enable_contact_notes'] = 'no';
    	$reset = true;
    }


    if ($reset){
    	$return = \CDR::write_cdr_conf($settings);
    }

    if ($settings['csv']['enabled'] == 'yes'){
        PBX::getInstance()->Command('module load cdr_csv.so');
    }else{
        PBX::getInstance()->Command('module unload cdr_csv.so');
    }

    if ($settings['tds']['enabled'] == 'yes'){
        PBX::getInstance()->Command('module unload cdr_tds.so');
        PBX::getInstance()->Command('module load cdr_tds.so');
    }else{
        PBX::getInstance()->Command('module unload cdr_tds.so');
    }

    if ($settings['mysql']['enabled'] == 'yes'){
        PBX::getInstance()->Command('module unload cdr_mysql.so');
        PBX::getInstance()->Command('module load cdr_mysql.so');
    }else{
        PBX::getInstance()->Command('module unload cdr_mysql.so');
    }

    if ($settings['sqlite3']['enabled'] == 'yes'){
        PBX::getInstance()->Command('module unload cdr_sqlite3_custom.so');
        PBX::getInstance()->Command('module load cdr_sqlite3_custom.so');
    }else{
        PBX::getInstance()->Command('module unload cdr_sqlite3_custom.so');
    }

    PBX::getInstance()->Command('module reload cdr');

    if (count($error_msg) > 0){
        $return = false;
    }else{
        $return = true;
        $error_msg = $error;
    }

    return array('subj'=>'all','state'=>$return, 'error_msg' => $error_msg);
}
