<?php
class Bticino{

    private $_daemonFilePatch = '/usr/sbin/whoteld';
    private $_initdFilePatch = '/etc/init.d/whoteld';
    private $_generalConfPatch = '/tmp/whoteld.txt';
    private $_fiasConfPatch = '/etc/wildix/whoteld_fias_wms.conf';
    private $_xopenConfPatch = '/etc/wildix/whoteld_xopen_wms.conf';
    private $_managerConfPatch = '/etc/wildix/whoteld_manager_wms.conf';
    private $_variablesConfPatch = '/etc/wildix/whoteld_cwvariables_wms.conf';
    private $_workstationsXmlFile = '/etc/wildix/WorkstationsMappingFile.xml';
    private $_packageName = 'whoteld';
    private $_installLogFilePath = '/tmp/whotel-install-log';


    private $_xmlObj = null;
    private $_rootTag = 'configurator';

    private $_xmlObjWs = null;

    private static $_Instances = null;
    public static function getInstance(){
        if (self::$_Instances === null) {
            self::$_Instances = new self();
        }
        return self::$_Instances;
    }

    public function isInstalled(){
        if(file_exists($this->_daemonFilePatch)){
            return true;
        }
        return false;
    }

    /**
     * Instalation(uninstalation) process below will keep text file while it not ended
     * @return boolean | 'install' | 'ininstall'
     */
    public function getInstallationProgress(){
        exec("ps -eo args | grep -v grep | grep '/usr/bin/apt-get'", $output, $return_value);
        return $return_value == 0 && strpos( implode(';', $output), 'apt-get') !==false;
    }

    /**
     * Returns true if last instalation was successful or error string
     * @return boolean | string
     */
    public function getInstallationResult(){
        if(file_exists($this->_installLogFilePath)){
            $log = trim(file_get_contents($this->_installLogFilePath));
            if (
                strpos($log, 'Setting up whoteld')!==false ||
                strpos($log, 'Removing whoteld')!==false
               ){
                return true;
            } else if ($log){
                return $log;
            }
        }
        return true;
    }

    /**
     * Run instalation process without waiting
     * for the end due to it block lighttpd
     * with one worker for next requests
     * @return true or string if error
     */
    public function install(){
    	if($this->isInstalled()){
    		return true;
    	}


        $command =
                "(nohup "
                    . "sudo DEBIAN_FRONTEND=noninteractive /usr/bin/apt-get -y --allow-unauthenticated -q update; "
                    . "sudo DEBIAN_FRONTEND=noninteractive /usr/bin/apt-get -y --allow-unauthenticated -q install ".$this->_packageName." ; "
                    . "sudo /usr/bin/apt-get clean; "
                    . "sudo /usr/bin/apt-get -y autoremove; "
                . ") > ".$this->_installLogFilePath." 2>&1 & ";
        exec($command);

    	return true;
    }

    /**
     * Run deinstalation process without waiting for the end
     * @return true or string if error
     */
    public function uninstall(){
    	if(!$this->isInstalled()){
    		return true;
    	}

        $command =
                "(nohup "
                    . "sudo DEBIAN_FRONTEND=noninteractive /usr/bin/apt-get -y -q purge ".$this->_packageName." ; "
                    . "sudo /usr/bin/apt-get clean; "
                    . "sudo /usr/bin/apt-get -y autoremove; "
                .") > ".$this->_installLogFilePath." 2>&1 &  ";
        exec($command);

    	return true;
    }

    public function restartDaemon(){
        $cmd = 'sudo '.$this->_initdFilePatch.' restart';
        exec($cmd, $output);
        return true;
    }

    private $_managerConf = null;
    public function getManagerConf(){
        if($this->_managerConf === null){
            $this->_managerConf = array(
                    'XOpenSecret' => '',
                    'BillingType' => 'DurationOnly',
            		'MinibarType' => 'CostOnly',
                    'WakeUpTimeout' => 300,
                    'WakeUpTries' => 3,
            		'WakeUpOption' => '',
            		'EnableAutomation'=> 'no',
            		'BadgeController' => 'yes'
            );

            $this->_managerConf = array_merge($this->_managerConf, $this->getConfFromFile($this->_managerConfPatch), $this->getConfFromFile($this->_variablesConfPatch));
        }
        return $this->_managerConf;
    }

    public function resetWakeUpService	(){
        $managerConf = $this->getManagerConf();
        $managerConf['WakeUpTimeout'] = '300';
        $managerConf['WakeUpTries'] = '3';
        $managerConf['WakeUpOption'] = '';
        return $this->updateManagerConf($managerConf);
    }

    public function updateManagerConf($data){
        if(empty($data)){
            return true;
        }

        $newConf = array_merge($this->getManagerConf(), $data);

        if( ! $this->updateConfFile($newConf, $this->_managerConfPatch)){
			return false;
        }

    	if( ! $this->updateConfFile($newConf, $this->_variablesConfPatch)){
			return false;
        }

        exec('callweaver -rx "dialplan reload"');

        $this->_managerConf = $newConf;
        return true;
    }

    private function updateConfFile($newConf, $file){
    	$key = array();
    	switch ($file){
    		case $this->_managerConfPatch:
    			$key = array('XOpenSecret',	'BillingType', 'WakeUpTimeout', 'WakeUpTries', 'BadgeController');
    			break;
    		case $this->_variablesConfPatch:
    			$key = array('EnableAutomation', 'MinibarType', 'WakeUpOption');
    			break;
    	}

    	$newConf = array_intersect_key($newConf, array_flip($key));

    	$paramsToFile = array();
        foreach ($newConf as $key=>$value){

                $newConf[$key] = trim($newConf[$key]);

                switch ($key){
                    case 'EnableAutomation':
                    case 'BadgeController':
                    case 'WakeUpOption':
                    case 'MinibarType':
                    case 'BillingType': $paramsToFile[] = $key.' = "'.$newConf[$key].'";';
                        break;
                    case 'XOpenSecret':
                    		if(empty($newConf[$key])){
                    			$paramsToFile[] = $key.' = "'.$newConf[$key].'";';
                    		}else{
                    			$paramsToFile[] = $key.' = '.$newConf[$key].';';
                    		}
                    	break;
                    default: $paramsToFile[] = $key.' = '.$newConf[$key].';';
			}
        }

        if(file_put_contents($file, join(PHP_EOL, $paramsToFile)) === false){
            return false;
        }

        return true;
    }

    public function getConfFromFile($file){
    	$return = array();
    	if(file_exists($file)){
    		$strs = file($file);
			if(!empty($strs)){
				foreach ($strs as $value){
                	$patern = '/([^=\s]*)[\s]*=[\s"]*([^;"]*)/i';
                    if(preg_match($patern, $value, $matches)){
                    	$return[$matches[1]] = $matches[2];
                    }
                }
            }
    	}
    	return $return;
    }


    private $_xopenConf = null;
    public function getXOpenConf(){
        if($this->_xopenConf === null){
            $this->_xopenConf = array(
                    'host' => '',
                    'port' => '',
                    'fcode' => '',
                    'ucode' => '',
                    'secret' => '',
            		'BadgeController' => 'yes'
            );

            $fContent = '';

            if(file_exists($this->_xopenConfPatch)){
                $fContent .= trim(file_get_contents($this->_xopenConfPatch));
            }


            if(!empty($fContent)){
                foreach ($this->_xopenConf as $key=>$value){
                    $patern = '';
                    switch ($key){
                        case 'secret':
                        case 'BadgeController':
                            break;
                        case 'host': $patern = '/'.$key.'.*?=.*?"([^"]*)".*?;/i';
                            break;
                        default: $patern = '/'.$key.'.*?=.*?([^;]*);/i';
                            break;
                    }

                    if(!empty($patern)){
                        if(preg_match($patern, $fContent, $matches)){
                            $var = trim($matches[1]);
                            if(!empty($var)){
                                $this->_xopenConf[$key] = $var;
                            }
                        }
                    }
                }
            }

            $managerConf = $this->getManagerConf();
            if(!empty($managerConf) && !empty($managerConf['XOpenSecret'])){
                $this->_xopenConf['secret'] = $managerConf['XOpenSecret'];
                $this->_xopenConf['BadgeController'] = $managerConf['BadgeController'];
            }
        }
        return $this->_xopenConf;
    }


    public function updateXOpenConf($data){
        if(empty($data)){
            return 'Empty argument';
        }
        $data['fcode'] = trim($data['fcode']);
        $data['ucode'] = trim($data['ucode']);
        if(empty($data['fcode'])){
            $data['fcode'] = '99999';
        }
        if(empty($data['ucode'])){
            $data['ucode'] = '1';
        }


        $oldConf = $this->getXOpenConf();

        $conf = array();
        $dirty = false;

        if($oldConf['host'] != $data['host']
        || $oldConf['port'] != $data['port']
        || $oldConf['fcode'] != $data['fcode']
        || $oldConf['ucode'] != $data['ucode']
        || $oldConf['secret'] != $data['secret']
        || $oldConf['BadgeController'] != $data['BadgeController']){
            $dirty = true;
        }

        if($dirty){

            if(!empty($data['host'])
            && !empty($data['port'])){
                $conf[] = 'host  = "'.$data['host'].'";';
                $conf[] = 'port  = '.$data['port'].';';
                $conf[] = 'fcode = '.$data['fcode'].';';
                $conf[] = 'ucode = '.$data['ucode'].';';
            }

            if(file_put_contents($this->_xopenConfPatch, join("\n", $conf)) === false){
                return 'Cannot write XOpen config.';
            }else{

                $oldManagerConf = $this->getManagerConf();
                $oldManagerConf['XOpenSecret'] = $data['secret'];
                if($oldManagerConf['BadgeController'] != $data['BadgeController']){
                	$resetFias = true;
                	$oldManagerConf['BadgeController'] = $data['BadgeController'];
                }
                if($this->updateManagerConf($oldManagerConf) === false){
                    return 'Cannot write secret to config.';
                }else{
                	if($resetFias){
                		$this->updateFiasConf(false, true);
                	}
                    $this->restartDaemon();
                }
            }
        }
        return true;
    }


    private $_fiasConf = null;
    public function getFiasConf(){
        if($this->_fiasConf === null){
            $this->_fiasConf = array(
                    'telephony' => array(),
                    'automation' => array()
            );
            if(file_exists($this->_fiasConfPatch)){
                $fContent = trim(file_get_contents($this->_fiasConfPatch));
                if(!empty($fContent)){

                    if(preg_match('/PB.*?=.*?\{((.|\s|\S)*?)\}.*?;/i', $fContent, $matches)){
                        $telephonyContent = trim($matches[1]);
                        if(!empty($telephonyContent)){
                            if(preg_match('/host.*?=.*?"([^"]*)".*?;/i', $telephonyContent, $hostMatches)){
                                $host = trim($hostMatches[1]);
                                if(!empty($host)){
                                    $this->_fiasConf['telephony']['host'] = $host;
                                }
                            }
                            if(preg_match('/port.*?=.*?([^;]*);/i', $telephonyContent, $portMatches)){
                                $port = trim($portMatches[1]);
                                if(!empty($port)){
                                    $this->_fiasConf['telephony']['port'] = $port;
                                }
                            }
                            if(preg_match('/delimiter.*?=.*?"([^"]*)".*?;/i', $telephonyContent, $delimiterMatches)){
                                $delimiter = trim($delimiterMatches[1]);
                                if(!empty($host)){
                                    $this->_fiasConf['telephony']['delimiter'] = $delimiter;
                                }
                            }
                        }
                    }

                    if(preg_match('/DL.*?=.*?\{((.|\s|\S)*?)\}.*?;/i', $fContent, $matches)){
                        $automationContent = trim($matches[1]);

                        if(!empty($automationContent)){

                            if(preg_match('/host.*?=.*?"([^"]*)".*?;/i', $automationContent, $hostMatches)){
                                $host = trim($hostMatches[1]);
                                if(!empty($host)){
                                    $this->_fiasConf['automation']['host'] = $host;
                                }
                            }
                            if(preg_match('/port.*?=.*?([^;]*);/i', $automationContent, $portMatches)){
                                $port = trim($portMatches[1]);
                                if(!empty($port)){
                                    $this->_fiasConf['automation']['port'] = $port;
                                }
                            }
                            if(preg_match('/delimiter.*?=.*?"([^"]*)".*?;/i', $automationContent, $delimiterMatches)){
                                $delimiter = trim($delimiterMatches[1]);
                                if(!empty($host)){
                                    $this->_fiasConf['automation']['delimiter'] = $delimiter;
                                }
                            }
                        }
                    }
                }
            }

            $managerConf = $this->getManagerConf();
            if(!empty($managerConf) && !empty($managerConf['BillingType'])){
                $this->_fiasConf['billingType'] = $managerConf['BillingType'];
            }
        	if(!empty($managerConf) && !empty($managerConf['MinibarType'])){
                $this->_fiasConf['minibarType'] = $managerConf['MinibarType'];
            }
        }
        return $this->_fiasConf;
    }

    public function updateFiasConf($data, $reset = false){

    	$conf = array();
	    $dirty = false;

    	if($reset){
    		$dirty = true;
    		$oldConf = $this->getFiasConf();
    		$data = $oldConf;
    	}else{
	    	if(empty($data)){
	            return 'Empty argument';
	        }

	    	if(empty($data['telephony']['delimiter'])){
	            $data['telephony']['delimiter'] = '|';
	        }
	        if(empty($data['automation']['delimiter'])){
	            $data['automation']['delimiter'] = '|';
	        }

	        $oldConf = $this->getFiasConf();

	        if($oldConf['telephony']['host'] != $data['telephony']['host']
	                || $oldConf['telephony']['port'] != $data['telephony']['port']
	                || $oldConf['telephony']['delimiter'] != $data['telephony']['delimiter']){
	            $dirty = true;
	        }else if($oldConf['automation']['host'] != $data['automation']['host']
	                || $oldConf['automation']['port'] != $data['automation']['port']
	                || $oldConf['automation']['delimiter'] != $data['automation']['delimiter']){
	            $dirty = true;
	        }else if($oldConf['billingType'] != $data['billingType']){
	            $dirty = true;
	        }else if($oldConf['minibarType'] != $data['minibarType']){
	            $dirty = true;
	        }
    	}

        if($dirty){

        	$oldManagerConf = $this->getManagerConf();

            if(!empty($data['telephony'])
            && !empty($data['telephony']['host'])
            && !empty($data['telephony']['port'])){
                $conf[]= 'PB = {
        host = "'.$data['telephony']['host'].'";
        port = '.$data['telephony']['port'].';
        delimiter = "'.$data['telephony']['delimiter'].'";
};';
            }

            if(!empty($data['automation'])
            && !empty($data['automation']['host'])
            && !empty($data['automation']['port'])){
            	if($oldManagerConf['BadgeController'] == 'yes'){
            		$pref = '';
            	}else{
            		$pref = '//';
            	}
                $conf[]= $pref.'DL = {
'.$pref.'        host = "'.$data['automation']['host'].'";
'.$pref.'        port = '.$data['automation']['port'].';
'.$pref.'        delimiter = "'.$data['automation']['delimiter'].'";
'.$pref.'};
';
            }

            if(file_put_contents($this->_fiasConfPatch, join("\n", $conf)) === false){
                return 'Cannot write FIAS-Fidelio config.';
            }else{

                $oldManagerConf['BillingType'] = $data['billingType'];
                $oldManagerConf['MinibarType'] = $data['minibarType'];
                if($this->updateManagerConf($oldManagerConf) === false){
                    return 'Cannot write billing type or minibar type to config.';
                }else{
                    $this->restartDaemon();
                }
            }
        }
        return true;
    }

    private $_xmlFile = null;
    private function getXmlFilePatch(){
        if($this->_xmlFile === null){
            $this->_xmlFile = '/etc/wildix/HotelConfigurationFile.hsprj';
        }
        return $this->_xmlFile;
    }

    public function generateRoomId($extension){
    	$result = '';
    	$newId = '00000000-0000-0000-0000-000000000000';
    	$newId = substr($newId, 0, strlen($newId)-strlen($extension)).$extension;
		$i=0;
    	do{
    		$i++;
    		if($this->getRoomById($newId) == false){
    			$result = $newId;
    			break;
    		}else{
    			$extension.rand(0, 9);
    			$newId = substr($newId, 0, strlen($newId)-strlen($extension)).$extension;
    		}
    	}while($i<5);

    	return $result;
    }

    /*private function changeProjectID(){
    	//{88F5BC8F-E552-42C1-9C8E-A8D5ED787AE7}
    	$result = '';
		$xmlProjectId = $this->getProjectId();
		if($xmlProjectId){
			$id = $xmlProjectId->__toString();

			$str = '0123456789ABCDEF';
			$i=0;
			do{
				$i++;

				$newId = array();
				foreach (array(8,4,4,4,12) as $length){
					$newId[] = substr(str_shuffle($str), 0, $length);
				}
				$newId = '{'.join('-', $newId).'}';

				if($id != $newId){
					$result = $newId;
					break;
				}
			}while($i<5);

			if($result!=''){
				$xmlProjectId[0] = $result;
			}
		}
		return $result;
    }*/

    public function generateHotelConfigurationFile(){
    	if($this->getXmlObject()){
    		$xmlRooms = $this->getAllRooms();

    		$rooms = array();
    		foreach ($xmlRooms as $key=>$value){
    			$rooms[$value->extension->__toString()] = $value->id->__toString();
    		}

    		$dirty = false;
    		$ldapProps = array(LDAP_EXTEN_NUMBER, 'userKind');
    		$start = 0;
    		$count = 500;

    		do{
    			$ldapUsers = WMS_Ldap::getInstance()->getEntriesSortLimit(WMS_Ldap::PERSONS, "(|(userKind=user)(userKind=admin)(userKind=fax)(userKind=room))", $ldapProps, $start, $count);

    			foreach ($ldapUsers as $user) {

    				if (!isset($user[LDAP_EXTEN_NUMBER])) {
    					continue;
    				}

    				if (isset($rooms[$user[LDAP_EXTEN_NUMBER]])){
    					// update

    					unset($rooms[$user[LDAP_EXTEN_NUMBER]]);
    				}else{
    					// insert

    					$xmlRoomColleaction = $this->getXmlObject()->xpath('/configurator/rooms');
    					if(!empty($xmlRoomColleaction)){
    						$xmlRoomColleaction = $xmlRoomColleaction[0];

							$extension = $user[LDAP_EXTEN_NUMBER];
							$kind = $user['userKind'] == 'room'? 'room': 'user';

							$id = $this->generateRoomId($extension);

    						$room = $xmlRoomColleaction->addChild('room', '');
    						$room->addChild('id', $id);
    						$room->addChild('extension', $extension);
    						$room->addChild('rn', $extension);
    						$room->addChild('kind', $kind);
    						$room->addChild('descr', 'Room '.$extension);
    						$room->addChild('building', '1');
    						$room->addChild('floor', '1');
    						$room->addChild('category', '1');
    						$room->addChild('FC', '98');
    						$room->addChild('UC', $extension);

    						$dirty = true;
    					}
    				}
    			}
    			$start += $count;
    		} while ($start <= $ldapUsers['count']);



    		if(!empty($rooms)){
    			// delete
    			$dirty = true;
    			foreach($rooms as $extension => $id){
    				$this->deleteRoomById($id);
    			}
    		}


    		//if($dirty){
    			//$projectId = $this->changeProjectID();
    		//}


    		if($this->saveXml()){
    			return true;
    		}else{
    			return 'Cannot save Common area "'.$data['id'].'"';
    		}

    		return true;
    	}
    }

    public function removeHotelConfigurationFile(){
        if(file_exists($this->getXmlFilePatch())){
            if(unlink($this->getXmlFilePatch())){
                return true;
            }
        }else{
            return true;
        }
        return 'Failed cleaned hotel configuration file';
    }

    public function removeWorkstationsMappingFile(){
        if(file_exists($this->_workstationsXmlFile)){
            if(unlink($this->_workstationsXmlFile)){
                return true;

            }
        }else{
            return true;
        }
        return 'Failed cleaned workstations mapping file';
    }


    private function loadXml($patch){
        if(file_exists($patch)){
            return simplexml_load_file($patch);
        }
        return false;
    }

    private function getXmlObject(){
        if($this->_xmlObj === null){
        	if(file_exists($this->getXmlFilePatch())){
        		$this->_xmlObj = $this->loadXml($this->getXmlFilePatch());
        		if(!$this->_xmlObj || $this->_xmlObj->getName() != $this->_rootTag){
        			$this->_xmlObj = false;
        		}
        	}

        	if(!$this->_xmlObj){
        		$xml_string = <<<XML
<?xml version="1.0" encoding="UTF-8"?>
<configurator>
	<ver_xml>2.0.0</ver_xml>
	<projectID>{88F5BC8F-E552-42C1-9C8E-A8D5ED787AE7}</projectID>
	<rooms></rooms>
    <commonareas></commonareas>
</configurator>
XML;
        		$this->_xmlObj = simplexml_load_string($xml_string);
        	}

        }
        return $this->_xmlObj;
    }

	private function getXmlWsObject(){
        if($this->_xmlObjWs === null){
        	if(file_exists($this->_workstationsXmlFile)){
            	$this->_xmlObjWs = $this->loadXml($this->_workstationsXmlFile);
        	}else{
            $xml_string = <<<XML
<?xml version="1.0" encoding="UTF-8"?>
<workstations>
</workstations>
XML;
				$this->_xmlObjWs = simplexml_load_string($xml_string);
        	}
        }
        return $this->_xmlObjWs;
    }

    private $_workstations = null;
    public function getAllWorkstations(){
		if($this->_workstations === null){
			$this->_workstations = $this->getXmlWsObject()->xpath('workstation');
		}
    	return $this->_workstations;
    }

    private $_rooms = null;
    public function getAllRooms(){
        if($this->_rooms === null){
            if($this->getXmlObject()){
                $this->_rooms = $this->getXmlObject()->xpath('/configurator/rooms/room');
            }
        }
        return $this->_rooms;
    }

    private $_commonAreas = null;
    public function getAllCommonAreas(){
        if($this->_commonAreas === null){
            if($this->getXmlObject()){
                $this->_commonAreas = $this->getXmlObject()->xpath('/configurator/commonareas/commonarea');
            }
        }
        return $this->_commonAreas;
    }

    public function getCommonAreas($startIndex, $rowsPerPage, $sortKey, $sortDir, $search){
        if(empty($sortDir)){
            $sortDir = 'asc';
        }
        if(empty($sortKey)){
            $sortKey = 'extension';
        }
        $search = trim($search);

        $commonAreas = array(
                'BODY' => array(),
                'rowsPerPage' => (!empty($rowsPerPage)) ? (int)$rowsPerPage : 20,
                'sortDir' => $sortDir,
                'sortKey' => $sortKey,
                'startIndex' => (!empty($startIndex)) ? (int)$startIndex: 0,
                'totalRecords' => 0
        );


        $xmlCommonAreas = $this->getAllCommonAreas();

        if($xmlCommonAreas && count($xmlCommonAreas) > 0){
            $end = $commonAreas['startIndex'] + $commonAreas['rowsPerPage'];

            /* filter */
            if(!empty($search)){
                $this->filter($xmlCommonAreas, $search, array('rn', 'extension', 'descr', 'id'));
            }
            $this->sort($xmlCommonAreas, $sortKey, $sortDir);

            $commonAreas['totalRecords'] = count($xml_rooms);

            for($i = $commonAreas['startIndex']; $i < $end; $i++){
                if(!$xmlCommonAreas[$i]){
                    break;
                }
                $commonAreas['BODY'][] = array(
                        'id' => $xmlCommonAreas[$i]->id->__toString(),
                        'extension' => $xmlCommonAreas[$i]->extension->__toString(),
                        'rn' => $xmlCommonAreas[$i]->rn->__toString(),
                        'descr' => $xmlCommonAreas[$i]->descr->__toString(),
                        'name' => $xmlCommonAreas[$i]->name->__toString(),
                        'building' => $xmlCommonAreas[$i]->building->__toString(),
                        'floor' => $xmlCommonAreas[$i]->floor->__toString(),
                        'payment' => $xmlCommonAreas[$i]->payment->__toString()
                );
            }
        }

        return $commonAreas;
    }

    public function getRooms($startIndex, $rowsPerPage, $sortKey, $sortDir, $search){
        if(empty($sortDir)){
            $sortDir = 'asc';
        }
        if(empty($sortKey)){
            $sortKey = 'extension';
        }
        $search = trim($search);

        $rooms = array(
                'BODY' => array(),
                'rowsPerPage' => (!empty($rowsPerPage)) ? (int)$rowsPerPage : 20,
                'sortDir' => $sortDir,
                'sortKey' => $sortKey,
                'startIndex' => (!empty($startIndex)) ? (int)$startIndex: 0,
                'totalRecords' => 0
        );

        $xml_rooms = $this->getAllRooms();

        if($xml_rooms && count($xml_rooms) > 0){
            $end = $rooms['startIndex'] + $rooms['rowsPerPage'];

            /* filter */
            if(!empty($search)){
                $this->filter($xml_rooms, $search, array('rn', 'extension', 'descr', 'id'));
            }
            $this->sort($xml_rooms, $sortKey, $sortDir);

            $rooms['totalRecords'] = count($xml_rooms);

            for($i = $rooms['startIndex']; $i < $end; $i++){
                if(!$xml_rooms[$i]){
                    break;
                }
                $rooms['BODY'][] = array(
                        'id' => $xml_rooms[$i]->id->__toString(),
                        'extension' => $xml_rooms[$i]->extension->__toString(),
                        'rn' => $xml_rooms[$i]->rn->__toString(),
                        'descr' => $xml_rooms[$i]->descr->__toString(),
                        'name' => $xml_rooms[$i]->name->__toString(),
                        'building' => $xml_rooms[$i]->building->__toString(),
                        'floor' => $xml_rooms[$i]->floor->__toString(),
                        'category' => $xml_rooms[$i]->category->__toString()
                );
            }
        }

        return $rooms;
    }

    public function getWorkstations($startIndex, $rowsPerPage, $sortKey, $sortDir, $search){
        if(empty($sortDir)){
            $sortDir = 'asc';
        }
        if(empty($sortKey)){
            $sortKey = 'ws';
        }
        $search = trim($search);
        $result = array(
                'BODY' => array(),
                'rowsPerPage' => (!empty($rowsPerPage)) ? (int)$rowsPerPage : 20,
                'sortDir' => $sortDir,
                'sortKey' => $sortKey,
                'startIndex' => (!empty($startIndex)) ? (int)$startIndex: 0,
                'totalRecords' => 0
        );

        $xml_ws = $this->getAllWorkstations();

        if($xml_ws && count($xml_ws) > 0){
            $end = $result['startIndex'] + $result['rowsPerPage'];

            /* filter */
            if(!empty($search)){
                $this->filter($xml_ws, $search, array('ws', 'description', 'fc', 'uc', 'ip'));
            }

            $this->sort($xml_ws, $sortKey, $sortDir);

            $result['totalRecords'] = count($xml_ws);

            for($i = $result['startIndex']; $i < $end; $i++){
                if(!$xml_ws[$i]){
                    break;
                }
                $result['BODY'][] = array(
                        'ws' => ($xml_ws[$i]->ws)? $xml_ws[$i]->ws->__toString(): '',
                        'description' => $xml_ws[$i]->description->__toString(),
                        'fc' => $xml_ws[$i]->fc->__toString(),
                        'uc' => $xml_ws[$i]->uc->__toString(),
                		'ip' => $xml_ws[$i]->ip->__toString()
                );
            }
        }

        return $result;
    }


    private function filter(&$items, $searchWord, $fields){

        $items = array_filter($items, function($a) use ($searchWord, $fields) {
            foreach ($fields as $key){
                if($a->$key && strpos($a->$key->__toString(), $searchWord) !== false){
                    return true;
                }
            }
            return false;
        });
    }

    private function sort(&$items, $sortKey, $sortDir){
        /* sorting */
        usort($items, function($a, $b) use ($sortKey, $sortDir) {
            if ($a->$sortKey->__toString() == $b->$sortKey->__toString()) {
                return 0;
            }
            if($sortDir == 'asc'){
                return ($a->$sortKey->__toString() < $b->$sortKey->__toString()) ? -1 : 1;
            }
            return ($a->$sortKey->__toString() > $b->$sortKey->__toString()) ? -1 : 1;
        });
    }

    /*private function getProjectId(){
    	$xmlItems = $this->getXmlObject()->xpath('/configurator/projectID');
    	if(count($xmlItems)>0){
    		return $xmlItems[0];
    	}
    	return false;
    }*/

    private function getRoomById($id){
        $xmlItems = $this->getXmlObject()->xpath('/configurator/rooms/room/id[text()="'.$id.'"]/parent::*');
        if(count($xmlItems)>0){
            return $xmlItems[0];
        }
        return false;
    }

    private function getRoomByRn($rn){
        $xmlItems = $this->getXmlObject()->xpath('/configurator/rooms/room/rn[text()="'.$rn.'"]/parent::*');
        if(count($xmlItems)>0){
            return $xmlItems[0];
        }
        return false;
    }

    private function getRoomByExtension($rn){
    	$xmlItems = $this->getXmlObject()->xpath('/configurator/rooms/room/extension[text()="'.$rn.'"]/parent::*');
    	if(count($xmlItems)>0){
    		return $xmlItems[0];
    	}
    	return false;
    }

    private function deleteRoomById($id){
    	$room = $this->getRoomById($id);
    	if($room){
    		$dom = dom_import_simplexml($room);
    		$dom->parentNode->removeChild($dom);
    	}

    	return true;
    }

    private function getCommonAreaById($id){
        $xmlItems = $this->getXmlObject()->xpath('/configurator/commonareas/commonarea/id[text()="'.$id.'"]/parent::*');
        if(count($xmlItems)>0){
            return $xmlItems[0];
        }
        return false;
    }
    private function getCommonAreaByRn($rn){
        $xmlItems = $this->getXmlObject()->xpath('/configurator/commonareas/commonarea/rn[text()="'.$rn.'"]/parent::*');
        if(count($xmlItems)>0){
            return $xmlItems[0];
        }
        return false;
    }

	private function getWorkstationByWs($ws){
		if($this->getXmlWsObject()){
			$xmlItems = $this->getXmlWsObject()->xpath('workstation/ws[text()="'.$ws.'"]/parent::*');
	        if(count($xmlItems)>0){
	            return $xmlItems[0];
	        }
		}
        return false;
    }


    public function updateRoom($data){
        $room = $this->getRoomById($data['id']);
        if($room){
            if($data['rn'] != $data['rn_old']){
                $dublicateRN = $this->getRoomByRn($data['rn']);
                if($dublicateRN){
                    return 'Cannot save room, FIAS RN "'.$data['rn'].'" already exists';
                }
            }

            $room_extension = $this->getRoomByExtension($data['extension']);
            if($room_extension && $data['extension'] != $data['extension_old']){
                return 'Cannot save room, Extension "'.$data['extension'].'" already exists';
            }

            $room->extension[0][0] = $data['extension'];
            $room->rn[0][0] = $data['rn'];
            $room->descr[0][0] = $data['descr'];
            $room->building[0][0] = $data['building'];
            $room->floor[0][0] = $data['floor'];
            $room->category[0][0] = $data['category'];

            if($this->saveXml()){
                return true;
            }else{
                return 'Cannot save room "'.$data['id'].'"';
            }
        }
        return 'Room "'.$data['id'].'" not found';
    }

    public function updateCommonArea($data){
        $room = $this->getCommonAreaById($data['id']);
        if($room){
            if($data['rn'] != $data['rn_old']){
                $dublicateRN = $this->getCommonAreaByRn($data['rn']);
                if($dublicateRN){
                    return 'Cannot save Common area, FIAS ID "'.$data['rn'].'" already exists';
                }
            }
            $room->extension[0][0] = $data['extension'];
            $room->rn[0][0] = $data['rn'];
            if($this->saveXml()){
                return true;
            }else{
                return 'Cannot save Common area "'.$data['id'].'"';
            }
        }
        return 'Common area "'.$data['id'].'" not found';
    }

    public function updateWorkstation($data){

        if($this->getWorkstationByWs($data['ws']) && (($data['ws_old'] && $data['ws_old'] != $data['ws']) || !$data['ws_old'])){
        	return 'Duplicate workstation "'.$data['ws'].'"';
        }

        $ws = $this->getWorkstationByWs($data['ws_old']);

        unset($data['ws_old']);
        $data['fc'] = '9993'; //const

        if(!$ws){
        	$new = $this->getXmlWsObject()->addChild('workstation');
        	foreach($data as $key=>$val){
        		$new->addChild($key, $val);
        	}
        }else{
        	foreach($data as $key=>$val){
        		$ws->$key = ($val)?$val:'';
        	}
        }

        if($this->saveXmlWs()){
        	return true;
        }else{
            return 'Cannot save Workstation "'.$data['ws'].'"';
        }


    }

    public function deleteWorkstation($data){
    	foreach($data as $val){
    		$ws = $this->getWorkstationByWs($val);
    		if($ws){
				$dom=dom_import_simplexml($ws);
        		$dom->parentNode->removeChild($dom);
    		}
    	}
    	if($this->saveXmlWs()){
        	return true;
        }else{
            return 'Error delete';
        }
    }

    public function validateAndApplyXml($patch){

        $warningsRoom = array();
        $dublicateID = array();

        $xmlObj = $this->loadXml($patch);
        if($xmlObj && $xmlObj->getName() == $this->_rootTag){
            $badRooms = array();
            $badExtension = array();

            $rooms = $xmlObj->xpath('/configurator/rooms/room');
            if($rooms){
                $total = count($rooms);
                for($i = 0; $i < $total; $i++){
                    $id = trim($rooms[$i]->id->__toString());

                    if(empty($id)){
                        $badRooms[] = $rooms[$i];
                    }else{
                        $xmlItems = $xmlObj->xpath('/configurator/rooms/room/id[text()="'.$id.'"]/parent::*');

                        if(count($xmlItems) > 1){
                            $dublicateID[$id] = true;
                        }else{
                            $xmlItems = $xmlObj->xpath('/configurator/commonareas/commonarea/id[text()="'.$id.'"]/parent::*');
                            if(count($xmlItems) > 0){
                                $dublicateID[$id] = true;
                            }
                        }

                        if(!$rooms[$i]->extension){
                        	$number = trim($rooms[$i]->number->__toString());
                            $unique_number = $number;
                            while(count($xmlObj->xpath('/configurator/rooms/room/extension[text()="'.$unique_number.'"]/parent::*')) > 0){
                                $unique_number = $number.mt_rand(1000, 9999);
                            }
                            $rooms[$i]->addChild('extension', $unique_number);
                        }else {
                            if(count($xmlObj->xpath('/configurator/rooms/room/extension[text()="'.$rooms[$i]->extension->__toString().'"]/parent::*')) > 1) {
                                $badExtension[] = $id;
                            }
                        }

                        if(!$rooms[$i]->rn){
                            $clearRn = $rn = $rooms[$i]->building->__toString().$rooms[$i]->floor->__toString().$rooms[$i]->number->__toString();
                            $addInWarning = false;
                            do{
                                $xmlItems = $xmlObj->xpath('/configurator/rooms/room/rn[text()="'.$rn.'"]/parent::*');
                                if(count($xmlItems) > 0){
                                    $rn = $clearRn.'_'.rand(1, 429496729);
                                    $addInWarning = true;
                                }
                            }while(count($xmlItems) > 0);

                            if($addInWarning){
                                $warningsRoom[] = $rn;
                            }

                            $rooms[$i]->addChild('rn', $rn);
                        }
                    }
                }
            }

            $badCommonAreas = array();
            $commonareas = $xmlObj->xpath('/configurator/commonareas/commonarea');
            if($commonareas){
                $total = count($commonareas);
                for($i = 0; $i < $total; $i++){
                    $id = trim($commonareas[$i]->id->__toString());

                    if(empty($id)){
                        $badCommonAreas[] = $commonareas[$i];
                    }else{
                        $xmlItems = $xmlObj->xpath('/configurator/commonareas/commonarea/id[text()="'.$id.'"]/parent::*');
                        if(count($xmlItems) > 1){
                            $dublicateID[$id] = true;
                        }else{
                            $xmlItems = $xmlObj->xpath('/configurator/rooms/room/id[text()="'.$id.'"]/parent::*');
                            if(count($xmlItems) > 0){
                                $dublicateID[$id] = true;
                            }
                        }
                        if(!$commonareas[$i]->extension){
                            $commonareas[$i]->addChild('extension', $commonareas[$i]->number->__toString());
                        }
                        if(!$commonareas[$i]->rn){
                            $commonareas[$i]->addChild('rn', '');
                        }
                    }
                }
            }

            if(count($badExtension)>0){
                return array('result'=>'error', 'reason'=>array('message'=>'Some Extension have the same value', 'data'=>$badExtension));
            }


            if(empty($dublicateID)){
                if(empty($badRooms) && empty($badCommonAreas)){
                    if($xmlObj->saveXML($patch)){
                        if(move_uploaded_file($patch, $this->getXmlFilePatch())){
                            //$this->restartDaemon();
                            if(!empty($warningsRoom)){
                                return array('result'=>'warning', 'reason'=>array('duplicatedRoom'=>$warningsRoom));
                            }
                            return array('result'=>'success');
                        }else{
                            return array('result'=>'error', 'reason'=>'Cannot move file.');
                        }
                    }else{
                        return array('result'=>'error', 'reason'=>'Cannot write config file.');
                    }
                }else{
                    return array('result'=>'error', 'reason'=>'Some Rooms/Common Areas do not have id');
                }
            }else{
                return array('result'=>'error', 'reason'=>array('message'=>'Some Rooms/Common Areas have the same ID', 'data'=>array_keys($dublicateID)));
            }
        }
        return array('result'=>'error', 'reason'=>'File not valid.');
    }

    public function saveXml(){
        if($this->getXmlObject()){
            if($this->getXmlObject()->saveXML($this->getXmlFilePatch())){
                //$this->restartDaemon();
                return true;
            }
        }
        return false;
    }

	public function saveXmlWs(){
        if($this->getXmlWsObject()){
            if($this->getXmlWsObject()->saveXML($this->_workstationsXmlFile)){
                return true;
            }
        }
        return false;
    }

	public function getStatus(){
		$return = array(
				'FIAS' => -1,
				'XOPEN' => -1
		);
		if(file_exists($this->_generalConfPatch)){
		    try{
				$conf = parse_ini_file($this->_generalConfPatch, true, INI_SCANNER_RAW);
				if(is_array($conf) && count($conf) > 0 && isset($conf['MemHost']) && isset($conf['MemPort']) && isset($conf['IfaceKey']) ){

					$host = $conf['MemHost'];
					$port = $conf['MemPort'];
					$ifaceKey = $conf['IfaceKey'];

					$memcache = new Memcache;
					$memcache->connect($host, $port);

					$cache = $memcache->get(Array($ifaceKey.'/FIAS', $ifaceKey.'/XOPEN'));
					if(array_key_exists($ifaceKey.'/FIAS',$cache)){
						$return['FIAS'] = $cache[$ifaceKey.'/FIAS'];
					}
					if(array_key_exists($ifaceKey.'/XOPEN',$cache)){
						$return['XOPEN'] = $cache[$ifaceKey.'/XOPEN'];
					}

					$memcache->close();
				}
		    }catch (Exception $e){
            	return array('result'=>'error', 'reason'=>$e->getMessage());
            }
		}
		return $return;
    }
}
