<?php
/**
 * Class CDR
 *
 * @todo separate:
 *       - models, config store and connection manager, schema manager
 *       - cdr and chat models
 */
class CDR{
    const CDR_GENERAL_CUSTOM_INCLUDE = '#include "cdr-general-custom.conf"';
    const CANNOT_CONNECT_TO_DB = 100001;
    const CHAT_HISTORY_DB = 'chat_history.db';
    const DEFAULT_SETTINGS_MYSQL_CLOUD = [
        'enabled' => 'yes',
        'hostname' => '127.0.0.1',
        'dbname' => 'cdr',
        'table' => 'cdr',
        'password' => 'wil01dix',
        'user' => 'root',
        'port' => '3306',
        'timeout' => '2',
        'charset' => 'utf8mb4'
    ];
    const DEFAULT_CHARSET_MYSQL = 'utf8mb4';

    const SUPPORTED_PROVIDERS = [
        'sqlite3' => '_clearCdrSqlite',
        'mysql' => '_clearCdrMysql',
        'tds' => '_clearCdrMssql',
    ];

    const MYSQL_PURGE_COUNT_FOR_ITERATION = 3000;

    private $_logLevel = 0;

    private $settings = array();
    private $connections = array();
    private $tables = array();

    private $default_cdr_fields_mysql = array(
        'rowid' => "int(11) NOT NULL AUTO_INCREMENT PRIMARY KEY ",
        'accountcode' => "varchar(20) NOT NULL DEFAULT '' ",
        'src' => "varchar(80) NOT NULL DEFAULT '' ",
        'dst' => "varchar(80) NOT NULL DEFAULT '' ",
        'dcontext' => "varchar(80) NOT NULL DEFAULT '' ",
        'clid' => "varchar(80) NOT NULL DEFAULT '' ",
        'channel' => "varchar(80) NOT NULL DEFAULT '' ",
        'dstchannel' => "varchar(80) NOT NULL DEFAULT '' ",
        'lastapp' => "varchar(80) NOT NULL DEFAULT '' ",
        'lastdata' => "varchar(255) NOT NULL DEFAULT '' ",
        'start' => "datetime ",
        'answer' => "datetime ",
        'end' => "datetime ",
        'duration' => "int(11) NOT NULL DEFAULT '0' ",
        'billsec' => "int(11) NOT NULL DEFAULT '0' ",
        'disposition' => "varchar(45) NOT NULL DEFAULT '' ",
        'amaflags' => "varchar(32) NOT NULL DEFAULT '' ",
        'userfield' => "varchar(255) NOT NULL DEFAULT '' ",
        'uniqueid' => "varchar(32) NOT NULL DEFAULT '' ",
        'c_from' => "varchar(80) NOT NULL DEFAULT '' ",
        'c_to' => "varchar(80) NOT NULL DEFAULT '' ",
        'cost' => "varchar(20) NOT NULL DEFAULT '' ",
        'callclass' => "int(11) NOT NULL DEFAULT '0' ",
        'pbxid' => "varchar(13) NOT NULL DEFAULT '' ",
        'srcgrp' => "int(11) NOT NULL DEFAULT '0' ",
        'dstgrp' => "int(11) NOT NULL DEFAULT '0' ",
        'faxdata' => "varchar(255) NOT NULL DEFAULT '' ",
        'dest_type' => "int(1) NOT NULL DEFAULT '0' ",
        'app' => "int(1) NOT NULL DEFAULT '0' ",
        'stat' => "TEXT",
        'isupcause' => "INT(11) NOT NULL default '0'",
        'src_rfactor' => 'double NOT NULL default -1.0',
        'dst_rfactor' => 'double NOT NULL default -1.0',
        'to_name' => "VARCHAR(100) NOT NULL default ''",
        'from_name' => "VARCHAR(100) NOT NULL default ''",
        'to_archived' => "int(1) NOT NULL default '0' ",
        'from_archived' => "int(1) NOT NULL default '0' ",
        'organization' => "VARCHAR(100) NOT NULL default ''",
        'email' => "VARCHAR(100) NOT NULL default ''"
    );
    private $default_cdr_fields_sqlite3 = array(
        'accountcode' => "varchar(20) NOT NULL default '' ",
        'src' => "varchar(80) NOT NULL default '' ",
        'dst' => "varchar(80) NOT NULL default '' ",
        'dcontext' => "varchar(80) NOT NULL default '' ",
        'clid' => "varchar(80) NOT NULL default '' ",
        'channel' => "varchar(80) NOT NULL default '' ",
        'dstchannel' => "varchar(80) NOT NULL default '' ",
        'lastapp' => "varchar(80) NOT NULL default '' ",
        'lastdata' => "varchar(255) NOT NULL default '' ",
        'start' => "datetime ",
        'answer' => "datetime ",
        'end' => "datetime ",
        'duration' => "int(11) NOT NULL default '0' ",
        'billsec' => "int(11) NOT NULL default '0' ",
        'disposition' => "varchar(45) NOT NULL default '' ",
        'amaflags' => "int(11) NOT NULL default '' ",
        'userfield' => "varchar(255) NOT NULL default '' ",
        'uniqueid' => "varchar(32) NOT NULL default '' ",
        'c_from' => "varchar(80) NOT NULL default '' ",
        'c_to' => "varchar(80) NOT NULL default '' ",
        'cost' => "varchar(20) NOT NULL default '' ",
        'callclass' => "int(11) NOT NULL default '0' ",
        'pbxid' => "varchar(13) NOT NULL default '' ",
        'srcgrp' => "int(11) NOT NULL default '0' ",
        'dstgrp' => "int(11) NOT NULL default '0' ",
        'faxdata' => "varchar(255) NOT NULL default '' ",
        'dest_type' => "int(1) NOT NULL default '0' ",
        'app' => "int(1) NOT NULL default '0' ",
        'stat' => "TEXT NOT NULL default ''",
        'isupcause' => "INT(11) NOT NULL default '0'",
        'src_rfactor' => 'real NOT NULL default -1.0',
        'dst_rfactor' => 'real NOT NULL default -1.0',
        'to_name' => "VARCHAR(100) NOT NULL default ''",
        'from_name' => "VARCHAR(100) NOT NULL default ''",
        'to_archived' => "int(1) NOT NULL default '0' ",
        'from_archived' => "int(1) NOT NULL default '0' ",
        'organization' => "VARCHAR(100) NOT NULL default ''",
        'email' => "VARCHAR(100) NOT NULL default ''"
    );
    private $default_cdr_fields_mssql = array(
        'rowid' => "int IDENTITY(1,1) primary key ",
        'accountcode' => "varchar(20) NOT NULL default '' ",
        'src' => "varchar(80) NOT NULL default '' ",
        'dst' => "varchar(80) NOT NULL default '' ",
        'dcontext' => "varchar(80) NOT NULL default '' ",
        'clid' => "varchar(80) NOT NULL default '' ",
        'channel' => "varchar(80) NOT NULL default '' ",
        'dstchannel' => "varchar(80) NOT NULL default '' ",
        'lastapp' => "varchar(80) NOT NULL default '' ",
        'lastdata' => "varchar(255) NOT NULL default '' ",
        'start' => "datetime ",
        'answer' => "datetime ",
        'end' => "datetime ",
        'duration' => "int NOT NULL default '0' ",
        'billsec' => "int NOT NULL default '0' ",
        'disposition' => "varchar(45) NOT NULL default '' ",
        'amaflags' => "varchar(32) NOT NULL default '' ",
        'userfield' => "varchar(255) NOT NULL default '' ",
        'uniqueid' => "varchar(32) NOT NULL default '' ",
        'c_from' => "varchar(80) NOT NULL default '' ",
        'c_to' => "varchar(80) NOT NULL default '' ",
        'cost' => "varchar(20) NOT NULL default '' ",
        'callclass' => "int NOT NULL default '0' ",
        'pbxid' => "varchar(13) NOT NULL default '' ",
        'srcgrp' => "int NOT NULL default '0' ",
        'dstgrp' => "int NOT NULL default '0' ",
        'faxdata' => "varchar(255) NOT NULL default '' ",
        'dest_type' => "tinyint NOT NULL default '0' ",
        'app' => "tinyint NOT NULL default '0' ",
        'stat' => "TEXT NOT NULL default ''",
        'isupcause' => "int NOT NULL default '0'",
        'src_rfactor' => 'real NOT NULL default -1.0',
        'dst_rfactor' => 'real NOT NULL default -1.0',
        'to_name' => "VARCHAR(100) NOT NULL default ''",
        'from_name' => "VARCHAR(100) NOT NULL default ''",
        'to_archived' => "tinyint NOT NULL default '0' ",
        'from_archived' => "tinyint NOT NULL default '0' ",
        'organization' => "VARCHAR(100) NOT NULL default ''",
        'email' => "VARCHAR(100) NOT NULL default ''"
    );


    private static $_obj = null;

    public static function getInstance(){
        if (self::$_obj == null) {
            self::$_obj = new cdr();
        }
        return self::$_obj;
    }

    public function getSettings($force=false){
        if ($this->settings==null || $force==true){
            $path_general = PATH_TO_CW_CONF."cdr.conf";
            $path_sqlite   = PATH_TO_CW_CONF."cdr_sqlite3_custom.conf";
            $path_mysql   = PATH_TO_CW_CONF."cdr_mysql.conf";
            $path_tds     = PATH_TO_CW_CONF."cdr_tds.conf";

            $this->settings = array(
		        "general" => array(
		            "enabled" => "yes",
		            "batch" => "yes",
		            "size" => "100",
		            "time" => "3",
		            "scheduleronly" => "no",
		            "safeshutdown" => "yes",
		            "endbeforehexten" => "no",
		            "ctibackend" => "",
		            'unanswered' => 'yes',
		            'enable_contact_notes' => 'no',
            		'save_history_base' => 'yes'
		        ),
		        "sqlite3" => array(
		            "enabled" => "no",
		            "dbfile" => "cdrdb",
		            "dbdir" => "/mnt/cdr",
		            "table" => "cdr",
		            'columns' => 'src,dst,dcontext,channel,dstchannel,start,answer,end,duration,billsec,disposition,userfield,uniqueid,c_from,c_to,cost,callclass,faxdata,stat,isupcause,src_rfactor,dst_rfactor,to_name,from_name,lastapp,organization,pbxid,dest_type,lastdata',
					'values' => "'\${CDR(src)}','\${CDR(dst)}','\${CDR(dcontext)}', '\${CDR(channel)}', '\${CDR(dstchannel)}', '\${CDR(start)}', '\${CDR(answer)}', '\${CDR(end)}', '\${CDR(duration)}', '\${CDR(billsec)}', '\${CDR(disposition)}', '\${CDR(userfield)}', '\${CDR(uniqueid)}', '\${CDR(c_from)}', '\${CDR(c_to)}', '\${CDR(cost)}', '\${CDR(callclass)}', '\${CDR(faxdata)}', '\${CDR(stat)}', '\${CDR(isupcause)}', '\${CDR(src_rfactor)}', '\${CDR(dst_rfactor)}', '\${CDR(to_name)}', '\${CDR(from_name)}', '\${CDR(lastapp)}', '\${CDR(organization)}', '\${CDR(pbxid)}', '\${CDR(dest_type)}', '\${CDR(tags)}'"
		        ),
		        "csv" => array(
		            "enabled" => "no"
		        ),
		        "mysql" => array(
		            "enabled" => "no",
		            "hostname" => "",
		            "dbname" => "",
		            "table" => "",
		            "password" => "",
		            "user" => "",
		            "port" => "3306",
		            "timeout" => "2",
		        	"charset" => "utf8"
		        ),
		        "tds" => array(
		            "enabled" => "no",
		            "hostname" => "",
		            "port" => "",
		            "dbname" => "",
		            "table" => "",
		            "user" => "",
		            "password" => "",
		        	"charset" => "utf8"
		        )
		    );
            if(file_exists($path_general)){
                $tmp = self::parse_ini_file_quotes_safe($path_general);
                $this->settings['general'] = array_merge($this->settings['general'], $tmp['general']);
                if (!empty($tmp['csv'])) {
                    $this->settings['csv'] = array_merge($this->settings['csv'], $tmp['csv']);
                }
            }

            if(file_exists($path_mysql)){
                $tmp = self::parse_ini_file_quotes_safe($path_mysql);
                $this->settings['mysql'] = array_merge($this->settings['mysql'], $tmp['global']);
                $this->settings['mysql']['charset'] = self::DEFAULT_CHARSET_MYSQL;
            }

            if(file_exists($path_tds)){
                $tmp = self::parse_ini_file_quotes_safe($path_tds);
                $this->settings['tds'] = array_merge($this->settings['tds'], $tmp['global']);
            }

            if(file_exists($path_sqlite)){
                $tmp = self::parse_ini_file_quotes_safe($path_sqlite);
                $this->settings['sqlite3'] = array_merge($this->settings['sqlite3'], $tmp['cdrdb']);
            }
        }
        return $this->settings;
    }


    private function _getTable($type){
        if ($this->tables[$type]){
            return $this->tables[$type];
        }
        return false;
    }

    /*
      Connects to CDR databases
    */
    private function _getConnection($type, $settings = array()){
        if(!empty($this->connections[$type])){
            return $this->connections[$type];
        }
        if(empty($settings)){
            $settings=$this->getSettings();
        }else{
            $this->settings = $settings;
        }

        $enabled = isset($settings[$type]['enabled']) ? $settings[$type]['enabled'] : false;
        $hostname = isset($settings[$type]['hostname']) ? $settings[$type]['hostname'] : false;
        $dbname = isset($settings[$type]['dbname']) ? $settings[$type]['dbname'] : false;
        $table = isset($settings[$type]['table']) ? $settings[$type]['table'] : false;
        $password = isset($settings[$type]['password']) ? $settings[$type]['password'] : false;
        $user = isset($settings[$type]['user']) ? $settings[$type]['user'] : false;
        $port = isset($settings[$type]['port']) ? $settings[$type]['port'] : false;

        switch($type){
            case 'mysql' :
                if($enabled == 'yes'){
                    if (isset($settings[$type]['timeout']) && is_numeric($settings[$type]['timeout'])) {
                        $timeout = $settings[$type]['timeout'];
                    } else {
                        $timeout = 10;
                    }

                    try {
                    	$connect = new \PDO('mysql:host='.$hostname.';port='.$port.';dbname='.$dbname, $user, $password,
                            array(
                                PDO::ATTR_TIMEOUT => $timeout,
                                PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION
                            ));
                    } catch (\PDOException $exception) {
                        throw new Exception( $exception->getMessage(), $exception->getCode());
                    }

                    $this->tables[$type] = $table;
                    $this->connections[$type] = $connect;
                }
                break;
            case 'sqlite3' :
                if($enabled == 'yes'){
                    $dbfile = rtrim($settings['sqlite3']['dbdir'],'/').'/'.ltrim($settings['sqlite3']['dbfile'],'/');
                    $connect = new SQLite3($dbfile);
                    if ($connect){
                        $this->connections[$type] = $connect;
                        $this->tables[$type] = $table;
                    }else{
                        throw new Exception( _t('cdr.CannotConnectSqliteDatabase'), CDR::CANNOT_CONNECT_TO_DB);
                    }
                }
                break;
            case 'tds' :
                if($enabled == 'yes'){
                    // WMS-3396. check if the port defined
                    $port = !empty($port) ? ':'.$port : '';

                    try {
                        $connect = new \PDO('dblib:host='.$hostname.$port.';dbname='.$dbname, $user, $password);

                    } catch (Exception $exception) {
                        throw new Exception( $exception->getMessage(), $exception->getCode());
                    }

                    $this->connections[$type] = $connect;
                    $this->tables[$type] = $table;
                }
                break;
        }

        return $this->connections[$type];
    }

    private function _disconnect($type){
        $connection = $this->_getConnection($type);
        if(empty($connection)){
            return;
        }
        switch($type){
            case 'tds':
            case 'mysql':
                $this->connections[$type] = null;
                break;
            case 'sqlite3':
                $connection->close();
                break;
        }
        unset($this->connections[$type], $this->tables[$type]);
    }

    private $_log = null;
    private function getLog() {
        if ($this->_log === null) {
            $this->_log = new \Syslog('CDR', $this->_logLevel);
        }
        return $this->_log;
    }

    private function _clearCdrSqlite(int $quantityOfMonths): bool {
        try {
            $serial  = \Models\PBX::getInstance()->getSerial();
            $type    = 'sqlite3';
            $connect = $this->_getConnection($type);
            $connect->query(sprintf('DELETE FROM %s WHERE start < DATE(\'NOW\',\'-%d SECOND\') AND pbxid=\'%s\'', $this->_getTable($type), $this->_differenceInSeconds($quantityOfMonths), $serial));
            $connect->query('VACUUM');
            $connect->query('pragma wal_checkpoint(passive)');
        } catch (Exception $e) {
            $this->getLog()->error(__LINE__, sprintf('SQLite clear error: %s', $e->getMessage()));
        }
        return true;
    }

    private function _clearCdrMysql(int $quantityOfMonths): bool {
        try {
            $connect = $this->_getConnection('mysql');
            $connect->query(sprintf('CALL purge_cdr(%d, %d)', $quantityOfMonths, self::MYSQL_PURGE_COUNT_FOR_ITERATION));
        } catch (Exception $e) {
            $this->getLog()->error(__LINE__, sprintf('Mysql clear error: %s', $e->getMessage()));
        }
        return true;
    }

    private function _clearCdrMssql(int $quantityOfMonths): bool {
        try {
            $type    = 'tds';
            $serial  = \Models\PBX::getInstance()->getSerial();
            $connect = $this->_getConnection($type);
            $connect->query(sprintf('DELETE FROM [%s] WHERE [start] < DATEADD(SECOND, -%d, GETDATE()) AND [pbxid]=\'%s\'', $this->_getTable($type), $this->_differenceInSeconds($quantityOfMonths), $serial));
        } catch (Exception $e) {
            $this->getLog()->error(__LINE__, sprintf('Mssql clear error: %s', $e->getMessage()));
        }
        return true;
    }

    private function _differenceInSeconds(int $quantityOfMonths): int {
        $currentDate = new \DateTime();
        $newDate     = new \DateTime();
        $newDate->modify('-' . $quantityOfMonths . ' month');

        return $currentDate->format('U') - $newDate->format('U');
    }

    /*
      Checks CDR fields
    */
    private function _checkFields($type, $should_disconnect = true){
        $connect = $this->_getConnection($type);
        $table = $this->_getTable($type);

        switch($type){
            case 'mysql' :
                $sql = "DESCRIBE $table ";

                try{
                    $result = $connect->query($sql);

                    if ($result !== false) {
                        $fields = array();

                        foreach ($result as $row) {
                            $fields[$row['Field']] = $row['Type'];
                        }

                        $diff = array_diff_key($this->default_cdr_fields_mysql, $fields);
                        return $diff;
                    }
                } catch (Exception $exception){
                        throw new Exception($exception->getMessage(), $exception->getCode());
                }
                break;
            case 'sqlite3' :
                $sql = "PRAGMA table_info (`$table`);";
                try {
                    $query = $connect->query($sql);
                    if($query){
                        $fields = array();
                        while($result = $query->fetchArray(SQLITE3_ASSOC)) {
                            $fields[$result['name']] = $result['type'];
                        }
                        $diff = array_diff_key($this->default_cdr_fields_sqlite3, $fields);
                        return $diff;
                    }
                } catch (Exception $exception){
                    throw new Exception($exception->getMessage(), $exception->getCode());
                }
                break;
            case 'tds' :

                $sql = "exec sp_columns $table";

                try{
                    $result = $connect->query($sql);

                    if ($result !== false) {
                        $fields = array();

                        foreach ($result as $row) {
                            $fields[$row['COLUMN_NAME']] = $row['TYPE_NAME'];
                        }

                        $diff = array_diff_key($this->default_cdr_fields_mssql, $fields);
                        return $diff;
                    }
                } catch (Exception $exception){
                    throw new Exception($exception->getMessage(), $exception->getCode());
                }

                break;
        }

        if($should_disconnect){
            $this->_disconnect($type);
        }
        return array();
    }

    private function _updateCdrTable($type, $should_disconnect = true){
        $connect = $this->_getConnection($type);
        $table = $this->_getTable($type);

        $fields = $this->_checkFields($type, false);

        switch($type){
            case 'mysql' :
                if(!empty($fields)){
                    $sql = "ALTER TABLE ".$table." ADD (";
                    foreach($fields as $k => $v){
                        $sql .= " `".$k."` ".$v.',';
                    }
                    $sql = substr($sql, 0, strlen($sql) - 1 ). ");";
                    $result = $connect->exec($sql);
                    if($result === false){
                        $e = $connect->errorInfo();
                        throw new Exception( $e[2], $e[0]);
                    }
                }
                break;
            case 'sqlite3' :
                if(!empty($fields)){
                    $query = $connect->query('BEGIN;');
                    if($query){
                        foreach($fields as $k => $v){
                            $sql = "ALTER TABLE $table ADD $k $v ;";
                            if(!$connect->exec($sql)){
                                throw new Exception( $connect->lastErrorMsg(), $connect->lastErrorCode());
                            }
                        }
                        $query = $connect->query('COMMIT;');
                        if(!$query){
                            if($connect->lastErrorCode()!==0) {
                                throw new Exception( $connect->lastErrorMsg(), $connect->lastErrorCode());
                            }
                        }
                    }else{
                        if($connect->lastErrorCode()!==0) {
                            throw new Exception( $connect->lastErrorMsg(), $connect->lastErrorCode());
                        }
                    }
                }
                break;
            case 'tds' :
                if(!empty($fields)){
                    $sql = "ALTER TABLE ".$table." ADD ";
                    foreach($fields as $k => $v){
                        $sql .= " [".$k."] ".$v.',';
                    }
                    $sql = substr($sql, 0, strlen($sql) - 1 );
                    $connect->exec($sql);
                    if($connect->errorCode() === '00000'){
                        $e = $connect->errorInfo();
                        throw new Exception($e[2], $e[0]);
                    }
                }
                break;
        }
        if($should_disconnect){
            $this->_disconnect($type);
        }
        return true;
    }

    private function _updateIndexes($type){
        $table = $this->_getTable($type);
        $connect = $this->_getConnection($type);

        switch($type){
            case 'mysql' :
                $query = array(
                    'start_idx' => 'CREATE INDEX start_idx ON '.$table.' (`start`)',
                    'dst_idx' => 'CREATE INDEX dst_idx on '.$table.' (`dst`)',
                    'end_idx' => 'CREATE INDEX end_idx on '.$table.' (`end`)',
                    'c_from_start_idx' => 'CREATE INDEX `c_from_start_idx` on `'.$table.'` (`c_from`,`start`)',
                    'missed_call' => 'CREATE INDEX `missed_call` on `'.$table.'` (`c_to`, `disposition`)',
                );

                $index = $connect->query("SELECT `INDEX_NAME` FROM INFORMATION_SCHEMA.STATISTICS
	              WHERE `TABLE_CATALOG` = 'def' AND `TABLE_SCHEMA` = database() AND `TABLE_NAME` = '".$table."' AND `INDEX_NAME` <> 'PRIMARY'
	              GROUP BY `INDEX_NAME`;
	            ");

                foreach ($index as $row) {
                    if (array_key_exists($row['INDEX_NAME'], $query)) {
                        unset($query[$row['INDEX_NAME']]);
                    }
                }

                if (!empty($query)) {
                    foreach ($query as $query_item) {
                    	try {
                    		$connect->exec($query_item);
                    	} catch (\PDOException $error) {
                    		if(!empty($error->errorInfo) && !empty($error->errorInfo[1]) && $error->errorInfo[1] == '1061'){
                    			// Duplicate key name do not print in syslog
                    		}else{
                    			$log = new \Syslog('\CDR');
                    			$log->error(__LINE__, $error->getMessage());
                    		}
                    	}
                    }
                }

                break;
            case 'sqlite3' :
                $connect->exec('CREATE INDEX if not exists `idx_'.$table.'_start` on `'.$table.'`(`start`);');
                $connect->exec('CREATE INDEX if not exists `idx_'.$table.'_accountcode` on `'.$table.'`(`accountcode`);');
                $connect->exec('CREATE INDEX if not exists `idx_'.$table.'_dst` on `'.$table.'`(`dst`);');
                $connect->exec('CREATE INDEX if not exists `idx_'.$table.'_end` on `'.$table.'`(`end`);');
                $connect->exec('CREATE INDEX if not exists `idx_'.$table.'_c_from_start` on `'.$table.'`(`c_from`,`start`);');

                $connect->exec('CREATE INDEX if not exists `idx_'.$table.'_c_to` on `'.$table.'`(`c_to`);');
                $connect->exec('CREATE INDEX if not exists `idx_'.$table.'_missed_call` on `'.$table.'`(`c_to`,`disposition`, `faxdata`, `start`);');
                $connect->exec('CREATE INDEX if not exists `idx_'.$table.'_faxin` on `'.$table.'`(`c_to`, `faxdata`, `start`);');
                $connect->exec('CREATE INDEX if not exists `idx_'.$table.'_voicemail` on `'.$table.'`(`c_to`, `lastapp`, `start`);');
                $connect->exec('CREATE INDEX if not exists `idx_'.$table.'_faxout` on `'.$table.'`(`c_from`, `faxdata`, `start`);');
                break;
            case 'tds' :
                $connect->exec('CREATE INDEX start_idx ON ['.$table.'] (start)');
                $connect->exec('CREATE INDEX accountcode_idx ON ['.$table.'] (accountcode)');
                $connect->exec('CREATE INDEX dst_idx ON ['.$table.'] (dst)');
                $connect->exec('CREATE INDEX end_idx ON ['.$table.'] ([end])');
                $connect->exec('CREATE INDEX c_from_start_idx ON ['.$table.'] (c_from, start)');

                $connect->exec('CREATE INDEX c_to_idx ON ['.$table.'] (c_to)');
                $connect->exec('CREATE INDEX missed_call ON ['.$table.'] (c_to, disposition, faxdata, start)');
                $connect->exec('CREATE INDEX faxin ON ['.$table.'] (c_to, faxdata, start)');
                $connect->exec('CREATE INDEX voicemail ON ['.$table.'] (c_to, lastapp, start)');
                $connect->exec('CREATE INDEX faxout ON ['.$table.'] (c_from, faxdata, start)');
                break;
        }
    }

    public function SetMssqlDB(){
        try {
            $type="tds";
            $settings = $this->getSettings();
            if($settings[$type]['enabled'] != 'yes'){
                return true;
            }

            $connect = $this->_getConnection($type);
            $table = $this->_getTable($type);

            // generate odbc configuration /etc/odbc.ini
            /* [cdrtest] */
            /* Driver          = FreeTDS */
            /* Description     = CDR database */
            /* Trace           = Yes */
            /* Server          = 192.168.1.96 */
            /* Port            = 666 */
            /* Database        = cdrtest */
            /* TDS Version     = 7.0  */
            /* UID             = wms */
            /* PWD             = wms */
            $tofile = array($settings[$type]['dbname'] => array(
                            'Driver' => 'FreeTDS',
                            'Description' => 'CDR database',
                            'TDS_Version' => '7.0',
                            'Trace' => 'No',
                            'Server' => $settings[$type]['hostname'],
                            'Port' => $settings[$type]['port'],
                            'Database' => $settings[$type]['dbname'],
                            'UID' => $settings[$type]['user'],
                            'PWD' => $settings[$type]['password'],
                    )
            );

            if (empty($settings[$type]['port'])){
                unset($tofile[$settings[$type]['dbname']]['Port']);
            }
            $this->write_odbc_conf($tofile);

            $queryContactNotes = "IF NOT EXISTS (SELECT * FROM sysobjects WHERE id = object_id(N'[dbo].[".$table."_contact_notes]')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
                         CREATE TABLE [dbo].[".$table."_contact_notes] (
                        [id] INT IDENTITY (1,1) PRIMARY KEY,
                        [contact_id] int NOT NULL,
                        [owner] int NOT NULL,
                        [note] text NOT NULL,
                        [time] int NOT NULL
                        )";

            $fields = array();
            foreach($this->default_cdr_fields_mssql as $key=> $value){
            	$fields[] = '['.$key.'] '.$value;
            }
            $query = "IF NOT EXISTS (SELECT * FROM sysobjects WHERE id = object_id(N'[dbo].[$table]')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
                        CREATE TABLE [dbo].[$table] (".implode(", ".PHP_EOL, $fields).")";

            $connect->exec($query);

            if($connect->errorCode() === '00000'){
                if($this->_updateCdrTable($type, false) === true){
                    // create indexes
                    $this->_updateIndexes($type);

                    if($settings['general']['enable_contact_notes']
                        && $settings['general']['enable_contact_notes'] == 'yes'
                        && $settings['general']['ctibackend'] == 'tds'){

                        $connect->exec($queryContactNotes);
                        if($connect->errorCode() === '00000'){
                            $connect->exec('CREATE INDEX contact_id_idx ON ['.$table.'_contact_notes] (contact_id)');
                        }else{
                            $e = $connect->errorInfo();
                            throw new Exception($e[0] . ': ' . $e[2], 1);
                        }
                    }
                    $this->_setChatHistoryDB($type, $settings);
                }
            }else{
                $e = $connect->errorInfo();
                if ($e !== '00000') {
                    throw new Exception($e[0] . ': ' . $e[2], 1);
                }
            }

            $this->_disconnect($type);
        }catch (Exception $ex){
            if ($ex->getCode() !== 0) {
                return $ex->getMessage();
            }
        }
        return true;
    }

    public function SetMysqlDB(){

        try {
            $type="mysql";

            $settings = $this->getSettings();
            if($settings[$type]['enabled'] != 'yes'){
                return true;
            }

            $connect = $this->_getConnection($type);
            $table = $this->_getTable($type);


            $queryContactNotes = "CREATE TABLE IF NOT EXISTS `".$table."_contact_notes`(
                    `id` int(11) NOT NULL AUTO_INCREMENT,
                    `contact_id` int(11) NOT NULL,
                    `owner` int(11) NOT NULL,
                    `note` TEXT NOT NULL,
                    `time` int(11) NOT NULL,
                    PRIMARY KEY (`id`),
                    KEY `contact_id` (`contact_id`)
                    ) ENGINE=InnoDB DEFAULT CHARSET=utf8;";


            $queryProcedurePurgeCdr = "
                    DROP PROCEDURE IF EXISTS `purge_cdr`;
                    CREATE PROCEDURE `purge_cdr`(IN purge_time INT, IN purge_count INT)
                    purge_proc: BEGIN
                       set @a = (select min(rowid) from ".$table.");
                       set @b = (select count(*) from ".$table." where start < (now() - INTERVAL purge_time MONTH) ORDER BY rowid LIMIT purge_count);
                       set @reverse_count = 200;
                       if @b <= purge_count then
                          delete from ".$table." where start < now() - interval purge_time month;
                          leave purge_proc;
                          end if;

                       purge_loop: LOOP
                          set @z = (select rowid from ".$table." where rowid >= @a order by rowid limit purge_count,1);

                          if @c <= purge_count then leave purge_loop;
                          end if;

                          if @reverse_count <= 0 then leave purge_loop;
                          end if;

                          delete from ".$table." where rowid >= @a and rowid < @z and start < now() - interval purge_time month;
                          set @a = @z;
                          set @c = @b - purge_count;
                          set @reverse_count=@reverse_count - 1;
                          do sleep(1);
                       END LOOP purge_loop;

                    delete from ".$table." where start < (now() - INTERVAL purge_time MONTH) ORDER BY rowid LIMIT purge_count;

                    END";

            $fields = array();
            foreach($this->default_cdr_fields_mysql as $key=> $value){
            	$fields[] = '`'.$key.'` '.$value;
            }

            $query = "CREATE TABLE IF NOT EXISTS `$table` (".implode(", ".PHP_EOL, $fields).") ENGINE=InnoDB DEFAULT CHARSET=latin1;";

            if($connect->exec($query) !== false){

                if($connect->exec($queryProcedurePurgeCdr) === false) {
                    $e = $connect->errorInfo();
                    throw new Exception($e[2], $e[0]);
                }

                if($this->_updateCdrTable($type, false) === true){
                    // create indexes
                    $this->_updateIndexes($type);
                    if($settings['general']['enable_contact_notes']
                        && $settings['general']['enable_contact_notes'] == 'yes'
                        && $settings['general']['ctibackend'] == 'mysql'){

                        if($connect->exec($queryContactNotes) === false) {
                            $e = $connect->errorInfo();
                            throw new Exception($e[2], $e[0]);
                        }
                    }

                    $this->_setChatHistoryDB($type, $settings);
                }
            }else{
                $e = $connect->errorInfo();
                throw new Exception($e[2], $e[0]);
            }
            $this->_disconnect($type);
        }catch (Exception $ex){
            return '['.$ex->getCode().'] '.$ex->getMessage();
        }
        return true;
    }

    public function SetSqliteDB($settings = array()){
        try {
            $type="sqlite3";

            $settings = $this->getSettings();

            $connect = $this->_getConnection($type);
            $table = $this->_getTable($type);

            $this->_setChatHistoryDB($type, $settings);

            if($settings[$type]['enabled'] != 'yes'){
                return true;
            }

            $queryContactNotes = "create table if not exists `".$table."_contact_notes`(
                    `id` INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
                    `contact_id` INT(11) NOT NULL,
                    `owner` INT(11) NOT NULL,
                    `note` TEXT NOT NULL default '',
                    `time` INT(11) NOT NULL
                    );";

            $fields = array();
            foreach($this->default_cdr_fields_sqlite3 as $key=> $value){
            	 $fields[] = '`'.$key.'` '.$value;
            }
            $query = "create table if not exists `$table` (".implode(", ".PHP_EOL, $fields).");";

            // Double check on malformed database
            $check_query = "select count(*) from `$table`;";
            $connect->exec($check_query);
            if ($connect->lastErrorCode()==11){
                return _t('cdr.db_actions');
            }
            if ($connect->exec($query)){
                $this->_updateIndexes($type);
                if($this->_updateCdrTable($type, false) === true) {
                    if($settings['general']['enable_contact_notes']
                        && $settings['general']['enable_contact_notes'] == 'yes'
                        && $settings['general']['ctibackend'] == 'sqlite3'){

                        if ($connect->exec($queryContactNotes)){
                            $connect->exec('CREATE INDEX if not exists `idx_'.$table.'_contact_notes_contact_id` on `'.$table.'_contact_notes`(`contact_id`);');
                        }else{
                            throw new Exception( $connect->lastErrorMsg(), $connect->lastErrorCode());
                        }
                    }
                }
            }else{
                throw new Exception($connect->lastErrorMsg(), $connect->lastErrorCode());
            }

            $this->_disconnect($type);
        }catch (Exception $ex){
            if ($ex->getCode()==11){
                return _t('cdr.db_actions');
            }
            return '['.$ex->getCode().'] '.$ex->getMessage();
        }

        return true;
    }

    public function setCticonnectDb() {
        exec('/usr/sbin/init_cticonnectdb', $out, $ret);
        return $ret === 0;
    }

    public function moveChatHistoryDb($mountFlag) {
        $path = '/mnt/cdr/' . self::CHAT_HISTORY_DB;

        if ($mountFlag == true && file_exists('/mnt/cticonnect/' . self::CHAT_HISTORY_DB)) {
            exec('mv /mnt/cticonnect/' . self::CHAT_HISTORY_DB . ' /mnt/cdr/' . self::CHAT_HISTORY_DB);
        } else if ($mountFlag == false && file_exists('/mnt/cdr/' . self::CHAT_HISTORY_DB) && file_exists('/mnt/cticonnect')) {
            exec('mv /mnt/cdr/' . self::CHAT_HISTORY_DB . ' /mnt/cticonnect/' . self::CHAT_HISTORY_DB);
            $path = '/mnt/cticonnect/' . self::CHAT_HISTORY_DB;
        }

        $oldSettings = \Wildix\Ejabberd::getInstance()->getSettings();

        if ($oldSettings['sql']['type'] == 'sqlite') {
            $newSettings['sql']['db'] = $path;

            \Wildix\Ejabberd::getInstance()->setSettings($newSettings);
        }
    }

    private function _setChatHistoryDB($type, $settings){
    	if($settings['general']['save_history_base'] && $settings['general']['save_history_base'] == 'yes'){
    	    $dbConfig = array(
    	        'type' => $type
    	    );

    		switch ($type) {
                case 'sqlite3' :
                    $dbHistory = $settings[$type]['dbdir'] . '/' . self::CHAT_HISTORY_DB;
                    $dbConfig['database'] = $dbHistory;

                    if(!is_writable($dbHistory)){
                        if(!file_exists($dbHistory)){
                            if(touch($dbHistory)){
                                chmod($dbHistory, 0666);
                            }
                        }else{
                            exec('sudo chmod 666 '.$dbHistory);
                        }
                    }
                    break;
                case 'tds' :
                    $dbConfig['server'] = isset($settings[$type]['hostname']) ? $settings[$type]['hostname'] : '';
                    $dbConfig['port'] = isset($settings[$type]['port']) ? $settings[$type]['port'] : '';
                    $dbConfig['database'] = isset($settings[$type]['dbname']) ? $settings[$type]['dbname'] : '';
                    $dbConfig['username'] = isset($settings[$type]['user']) ? $settings[$type]['user'] : '';
                    $dbConfig['password'] = isset($settings[$type]['password']) ? $settings[$type]['password'] : '';
                    break;
                case 'mysql':
                    $dbConfig['server'] = isset($settings[$type]['hostname']) ? $settings[$type]['hostname'] : '';
                    $dbConfig['port'] = isset($settings[$type]['port']) ? $settings[$type]['port'] : '';
                    $dbConfig['database'] = isset($settings[$type]['dbname']) ? $settings[$type]['dbname'] : '';
                    $dbConfig['username'] = isset($settings[$type]['user']) ? $settings[$type]['user'] : '';
                    $dbConfig['password'] = isset($settings[$type]['password']) ? $settings[$type]['password'] : '';
                    break;
            }


            $diContainer    = new \Wildix\DependencyInjection\Container();
            $chatHistoryMigrateFactory = $diContainer->get(\Wildix\ChatHistory\Migrate\MigrateFactory::class);
            $chatHistoryMigrate = $chatHistoryMigrateFactory->build($dbConfig);

            if($chatHistoryMigrate){
                $chatHistoryMigrate->upgrade();
            }
        }
    }

    static public function parse_ini_file_quotes_safe($f){
        $r = false;
        $sec = false;
        $f = @file($f);
        for($i = 0; $i < @count($f); $i++){
            $newsec = 0;
            $w = @trim($f[$i]);
            if($w){
                if((!$r) or ($sec)){
                    if((@substr($w, 0, 1) == '[') and (@substr($w, -1, 1)) == ']'){
                        $sec = @substr($w, 1, @strlen($w) - 2);
                        $newsec = 1;
                    }
                }
                if(!$newsec){
                    $w = @explode("=",$w);
                    $k = @trim($w[0]);
                    unset($w[0]);
                    $v = @trim(@implode("=",$w));
                    if((@substr($v, 0, 1) == '"') and (@substr($v, -1, 1) == '"')){
                        $v = @substr($v, 1, @strlen($v) - 2);
                    }
                    if($sec){
                        $r[$sec][$k] = $v;
                    }else{
                        $r[$k] = $v;
                    }
                }
            }
        }
        return $r;
    }

    static function write_odbc_conf(array $conf) {
    	$odbc_ini = '/etc/odbc.ini';

        if (!write_ini_file($odbc_ini, $conf, true)) {
            logger('Could not write to ' . $odbc_ini,__FUNCTION__,__LINE__);
        }
    }

    static public function write_cdr_conf($assoc){
        $path_general = PATH_TO_CW_CONF."cdr.conf";
        $path_mysql   = PATH_TO_CW_CONF."cdr_mysql.conf";
        $path_tds     = PATH_TO_CW_CONF."cdr_tds.conf";
        $path_sqlite  = PATH_TO_CW_CONF."cdr_sqlite3_custom.conf";

        $assoc['general']['time'] = 3;
        $assoc['general']['unanswered'] = 'yes';
        $assoc['general']['batch'] = 'yes';

        if(is_array($assoc['sqlite3'])){
        	if(empty($assoc['sqlite3']['dbdir'])){
        		$assoc['sqlite3']['enabled'] = 'no';
        	}

        	if($assoc['general']['ctibackend'] == 'sqlite3' && $assoc['sqlite3']['enabled'] != 'yes'){
        		$assoc['general']['ctibackend'] = '';
        	}

        	if($assoc['sqlite3']['enabled'] == 'yes'){
        		$assoc['general']['scheduleronly'] = 'yes';
        	}else{
        		$assoc['general']['scheduleronly'] = 'no';
        	}
        	$assoc['sqlite3']['table'] = 'cdr';
        }

        if(is_array($assoc['tds'])){
        	$assoc['tds']['port'] = trim($assoc['tds']['port']);

        	if (empty($assoc['tds']['port'])){
        		unset($assoc['tds']['port']);
        	}
        	$assoc['tds']["charset"] = "utf8";
        }

        if(is_array($assoc['mysql'])){
        	$assoc['mysql']['timeout'] = trim($assoc['mysql']['timeout']);
        	$assoc['mysql']['port'] = trim($assoc['mysql']['port']);

        	if (empty($assoc['mysql']['timeout'])){
        		$assoc['mysql']['timeout'] = '2';
        	}
        	if (empty($assoc['mysql']['port'])){
        		$assoc['mysql']['port'] = '3306';
        	}
        	$assoc['mysql']['charset'] = 'utf8mb4';
        }

        if(is_array($assoc['csv']) && empty($assoc['csv']['logdir'])){
        	$assoc['csv']['enabled'] = 'no';
        }

        $assoc['general'][self::CDR_GENERAL_CUSTOM_INCLUDE] = '';

        unlink($path_general);
        foreach ($assoc as $section => $section_arr) {
            switch($section){
                case 'general':
                    $filename = $path_general;
                    $section_name = 'general';
                    $mode = 'a';
                    break;
                case 'csv':
                    $filename = $path_general;
                    $section_name = 'csv';
                    $mode = 'a';
                    break;
                case 'mysql':
                    $filename = $path_mysql;
                    $section_name = 'global';
                    $mode = 'w';
                    break;
                case 'tds':
                    $filename = $path_tds;
                    $section_name = 'global';
                    $mode = 'w';
                    break;
                case 'sqlite3':
                    $filename = $path_sqlite;
                    $section_name = 'cdrdb';
                    $mode = 'w';
                    break;
                default: $filename = false;
            }
            if(!$filename){
            	continue;
            }
            $fp = @fopen($filename,$mode);
            if ($fp === false){
                logger('failed to open: '.$filename);
                continue;
            }
            @fwrite($fp,'['.$section_name.']'."\n");
            foreach ($section_arr as $param => $value){
                if (!(substr($param, 0, 9) === "#include ")) {
                    $param .= " = $value";
                }
                @fwrite($fp, "$param\n");
            }
            @fclose($fp);
        }


		$ejabberdSettings = \Wildix\Ejabberd::getInstance()->getSettings();

        $ejabberdSettings['sql']['enabled'] = true;

        if ($assoc['general']['save_history_base'] == 'no') {
            $ejabberdSettings['sql']['enabled'] = false;
        }

        if($assoc['general']['ctibackend'] == 'mysql' && $assoc['mysql']['enabled'] == 'yes'){
            $ejabberdSettings['sql']['type'] = 'mysql';
            $ejabberdSettings['sql']['server'] = $assoc['mysql']['hostname'];
            $ejabberdSettings['sql']['port'] = $assoc['mysql']['port'];
            $ejabberdSettings['sql']['db'] = $assoc['mysql']['dbname'];
            $ejabberdSettings['sql']['username'] = $assoc['mysql']['user'];
            $ejabberdSettings['sql']['password'] = $assoc['mysql']['password'];

        } elseif($assoc['general']['ctibackend'] == 'tds' && $assoc['tds']['enabled'] == 'yes') {
            $ejabberdSettings['sql']['type'] = 'mssql';
            $ejabberdSettings['sql']['server'] = $assoc['tds']['hostname'];
            $ejabberdSettings['sql']['port'] = $assoc['tds']['port'];
            $ejabberdSettings['sql']['db'] = $assoc['tds']['dbname'];
            $ejabberdSettings['sql']['username'] = $assoc['tds']['user'];
            $ejabberdSettings['sql']['password'] = $assoc['tds']['password'];
        } else {
            $ejabberdSettings['sql']['type'] = 'sqlite';
            $ejabberdSettings['sql']['db'] = $assoc['sqlite3']['dbdir'] . '/' . self::CHAT_HISTORY_DB;
        }

		// save new configs
		\Wildix\Ejabberd::getInstance()->setSettings($ejabberdSettings);

        CDR::getInstance()->getSettings(true);
        return true;
    }

    public function clearDatabases(int $quantityOfMonths): bool {
        if ($quantityOfMonths <= 0) {
            return false;
        }

        foreach ($this->getSettings() as $key => $item) {
            if ($key !== 'general' && $item['enabled'] === 'yes') {
                if (isset(self::SUPPORTED_PROVIDERS[$key])) {
                    $this->{self::SUPPORTED_PROVIDERS[$key]}($quantityOfMonths);
                } else {
                    throw new Exception('Data provider not found');
                }
            }
        }

        return true;
    }
}
