<?php

use Wildix\Core\Notification;

class WmsPhonebooksImport {

	var $phonebooks_class = false;
	var $phonebook = array();
	var $dry_run = false;
	var $verbose = false;
	var $g_summary = array();
	var $send_email = '';
	var $remove_user = false;
	var $erase_values = false;
	var $backend_params = array();
	var $map = array();
	var $external_record_empty = array();
	var $_g_attrs_translation = array();
	var $_g_country = '';
	var $time_start = 0;
	var $records = array();
	var $_count_flush = 1000;
	var $_phoneNormalizer;

	var $log_id = 0;

	function __construct($got_params=false, $phonebook_id) {

		$this->time = microtime(1);

		$this->phonebooks_class = new phonebook();

		$this->phonebooks_class->db->connection->exec('PRAGMA synchronous = 0;');

		$this->phonebook['id'] = intval($phonebook_id);

		$this->toLog('Beginning syncronization.');

		$phonebook_arr = $this->phonebooks_class->get($this->phonebook['id']);
		if(empty($phonebook_arr) || !is_array($phonebook_arr)){
			$this->toLog('ERROR: Cannot find phonebook with id '.$this->phonebook['id']);
			$this->out();
		}
		$this->phonebook['name'] = $phonebook_arr['name'];

		$this->toLog('Phonebook "'.$this->phonebook['name'].'".');

		if ($got_params) {
			$this->dry_run = isset($got_params['dry_run']) && $got_params['dry_run'] == 'yes';
			$this->verbose = isset($got_params['verbose']) && $got_params['verbose'] == 'yes';

			$this->backend_params = $got_params['settings'];
			$this->map = $got_params['map'];

			$this->log_id = $got_params['syncid'];

		}else{
			$this->log_id = rand(10000,99999);

			$got_params = $this->phonebooks_class->get_sync_settings_n_map($this->phonebook['id'], 'pbook_id');

			//$this->toLog(print_r($got_params));
			$this->send_email = $got_params['recurrent_job']['email'];

			if (!in_array($got_params['global']['backend'], array('ldap','mysql','activeD','domino','mssql', 'hanaDb', 'office365', 'google', 'infusionsoft', 'exchange', 'csv'))){
				$this->toLog('ERROR: Cannot use '.$got_params['global']['backend']. ' backend for recurrent synchronization.');
				$this->out();
			}

			$this->backend_params = $got_params['settings'][$got_params['global']['backend']];
			$this->backend_params['backend'] = $got_params['global']['backend'];
			$this->map = $got_params['map'][$this->backend_params['backend']];

			if ($this->backend_params['backend'] == 'csv' && $this->backend_params['import_type'] == 'upload'){
				$this->toLog('ERROR: Cannot use CSV Upload for recurrent synchronization.');
				$this->out();
			}
		}

		if(empty($this->map['source_id'])){
			// for backward compatibility with the old logic, when the name was unique key
			$this->map['source_id'] = $this->map['username'];
		}

		$this->g_summary = array(
			'added' => 0,
			'updated' => 0,
			'removed' => 0,
			'added_with_err' => 0,
			'updated_with_err' => 0
		);

		if ($this->dry_run) {
			$this->toLog('DRY-RUN mode'.(($this->verbose)?' with additional verbose':'').'.');
		}

		$this->_g_attrs_translation = $this->phonebooks_class->get_sync_attributes_translation();

		$this->external_record_empty = array();

		if ($got_params['global']['erase_values'] == 'yes'){
			$this->erase_values = true;
			foreach($this->map as $key=>$val){
				if($key != 'source_id' && $key != 'username'){
					$this->external_record_empty[$key] = '';
				}
			}
		}

		if($got_params['global']['remove_users'] == 'yes'){
			$this->remove_user = true;
		}

		unset($param, $got_params, $phonebook_arr);

        $extensionsVars = \Wildix\Dialplan\ExtensionsVariables::getInstance();
		$this->_phoneNormalizer = new \Wildix\Normalizer\PhoneNumberNormalizer(
            $extensionsVars->get(\Wildix\Dialplan\ExtensionsVariables::INTERNATIONAL_PREFIX),
            $extensionsVars->get(\Wildix\Dialplan\ExtensionsVariables::NATIONAL_PREFIX),
            $extensionsVars->get(\Wildix\Dialplan\ExtensionsVariables::COUNTRY_CODE)
        );
	}

	function import(){
		$this->time_start = date('Y-m-d H:i:s');
		if ($this->backend_params['backend'] == 'ldap'){
			$this->importFromLdap();
		}elseif ($this->backend_params['backend'] === 'activeD'){
			$this->importFromLdap();
        }elseif ($this->backend_params['backend'] === 'domino'){
            $this->importFromLdap(true);
		}elseif ($this->backend_params['backend'] === 'mysql'){
			$this->importFromMySql();
        }elseif ($this->backend_params['backend'] === 'hanaDb'){
			$this->importFromHanaDb();
		}elseif ($this->backend_params['backend'] === 'mssql'){
			$this->importFromMsSql();
		}elseif ($this->backend_params['backend'] === 'csv'){
			$this->importFromCsv();
		}elseif ($this->backend_params['backend'] === 'google'){
			$this->importFromGoogle();
		}elseif ($this->backend_params['backend'] === 'infusionsoft'){
            $this->importFromInfusionsoft();
        }elseif ($this->backend_params['backend'] === 'exchange'){
			$this->importFromExchangeServer();
		}elseif ($this->backend_params['backend'] === 'office365'){
			$this->importFromOffice365();
		}

		$this->flushContacts();

		if ($this->remove_user){
			$this->remove_local_entries();
		}

		$this->progress_to_log( true);

		$this->toLog('The operation is completed.');
		$this->sendMail();
		//$this->toLog("Peak memory:".memory_get_peak_usage());
		//$this->toLog("Time:".(microtime(1)-$this->time));

		$this->phonebooks_class->db->connection->exec('PRAGMA synchronous = FULL;');
	}

	function importFromLdap($isDomino=false){

		$ldapConnector = new Wildix\Ldap\Connector(
			$this->backend_params['host'],
			$this->backend_params['port'],
			filter_var($this->backend_params['secure'],FILTER_VALIDATE_BOOLEAN),
			$this->backend_params['user'],
			$this->backend_params['password']
		);

		$this->toLog('Connecting to server '. $ldapConnector->getConnectString() );
		try{
			$external_ldap_dbh = $ldapConnector->getConnection();
		} catch (\Exception $e){
			$this->toLog('ERROR: '.$e->getMessage());
			$this->out();
		}

		$this->toLog('Performing the search with the filter: '.$this->backend_params['filter']);


		$cookie = '';
		$pageSize = 200;
		$attributes = array_map('trim',preg_split("/\||,|\+/",implode(',',$this->map)));
		$filter = '(&'.$this->backend_params['filter'].')';

		do {
            if ($isDomino){
                ldap_control_paged_result($external_ldap_dbh, $pageSize);
            } else {
                ldap_control_paged_result($external_ldap_dbh, $pageSize, true, $cookie);
            }
			$searchResult = ldap_search($external_ldap_dbh, $this->backend_params['basedn'], $filter, $attributes, 0, 0, 2);
			if (!is_resource($searchResult)) {
				return $this->toLog('ERROR: '.ldap_error($external_ldap_dbh));
			}

			$ldapSearchErrno = ldap_errno($external_ldap_dbh);

			$entryID=ldap_first_entry($external_ldap_dbh,$searchResult);

			do {
				$external_record = $this->external_record_empty;
				$ext_attrs = ldap_get_attributes( $external_ldap_dbh, $entryID );
				//Normalize to appliable for processMappingSyntax function
				$sourceRow = array();
				for ($i=0; $i < $ext_attrs["count"]; $i++) {
					if ( $ext_attrs[ $ext_attrs[$i] ] ){
						$sourceRow[ $ext_attrs[$i] ] = trim($ext_attrs[ $ext_attrs[$i] ][0]);
					}
				}
				foreach($this->map as $key=>$val){
					$ext_value =   $this->processMappingSyntax($sourceRow,$val,$selectedColumnName);
					if ($ext_value == ''){
						continue;
					}
					if(strtolower($key) != 'note') {
						$ext_value = $this->removeNewLines($ext_value);
					}
					$ext_value = $this->normalize_value($key, $ext_value);
					$external_record[$key] = $ext_value;
				}

				$this->compare_the_records($external_record);

			}while ($entryID = ldap_next_entry($external_ldap_dbh,$entryID));

			unset($ext_attrs,$entryID);
            if (!$isDomino){
                ldap_control_paged_result_response($external_ldap_dbh, $searchResult, $cookie);
            }
			ldap_free_result($searchResult);

			if($ldapSearchErrno != 0) {
				$this->toLog('ERROR: '.ldap_err2str($ldapSearchErrno));
				break;
			}

		} while($cookie !== null && $cookie != '');

		unset($cookie);
		ldap_close($external_ldap_dbh);
	}

	function importFromMySql(){
        if (!isset($this->backend_params['port']) || $this->backend_params['port'] == ''){
            $t_connect_str = 'mysql:dbname='.$this->backend_params['database'].';host='.$this->backend_params['host'];
        }else{
            $t_connect_str = 'mysql:dbname='.$this->backend_params['database'].';host='.$this->backend_params['host'].';port='.$this->backend_params['port'];
        }

        if (isset($this->backend_params['timeout']) && is_numeric($this->backend_params['timeout'])) {
            $timeout = $this->backend_params['timeout'];
        } else {
            $timeout = 10;
        }

        $this->toLog('Connecting to MySQL server '. $t_connect_str. ' (Timeout: '.$this->backend_params['timeout'].'s)');

        try {
            $external_mysql_dbh = new \PDO($t_connect_str, $this->backend_params['user'], $this->backend_params['password'], array(
                PDO::ATTR_TIMEOUT => $timeout,
                PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION,
                PDO::MYSQL_ATTR_INIT_COMMAND =>  "SET CHARACTER SET 'utf8'",
            ));
        } catch (\PDOException $exception) {
            $this->toLog('ERROR: '.$exception->getMessage());
            $this->out();
        }

		unset($t_connect_str);

		$dbcolumns = array_map('trim',preg_split("/\||,|\+/",implode(',',$this->map)));
		$this->backend_params['filter'] = str_replace('${MAP}','`'.implode('`, `',$dbcolumns).'`',$this->backend_params['filter']);

		$this->toLog('Performing the search with the query: '.$this->backend_params['filter']);

        try {
            $search_res = $external_mysql_dbh->query($this->backend_params['filter']);
        } catch (\PDOException $exception) {
            $this->toLog('ERROR: '.$exception->getMessage());
            $this->out();
        }

        if ($search_res === false) {
            $e = $external_mysql_dbh->errorInfo();
            $this->toLog('ERROR: '.$e[2]);
            $this->out();
        }

        foreach ($search_res as $ext_entry) {

			$external_record = $this->external_record_empty;

			foreach ($this->map as $internal => $external){
				if ($external != ''){
					$external_val = $this->processMappingSyntax($ext_entry, $external, $selectedColumnName);
					if ($external_val == '')
						continue;
					if(strtolower($internal) != 'note') {
						$external_val = $this->removeNewLines($external_val);
					}
					$external_record[$internal] = $this->normalize_value($internal, $external_val );
				}
			}

			$this->compare_the_records($external_record);

		}

		unset($search_res,$external_record, $internal, $external, $ext_entry, $external_mysql_dbh);

	}

    function importFromHanaDb() {
        try{
            $parametersDb = $this->backend_params;
            $timeout = 0;// - 0 - IS DISABLED TIME OUT
            if (isset($parametersDb['timeout']) && is_numeric($parametersDb['timeout'])) {
                $timeout = $parametersDb['timeout'];
            }
            $parametersDb['port'] = !empty($parametersDb['port']) ? $parametersDb['port'] : 30015;
            $connectString = sprintf('odbc:CHAR_AS_UTF8=true;Driver=%s;ServerNode=%s;Uid=%s;Pwd=%s;SERVDB=%s;CONNECTTIMEOUT=%s', 'HanaDB', $parametersDb['host'] . ':' . $parametersDb['port'], $parametersDb['user'], $parametersDb['password'], $parametersDb['database'], $timeout);

            $this->toLog('Connecting to HanaDb server ' . $connectString . ' (Timeout: ' . $timeout . 's)');

            try {
                $externalHanaDb = new \PDO($connectString);
            } catch (\PDOException $exception) {
                $this->toLog('ERROR: ' . $exception->getMessage());
                $this->out();
            }

            unset($connectString);

            $dbcolumns = array_map('trim', preg_split("/\||,|\+/", implode(',', $this->map)));
            $this->backend_params['filter'] = str_replace('${MAP}', '"'.implode('", "', $dbcolumns) . '"', $this->backend_params['filter']);
            $this->backend_params['filter'] = str_replace('${DBNAME}', '"' . $parametersDb['database'] . '"', $this->backend_params['filter']);

            $this->toLog('Performing the search with the query: ' . $this->backend_params['filter']);

            try {
                $searchResource = $externalHanaDb->query($this->backend_params['filter']);
            } catch (\PDOException $exception) {
                $this->toLog('ERROR: ' . $exception->getMessage());
                $this->out();
            }
            $this->toLog('Check data processing...');
            if ($searchResource === false) {
                $this->toLog('ERROR: resource not found');
                $e = $externalHanaDb->errorInfo();
                $this->toLog('ERROR: ' . $e[2]);
                $this->out();
            }
            $process    = 0;
            $allRecords = $searchResource->rowCount();
            foreach ($searchResource as $ext_entry) {
                $external_record = $this->external_record_empty;
                foreach ($this->map as $internal => $external) {
                    if ($external != '') {
                        $external_val = $this->processMappingSyntax($ext_entry, $external, $selectedColumnName);
                        if ($external_val == '') {
                            continue;
                        }
                        if (strtolower($internal) !== 'note') {
                            $external_val = $this->removeNewLines($external_val);
                        }
                        $external_record[$internal] = $this->normalize_value($internal, $external_val);
                    }
                }
                $this->compare_the_records($external_record);
                $process++;
            }
            $this->toLog('Finish processing...');
            unset($search_res, $external_record, $internal, $external, $ext_entry, $external_mysql_dbh);
        } catch (\Throwable $e) {
            $this->toLog($e->getMessage());
        }
	}

	function importFromMsSql(){

        if (!isset($this->backend_params['port']) || $this->backend_params['port'] == ''){
            $t_connect_str = 'dblib:host='.$this->backend_params['host'].';dbname='.$this->backend_params['database'];
        }else{
            $t_connect_str = 'dblib:host='.$this->backend_params['host'].':'.$this->backend_params['port'].';dbname='.$this->backend_params['database'];
        }

		if (!isset($this->backend_params['timeout']) || !$this->backend_params['timeout'] || $this->backend_params['timeout'] <= 5){
			$this->backend_params['timeout'] = ini_get('mssql.connect_timeout');
		}
		ini_set('mssql.connect_timeout', $this->backend_params['timeout']);

		$this->toLog('Connecting to MSSQL server '. $t_connect_str. ' (Timeout: '.$this->backend_params['timeout'].'s)');

        try {
            $external_mssql_dbh = new PDO($t_connect_str, $this->backend_params['user'], $this->backend_params['password']);
        } catch (\PDOException $exception) {
            $this->toLog('ERROR: '.$exception->getMessage());
            $this->out();
        }

		$dbcolumns = array_map('trim',preg_split("/\||,|\+/",implode(',',$this->map)));
		$this->backend_params['filter'] = str_replace('${MAP}','['.implode('], [',$dbcolumns).']',$this->backend_params['filter']);

		$this->toLog('Performing the search with the query: '.$this->backend_params['filter']);

        try {
		    $search_res = $external_mssql_dbh->query($this->backend_params['filter']);
        } catch (\PDOException $exception) {
            $this->toLog('ERROR: '.$exception->getMessage());
            $this->out();
        }

		if ($search_res === false) {
            $e = $external_mssql_dbh->errorInfo();
            $this->toLog('ERROR: '.$e[2]);
            $this->out();
		}

        foreach ($search_res as $ext_entry) {

            $external_record = $this->external_record_empty;

            foreach ($this->map as $internal => $external){
                if ($external != ''){
                    $external_val = $this->processMappingSyntax($ext_entry, $external, $selectedColumnName);
                    if ($external_val == '')
                        continue;
                    if(strtolower($internal) != 'note') {
                        $external_val = $this->removeNewLines($external_val);
                    }
                    $external_record[$internal] = $this->normalize_value($internal, $external_val ) ;
                }
            }

            $this->compare_the_records($external_record);

        }

		unset($external_mssql_dbh);
	}

    private $separator = ",";
    private $separatorArray = array(";", "|", "\t");

	function importFromCsv() {
		if ($this->backend_params['import_type'] == 'upload') {
			$this->toLog('Opening uploaded file.');
		} else {
			$this->toLog('Opening CSV file: '._t('devices.'.$this->backend_params['import_mountpoint']).'/'.$this->backend_params['import_filepath']);
			$this->backend_params['filename'] = $this->backend_params['import_mountpoint'].'/'.$this->backend_params['import_filepath'];
		}

		$content = file_get_contents($this->backend_params['filename']);
        $contentEncoding = mb_detect_encoding($content, 'ASCII, UTF-8, ISO-8859-1', true);
        if ($contentEncoding === false) {
            if ($this->backend_params['import_type'] === 'upload') {
                unlink($this->backend_params['filename']);
            }

            $this->toLog('ERROR: Cannot detect uploaded file encoding.');
            $this->out();
        }

        if ($contentEncoding !== 'UTF-8') {
            $this->toLog('WARNING: Uploaded file has encoding:' . $contentEncoding);
            file_put_contents($this->backend_params['filename'], mb_convert_encoding($content, 'UTF-8', $contentEncoding));
        }

		if (($csv_handle = fopen($this->backend_params['filename'], "r")) === false){
			if ($this->backend_params['import_type'] == 'upload') {
				unlink($this->backend_params['filename']);
				$this->toLog('ERROR: Cannot open uploaded file.');
			} else {
				$this->toLog('ERROR: Cannot open CSV file.');
			}
			$this->out();
		};

        $testColumn = fgetcsv($csv_handle, 1000, $this->separator);

        if ($testColumn === false){
			if ($this->backend_params['import_type'] == 'upload') {
				unlink($this->backend_params['filename']);
				$this->toLog('ERROR: Cannot read the first row from uploaded file.');
			} else {
				$this->toLog('ERROR: Cannot read the first row from CSV file.');
			}
			$this->out();
		} else if (is_array($testColumn) && count($testColumn) <= 1) {
            $this->setSeparator($csv_handle);
        }

        fseek($csv_handle, 0);

        // get the first csv row to get the header values
        $csv_columns = fgetcsv($csv_handle, 1000, $this->separator);

        while (($csv_row = fgetcsv($csv_handle, 1000, $this->separator)) !== FALSE) {

			$external_record = $this->external_record_empty;
			foreach($this->map as $destColumnName => $sourceColumnName){
				$ext_value = $this->processMappingSyntax($csv_row,$sourceColumnName, $selectedColumnName, $csv_columns);
				if($destColumnName == 'source_id' && $ext_value == ''){
					// if the id in CSV empty uses the name as the id
					$ext_value = $this->processMappingSyntax($csv_row,$this->map['username'], $selectedColumnName, $csv_columns);
				}
				if ($ext_value == ''){
					continue;
				}
				$ext_value = $this->normalize_value($destColumnName, $ext_value);

				if(strtolower($destColumnName) != 'note') {
				    $ext_value = $this->removeNewLines($ext_value);
                }
				$external_record[$destColumnName] = $ext_value;
			}

			$this->compare_the_records($external_record);

		}

		if ($this->backend_params['import_type'] == 'upload') {
			unlink($this->backend_params['filename']);
		}
	}

    private function setSeparator($csvHandle) {
        $firstLine = fgets($csvHandle);
        $max = 0;

        foreach ($this->separatorArray as $delimiter) {
            $count = count(str_getcsv($firstLine, $delimiter));

            if ($count > $max) {
                $max = $count;
                $this->separator = $delimiter;
            }
        }

        if ($max == 1) {
            $this->toLog('WARNING: separator can not be detected.');
        }
    }

	function importFromGoogle(){
	    $this->toLog('Connecting to Google server');

	    $selectedPhonebooks = null;
	    if(!empty($this->backend_params['phonebooks'])){
	        $selectedPhonebooks = array_filter(array_map('trim', explode(',', $this->backend_params['phonebooks'])), 'strlen');
	    }

	    if(!is_array($selectedPhonebooks) || count($selectedPhonebooks) == 0){
	        $this->toLog('ERROR: Not selected phone books');
	        $this->out();
	    }

        $token = array(
                'received_token_time'=> $this->backend_params['received_token_time'],
                'access_token' => $this->backend_params['access_token'],
                'token_type' => $this->backend_params['token_type'],
                'expires_in' => $this->backend_params['expires_in'],
                'refresh_token' => $this->backend_params['refresh_token']
        );

        $googleApi = GoogleAPI::getInstance();
        if($googleApi->setToken($token) != GoogleAPI::TOKEN_VALID){
            $this->toLog('ERROR: Token invalid');
            $this->out();
        }

        $phonebooks = $googleApi->getPhonebooks(1000);

        if(!empty($phonebooks['error'])){
            $this->toLog('ERROR: '.$phonebooks['error']['message']);
            $this->out();
        }

        if($phonebooks['total'] > 0){
            $phonebooks = array_filter($phonebooks['entry'], function($value=null, $key=null) use($selectedPhonebooks) {
                return in_array($value['id'], $selectedPhonebooks) ? true : false;
            });
        }
        unset($selectedPhonebooks);

        ini_set("memory_limit", "-1");

        /************************************
         * start import contacts
         ************************************/
        foreach ($phonebooks as $phonebook){
            $phonebookName = str_replace('System Group: ', '', $phonebook['name']);
            $this->toLog('Phonebook: ' . $phonebookName);

            $contacts = $googleApi->getContacts($phonebook['id']);
            $this->toLog(sprintf('In the phonebook %s found %d contacts and %d errors', $phonebookName, count($contacts['entry']), count($contacts['errors'])));

            if ($contacts && !empty($contacts['errors'])) {
                foreach ($contacts['errors'] as $err) {
                    $this->toLog($err);
                }
            }

            if(empty($contacts) || !isset($contacts['entry'])){
                $this->toLog('Contacts not found');
                break;
            }

            foreach($contacts['entry'] as $ext_entry){
                $contact = array(
                        'id' => $ext_entry['id'],
                        'birthday' => $ext_entry['birthday'],
                        'notes' => $ext_entry['notes'],
                        'name'=> trim($ext_entry['name']['name']).' '.trim($ext_entry['name']['additionalName']).' '.trim($ext_entry['name']['familyName']),
                        'firstName' => $ext_entry['name']['name'],
                        'additionalName' => $ext_entry['name']['additionalName'],
                        'familyName' => $ext_entry['name']['familyName'],
                        'namePrefix' => $ext_entry['name']['namePrefix'],
                        'phoneWork' => $ext_entry['phone']['work'],
                        'phoneMobile' => $ext_entry['phone']['mobile'],
                        'phoneHome' => $ext_entry['phone']['home'],
                        'phoneMain' => $ext_entry['phone']['main'],
                        'phoneWorkFax' => $ext_entry['phone']['workFax'],
                        'phoneHomeFax' => $ext_entry['phone']['homeFax'],
                        'phonePager' => $ext_entry['phone']['pager'],
                        'organization' => $this->getGoogleOrganization($ext_entry['organization']),
                        'emailHome' => $ext_entry['email']['home'],
                        'emailWork' => $ext_entry['email']['work'],
                        'websiteProfile' => $ext_entry['website']['profile'],
                        'websiteBlog' => $ext_entry['website']['blog'],
                        'websiteHomePage' => $ext_entry['website']['homePage'],
                        'websiteWork' => $ext_entry['website']['work'],
                        'addressHome'=> str_replace("\n", ' ',$ext_entry['address']['home']['street']).' '.str_replace("\n", ' ',$ext_entry['address']['home']['pobox']),
                        'streetHome'=> str_replace("\n", ' ',$ext_entry['address']['home']['street']),
                        'poboxHome' => str_replace("\n", ' ',$ext_entry['address']['home']['pobox']),
                        'addressWork' => str_replace("\n", ' ',$ext_entry['address']['work']['street']).' '.str_replace("\n", ' ',$ext_entry['address']['work']['pobox']),
                        'streetWork' => str_replace("\n", ' ',$ext_entry['address']['work']['street']),
                        'poboxWork'=> str_replace("\n", ' ',$ext_entry['address']['work']['pobox']),
                        'cityHome'=> trim($ext_entry['address']['home']['city']),
                        'cityWork'=> trim($ext_entry['address']['work']['city']),
                        'postcodeHome'=> trim($ext_entry['address']['home']['postcode']),
                        'postcodeWork'=> trim($ext_entry['address']['work']['postcode']),
                        'regionHome'=> trim($ext_entry['address']['home']['region']),
                        'regionWork'=> trim($ext_entry['address']['work']['region']),
                );

                $external_record = $this->external_record_empty;
                $addressWork = false;
                foreach ($this->map as $internal => $external){

                    if (!empty($external)){
                        $value = $this->processMappingSyntax($contact, $external, $selectedColumnName);

                        if(!empty($value)){
                            $value = preg_replace('/\s{2,}/', ' ', $value);
                            if($internal == 'address'){
                                $addressWork = ($selectedColumnName == 'addressWork');
                            }
                        }

                        if(strtolower($internal) != 'note') {
                            $value = $this->removeNewLines($value);
                        }
                        $external_record[$internal] = $this->normalize_value($internal, $value);
                    }
                }

                if(!empty($contact['birthday'])){
                    $birthday = \DateTime::createFromFormat('Y-m-d', $contact['birthday']);
                    if($birthday !== false){
                        $external_record['date_birth'] = $birthday->format('m/d/Y');
                    }
                }

                $this->compare_the_records($external_record);
            }
        }
        /************************************
         * end import contacts
        ************************************/
	}

    function getGoogleOrganization($data) {
        if (!is_array($data)) {
            return null;
        }

        $names = [];
        foreach ($data as $val) {
            if (!empty($val)) {
                $names[] = $val;
            }
        }

        return count($names) ? implode(', ', $names) : null;
    }

	function importFromInfusionsoft() {
        $this->toLog('Connecting to Infusionsoft server');

        $savedToken = array(
            'received_token_time'=> $this->backend_params['received_token_time'],
            'access_token' => $this->backend_params['access_token'],
            'token_type' => $this->backend_params['token_type'],
            'expires_in' => $this->backend_params['expires_in'],
            'refresh_token' => $this->backend_params['refresh_token']
        );

        $kite         = new \Wildix\Services\Kite();
        $infusionsoft = new \Wildix\Import\Infusionsoft($kite, env('INFUSIONSOFT_AUTH_URI'), env('INFUSIONSOFT_API_URI'), \Syslog::ERROR);

        try {
            $infusionsoft->setToken($savedToken);
        } catch (\Exception $e) {
            $this->toLog('ERROR: Token invalid');
            $this->out();
        }

        $start = 0;
        $count = 1000;

        do {
            $token    = $infusionsoft->getToken();
            $contacts = $infusionsoft->getContacts($token, $count, $start);

            if (!isset($contacts)) {
                $this->remove_user = false;
                $this->toLog('ERROR: could not connect to Infusionsoft server');
                break;
            }

            if (empty($contacts['contacts'])) {
                $this->toLog('Contacts not found');
                break;
            }

            $contacts = $contacts['contacts'];

            $this->toLog('Contacts: ' . count($contacts));

            foreach ($contacts as $contactEntry) {
                $contact        = $infusionsoft->parseContact($contactEntry);
                $externalRecord = $this->external_record_empty;

                foreach ($this->map as $internal => $external) {
                    if (empty($external)) {
                        continue;
                    }

                    $value = $this->processMappingSyntax($contact, $external, $selectedColumnName);

                    if (empty($value)) {
                        continue;
                    }

                    if(strtolower($internal) !== 'note') {
                        $value = $this->removeNewLines($value);
                    }

                    $externalRecord[$internal] = $this->normalize_value($internal, $value);
                }

                if (!empty($contact['birthday'])) {
                    $birthday = \DateTime::createFromFormat('Y-m-d', $contact['birthday']);
                    if($birthday !== false){
                        $externalRecord['date_birth'] = $birthday->format('m/d/Y');
                    }
                }

                $this->compare_the_records($externalRecord);
            }
            $start += $count;
        } while (count($contacts) === $count);

        $lastUsedToken = $infusionsoft->getToken();
        if ($savedToken !== $lastUsedToken) {
            $settings = $this->phonebooks_class->get_sync_settings_n_map($this->phonebook['id'], 'pbook_id');
            $oldInfusionsoftSettings = $settings['settings']['infusionsoft'];

            $newSettings = array();
            foreach ($settings['settings'] as $backend => $backendSettings) {
                if ($backend === 'infusionsoft') {
                    $backendSettings = array_merge($oldInfusionsoftSettings, $lastUsedToken);
                }
                $newSettings[$backend]['settings'] = $backendSettings;
            }
            foreach ($settings['map'] as $backend => $backendMap) {
                $newSettings[$backend]['map'] = $backendMap;
            }
            $newSettings['global'] = $settings['global'];
            $newSettings['recurrent_job'] = $settings['recurrent_job'];
            $this->phonebooks_class->set_sync_settings_n_map($this->phonebook['id'], $newSettings);
        }
    }

	function importFromExchangeServer(){
		$this->toLog('Connecting to Exchange server');


		$host = $this->backend_params['host'];
		$user = $this->backend_params['user'];
		$password = $this->backend_params['password'];
		$selectedPhonebooks = null;
		if(!empty($this->backend_params['phonebooks'])){
			$selectedPhonebooks = array_filter(array_map('trim', explode(',', $this->backend_params['phonebooks'])), 'strlen');
		}

		if(!is_array($selectedPhonebooks) || count($selectedPhonebooks) == 0){
			$this->toLog('ERROR: Not selected phone books');
			$this->out();
		}

		$server = new \Microsoft\ExchangeServer($host, $user, $password);

		/************************************
		 * start import contacts
		 ************************************/

		try {
			$phonebooks = $server->getPhonebooks(1, 1000);
		} catch (\Exception $e) {
			$this->toLog($e->getMessage());
			$this->out();
		}


        if(!empty($phonebooks['error'])){
            $this->toLog('ERROR: '.$phonebooks['error']['message']);
            $this->out();
        }

        if(count($phonebooks) > 0){
            $phonebooks = array_filter($phonebooks, function($value=null, $key=null) use($selectedPhonebooks) {
                return in_array($value['FolderId'], $selectedPhonebooks) ? true : false;
            });
        }
        unset($selectedPhonebooks);

		foreach ($phonebooks as $phonebook){
			$this->toLog('Phonebook: '.$phonebook['Patch']);
			$count = 1000;
			$start = 0;
			do{
				try {
					$contacts = $server->getContacts($phonebook['FolderId'], $start, $count);
				} catch (\Exception $e) {
					$this->toLog($e->getMessage());
				}

				$this->toLog('Contacts: '.count($contacts['entry']));

				if(empty($contacts) || !isset($contacts['entry'])){
					$this->toLog('Contacts not found');
					break;
				}

				foreach($contacts['entry'] as $ext_entry){

					$contact = array(
							'id' => $ext_entry['id'],
							'name'=> trim($ext_entry['name']['FullName']),
							'firstName'=> trim($ext_entry['name']['FirstName']),
							'middleName'=> trim($ext_entry['name']['MiddleName']),
							'lastName'=> trim($ext_entry['name']['LastName']),
							'companyName' => $ext_entry['CompanyName'],
							'department' => $ext_entry['Department'],
							'assistantName' => $ext_entry['AssistantName'],
							'email1' => $ext_entry['email']['EmailAddress1'],
							'email2' => $ext_entry['email']['EmailAddress2'],
							'email3' => $ext_entry['email']['EmailAddress3'],
							'homePage' => $ext_entry['BusinessHomePage'],
							'phoneAssistant' => $ext_entry['phone']['AssistantPhone'],
							'phoneBusinessFax' => $ext_entry['phone']['BusinessFax'],
							'phoneBusiness' => $ext_entry['phone']['BusinessPhone'],
							'phoneBusiness2' => $ext_entry['phone']['BusinessPhone2'],
							'phoneCallback' => $ext_entry['phone']['Callback'],
							'phoneCar' => $ext_entry['phone']['CarPhone'],
							'phoneCompanyMain' => $ext_entry['phone']['CompanyMainPhone'],
							'phoneHomeFax' => $ext_entry['phone']['HomeFax'],
							'phoneHome' => $ext_entry['phone']['HomePhone'],
							'phoneHome2' => $ext_entry['phone']['HomePhone2'],
							'phoneIsdn' => $ext_entry['phone']['Isdn'],
							'phoneMobile' => $ext_entry['phone']['MobilePhone'],
							'phoneOtherFax' => $ext_entry['phone']['OtherFax'],
							'phoneOther' => $ext_entry['phone']['OtherTelephone'],
							'phonePager' => $ext_entry['phone']['Pager'],
							'phonePrimary' => $ext_entry['phone']['PrimaryPhone'],
							'phoneRadio' => $ext_entry['phone']['RadioPhone'],
							'phoneTelex' => $ext_entry['phone']['Telex'],
							'phoneTtyTdd' => $ext_entry['phone']['TtyTddPhone'],

							'addressBusiness' => $ext_entry['address']['Business']['Street'],
							'addressBusinessCity' => $ext_entry['address']['Business']['City'],
							'addressBusinessPostalCode' => $ext_entry['address']['Business']['PostalCode'],
							'addressBusinessState' => $ext_entry['address']['Business']['State'],

							'addressHome' => $ext_entry['address']['Home']['Street'],
							'addressHomeCity' => $ext_entry['address']['Home']['City'],
							'addressHomePostalCode' => $ext_entry['address']['Home']['PostalCode'],
							'addressHomeState' => $ext_entry['address']['Home']['State'],

							'addressOther' => $ext_entry['address']['Other']['Street'],
							'addressOtherCity' => $ext_entry['address']['Other']['City'],
							'addressOtherPostalCode' => $ext_entry['address']['Other']['PostalCode'],
							'addressOtherState' => $ext_entry['address']['Other']['State']
					);

					$this->fetched_records_counter++;

					$external_record = $this->external_record_empty;

					$addressKey = false;
					foreach ($this->map as $internal => $external){

						if (!empty($external)){
							$value = $this->processMappingSyntax($contact, $external, $selectedColumnName);

							if(!empty($value)){
								$value = preg_replace('/\s{2,}/', ' ', $value);
								if($internal == 'address'){
									$addressKey = $selectedColumnName;
								}
							}
							if(strtolower($internal) != 'note') {
								$value = $this->removeNewLines($value);
							}

							$external_record[$internal] = $this->normalize_value($internal, $value);
						}
					}

					/*if($addressKey){
						$external_record['city'] = preg_replace('/\s{2,}/', ' ', $contact[$addressKey.'City']);
						$external_record['postal_code'] = preg_replace('/\s{2,}/', ' ', $contact[$addressKey.'PostalCode']);
						$external_record['province'] = preg_replace('/\s{2,}/', ' ', $contact[$addressKey.'State']);
					}*/

					//$this->toLog(print_r($external_record, true));

					$this->compare_the_records($external_record);

					if (!$this->verbose && $this->fetched_records_counter % 500 == 0 ) {
						$this->progress_to_log();
					}
				}
				$start+=$count;
			}while (count($contacts['entry']) == $count);
		}
		/************************************
		 * end import contacts
		 ************************************/
	}

	function importFromOffice365(){
	    $this->toLog('Connecting to Office365 server');

	    $selectedPhonebooks = null;
	    if(!empty($this->backend_params['phonebooks'])){
	        $selectedPhonebooks = array_filter(array_map('trim', explode(',', $this->backend_params['phonebooks'])), 'strlen');
	    }

	    if(!is_array($selectedPhonebooks) || count($selectedPhonebooks) == 0){
	        $this->toLog('ERROR: Not selected phone books');
	        $this->out();
	    }

        $token = array(
                'received_token_time'=> $this->backend_params['received_token_time'],
                'access_token' => $this->backend_params['access_token'],
                'token_type' => $this->backend_params['token_type'],
                'expires_in' => $this->backend_params['expires_in'],
                'id_token' => $this->backend_params['id_token'],
        		'id_token_expires_in' => $this->backend_params['id_token_expires_in'],
        		'refresh_token' => $this->backend_params['refresh_token']
        );

        $office365 =  \Microsoft\Office365::getInstance();
        if($office365->setToken($token) != \Microsoft\Office365::TOKEN_VALID){
            $this->toLog('ERROR: Token invalid');
            $this->out();
        }

        $phonebooks = $office365->getPhonebooks(0, 1000);

        if(!empty($phonebooks['error'])){
            $this->toLog('ERROR: '.$phonebooks['error']['message']);
            $this->out();
        }

        if(count($phonebooks) > 0){
            $phonebooks = array_filter($phonebooks, function($value=null, $key=null) use($selectedPhonebooks) {
                return in_array($value['id'], $selectedPhonebooks) ? true : false;
            });
        }
        unset($selectedPhonebooks);

        /************************************
         * start import contacts
         ************************************/
        foreach ($phonebooks as $phonebook){
            $this->toLog('Phonebook: '.$phonebook['name']);
            $count = 500;  // Office 365 returns a maximum of 500 records per page
            $start = 0;
            do{
                $contacts = $office365->getContacts($phonebook['id'], $start, $count);

                if($contacts && !empty($contacts['error']) && !empty($contacts['error']['message'])){
                    $this->toLog('ERROR: '.$contacts['error']['message']);
                    break;
                }

                if(empty($contacts)){
                	if($start==0){
                		$this->toLog('Contacts not found');
                	}
                    break;
                }else{
                	$this->toLog('Contacts: '.count($contacts));
                }

                foreach($contacts as $ext_entry){

                    $contact = array(
                            'id' => $ext_entry['id'],
                            'birthday' => $ext_entry['birthday'],
                            'notes' => $ext_entry['notes'],
                            'name'=> trim($ext_entry['name']['FirstName']).' '.trim($ext_entry['name']['MiddleName']).' '.trim($ext_entry['name']['LastName']),
                    		'firstName' => $ext_entry['name']['FirstName'],
                    		'middleName' => $ext_entry['name']['MiddleName'],
                    		'lastName' => $ext_entry['name']['LastName'],
                    		'nameTitle' => $ext_entry['name']['Title'],
                    		'website' => $ext_entry['website'],
                    		'email1' => $ext_entry['email']['1'],
                    		'email2' => $ext_entry['email']['2'],
                    		'email3' => $ext_entry['email']['3'],
                    		'phoneHome1' => $ext_entry['phone']['Home1'],
                    		'phoneHome2' => $ext_entry['phone']['Home2'],
                    		'phoneBusiness1' => $ext_entry['phone']['Business1'],
                    		'phoneBusiness2' => $ext_entry['phone']['Business2'],
                    		'phoneMobile1' => $ext_entry['phone']['Mobile1'],
                    		'company' => $ext_entry['company'],
                    		'addressHome'=> trim($ext_entry['HomeAddress']['street']),
                    		'cityHome'=> trim($ext_entry['HomeAddress']['city']),
                    		'stateHome'=> trim($ext_entry['HomeAddress']['state']),
                    		'regionHome'=> trim($ext_entry['HomeAddress']['countryOrRegion']),
                    		'postcodeHome'=> trim($ext_entry['HomeAddress']['postalCode']),
                            'addressWork'=> trim($ext_entry['BusinessAddress']['street']),
                            'cityWork'=> trim($ext_entry['BusinessAddress']['city']),
                    		'stateWork'=> trim($ext_entry['BusinessAddress']['state']),
                            'regionWork'=> trim($ext_entry['BusinessAddress']['countryOrRegion']),
                    		'postcodeWork'=> trim($ext_entry['BusinessAddress']['postalCode']),
                    		'addressOther'=> trim($ext_entry['OtherAddress']['street']),
                    		'cityOther'=> trim($ext_entry['OtherAddress']['city']),
                    		'stateOther'=> trim($ext_entry['OtherAddress']['state']),
                    		'regionOther'=> trim($ext_entry['OtherAddress']['countryOrRegion']),
                    		'postcodeOther'=> trim($ext_entry['OtherAddress']['postalCode']),
                    );

                    $external_record = $this->external_record_empty;

                    $addressWork = false;
					foreach ($this->map as $internal => $external) {

						if (!empty($external)) {
							$value = $this->processMappingSyntax($contact, $external, $selectedColumnName);

							if (!empty($value)) {
								$value = preg_replace('/\s{2,}/', ' ', $value);
								if ($internal == 'address') {
									$addressWork = ($selectedColumnName == 'addressWork');
									$addressHome = ($selectedColumnName == 'addressHome');
								}
							}
							if(strtolower($internal) != 'note') {
								$value = $this->removeNewLines($value);
							}

							$external_record[$internal] = $this->normalize_value($internal, $value);
						}
					}

                    /*if($addressWork){
                        $external_record['city'] = preg_replace('/\s{2,}/', ' ', $contact['cityWork']);
                        $external_record['postal_code'] = preg_replace('/\s{2,}/', ' ', $contact['postcodeWork']);
                        $external_record['province'] = preg_replace('/\s{2,}/', ' ', $contact['regionWork']);
                    }else if($addressHome){
                    	$external_record['city'] = preg_replace('/\s{2,}/', ' ', $contact['cityHome']);
                        $external_record['postal_code'] = preg_replace('/\s{2,}/', ' ', $contact['postcodeHome']);
                        $external_record['province'] = preg_replace('/\s{2,}/', ' ', $contact['regionHome']);
                    }else{
                    	$external_record['city'] = preg_replace('/\s{2,}/', ' ', $contact['cityOther']);
                    	$external_record['postal_code'] = preg_replace('/\s{2,}/', ' ', $contact['postcodeOther']);
                    	$external_record['province'] = preg_replace('/\s{2,}/', ' ', $contact['regionOther']);
                    }*/

                    if(!empty($contact['birthday'])){
                        $birthday = new \DateTime($contact['birthday']);
                        if($birthday !== false){
                            $external_record['date_birth'] = $birthday->format('m/d/Y');
                        }
                    }
                    $this->compare_the_records($external_record);
                }
                $start+=$count;
			/**
			 * WMS-4703 - Api graph.microsoft.com sometime may return not all records requested in $top parameter
			 * that is why we try while api give empty response
			 */
			}while (count($contacts)>0);
        }
        /************************************
         * end import contacts
        ************************************/
	}

	function normalize_value($key, $value){		//
		if (in_array($key,array('phone', 'fax', 'mobile', 'extension', 'office', 'home', 'home_mobile'))){
			return $this->_phoneNormalizer->normalize($this->utils_filter_the_number($value), $key === 'extension' ? 7 : 6 ,true);
		}elseif($value && mb_detect_encoding($value.' ') != 'UTF-8'){
            //During mb_detect_encoding we add space to the end of string because result will wrong if multibite symbol at the end of string!
			return mb_convert_encoding($value, "UTF-8");
		}
		return $value;
	}

	function utils_filter_the_number($number) {
		return preg_replace('/[^\+0-9a-zA-Z]/', '', $number);
	}

	function removeNewLines($value) {
        return trim(preg_replace('/\s+/', ' ', $value));
    }

	function compare_the_records($external_record) {
		// have $external_record
		if (empty($external_record)) {
			return false;
		}elseif (!isset($external_record['username']) || $external_record['username'] == ''){
			$this->toLog('WARNING: Attribute "'.$this->_g_attrs_translation['username'].'" is not present for the record with value(s) "'.implode('","',$external_record).'". User is not added.');
			return false;
		} elseif (mb_strlen($external_record['username'], 'UTF-8') < \Wildix\Phonebooks\Contact::NAME_MIN_LENGTH) {
            $msg = 'WARNING: Attribute "%s" is not valid (min %d symbol) for the record with value(s) "%s". User is not added.';
            $this->toLog(sprintf($msg, $this->_g_attrs_translation['username'], \Wildix\Phonebooks\Contact::NAME_MIN_LENGTH, implode('","',$external_record)));
            return false;
        }

        $external_record = $this->normalizeRecordData($external_record);

		$count_records = count($this->records);

		for($i = 0; $i < $count_records; $i++){
			if (! $external_record['source_id'] && $this->records[$i]['username'] == $external_record['username']){
				$this->toLog('WARNING: Duplicated name received: "'.$external_record['username'].'"');
				return false;
			}elseif($this->records[$i]['source_id'] == $external_record['source_id']){
				$this->toLog('WARNING: Duplicated ID received: "'.$external_record['source_id'].'"');
				return false;
			}elseif(!empty($this->records[$i]['shortcut']) && $this->records[$i]['shortcut'] == $external_record['shortcut']) {
				$this->toLog('WARNING: Shortcut ' . $external_record['shortcut'] . ' already exists. ID received: "' . $this->records[$i]['source_id'] . '"');
				$external_record['shortcut'] = "";
			}
		}

		if ($this->verbose) {
			$t_log_str = 'Contact "'.$external_record['username'].'". Wrong data. ';
		}

		$external_record = $this->validate_input_record($external_record, $t_log_str);// ---------------------------------------------

		if (empty($external_record) OR count($external_record) < 1){
			$this->toLog($t_log_str);
			$this->g_summary['added_with_err']++;
			return false;
		}

		$this->records[] = $external_record;

		if($count_records + 1 ==  $this->_count_flush){
			$this->flushContacts();
		}

		return true;
	}

    private function normalizeRecordData(array $data) {
        foreach ($data as $_key => &$_item) {
            switch ($_key) {
                case \Wildix\Phonebooks\Contact::NOTE:
                    // remove all control chars except LF(line feed), CR(carriage return)
                    $_item = preg_replace('/[\x{0}-\x{9}\x{0B}\x{0C}\x{0E}-\x{1F}]/', ' ', $_item);
                    break;
                default:
                    $_item = preg_replace('/[\x{0}-\x{1F}]/', ' ', $_item);
                    break;
            }
        }

        return $data;
    }

	function flushContacts(){

		$count_records = count($this->records);
		if( ! $count_records){
			return true;
		}

        $query = [];

        $oldContactWhere = " WHERE `source_id` LIKE ('http://www.google.com/m8/feeds/contacts%') AND phonebook_id=" . $this->phonebook['id'];
        $res = $this->phonebooks_class->db->getAll(sprintf('SELECT count(*) as cnt FROM `%s` %s', $this->phonebooks_class->contacts_table , $oldContactWhere));
        $oldCount = $res[0]['cnt'] ?? 0;
        $this->g_summary['removed'] = $oldCount;
        if ($oldCount) {
            $query[] = 'DELETE FROM `' . $this->phonebooks_class->contacts_table . '` ' . $oldContactWhere;
        }

		$users_source = array();
		$users_name = array();
		$users_shortcut = array();

		for($i = 0; $i < $count_records; $i++){
			if($this->records[$i]['source_id']){
				$users_source[] = SQLite3::escapeString($this->records[$i]['source_id']);
			}else{
				$users_name[] = SQLite3::escapeString($this->records[$i]['username']);
			}

			if($this->records[$i]['shortcut']){
				$users_shortcut[] = $this->records[$i]['shortcut'];
			}
		}
		if(count($users_source)){
			$where[] = "`source_id` IN ('" . implode("','", $users_source) . "')";
		}
		if(count($users_name)){
			$where[] = "(`username` IN ('" . implode("','", $users_name) . "') AND (`source_id` = ''))";
		}

		$users_source = array();
		$users_name = array();
		$t = microtime(1);
		$SQL = 'SELECT `rid`, `username`, `source_id` FROM `' . $this->phonebooks_class->contacts_table . '` WHERE phonebook_id="'.$this->phonebook['id'].'" AND (' . implode(' OR ', $where) . ');';
		$res = $this->phonebooks_class->db->query($SQL);
        while ($tmp = $res->fetchRow(DB_FETCHMODE_ASSOC)) {
        	if(!empty($tmp['source_id'])){
				$users_source[$tmp['source_id']] = $tmp['rid'];
			}else{
				$users_name[$tmp['username']] = $tmp['rid'];
			}
        }

        $where = array();
		if(count($users_shortcut)){
			$users_shortcut = array();
			$SQL = 'SELECT  `username`, `source_id`, `shortcut` FROM `' . $this->phonebooks_class->contacts_table . '` WHERE phonebook_id="'.$this->phonebook['id'].'" AND `shortcut` IN ("' . implode('","', $users_shortcut) . '");';
			$res = $this->phonebooks_class->db->query($SQL);
	        while ($tmp = $res->fetchRow(DB_FETCHMODE_ASSOC)) {
				if(!empty($tmp['shortcut'])){
					$users_shortcut[$tmp['shortcut']] = (!empty($tmp['source_id'])) ? $tmp['source_id'] : $tmp['username'];
				}
	        }
		}

        if (is_object($res)) {
            $res->free();
        }

        for($i = 0; $i < $count_records; $i++){
        	$external_record = $this->records[$i];

	        $t_log_str = '';
			if ($this->verbose) {
				$t_log_str = 'Contact "'.$external_record['username'].'". ';
			}
	        if (isset($users_name[$external_record['username']]) || isset($users_source[$external_record['source_id']])){

				if ($this->verbose) {
					$t_lang_change_attrs = array();
					foreach ($external_record as $t_attr_key => $val){
						$t_lang_change_attrs[$t_attr_key] = $this->_g_attrs_translation[$t_attr_key];
					}
					$t_log_str .= ' Updating attribute(s) "'.implode('", "',$t_lang_change_attrs).'" with value(s) "'.implode('", "',$external_record).'".';
					unset($t_lang_change_attrs);
					$this->toLog($t_log_str);
				} elseif ($t_log_str != '') {
					$t_log_str = 'User "'.$external_record['username'].'".' . $t_log_str;
					$this->toLog($t_log_str);
				}

				if(isset($users_source[$external_record['source_id']])){
					$rid = $users_source[$external_record['source_id']];
				}else{
					$rid = $users_name[$external_record['username']];
				}

				$external_record['phonebook_id'] = $this->phonebook['id'];
				$external_record['hash'] = '';

				$set = array();
				foreach ($external_record as $par_key => $par_value){
					if($par_key != 'rid'){
						$set[] .= "`".$par_key."`='".SQLite3::escapeString($par_value)."'";
					}
		        }
				$query[] = 'UPDATE `'.$this->phonebooks_class->contacts_table.'` SET '. implode(',', $set) ." WHERE rid='".$rid."';";

				$this->g_summary['updated']++;

			}else{

				if ($this->verbose) {
					$t_lang_change_attrs = array();
					foreach (array_keys($external_record) as $t_attr_key) $t_lang_change_attrs[$t_attr_key] = $this->_g_attrs_translation[$t_attr_key];
					$t_log_str .= ' Adding attribute(s) "'.implode('", "',$t_lang_change_attrs).'" with value(s) "'.implode('", "',$external_record).'".';
					unset($t_lang_change_attrs);
					$this->toLog($t_log_str);
				} else if ($t_log_str != '') {
					$t_log_str = 'Contact "'.$external_record['username'].'" is not present.' . $t_log_str;
					$this->toLog($t_log_str);
				}

				$external_record['phonebook_id'] = $this->phonebook['id'];
				$external_record['country'] = $this->_g_country;

				foreach(array_diff_key($this->_g_attrs_translation, $external_record) as $key=>$val){
					$external_record[$key] = '';
				}

				foreach ($external_record as $par_key => $par_value){
		            $external_record[$par_key] = SQLite3::escapeString($par_value);
		        }
				$query[] =  "INSERT INTO `".$this->phonebooks_class->contacts_table."` (`".implode("`, `",array_keys($external_record))."`) VALUES ('" . implode("', '", array_values($external_record)) . "');";

				$this->g_summary['added']++;
			}
        }

		if (!$this->dry_run){
			sqlite3FastManip($query, $this->phonebooks_class->db);
		}

		if (!$this->verbose) {
            $this->progress_to_log();
        }

		$this->records = array();
	}

	function validate_input_record($external_record, &$to_log_str){

		// username attr is present every time : checked before
	    // fixme: right validation for username
	    //$checkField_username = '/^[0-9a-z\-_,\' ]{2,50}\z/i';
	    $checkFields = array(
	        'phone'       => '/^([\+]?[0-9\*\#]{2,50}\z)?/',
	    	'office'      => '/^([\+]?[0-9\*\#]{2,50}\z)?/',
		    'home'        => '/^([\+]?[0-9\*\#]{2,50}\z)?/',
		    'extension'   => '/^([\+]?[0-9\*\#]{2,50}\z)?/',
		    'home_mobile' => '/^([\+]?[0-9\*\#]{2,50}\z)?/',
	        'fax'         => '/^([\+]?[0-9\*\#]{2,50}\z)?/',
	        'email'       => '/^([^\W].*\@.*\.[a-z]{2,4}\z)?/i',
	        'mobile'      => '/^([\+]?[0-9\*\#]{2,50}\z)?/'
	    );

	    if (isset($external_record['username']) && trim($external_record['username']) == ''){
	        $to_log_str .= ' WARNING: Attribute "'.$this->_g_attrs_translation['username'].'" is not valid.';
	        return false;
	    }

	    foreach ($checkFields as $attr => $pattern){
	        if (isset($external_record[$attr]) && !preg_match($pattern,$external_record[$attr])){
	            $to_log_str .= ' WARNING: Attribute "'.$this->_g_attrs_translation[$attr].'" with value "'.$external_record[$attr].'" is not valid.';
	            unset($external_record[$attr]);
	        }
	    }

		unset($checkFields);
		return $external_record;
	}

	/**
	 * Find value for the provided $sourceColumnName in a $sourceRow with ability to use special syntax
	 * @param $sourceRow - imported row
	 * @param $sourceColumnName - Column name from imported backend, can contain special syntax with + and |
	 * @param string &$selectedColumnName - used when OR syntax going on
	 * @param array $sourceHeaders - appliable for csv, when col name have to be calculated by its position
	 * @return null|string - returns value for the provided coulumn name or null if $sourceColumnName was not found
	 */
	private function processMappingSyntax($sourceRow, $sourceColumnName, &$selectedColumnName, $sourceHeaders = array()){
		$result = null;
		$processOr = true;
		$processConcat = true;
		$selectedColumnName = null;

		//Appliable for csv
		foreach ($sourceHeaders as $sourceHeaderPos => $sourceHeaderName) {
			if (isset($sourceRow[$sourceHeaderPos])) {
				$sourceRow[$sourceHeaderName] = trim($sourceRow[$sourceHeaderPos]);
			}
		}

		//if no special syntax symbols then just return value
		if ($sourceColumnName && strpos($sourceColumnName, '+')===false && strpos($sourceColumnName, '|')===false ){
			if (isset($sourceRow[$sourceColumnName])){
				$result = trim($sourceRow[$sourceColumnName]);
			}
			return $result;
		}

		//Split for OR syntax
		$executionStack =
			$processOr?explode('|',$sourceColumnName):array($sourceColumnName);

		//Split for CONCAT syntax
		foreach($executionStack as $keyOr => $columnNameOr){
			$executionStack[$keyOr] =
				$processConcat?explode('+',$columnNameOr):array($columnNameOr);

			$result = "";
			foreach($executionStack[$keyOr] as $keyConcat=>$columnNameConcat){
				$columnNameConcat = trim($columnNameConcat);
				if (array_search(preg_replace('/\s+/', ' ',$columnNameConcat), array("' '",'" "')) ){
					$result .= ' ';
				} else if (isset($sourceRow[$columnNameConcat])){
					if (!empty($result) && substr($result, -1) != ' ')
						$result .= ' ';
					$result .= $sourceRow[$columnNameConcat];

					if (trim($sourceRow[$columnNameConcat])){
						//Selected column name used for applying city, postal code , so here just do not loose important column name
						if (!array_search( $selectedColumnName, array('addressHome','addressWork', 'addressBusiness', 'addressOther')))
							$selectedColumnName = $columnNameConcat;
					}
				}
			}
			$result = trim($result);
			if (!empty($result)){
				break;
			}
		}

		return $result;
	}

	function out() {
		$this->toLog("No change was provided.");
		$this->sendMail();
		$this->phonebooks_class->close();
		exit(1);
	}

	function sendMail(){
		if (trim($this->send_email) != '') {
			$this->toLog('Sending feedback email to '.$this->send_email);
			exec('export HOME=\'/tmp/\';[ -f /tmp/sent ]&&rm -f /tmp/sent{,.lock}; sudo /usr/sbin/syslog_grep \'phonebook_'.$this->phonebook['id'].'_sync3 #'.$this->log_id.'\' | sed \'s/ phonebook_'.$this->phonebook['id'].'_sync3 #'.$this->log_id.'//\' ', $output);
			$mailBody = implode(PHP_EOL, $output);
			$params = array(
			    'body' => $mailBody,
			    'to' => $this->send_email,
			    'subject' => \Models\PBX::getInstance()->getDomain(). ' phonebook \''.$this->phonebook['name'].'\' import report'
			);
			Notification::sendEmail($params);
		}
	}

	function remove_local_entries(){

		$SQL = "SELECT COUNT(*) as count FROM `" . $this->phonebooks_class->contacts_table . "` WHERE phonebook_id='".$this->phonebook['id']."'  ".((!$this->dry_run)?"AND `last_update` < '" . $this->time_start . "'":"").";";

		$res = $this->phonebooks_class->db->query($SQL);
        $tmp = $res->fetchRow(DB_FETCHMODE_ASSOC);

        if($tmp['count']){
        	if(!$this->dry_run){
        		$SQL = "DELETE FROM `" . $this->phonebooks_class->contacts_table . "` WHERE phonebook_id='".$this->phonebook['id']."' AND `last_update` < '" . $this->time_start . "';";
        		$res = $this->phonebooks_class->db->connection->exec($SQL);
        		$this->g_summary['removed'] = $tmp['count'];
        	}else{
        		$this->g_summary['removed'] = $tmp['count'] - $this->g_summary['updated'];
        	}

        }
        return true;
	}

	function progress_to_log($summary=false){
		$prefix_message = 'Progress';
		if ($summary) {
			$prefix_message = 'Summary';
		}
		$this->toLog($prefix_message.': '.$this->g_summary['added'].' added'.($this->g_summary['added_with_err']>0?' ('.$this->g_summary['added_with_err'].' with warning)':' ').', '.$this->g_summary['updated'].' updated'.($this->g_summary['updated_with_err']>0?' ('.$this->g_summary['updated_with_err'].' with warning)':' ').', '.$this->g_summary['removed'].' removed.');
	}

	function toLog($message, $type = LOG_INFO) {
		if(is_string($message)){
			openlog('phonebook_'.$this->phonebook['id'].'_sync3 #'.$this->log_id, LOG_ODELAY, LOG_LOCAL2);
			$m = explode("\n", $message);
			if(is_array($m) && count($m) > 0){
				foreach ($m as $line){
					syslog($type, $line);
				}
			}
			closelog();
		}
	}
}
