<?php

use Wildix\Colleagues\Colleagues;
use Wildix\Core\Notification;
use Wildix\UserDataCleaner;
use Wildix\UserDataCleaner\Factories\UserDataFactory;

class WmsUsersImport {

	var $aclpbx_class = false;
	var $dry_run = false;
	var $verbose = false;
	var $g_summary = array();
	var $send_email = '';
	var $remove_user = false;
	var $backend_params = array();
	var $map = array();
	var $g_allow_erase_values_arr = array();
	var $_g_attrs_translation = array();
	var $_g_d_vars = array();
	var $_g_mail_array = array();
	var $_g_validators_array = array();
	var $_g_groups_array = array();
	var $_g_default_values = array();
	var $_g_extenNumbers_array = array();
	var $_g_mobileNumbers_array = array();
	var $_g_login_array = array();
	var $local_ldap_entries = array();
	var $fetched_records_counter = 0;

	var $log_id = 0;

	private $_validator;

    /**
     * @var \Services\LuaService
     */
	private $_luaService;

    /**
     * @var WMS_Ldap
     */
	private $_wmsLdap;


	function __construct($got_params=false) {

		$this->_validator = new \Wildix\Validator();
		$this->_validator->rule('email', ['email']);

		$this->time = microtime(1);

		$this->aclpbx_class = new aclpbx();

		if ($got_params) {
			$this->dry_run = isset($got_params['dry_run']) && $got_params['dry_run'] == 'yes';
			$this->verbose = isset($got_params['verbose']) && $got_params['verbose'] == 'yes';

			$this->backend_params = $got_params['settings'];
			$this->map = $got_params['map'];

			$this->log_id = $got_params['syncid'];

		}else{
			$this->log_id = rand(10000,99999);

			$got_params = $this->aclpbx_class->get_sync_settings_n_map();
			//$this->toLog(print_r($got_params));
			$this->send_email = $got_params['recurrent_job']['email'];

			if (!in_array($got_params['global']['backend'],array('ldap','activeD','domino','mysql','mssql','office365', 'zohoCrm', 'google','csv'))){
				$this->toLog('ERROR: Cannot use '.$got_params['global']['backend']. ' backend for recurrent synchronization.');
				$this->out();
			}

			$this->backend_params = $got_params['settings'][$got_params['global']['backend']];
			$this->backend_params['backend'] = $got_params['global']['backend'];
			$this->map = $got_params['map'][$this->backend_params['backend']];

			if ($this->backend_params['backend'] == 'csv' && $this->backend_params['import_type'] == 'upload'){
				$this->toLog('ERROR: Cannot use CSV Upload for recurrent synchronization.');
				$this->out();
			}
		}

		// For BC
        if (!isset($this->map['sourceId']) || $this->map['sourceId'] === '') {
            $this->map['sourceId'] = $this->map['cn'];
        }

		$this->toLog('Beginning syncronization.');

		$this->g_summary = array(
			'added' => 0,
			'updated' => 0,
			'removed' => 0,
			'added_with_err' => 0,
			'updated_with_err' => 0,
			'moved' => 0,
            'addedUsers' => [],
            'updatedUsers' => [],
            'removedUsers' => [],
            'movedUsers' => [],
		);

		if ($got_params['global']['erase_values'] == 'yes'){
			$this->g_allow_erase_values_arr = array('facsimileTelephoneNumber'=> '', 'officeNumber'=>'', 'mail'=>'', 'mobile'=>'', 'ou'=>'', 'imageUrl'=>'');
		}

		if($got_params['global']['remove_users'] == 'yes'){
			$this->remove_user = true;
		}

		unset($param, $got_params);
		$multipbx_class = new multipbx();
		if ($multipbx_class->get_mode() == '1'){
			$this->toLog('ERROR: Cannot perform synchronization on a Client PBX.');
			if ($this->backend_params['backend'] == 'csv' && $this->backend_params['import_type'] == 'upload') {
				unlink($this->backend_params['filename']);
			}
			$this->out();
		}

		if ($this->dry_run) {
			$this->toLog('DRY-RUN mode'.(($this->verbose)?' with additional verbose':'').'.');
		}

		$this->_g_attrs_translation = $this->aclpbx_class->get_sync_attributes_translation();
		$this->_g_d_vars = WMS_Utils_get_normalization_variables();

		$this->_g_validators_array = array(
			'userKind' => $this->aclpbx_class->select_userKind(),
			'preferredLanguage' => $this->aclpbx_class->select_preferredLanguage(),
			'userDialplan' => array_keys(get_contextnames())
		);
		$this->_g_validators_array['userFaxDialplan'] = $this->_g_validators_array['userDialplan'];

		$this->_g_groups_array = $this->aclpbx_class->get_groups_assoc();

		$this->_g_default_values = array(
			'userKind' => 'user',
			'preferredLanguage' => 'it',
		);

		if ($sipRtpLanguage = \Wildix\SipRtp::getInstance()->getGeneralSip(\Wildix\SipRtp::LANGUAGE)){
			//WMS-4551: Default val for preferedLanguage impossible detect for some country codes
			//sip rtp language will be default if country code doesn't give language
			//Note: preferredLanguage 'en-us' has analog in sip rtp language named 'us', rest is identical!
			if ($sipRtpLanguage == 'us'){
				$this->_g_default_values['preferredLanguage'] = 'en-us';
			} else {
				$this->_g_default_values['preferredLanguage'] = $sipRtpLanguage;
			}
		}

		if($this->_g_d_vars['GCOUNTRY_CODE']){
		    switch ($this->_g_d_vars['GCOUNTRY_CODE']){
		        case '39': $this->_g_default_values['preferredLanguage'] = 'it';
		            break;
		        case '33': $this->_g_default_values['preferredLanguage'] = 'fr';
		            break;
		        case '49': $this->_g_default_values['preferredLanguage'] = 'de';
		            break;
		        case '7': $this->_g_default_values['preferredLanguage'] = 'ru';
		            break;
		        case '359': $this->_g_default_values['preferredLanguage'] = 'bg';
		            break;
		        case '34': $this->_g_default_values['preferredLanguage'] = 'es';
		            break;
		        case '31': $this->_g_default_values['preferredLanguage'] = 'nl';
		            break;
		        case '380': $this->_g_default_values['preferredLanguage'] = 'en';
		            break;
		        case '372': $this->_g_default_values['preferredLanguage'] = 'ee';
		            break;
				case '1': $this->_g_default_values['preferredLanguage'] = 'en-us';
		            break;
		    }
		}

		if (in_array('users', $this->_g_validators_array['userDialplan'])){
			$this->_g_default_values['userDialplan'] = 'users';
			$this->_g_default_values['userFaxDialplan'] = 'users';
		}elseif (sizeof($this->_g_validators_array['userDialplan']) > 0){
			$this->_g_default_values['userDialplan'] = reset($this->_g_validators_array['userDialplan']); // return the value of the first element
			$this->_g_default_values['userFaxDialplan'] = $this->_g_default_values['userDialplan'];
		}
		if (sizeof($this->_g_groups_array) > 0) $this->_g_default_values['owner'] = reset($this->_g_groups_array); // return the value of the first element

		$arr = array_keys($this->map);
		if( ! $this->map['userKind']){
			$arr[] = 'userKind';
		}
		$this->get_local_ldap_entries($arr);
	}

	function get_local_ldap_entries($attrs) {

		$pageSize = 500;

		$attrs[] = 'dn';
		$attrs[] = 'uid';
		$attrs[] = LDAP_EXTEN_NUMBER;
		$attrs[] = LDAP_OFFICE_NUMBER;
		$attrs[] = 'mobile';
		$attrs[] = 'mail';
		$attrs[] = 'sourceId';

		$filter = "(&(objectClass=".(WMS_Ldap::PERSONS)."))";

		$entries = WMS_Ldap::getInstance()->getEntriesPaged($filter, $attrs, $pageSize);

		foreach ($entries as $key=>$user) {

			$user['extenNumber'] = $user[LDAP_EXTEN_NUMBER];
			unset($user[LDAP_EXTEN_NUMBER]);
			$user['officeNumber'] = $user[LDAP_OFFICE_NUMBER];
			unset($user[LDAP_OFFICE_NUMBER]);

			if (isset($user['owner']) && isset($this->_g_groups_array[$user['owner']])) {
				$user['owner'] = $this->_g_groups_array[$user['owner']];
			}

			// cn for BC
			$userSourceId = $user['sourceId'] ?? $user['cn'];
			if ($user['extenNumber']) {
				$this->_g_extenNumbers_array[$user['extenNumber']] = $userSourceId;
			}
			if ($user['userPrincipalName']) {
				$this->_g_login_array[$user['userPrincipalName']] = $userSourceId;
			}
			if ($user['mobile']) {
				$this->_g_mobileNumbers_array[$user['mobile']] = $userSourceId;
			}
			if ($user['mail']) {
				$this->_g_mail_array[$user['mail']] = $userSourceId;
			}

            // LINK between local user and external user
            $this->local_ldap_entries[$userSourceId] = $user;
            unset($entries[$key]);
		}
		unset($entries,$user);

		return true;
	}

	function import(){
		if ($this->backend_params['backend'] == 'ldap'){
			$this->importFromLdap();
		}elseif ($this->backend_params['backend'] == 'activeD'){
			$this->importFromLdap();
		}elseif ($this->backend_params['backend'] == 'domino'){
            $this->importFromLdap(true);
        }elseif ($this->backend_params['backend'] == 'mysql'){
			$this->importFromMySql();
		}elseif ($this->backend_params['backend'] == 'mssql'){
			$this->importFromMsSql();
		}elseif ($this->backend_params['backend'] == 'csv'){
			$this->importFromCsv();
		}elseif ($this->backend_params['backend'] == 'google'){
			$this->importFromGoogle();
		}elseif ($this->backend_params['backend'] == 'office365'){
			$this->importFromOffice365();
		}elseif ($this->backend_params['backend'] == 'zohoCrm'){
			$this->importFromZohoCRM();
			$this->_syncToPhoneBridge();
		}

		unset($this->_g_extenNumbers_array);
		unset($this->_g_login_array);
		unset($this->_g_mobileNumbers_array);

		if ($this->remove_user){
			$this->remove_local_entries();
		}

        // remove global roster cache file
        if (file_exists($filename = '/dev/shm/groster.lua')) {
            unlink($filename);
        }

        if (!$this->dry_run) {
            exec('exec /usr/sbin/cleanup_avatar_cache.php > /dev/null &');
        }

		$this->progress_to_log( true);

		$this->toLog('The operation is completed.');
		$this->sendMail();
		//$this->toLog("Peak memory:".memory_get_peak_usage());
		//$this->toLog("Time:".(microtime(1)-$this->time));
	}

	function importFromLdap($isDomino=false){

		$ldapConnector = new Wildix\Ldap\Connector(
			$this->backend_params['host'],
			$this->backend_params['port'],
			filter_var($this->backend_params['secure'],FILTER_VALIDATE_BOOLEAN),
			$this->backend_params['user'],
			$this->backend_params['password']
		);

		$this->toLog('Connecting to server '. $ldapConnector->getConnectString() );
        try{
			$external_ldap_dbh = $ldapConnector->getConnection();
		} catch (\Exception $e){
			$this->toLog('ERROR: '.$e->getMessage());
			$this->out();
		}


		$this->toLog('Performing the search with the filter: '.$this->backend_params['filter']);


		$cookie = '';
		$pageSize = 200;
		$attributes = array_map('trim',preg_split("/\||,|\+/",implode(',',$this->map)));
		$filter = '(&'.$this->backend_params['filter'].')';

		do {
			$searchResult = ldap_search(
                $external_ldap_dbh,
                $this->backend_params['basedn'],
                $filter,
                $attributes,
                0,
                0,
                2,
                LDAP_DEREF_NEVER,
                [
                    [
                        'oid' => LDAP_CONTROL_PAGEDRESULTS,
                        'size' => $pageSize,
                        'cookie' => $cookie
                    ],
                ]
            );

            if (!is_resource($searchResult)) {
				return $this->toLog('ERROR: '.ldap_error($external_ldap_dbh));
			}

            $ldapSearchErrno = ldap_errno($external_ldap_dbh);
            if ($ldapSearchErrno !== 0) {
                return $this->toLog('ERROR: ' . ldap_err2str($ldapSearchErrno));
            }

			$entryID=ldap_first_entry($external_ldap_dbh,$searchResult);

			do {
				$this->fetched_records_counter++;
                $external_record = $this->getErasedFields();
				$ext_attrs = ldap_get_attributes( $external_ldap_dbh, $entryID );
				//Normalize to appliable for processMappingSyntax function
				$sourceRow = array();
				for ($i=0; $i < $ext_attrs["count"]; $i++) {
					if ( $ext_attrs[ $ext_attrs[$i] ] ){
						$sourceRow[ $ext_attrs[$i] ] = trim($ext_attrs[ $ext_attrs[$i] ][0]);
					}
				}

				foreach($this->map as $key=>$val){
					$ext_value =   $this->processMappingSyntax($sourceRow,$val,$selectedColumnName);
					if ($ext_value == '' && ! array_key_exists($key,$this->g_allow_erase_values_arr)) continue;
					if (in_array($key,array('officeNumber', 'mobile', 'facsimileTelephoneNumber'))){
						$ext_value = WMS_Utils_normalize_the_number(WMS_Utils_filter_the_number_e164($ext_value),$this->_g_d_vars['GINTERNATIONAL_PREFIX'],$this->_g_d_vars['GNATIONAL_PREFIX'],$this->_g_d_vars['GCOUNTRY_CODE']);
					}
					$external_record[$key] = $ext_value;

				}

                $externalSourceId = $external_record['sourceId'];
				if(!trim($this->map['extenNumber'])){
					if(!empty($this->local_ldap_entries[$externalSourceId]) && !empty($this->local_ldap_entries[$externalSourceId]['extenNumber'])){
						$external_record['extenNumber'] = $this->local_ldap_entries[$externalSourceId]['extenNumber'];
					}else{
						$external_record['extenNumber'] = $this->getNewPhone();
					}
				}

				// have $external_record
				if ($this->local_ldap_entries[$externalSourceId] && $this->local_ldap_entries[$externalSourceId]['update']){
					$this->toLog('WARNING: Duplicated ID received: "'.$externalSourceId.'"');
				}else{
					$this->compare_the_records($external_record);
				}

			}while ($entryID = ldap_next_entry($external_ldap_dbh,$entryID));

			unset($ext_attrs,$entryID);
			ldap_free_result($searchResult);

			if($ldapSearchErrno != 0) {
				$this->toLog('ERROR: '.ldap_err2str($ldapSearchErrno));
				break;
			}

		} while($cookie !== null && $cookie != '');


		unset($cookie);
		ldap_close($external_ldap_dbh);
	}

	function importFromMySql(){
		if (!isset($this->backend_params['port']) || $this->backend_params['port'] == ''){
			$t_connect_str = 'mysql:dbname='.$this->backend_params['database'].';host='.$this->backend_params['host'];
		}else{
			$t_connect_str = 'mysql:dbname='.$this->backend_params['database'].';host='.$this->backend_params['host'].';port='.$this->backend_params['port'];
		}

		if (isset($this->backend_params['timeout']) && is_numeric($this->backend_params['timeout'])) {
		    $timeout = $this->backend_params['timeout'];
        } else {
		    $timeout = 10;
        }

		$this->toLog('Connecting to MySQL server '. $t_connect_str. ' (Timeout: '.$this->backend_params['timeout'].'s)');

        try {
            $external_mysql_dbh = new \PDO($t_connect_str, $this->backend_params['user'], $this->backend_params['password'], array(
                PDO::ATTR_TIMEOUT => $timeout,
                PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION
            ));
        } catch (\PDOException $exception) {
            $this->toLog('ERROR: '.$exception->getMessage());
            $this->out();
        }

		unset($t_connect_str);

		$dbcolumns = array_map('trim',preg_split("/\||,|\+/",implode(',',$this->map)));
		$this->backend_params['filter'] = str_replace('${MAP}','`'.implode('`, `',$dbcolumns).'`',$this->backend_params['filter']);

		$this->toLog('Performing the search with the query: '.$this->backend_params['filter']);

		try {
            $search_res = $external_mysql_dbh->query($this->backend_params['filter']);
        } catch (\PDOException $exception) {
            $this->toLog('ERROR: ' . $exception->getMessage());
            $this->out();
        }


        if ($search_res === false) {
            $e = $external_mysql_dbh->errorInfo();
            $this->toLog('ERROR: '.$e[2]);
            $this->out();
        }

		foreach ($search_res as $ext_entry) {
			$this->fetched_records_counter++;
            $external_record = $this->getErasedFields();

			foreach ($this->map as $internal => $external){
				if ($external != ''){
					$external_val = $this->processMappingSyntax($ext_entry, $external, $selectedColumnName);
					if ($external_val == '')
						continue;
					if ($external_val == '' && ! array_key_exists($internal,$this->g_allow_erase_values_arr)) continue;
					// normalize 'officeNumber', 'mobile', 'facsimileTelephoneNumber'
					if (in_array($internal,array('officeNumber', 'mobile', 'facsimileTelephoneNumber'))){
						$external_val = WMS_Utils_normalize_the_number(WMS_Utils_filter_the_number_e164($external_val),$this->_g_d_vars['GINTERNATIONAL_PREFIX'],$this->_g_d_vars['GNATIONAL_PREFIX'],$this->_g_d_vars['GCOUNTRY_CODE']);
					}
					$external_record[$internal] = $external_val;
				}
			}

			// have $external_record
            $externalSourceId = $external_record['sourceId'];
			if ($this->local_ldap_entries[$externalSourceId] && $this->local_ldap_entries[$externalSourceId]['update']){
				$this->toLog('WARNING: Duplicated ID received: "'.$externalSourceId.'"');
			}else{
				$this->compare_the_records($external_record);
			}

			if ( ! $this->verbose && $this->fetched_records_counter % 500 == 0 ) {
				$this->progress_to_log();
			}
		}

		unset($search_res,$external_record, $internal, $external, $ext_entry, $external_mysql_dbh);

	}

	function importFromMsSql(){

		if (!isset($this->backend_params['port']) || $this->backend_params['port'] == ''){
			$t_connect_str = 'dblib:host='.$this->backend_params['host'].';dbname='.$this->backend_params['database'];
		}else{
			$t_connect_str = 'dblib:host='.$this->backend_params['host'].':'.$this->backend_params['port'].';dbname='.$this->backend_params['database'];
		}

		if (!isset($this->backend_params['timeout']) || !$this->backend_params['timeout'] || $this->backend_params['timeout'] <= 5){
			$this->backend_params['timeout'] = ini_get('mssql.connect_timeout') ?: 10;
		}
		ini_set('mssql.connect_timeout', $this->backend_params['timeout']);

		$this->toLog('Connecting to MSSQL server '. $t_connect_str. ' (Timeout: '.$this->backend_params['timeout'].'s)');

        try {
		    $external_mssql_dbh = new PDO($t_connect_str, $this->backend_params['user'], $this->backend_params['password']);
        } catch (\PDOException $exception) {
            $this->toLog('ERROR: '.$exception->getMessage());
            $this->out();
        }

		$dbcolumns = array_map('trim',preg_split("/\||,|\+/",implode(',',$this->map)));
		$this->backend_params['filter'] = str_replace('${MAP}','['.implode('], [',$dbcolumns).']',$this->backend_params['filter']);

		$this->toLog('Performing the search with the query: '.$this->backend_params['filter']);

        try {
		    $search_res = $external_mssql_dbh->query($this->backend_params['filter']);
        } catch (\PDOException $exception) {
            $this->toLog('ERROR: ' . $exception->getMessage());
            $this->out();
        }

        if ($search_res === false) {
            $e = $external_mssql_dbh->errorInfo();
            $this->toLog('ERROR: '.$e[2]);
            $this->out();
        }

        foreach ($search_res as $ext_entry) {
            $this->fetched_records_counter++;
            $external_record = $this->getErasedFields();

            foreach ($this->map as $internal => $external){
                if ($external != ''){
                    $external_val = $this->processMappingSyntax($ext_entry, $external, $selectedColumnName);
                    if ($external_val == '')
                        continue;
                    if ($external_val == '' && ! array_key_exists($internal,$this->g_allow_erase_values_arr)) continue;
                    // normalize 'officeNumber', 'mobile', 'facsimileTelephoneNumber'
                    if (in_array($internal,array('officeNumber', 'mobile', 'facsimileTelephoneNumber'))){
                        $external_val = WMS_Utils_normalize_the_number(WMS_Utils_filter_the_number_e164($external_val),$this->_g_d_vars['GINTERNATIONAL_PREFIX'],$this->_g_d_vars['GNATIONAL_PREFIX'],$this->_g_d_vars['GCOUNTRY_CODE']);
                    }
                    $external_record[$internal] = $external_val;
                }
            }

            // have $external_record
            $externalSourceId = $external_record['sourceId'];
            if ($this->local_ldap_entries[$externalSourceId] && $this->local_ldap_entries[$externalSourceId]['update']){
                $this->toLog('WARNING: Duplicated ID received: "'.$externalSourceId.'"');
            }else{
                $this->compare_the_records($external_record);
            }

            if ( ! $this->verbose && $this->fetched_records_counter % 500 == 0 ) {
                $this->progress_to_log();
            }
        }

		unset($external_mssql_dbh);

	}

    private $separator = ",";
    private $separatorArray = array(";", "|", "\t");

	function importFromCsv(){

		if ($this->backend_params['import_type'] == 'upload') {
			$this->toLog('Opening uploaded file.');
		} else {
			$this->toLog('Opening CSV file: '._t('devices.'.$this->backend_params['import_mountpoint']).'/'.$this->backend_params['import_filepath']);
			$this->backend_params['filename'] = $this->backend_params['import_mountpoint'].'/'.$this->backend_params['import_filepath'];
		}

		if (($csv_handle = fopen($this->backend_params['filename'], "r")) === false){
			if ($this->backend_params['import_type'] == 'upload') {
				unlink($this->backend_params['filename']);
				$this->toLog('ERROR: Cannot open uploaded file.');
			} else {
				$this->toLog('ERROR: Cannot open CSV file.');
			}
			$this->out();
		};

        $testColumn = fgetcsv($csv_handle, 1000, $this->separator);

		if ($testColumn === false){
			if ($this->backend_params['import_type'] == 'upload') {
				unlink($this->backend_params['filename']);
				$this->toLog('ERROR: Cannot read the first row from uploaded file.');
			} else {
				$this->toLog('ERROR: Cannot read the first row from CSV file.');
			}
			$this->out();
		} else if (is_array($testColumn) && count($testColumn) <= 1) {
            $this->setSeparator($csv_handle);
        }

        fseek($csv_handle, 0);

        // get the first csv row to get the header values
        $csv_columns = fgetcsv($csv_handle, 1000, $this->separator);

		while (($csv_row = fgetcsv($csv_handle, 1000, $this->separator)) !== FALSE) {

			$this->fetched_records_counter++;
			$external_record = $this->getErasedFields();
			foreach ($this->map as $destColumnName => $sourceColumnName){
				$ext_value = $this->processMappingSyntax($csv_row,$sourceColumnName, $selectedColumnName, $csv_columns);
				if ($ext_value == '' && ! array_key_exists($destColumnName,$this->g_allow_erase_values_arr)) continue;


					// normalize 'officeNumber', 'mobile', 'facsimileTelephoneNumber'
					if (in_array($destColumnName,array('officeNumber', 'mobile', 'facsimileTelephoneNumber'))){
						$ext_value = WMS_Utils_normalize_the_number(WMS_Utils_filter_the_number_e164($ext_value),$this->_g_d_vars['GINTERNATIONAL_PREFIX'],$this->_g_d_vars['GNATIONAL_PREFIX'],$this->_g_d_vars['GCOUNTRY_CODE']);
					}
					$external_record[$destColumnName] = $ext_value;

			}

			// have $external_record
			if (!empty($external_record) && $external_record != $this->g_allow_erase_values_arr) {
			    $externalSourceId = $external_record['sourceId'];
				if ($this->local_ldap_entries[$externalSourceId] && $this->local_ldap_entries[$externalSourceId]['update']){
					$this->toLog('WARNING: Duplicated ID received: "'.$externalSourceId.'"');
				}else{
					$this->compare_the_records($external_record);
				}
			}

			if ( ! $this->verbose && $this->fetched_records_counter % 500 == 0 ) {
				$this->progress_to_log();
			}
		}

		if ($this->backend_params['import_type'] == 'upload') {
			unlink($this->backend_params['filename']);
		}
	}

	private function setSeparator($csvHandle) {
        $firstLine = fgets($csvHandle);
        $max = 0;

        foreach ($this->separatorArray as $delimiter) {
            $count = count(str_getcsv($firstLine, $delimiter));

            if ($count > $max) {
                $max = $count;
                $this->separator = $delimiter;
            }
        }

        if ($max == 1) {
            $this->toLog('WARNING: separator can not be detected.');
        }
    }

	function importFromOffice365(){
		$this->toLog('Connecting to Office365 server');

        $token = array(
                'received_token_time'=> $this->backend_params['received_token_time'],
                'access_token' => $this->backend_params['access_token'],
                'token_type' => $this->backend_params['token_type'],
                'expires_in' => $this->backend_params['expires_in'],
                'id_token' => $this->backend_params['id_token'],
        		'id_token_expires_in' => $this->backend_params['id_token_expires_in'],
        		'refresh_token' => $this->backend_params['refresh_token']
        );

        $office365 =  \Microsoft\Office365::getInstance();
        if($office365->setToken($token) != \Microsoft\Office365::TOKEN_VALID){
            $this->toLog('ERROR: Token invalid');
            $this->out();
        }

        $count = 500;
        $nextLink = null;
        do{
        	$res = $office365->getUsers($count, $nextLink);

            if($users && !empty($res['error']) && !empty($res['error']['message'])){
				$this->toLog('ERROR: '.$res['error']['message']);
				break;
			}

			$nextLink = $res['nextLink'];

			if(empty($res['users'])){
				if($start==0){
					$this->toLog('Users not found');
				}
                break;
            }else{
                $this->toLog('Users: '.count($res['users']));
            }

         	/************************************
            * start import users
            ************************************/
			foreach ($res['users'] as $ext_entry) {

				$this->fetched_records_counter++;
                $external_record = $this->getErasedFields();

				foreach ($this->map as $internal => $external) {
					if (!empty($external)) {
						$value = $this->processMappingSyntax($ext_entry, $external, $selectedColumnName);

						if ($value == '' && ! array_key_exists($internal,$this->g_allow_erase_values_arr)) continue;
						// normalize 'officeNumber', 'mobile', 'facsimileTelephoneNumber'
						if (in_array($internal, array('officeNumber', 'mobile', 'facsimileTelephoneNumber'))) {
							$value = WMS_Utils_normalize_the_number(WMS_Utils_filter_the_number_e164($value),$this->_g_d_vars['GINTERNATIONAL_PREFIX'],$this->_g_d_vars['GNATIONAL_PREFIX'],$this->_g_d_vars['GCOUNTRY_CODE']);
						}
						$external_record[$internal] = $value;
					}
				}

                $externalSourceId = $external_record['sourceId'];
				if (!trim($this->map['extenNumber'])) {
					if (!empty($this->local_ldap_entries[$externalSourceId]) && !empty($this->local_ldap_entries[$externalSourceId]['extenNumber'])){
						$external_record['extenNumber'] = $this->local_ldap_entries[$externalSourceId]['extenNumber'];
					} else {
						$external_record['extenNumber'] = $this->getNewPhone();
					}
				}

				if (empty($this->local_ldap_entries[$externalSourceId]['userPassword']) && empty($external_record['userPassword'])) {
					//$this->toLog('WARNING: Empty password for user ' . $external_record['cn'] . '. Password will be automatically generated');
				}

				if ($this->local_ldap_entries[$external_record['userPrincipalName']] && $this->local_ldap_entries[$external_record['userPrincipalName']]['update']) {
					$this->toLog('WARNING: Duplicated login received: "'.$external_record['userPrincipalName'].'"');
				} else {
					$this->compare_the_records($external_record);
				}

				if (!$this->verbose && $this->fetched_records_counter % 500 == 0) {
					$this->progress_to_log();
				}
			}

		}while ($nextLink);
	}

	function importFromZohoCRM() {
        $this->toLog('Connecting to ZohoCRM server');

        $writer    = new Logger\Writer\SysLog('wms');
        $formatter = new Logger\Formatter\MultiLine();
        $context   = new Logger\Context(array());
        $logger    = new Logger\Log($writer, $formatter, $context);
        $kite      = new \Wildix\Services\Kite();
        $zohoCrm   = new \Wildix\Import\ZohoClient\ZohoClient($logger, $kite, env('ZOHO_CLIENT_AUTH_URI'));

        $token   = array(
            'received_token_time'=> $this->backend_params['received_token_time'],
            'access_token' => $this->backend_params['access_token'],
            'token_type' => $this->backend_params['token_type'],
            'expires_in' => $this->backend_params['expires_in'],
            'refresh_token' => $this->backend_params['refresh_token'],
            'api_domain' => $this->backend_params['api_domain'],
            'location' => $this->backend_params['location'],
            'accounts_server' => $this->backend_params['accounts_server'],
        );

        $per_page = 200;
        $page = 1;

        $this->map['sourceId'] = 'zuid';

        do {
            $res = $zohoCrm->getUsers($token, $per_page, $page);

            if(!empty($res['error']) && !empty($res['error']['message'])) {
                $this->toLog('ERROR: ' . $res['error']['message']);
                $this->out();
            }

            if(empty($res)){
                $this->toLog('Users not found');
                $this->out();
            }else{
                $this->toLog('Users: '.count($res['users']));
            }


            foreach ($res['users'] as $ext_entry) {
                $this->fetched_records_counter++;
                $external_record = $this->getErasedFields();

                // apply external records values to local field map
                foreach ($this->map as $internal => $external) {
                    if (!empty($external)) {
                        $value = $this->processMappingSyntax($ext_entry, $external, $selectedColumnName);

                        if ($value == '' && !array_key_exists($internal, $this->g_allow_erase_values_arr)) continue;

                        if (in_array($internal, array('phone', 'mobile'))) {
                            $value = WMS_Utils_normalize_the_number(WMS_Utils_filter_the_number_e164($value), $this->_g_d_vars['GINTERNATIONAL_PREFIX'], $this->_g_d_vars['GNATIONAL_PREFIX'], $this->_g_d_vars['GCOUNTRY_CODE']);
                        }
                        $external_record[$internal] = $value;
                    }
                }

                if ((string)$ext_entry['zuid'] !== '') {
                    if (isset($this->local_ldap_entries[$ext_entry['id']])) {
                        $this->updateZohoUserSourceId($ext_entry['id'], $ext_entry['zuid']);
                    } else if (!empty($ext_entry['email'])
                        && isset($this->_g_mail_array[$ext_entry['email']])
                        && $this->_g_mail_array[$ext_entry['email']] !== $ext_entry['zuid']
                    ) {
                        $this->updateZohoUserSourceId($this->_g_mail_array[$ext_entry['email']], $ext_entry['zuid']);
                    }
                }

                $externalSourceId = $external_record['sourceId'];
                if (!trim($this->map['extenNumber'])) {
                    if (!empty($this->local_ldap_entries[$externalSourceId]) && !empty($this->local_ldap_entries[$externalSourceId]['extenNumber'])) {
                        $external_record['extenNumber'] = $this->local_ldap_entries[$externalSourceId]['extenNumber'];
                    } else {
                        $external_record['extenNumber'] = $this->getNewPhone();
                    }
                }

                if ($this->local_ldap_entries[$external_record['userPrincipalName']] && $this->local_ldap_entries[$external_record['userPrincipalName']]['update']) {
                    $this->toLog('WARNING: Duplicated login received: "' . $external_record['userPrincipalName'] . '"');
                } else {
                    $this->compare_the_records($external_record);
                }

                if (!$this->verbose && $this->fetched_records_counter % 500 == 0) {
                    $this->progress_to_log();
                }
            }

            $page++;
        } while ($res['info']['more_records'] == true);
    }

	function importFromGoogle() {
            $this->toLog('Connecting to Google server');

            $token = array(
                'received_token_time'=> $this->backend_params['received_token_time'],
                'access_token' => $this->backend_params['access_token'],
                'token_type' => $this->backend_params['token_type'],
                'expires_in' => $this->backend_params['expires_in'],
                'refresh_token' => $this->backend_params['refresh_token']
            );

            $google_api = GoogleAPI::getInstance();

            if ($google_api->setToken($token) != GoogleAPI::TOKEN_VALID) {
                $this->toLog('ERROR: Token invalid');
                $this->out();
            }

            $next_page_token = '';

            do {
                $data = $google_api->getDomainUsers($next_page_token);

                if (!empty($data['error'])) {
                    $this->toLog('ERROR: ' . $data['error']['message']);

                    continue;
                }

                $next_page_token = isset($data['nextPageToken']) ? $data['nextPageToken'] : '';

                /************************************
                 * start import users
                 ************************************/
                foreach ($data['users'] as $ext_entry) {
                    $this->toLog('User: ' . $ext_entry['name']);

                    $this->fetched_records_counter++;

                    $external_record = $this->getErasedFields();

                    foreach ($this->map as $internal => $external) {
						if (!empty($external)){
							$value = $this->processMappingSyntax($ext_entry, $external, $selectedColumnName);

                            if ($value == '' && ! array_key_exists($internal,$this->g_allow_erase_values_arr)) continue;
                            // normalize 'officeNumber', 'mobile', 'facsimileTelephoneNumber'
                            if (in_array($internal, array('officeNumber', 'mobile', 'facsimileTelephoneNumber'))) {
								$value = WMS_Utils_normalize_the_number(WMS_Utils_filter_the_number_e164($value),$this->_g_d_vars['GINTERNATIONAL_PREFIX'],$this->_g_d_vars['GNATIONAL_PREFIX'],$this->_g_d_vars['GCOUNTRY_CODE']);
                            }
                            $external_record[$internal] = $value;
                        }
                    }

                    $externalSourceId = $external_record['sourceId'];
                    if (!trim($this->map['extenNumber'])) {
                        if (!empty($this->local_ldap_entries[$externalSourceId]) && !empty($this->local_ldap_entries[$externalSourceId]['extenNumber'])){
                            $external_record['extenNumber'] = $this->local_ldap_entries[$externalSourceId]['extenNumber'];
                        } else {
                            $external_record['extenNumber'] = $this->getNewPhone();
                        }
                    }

                    if (empty($this->local_ldap_entries[$externalSourceId]['userPassword']) && empty($external_record['userPassword'])) {
                        $this->toLog('WARNING: Empty password for user ' . $externalSourceId . '. Password will be automatically generated');
                    }

                    // if there is avatar in google response
                    if (!empty($external_record['imageUrl'])) {
                        // existing user
                        if (!empty($this->local_ldap_entries[$externalSourceId])) {
                            if ($this->is_avatar_outdated($this->local_ldap_entries[$externalSourceId]['imageUrl'], $external_record['imageUrl'])) {
                                $external_record['imageUrl'] = $this->fetch_google_avatar($external_record['imageUrl'], $this->local_ldap_entries[$externalSourceId]['uid']);
                            } else {
                                $external_record['imageUrl'] = $this->local_ldap_entries[$externalSourceId]['imageUrl'];
                            }

                            // have $external_record
                            if ($this->local_ldap_entries[$externalSourceId] && $this->local_ldap_entries[$externalSourceId]['update']) {
                                $this->toLog('WARNING: Duplicated ID received: "'.$externalSourceId.'"');
                            } else {
                                $this->compare_the_records($external_record);
                            }
                        // new user
                        } else {
                            $_avatar = $external_record['imageUrl'];

                            unset($external_record['imageUrl']); // to save user without avatar, avatar would be added further
                            // have $external_record
                            if ($this->local_ldap_entries[$externalSourceId] && $this->local_ldap_entries[$externalSourceId]['update']) {
                                $this->toLog('WARNING: Duplicated ID received: "'.$externalSourceId.'"');
                            } else {
                                $this->compare_the_records($external_record);
                            }

                            $entries = WMS_Ldap::getInstance()->getEntries(WMS_Ldap::PERSONS, '(sourceId=' . $externalSourceId . ')', array(
                                'cn',
                                'uid',
                                'dn',
                                LDAP_EXTEN_NUMBER,
                                LDAP_OFFICE_NUMBER,
                                'imageUrl',
                            ));
                            if (!$entries || count($entries) < 1) {
                                $this->toLog('WARNING: Seems user "' . $external_record['cn'] . '" was not successfully saved. Avatar downloading will be skipped.');
                                continue;
                            }
                            $entry = $entries[0];

                            $entry['imageUrl'] = $this->fetch_google_avatar($_avatar, $entry['uid']);

                            if (!$this->aclpbx_class->set_user($entry, true)) {
                                $this->toLog('WARNING: Something went wrong. Profile was not updated.');
                            }
                        }
                    } else {
                        // have $external_record
                        if ($this->local_ldap_entries[$externalSourceId] && $this->local_ldap_entries[$externalSourceId]['update']) {
                            $this->toLog('WARNING: Duplicated ID received: "'.$externalSourceId.'"');
                        } else {
                            $this->remove_avatar($this->local_ldap_entries[$externalSourceId]['uid']);
                            $this->compare_the_records($external_record);
                        }
                    }

                    if (!$this->verbose && $this->fetched_records_counter % 500 == 0) {
                        $this->progress_to_log();
                    }
                }
            } while (!empty($next_page_token));
	}

	private function _fetch_avatar($url, $depth = 0) {
		$curl = curl_init();
		curl_setopt($curl, CURLOPT_URL, $url);
		curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
		curl_setopt($curl, CURLOPT_TIMEOUT, 5);
		curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);

		$content = curl_exec($curl);
		$code = curl_getinfo($curl, CURLINFO_HTTP_CODE);

		curl_close($curl);

		if ($code == 403) {
			$this->toLog('WARNING: You have no access to user\'s avatar');
			return false;
		} else {
			if ($content) {
				return $content;
			}
			if ($depth > 0) {
				$this->toLog('WARNING: Trying to download avatar "' . $url . '" tries left ' . $depth);
				return $this->_fetch_avatar($url, --$depth);
			} else {
				return false;
			}
		}
	}

	private function _get_avatar_root() {
		return '/var/www';
	}
	private function _get_avatar_path($uid) {
		return $this->_get_avatar_root() . '/cticonnect/cticonnect_share/user_avatar_' . $uid . '.png';
	}

	function fetch_google_avatar($url, $uid) {
    	$imgData = $this->_fetch_avatar($url, 3);
        if (!$imgData) {
        	return '';
        }

        $image = imagecreatefromstring($imgData);

		if ($image === false) {
			$this->toLog('WARNING: Invalid avatar for user ' . $uid . ' at url "' . $url . '" length ' . strlen($imgData));
			return '';
		}

		$filename = $this->_get_avatar_path($uid);
		if ($this->dry_run) {
			return str_replace($this->_get_avatar_root(), '', $filename);
		}

		return imagepng($image, $filename) ? str_replace($this->_get_avatar_root(), '', $filename) . '?' . sprintf('%u', crc32($url)) : '';
	}

	function remove_avatar($uid) {
    	if (!$uid) {
        	return;
        }

        $filename = $this->_get_avatar_path($uid);
        if (file_exists($filename)) {
        	if (!$this->dry_run) {
            	return unlink($filename);
            }
        } else {
            return;
        }
    }

    function is_avatar_outdated($old_avatar, $url) {
    	$old = explode('?', $old_avatar);
        if (count($old) < 2) { // there is no hash in avatar path
        	return true;
        }

        if (!file_exists($this->_get_avatar_root() . $old[0])) {
        	$this->toLog('WARNING: Avatar is set, but file does not exists.');
            return true;
        }

        $old_hash = $old[1];
        $new_hash = sprintf('%u', crc32($url));

        return $old_hash != $new_hash;
    }

	var $warning_is_present = false;
	function compare_the_records($external_record) {
		if (!isset($external_record['cn']) || $external_record['cn'] == ''){
			$this->toLog('WARNING: Attribute "'.$this->_g_attrs_translation['cn'].'" is not present for the record with value(s) "'.implode('","',$external_record).'". User is not added.');
			return false;
		}

        $externalSourceId = $external_record['sourceId'];
        if (!isset($externalSourceId) || $externalSourceId === '') {
            $this->toLog('WARNING: Attribute "' . $this->_g_attrs_translation['sourceId'] . '" is not present for the record with value(s) "' . implode('","', $external_record) . '". User is not added.');
            return false;
        }

        $external_record = $this->normalizeValue($external_record);

		$t_log_str = '';
		$this->warning_is_present = false;

		if (isset($this->local_ldap_entries[$externalSourceId])){
		    // update exited

			if ($this->verbose) {
				$t_log_str = 'User "'.$externalSourceId.'".';
			}

			foreach ($external_record as $attribute=>$val){
				if ($external_record[$attribute] == '' && ! array_key_exists($attribute,$this->g_allow_erase_values_arr)){
					// the attribute must be erased
					unset($external_record[$attribute]);
				}
			}

			$external_record = $this->validate_input_record($external_record, 'update', $t_log_str);// ---------------------------------------------

			if (empty($external_record) OR count($external_record) < 1){
				$this->toLog($t_log_str.' User is not updated.');
				return false;
			}
			if ($this->verbose) {
				$t_lang_change_attrs = array();
				foreach ($external_record as $t_attr_key => $val){
					$t_lang_change_attrs[$t_attr_key] = $this->_g_attrs_translation[$t_attr_key];
				}
				$t_log_str .= ' Updating attribute(s) "'.implode('", "',$t_lang_change_attrs).'" with value(s) "'.implode('", "',$external_record).'".';
				unset($t_lang_change_attrs);
				$this->toLog($t_log_str);
			} elseif ($t_log_str != '') {
				$t_log_str = 'User "'.$externalSourceId.'".' . $t_log_str;
				$this->toLog($t_log_str);
			}

			$external_record['dn'] = $this->local_ldap_entries[$externalSourceId]['dn'];
			$external_record['uid'] = $this->local_ldap_entries[$externalSourceId]['uid'];
			if (isset($external_record['owner'])){
				$external_record['owner'] = array_search($external_record['owner'], $this->_g_groups_array);
				$external_record['owner_old'] = array_search($this->local_ldap_entries[$externalSourceId]['owner'], $this->_g_groups_array);
			}

			if (!empty($external_record['pbxowner'])) {
                $external_record['pbxowner'] = $this->parsePbxOwner($external_record['pbxowner']);
            }

			$pbxOwnerOld = $this->local_ldap_entries[$externalSourceId]['pbxowner'];
			$pbxOwnerNew = $external_record['pbxowner'];

			if ($pbxOwnerNew && $pbxOwnerNew !== $pbxOwnerOld) {
                $this->toLog(sprintf('Move user %s from PBX %s to PBX "%s"', $external_record['uid'], $pbxOwnerOld, $pbxOwnerNew));
                $this->g_summary['moved']++;
                $this->addUserToLog($this->local_ldap_entries[$externalSourceId], 'moved');

                if (!$this->dry_run) {
                    $this->moveUserToOtherPbx($this->local_ldap_entries[$externalSourceId], $pbxOwnerNew);
                }
            }

            if (!$this->dry_run){
				$no_err = $this->aclpbx_class->set_user($external_record, true);
				if ($no_err !== true){
					$this->toLog('WARNING: User "'.$externalSourceId . ':' . $external_record['cn'] . '" is not updated: ' . (is_array($no_err) ? implode(';', $no_err) : $no_err));
					return false;
				}
			}

			if (isset($external_record['extenNumber'])){
				if( $this->local_ldap_entries[$externalSourceId]['extenNumber'] != $external_record['extenNumber'] OR
					$this->_g_extenNumbers_array[$external_record['extenNumber']] != $externalSourceId){
						unset($this->_g_extenNumbers_array[$this->local_ldap_entries[$externalSourceId]['extenNumber']] );
						$this->_g_extenNumbers_array[$external_record['extenNumber']] = $externalSourceId;
				}
			}

			if (isset($external_record['userPrincipalName'])){
				if( $this->local_ldap_entries[$externalSourceId]['userPrincipalName'] != $external_record['userPrincipalName'] OR
					$this->_g_login_array[$external_record['userPrincipalName']] != $externalSourceId){
						unset($this->_g_login_array[$this->local_ldap_entries[$externalSourceId]['userPrincipalName']] );
						$this->_g_login_array[$external_record['userPrincipalName']] = $externalSourceId;
				}
			}

			$this->g_summary['updated']++;
            $this->addUserToLog($this->local_ldap_entries[$externalSourceId], 'updated');

			if ($this->warning_is_present) {
				$this->g_summary['updated_with_err']++;
			}
		}else{
            // new user
			if ($this->verbose) {
				$t_log_str = 'User "'.$externalSourceId.'" is not present.';
			}

			$t_external_record = $external_record;
			$external_record = array();
			foreach ($t_external_record as $t_key => $t_val){
				if ($t_val != '') $external_record[$t_key] = $t_val;
			}
			unset($t_external_record);

			$external_record = $this->validate_input_record($external_record, 'add', $t_log_str);
			if (!is_array($external_record)){
				$this->toLog($t_log_str. ' User is not added.');
				return false;
			}

			// setting default values if they are not present
			foreach ($this->_g_default_values as $attr_key => $attr_val){
				if (!isset($external_record[$attr_key])) $external_record[$attr_key] = $attr_val;
			}

			if ($this->verbose) {
				$t_lang_change_attrs = array();
				foreach (array_keys($external_record) as $t_attr_key) $t_lang_change_attrs[$t_attr_key] = $this->_g_attrs_translation[$t_attr_key];
				$t_log_str .= ' Adding attribute(s) "'.implode('", "',$t_lang_change_attrs).'" with value(s) "'.implode('", "',$external_record).'".';
				unset($t_lang_change_attrs);
				$this->toLog($t_log_str);
			} else if ($t_log_str != '') {
				$t_log_str = 'User "'.$externalSourceId.'" is not present.' . $t_log_str;
				$this->toLog($t_log_str);
			}

			$external_record['uid'] = 'new';
			if (isset($external_record['owner'])){
				$external_record['owner'] = array_search($external_record['owner'], $this->_g_groups_array);
			}

            if (!empty($external_record['pbxowner'])) {
                $external_record['pbxowner'] = $this->parsePbxOwner($external_record['pbxowner']);
            }

			if (!$this->dry_run){
				$no_err = $this->aclpbx_class->set_user($external_record, true);
				if ($no_err !== true){
					$this->toLog('WARNING: User "'.$external_record['extenNumber'].'" is not added: '.((is_array($no_err))?implode('', $no_err):$no_err));
					return false;
				}
			}

			if (isset($external_record['extenNumber'])){
				$this->_g_extenNumbers_array[$external_record['extenNumber']] = $externalSourceId;
			}
			if (isset($external_record['userPrincipalName'])){
				$this->_g_login_array[$external_record['userPrincipalName']] = $externalSourceId;
			}
			if (isset($external_record['mobile'])){
				$this->_g_mobileNumbers_array[$external_record['mobile']] = $externalSourceId;
			}

			$this->g_summary['added']++;
            $this->addUserToLog($external_record, 'added');

			if ($this->warning_is_present) {
				$this->g_summary['added_with_err']++;
			}
		}

		unset($this->local_ldap_entries[$externalSourceId]);
		$this->local_ldap_entries[$externalSourceId] = array('update'=>1, 'extenNumber' =>$external_record['extenNumber']);
    }

    private function addUserToLog(array $item, string $type) {
        $this->g_summary[$type . 'Users'][] = [
            'name' => $item['cn'],
            'email' => $item['mail'],
            'ext' => $item['extenNumber'],
        ];
    }

    private function moveUserToOtherPbx($user, $pbxNewDn) {
        $this->_getLuaService()->moveUser([$user['uid'], $user['extenNumber'], $pbxNewDn]);
        $res = $this->_getWmsLdap()->moveUser($user['dn'], $user['pbxowner'], $pbxNewDn);
        if ($res) {
            \Wildix\CallweaverManager::getInstance()->sipPeerPrune($user['extenNumber']);
        } else {
            $this->toLog(sprintf('WARNING: User %s don\'t moved to PBX %s', $user['uid'], $pbxNewDn));
            $this->warning_is_present = true;
        }
    }

    private function parsePbxOwner(string $inputStr): string {
        $pbxOwner = '';

        $pbxs = \Wildix\PBXes\PBXes::getInstance();
        if (preg_match('/^(.*?)\.wildixin\.com$/', $inputStr)) {
            $pbx = $pbxs->getPBXByDomain($inputStr);
        } else if (preg_match('/^pbxid=([0-9a-z]+),dc=wildix$/', $inputStr)) {
            $pbx = $pbxs->getPBXByDN($inputStr);
        } else {
            $pbx = $pbxs->getPBXBySerial($inputStr);
        }

        if ($pbx) {
            $pbxOwner = $pbx->getDn();
        } else {
            $this->toLog(sprintf('WARNING: Not found PBX %s in the wms-network', $inputStr));
            $this->warning_is_present = true;
        }

        return $pbxOwner;
    }

    private function normalizeValue($value) {
	    if (is_array($value)) {
	        foreach ($value as &$item) {
	            $item = preg_replace('/[\x{0}-\x{1F}]/', ' ', $item);
            }
        } else if (is_string($value)) {
	        $value = preg_replace('/[\x{0}-\x{1F}]/', ' ', $value);
        }

        return $value;
    }

	function validate_input_record($external_record, $mode, &$to_log_str){

		// cn attr is present every time : checked before
		$checkField_cn = '/^[^^\/\\\@\|\+\=\}\{\]\[\)\(\*&\?%\$#@\!\,\":;]{2,50}\z/i'; //\'
		$checkFields = array(
			'userPrincipalName' => '/^[^^\/\\\|\+\=\}\{\]\[\)\(\*&\?%\$#\!\,\":;]{2,50}\z/i',
			'extenNumber' => '/^[0-9]{2,50}\z/',
			'officeNumber' => '/^[\+]?[0-9]{2,50}\z/',
			'facsimileTelephoneNumber' => '/^[\+]?[0-9]{2,50}\z/',
			'mobile' => '/^[\+]?[0-9]{2,50}\z/'
		);

		if (isset($external_record['cn'])){
			if(!preg_match($checkField_cn,$external_record['cn'])){
				$to_log_str .= ' WARNING: Attribute "'.$this->_g_attrs_translation['cn'].'" is not valid.';
				$warning_is_present = true;
				return false;
			}elseif(!isset($external_record['extenNumber'])){
				$to_log_str .= ' WARNING: Attribute "'.$this->_g_attrs_translation['extenNumber'].'" is not present for user "'.$external_record['cn'].'".';
				$warning_is_present = true;
				return false;
			}
		}

        $externalSourceId = $external_record['sourceId'];
		// validate the extenNumber is already set for another user
		if (isset($external_record['extenNumber'])){
			if (isset($this->_g_extenNumbers_array[$external_record['extenNumber']]) && $this->_g_extenNumbers_array[$external_record['extenNumber']] != $externalSourceId) {
				$to_log_str .= ' WARNING: Attribute "'.$this->_g_attrs_translation['extenNumber'].'" with value "'.$external_record['extenNumber'].'" is already set for user "'.$this->_g_extenNumbers_array[$external_record['extenNumber']].'".';
				unset($external_record['extenNumber']);
				$this->warning_is_present = true;
				if ($mode == 'add'){
					return false;
				}
			}
		}

	    // validate the userPrincipalName is already set for another user
		if (isset($external_record['userPrincipalName'])){
			if (isset($this->_g_login_array[$external_record['userPrincipalName']]) && $this->_g_login_array[$external_record['userPrincipalName']] != $externalSourceId) {
				$to_log_str .= ' WARNING: Attribute "'.$this->_g_attrs_translation['userPrincipalName'].'" with value "'.$external_record['userPrincipalName'].'" is already set for user "'.$this->_g_login_array[$external_record['userPrincipalName']].'".';
				unset($external_record['userPrincipalName']);
				$this->warning_is_present = true;
				if ($mode == 'add'){
					return false;
				}
			}
		}

		// validate the mail
		if (isset($external_record['mail']) && count($this->_validator->validateData(['email' => $external_record['mail']], ['email'])) > 0){
			$to_log_str .= ' WARNING: Attribute "'.$this->_g_attrs_translation['mail'].'" with value "'.$external_record['mail'].'" is not valid.';
			unset($external_record['mail']);
			$this->warning_is_present = true;
			if ($mode == 'add'){
				return false;
			}
		}

		// validate the mail is already set for another user
		if (isset($external_record['mail'])){
			if (isset($this->_g_mail_array[$external_record['mail']]) && $this->_g_mail_array[$external_record['mail']] != $externalSourceId) {
				$to_log_str .= ' WARNING: Attribute "' . $this->_g_attrs_translation['mail'] . '" with value "' . $external_record['mail'] . '" is already set for user "' . $this->_g_mail_array[$external_record['mail']] . '".';
				unset($external_record['mail']);
				$this->warning_is_present = true;
				if ($mode == 'add') {
					return false;
				}
			}
		}

		// validate password
		if (isset($external_record['userPassword']) && ! strlen(trim($external_record['userPassword']))){//$aclpbx_class->check_password_strength($external_record['userPassword'],true) == 'weak'
			$to_log_str .= ' WARNING: Attribute "'.$this->_g_attrs_translation['userPassword'].'" with value "'.$external_record['userPassword'].'" is not valid.';
			if ($mode == 'add'){
				$passwd = \Wildix\Generator\StringGenerator::random(10);
				$external_record['userPassword'] = \User::getInstance()->cryptPassword($passwd);
				$external_record['userPIN'] = \User::getInstance()->makeUserPinFromPassword($passwd);
			}else{
				unset($external_record['userPassword']);
				unset($external_record['userPIN']);
			}
			$this->warning_is_present = true;
		}

		// validate group
		if (isset($external_record['owner']) && array_search($external_record['owner'], $this->_g_groups_array) === false){
			$to_log_str .= ' WARNING: Attribute "'.$this->_g_attrs_translation['owner'].'" with value "'.$external_record['owner'].'" is not valid.';
			unset($external_record['owner']);
			$warning_is_present = true;
		}

                // validate the mobile is already set for another user
		if (isset($external_record['mobile']) && strlen(trim($external_record['mobile']))>0){
			if (isset($this->_g_mobileNumbers_array[$external_record['mobile']]) && $this->_g_mobileNumbers_array[$external_record['mobile']] != $externalSourceId) {
				$to_log_str .= ' WARNING: Attribute "'.$this->_g_attrs_translation['mobile'].'" with value "'.$external_record['mobile'].'" is already set for user "'.$this->_g_mobileNumbers_array[$external_record['mobile']].'".';
                                //Allow even add but do not update/insert this number
				unset($external_record['mobile']);
				$this->warning_is_present = true;
			}
		}

        if (!empty($external_record['ou'])) {
            $external_record['ou'] = str_replace('&', 'n', $external_record['ou']);
        }

        foreach ($checkFields as $attr => $pattern){
			if (isset($external_record[$attr]) && $external_record[$attr] !='' && !preg_match($pattern,$external_record[$attr])){
				$to_log_str .= ' WARNING: Attribute "'.$this->_g_attrs_translation[$attr].'" with value "'.$external_record[$attr].'" is not valid.';
				unset($external_record[$attr]);
				$this->warning_is_present = true;
				if($attr == 'extenNumber' && $mode == 'add'){
					return false;
				}
			}
		}
		foreach ($this->_g_validators_array as $attr => $vals_arr){
			if (isset($external_record[$attr]) && $external_record[$attr] !='' && !in_array($external_record[$attr],$vals_arr)){
				$to_log_str .= ' WARNING: Attribute "'.$this->_g_attrs_translation[$attr].'" with value "'.$external_record[$attr].'" is not valid.';
				unset($external_record[$attr]);
				//$external_record[$attr] = $this->_g_default_values[$attr];
				$this->warning_is_present = true;
			}
		}

		unset($checkFields, $checkField_cn);
		return $external_record;
	}

	function sendMail(){
		if (trim($this->send_email) != '') {
			$this->toLog('Sending feedback email to '.$this->send_email);
			exec('export HOME=\'/tmp/\';[ -f /tmp/sent ]&&rm -f /tmp/sent{,.lock}; sudo /usr/sbin/syslog_grep \'userssync #'.$this->log_id.'\' | sed \'s/localhost userssync #'.$this->log_id.': //\'', $output);
			$mailBody = implode(PHP_EOL, $output);
			$params = array(
			    'body' => $mailBody,
			    'to' => $this->send_email,
			    'subject' => \Models\PBX::getInstance()->getDomain(). ' users import report'
			);
			Notification::sendEmail($params);
		}
	}

	/**
	 * Find value for the provided $sourceColumnName in a $sourceRow with ability to use special syntax
	 * @param $sourceRow - imported row
	 * @param $sourceColumnName - Column name from imported backend, can contain special syntax with + and |
	 * @param string &$selectedColumnName - used when OR syntax going on
	 * @param array $sourceHeaders - appliable for csv, when col name have to be calculated by its position
	 * @return null|string - returns value for the provided coulumn name or null if $sourceColumnName was not found
	 */
	private function processMappingSyntax($sourceRow, $sourceColumnName, &$selectedColumnName, $sourceHeaders = array()){
		$result = null;
		$processOr = true;
		$processConcat = true;
		$selectedColumnName = null;

		//Appliable for csv
		foreach ($sourceHeaders as $sourceHeaderPos => $sourceHeaderName) {
			if (isset($sourceRow[$sourceHeaderPos])) {
				$sourceRow[$sourceHeaderName] = trim($sourceRow[$sourceHeaderPos]);
			}
		}

		//if no special syntax symbols then just return value
		if ($sourceColumnName && strpos($sourceColumnName, '+')===false && strpos($sourceColumnName, '|')===false ){
			if (isset($sourceRow[$sourceColumnName])){
				$result = trim($sourceRow[$sourceColumnName]);
			}
			return $result;
		}

		//Split for OR syntax
		$executionStack =
			$processOr?explode('|',$sourceColumnName):array($sourceColumnName);

		//Split for CONCAT syntax
		foreach($executionStack as $keyOr => $columnNameOr){
			$executionStack[$keyOr] =
				$processConcat?explode('+',$columnNameOr):array($columnNameOr);

			$result = "";
			foreach($executionStack[$keyOr] as $keyConcat=>$columnNameConcat){
				$columnNameConcat = trim($columnNameConcat);
				if (array_search(preg_replace('/\s+/', ' ',$columnNameConcat), array("' '",'" "')) ){
					$result .= ' ';
				} else if (isset($sourceRow[$columnNameConcat])){
					if (!empty($result) && substr($result, -1) != ' ')
						$result .= ' ';
					$result .= $sourceRow[$columnNameConcat];

					if (trim($sourceRow[$columnNameConcat])){
						//Selected column name used for applying city, postal code , so here just do not loose important column name
						if (!array_search( $selectedColumnName, array('addressHome','addressWork', 'addressBusiness', 'addressOther')))
							$selectedColumnName = $columnNameConcat;
					}
				}
			}
			$result = trim($result);
			if (!empty($result)){
				break;
			}
		}

		return $result;
	}

	function out() {
		$this->toLog("No change was provided.");
		$this->sendMail();
		exit(1);
	}

	function remove_local_entries(){

		$removeUids = [];
		$i=0;

		foreach ($this->local_ldap_entries as $sourceId => $userArray){
			$i++;

			if ($userArray['cn'] == 'admin' OR $userArray['update'] OR
				( ! $this->map['userKind'] AND ! ($userArray['userKind'] == 'admin' OR $userArray['userKind'] == 'user') )){
				continue;
			}

			if (isset($userArray['uid'], $userArray['sourceId']) && $userArray['uid'] === $userArray['sourceId']) {
                $this->toLog(sprintf('Don\'t delete the local user "%s"', $userArray['cn']));
			    continue;
            }

			if ($this->verbose) {
				$this->toLog('User "'.$userArray['cn'].'" is not present in the backend. Removing.');
			}
			if (!$this->dry_run){
				$removeUids[] = $userArray['uid'];
			}
            $this->g_summary['removed']++;
            $this->addUserToLog($this->local_ldap_entries[$sourceId], 'removed');
			unset($this->local_ldap_entries[$sourceId]);
			if ($i == 100) {
				$no_err = $this->removeUsersByUidList($removeUids);

                $removeUids = [];
				$i = 0;
				if ($no_err !== true && $no_err !== false){
					return false;
				}
			}
		}

		if (count($removeUids) > 0) {
            $no_err = $this->removeUsersByUidList($removeUids);

			if ($no_err !== true && $no_err !== false){
				return false;
			}
		}
	}

    function removeUsersByUidList(array $uidList) {
        $result = true;

        foreach ($uidList as $uid) {
            try {
                $colleague = $this->getColleaguesService()->getUserByID($uid);

                if (!$colleague) {
                    throw new Exception(sprintf('User with uid %s not found.', $uid));
                }

                $this->getUserDataCleaner()->clearUserData(
                    $colleague,
                    UserDataFactory::make([])
                );
                $this->getColleaguesService()->removeUser($colleague, $this->aclpbx_class->get_current_pbx_ldap_dn());
            } catch (Exception $e) {
                $this->toLog($e->getMessage());
                if (!is_array($result)) {
                    $result = [];
                }
                $result[$uid] = $e->getMessage();
            }
        }

        return $result;
    }

	function getNewPhone(){
		$rand = rand(10000, 99999);
		if($this->_g_extenNumbers_array[$rand]){
			return $this->getNewPhone();
		}
		return $rand;
	}

	function progress_to_log($summary = false){
        $this->toLog(str_repeat('=', 40));
        $this->toLog(($summary ? 'Summary ' : 'Progress ')
            . $this->g_summary['added'] . ' added' . ($this->g_summary['added_with_err'] > 0 ? ' (' . $this->g_summary['added_with_err'] . ' with warning)' : ' ') . ', '
            . $this->g_summary['updated'] . ' updated' . ($this->g_summary['updated_with_err'] > 0 ? ' (' . $this->g_summary['updated_with_err'] . ' with warning)' : ' ') . ', '
            . $this->g_summary['removed'] . ' removed'
            . ($this->g_summary['moved'] > 0 ? sprintf(', %d moved to another PBX', $this->g_summary['moved']) : '')
        );

        $this->printStatistic('added');
        $this->printStatistic('updated');
        $this->printStatistic('moved');
        $this->printStatistic('removed');

        $this->toLog(str_repeat('=', 40));
	}

	function printStatistic(string $type) {
	    $data = $this->g_summary[$type . 'Users'] ?? [];
        if (!$data) {
            return;
        }
        $this->toLog(str_repeat('=', 40));
        $this->toLog(ucfirst($type) . ':');

        foreach ($data as $item) {
            array_walk($item, function(&$val, $key) {
                $val = sprintf('%s: %s', $key, $val);
            });

            $this->toLog(' * ' . implode(', ', $item));
        }
    }

	function toLog($message, $type = LOG_INFO) {
	    openlog('userssync #' . $this->log_id, LOG_ODELAY, LOG_LOCAL2);
		syslog($type, $message);
		closelog();
		echo $message . "\n";
	}

	public function normalizeNumber($value, $internationalPrefix, $nationalPrefix, $countryCode) {
        return WMS_Utils_normalize_the_number($value, $internationalPrefix, $nationalPrefix, $countryCode);
    }

    private function _syncToPhoneBridge() {
        /* @var $zohoCrmSettings \Wildix\Integration\ZohoCrm */
        $zohoCrmSettings = $GLOBALS['diContainer']->get(\Wildix\Integration\ZohoCrm::class);

        if ($this->dry_run || !$zohoCrmSettings->isEnabled()) {
            return;
        }

        /* @var $phoneBridge \Wildix\Services\PhoneBridge */
        $phoneBridge = $GLOBALS['diContainer']->get(\Wildix\Services\PhoneBridge::class);

        $phoneBridge->sync(\Wildix\Services\PhoneBridge::SERVICE_ID_ZOHO_CRM);
    }

    private function updateZohoUserSourceId(string $extEntryOldId, string $extEntryNewId) {
        $existExtension = array_search($extEntryOldId, $this->_g_extenNumbers_array, true);
        if ($existExtension !== false) {
            $this->_g_extenNumbers_array[$existExtension] = $extEntryNewId;
        }

        $existLogin = array_search($extEntryOldId, $this->_g_login_array, true);
        if ($existLogin !== false) {
            $this->_g_login_array[$existLogin] = $extEntryNewId;
        }

        $existMobNumber = array_search($extEntryOldId, $this->_g_mobileNumbers_array, true);
        if ($existMobNumber !== false) {
            $this->_g_mobileNumbers_array[$existMobNumber] = $extEntryNewId;
        }

        $existEmail = array_search($extEntryOldId, $this->_g_mail_array, true);
        if ($existEmail !== false) {
            $this->_g_mail_array[$existEmail] = $extEntryNewId;
        }

        // replace id to zuid in local ldap search => update existed record with old zoho id
        $this->local_ldap_entries[$extEntryNewId] = $this->local_ldap_entries[$extEntryOldId];
        unset($this->local_ldap_entries[$extEntryOldId]);
    }

    private function _getWmsLdap(): \WMS_Ldap {
	    if (!$this->_wmsLdap) {
	        $this->_wmsLdap = $this->_getDiContainer()->get(\WMS_Ldap::class);
        }

	    return $this->_wmsLdap;
    }

    private function _getLuaService(): \Services\LuaService {
	    if (!$this->_luaService) {
	        $this->_luaService = $this->_getDiContainer()->get(\Services\LuaService::class);
        }

        return $this->_luaService;
    }

    private function getColleaguesService(): Colleagues {
        return $this->_getDiContainer()->get(Colleagues::class);
    }

    private function getUserDataCleaner(): UserDataCleaner {
        return $this->_getDiContainer()->get(UserDataCleaner::class);
    }

    private function _getDiContainer(): \Wildix\DependencyInjection\Container {
	    return isset($GLOBALS['diContainer']) ? $GLOBALS['diContainer'] : new \Wildix\DependencyInjection\Container();
    }

    private function getErasedFields(): array {
        return array_intersect_key($this->g_allow_erase_values_arr, $this->map);
    }
}
