<?php

/** Class for working with ACL (Users access level)
 * @author ITeam[Odessa]
 * @copyright wildix
 */
require_once('common/wms_ldap.php');
require_once("common/errors.php");

class ACL {

    var $menu_json = "";
    var $menu_html = "";
    var $menu_includes;

    function create_html_list($curr_deep, $opened_menu, $nodes) {
        if($curr_deep==0)$return = "<ul id='mmenu-1' class='menu'>\n";
        else $return = "<ul class='menu'>\n";
        if ($opened_menu == '') { // logout/login issue
            $opened_menu = 10;
        }
        if ($GLOBALS['wmsSpa']) {
            $opened_menu = 60;
            $_SESSION["Menuid"] = 60;
        }
        $iter = 1;
        $nsize = sizeof($nodes);
        $userPasswordIsDefaultOrNotActivatedWMS = $GLOBALS['got_userPasswordIsDefault'] || !\Wildix\License::getInstance()->isActivated();

        $disabledMenuIds = $GLOBALS['disabledMenuIds'];
        $hideMenuIds = $GLOBALS['hideMenuIds'];

        if(\Wildix\License::getInstance()->isCloud()){
            $not_show = array('qmetrics_settings', 'netsettings', 'proxy_settings', 'dhcp_server', 'snmp_settings', 'storages', 'vtun');
            foreach($not_show as $val){
                if($nodes[$val]){
                    unset($nodes[$val]);
                }
            }
        }

        $vals    = parse_ini_file('/rw2/etc/pbx/net.conf', false, INI_SCANNER_RAW);
        $modepbx = $vals['STARTUP'];

        // If pbx is in slave mode
        if ($modepbx == '1') {
            unset($nodes['ldap_net_settings']);
        }

        foreach ($nodes as $node_name => $node_val) {
            if(in_array($node_val['id'], $hideMenuIds)){
                continue;
            }
            $show_name = _t('menu.' . $node_name);

            $cclass = $iter == 1 && $curr_deep > 1 ? ' first' : ($iter == $nsize ? ' last' : '');
            if ($node_val['fa']) {
                $cclass .= ' text-secondary';
            }

            $disabled = false;
            $hidden = false;
            $denied = false;
            if (isset($node_val['include']) || isset($node_val['route'])) {
                // item
                if($node_val['type'] != 'hidden'){
                    $class_active = ($node_val['id'] == $opened_menu) ? 'active' : '';

                    if ($userPasswordIsDefaultOrNotActivatedWMS && in_array($node_val['id'], $disabledMenuIds)) {
                        $return .= "<li class='disabled'>" . '<a';
                        $disabled = true;
                    } else {
                        $target = !isset($node_val['target']) ? '' : 'target="_blank"';
                        if (isset($node_val['route'])) {
                            $return .= "<li class='" . $class_active . $cclass . "' data-menu-name='" . $node_name . "' data-spa-route='" . $node_val['route'] . "'>" . '<a class="hideOnClick" href="wms#/' . $node_val['route'] . '"' . $target ;   // attribute data-menu-name is used as a marker in UI tests [WMS-5088]
                        } else {
                            $return .= "<li class='" . $class_active . $cclass . "' data-menu-name='" . $node_name . "'>" . '<a class="" href="' . '?Menuid=' . $node_val['id'] . '"' . $target ;   // attribute data-menu-name is used as a marker in UI tests [WMS-5088]
                        }
                    }

                    if($node_val['fa']){
                        $return .= ' title="' . $show_name . '"><i class="fa '. $node_val['fa'] .'"></i></a>';
                    }else{
                        $return .= '>' . $show_name . '</a>';
                    }
                }else{
                    $return .= "<li style='display:none;'>";
                    $hidden = true;
                }

                if (
                    !empty($node_val['permission'])
                    && !WMS_Permissions::getInstance()->is_allowed('page', $node_val['permission'])
                ) {
                    $denied = true;
                }

                $this->menu_includes[
                    $node_val['id']] = ['include' => $node_val['include'],
                    'title' => $show_name,
                    'permission' => $node_val['permission'],
                    'route' => $node_val['route'],
                    'disabled' => $disabled,
                    'hidden' => $hidden,
                    'denied' => $denied
                ];
            } else {
                if (isset($node_val['id']) && $userPasswordIsDefaultOrNotActivatedWMS && in_array($node_val['id'], $disabledMenuIds)) {
                    $return .= "<li class='disabled'>" . '<a';
                    unset($node_val['type']);
                } else {
                    $class_active = ($curr_deep == 0 && $opened_menu > 40) ? 'active' : '';
                    $return .= "<li class='" . $class_active . $cclass . "' data-menu-name='" . $node_name . "'>" . '<a';  // attribute data-menu-name is used as a marker in UI tests [WMS-5088]
                }
                if($node_val['fa']){
                    $return .= ' title="' . $show_name . '"><i class="fa '. $node_val['fa'] .'"></i></a>';
                    unset($node_val['fa']);
                }else{
                    $return .= '>' . $show_name . '</a>';
                }
            }
            if (is_array($node_val) && isset($node_val['type']) && $node_val['type'] == 'menu') {
                unset($node_val['type'],$node_val['id']);
                $curr_deep++;
                $return .= $this->create_html_list($curr_deep, $opened_menu, $node_val);
            }
            $return .= "</li>\n";
            $iter++;
        }
        $return .= "</ul>\n";
        return $return;
    }

    private function protoFishMenu($opened_menu, $prefix_link) {
        $menu_xml_obl = simplexml_load_file(BASEPATH . 'dbsetup/menu.xml');
        convertXmlObjToArr($menu_xml_obl, $newarr);

        return $this->create_html_list(0, $opened_menu, $newarr);
    }

    public function init_menu($opened_menu, $prefix_link) {
        $this->menu_html = $this->protoFishMenu($opened_menu, $prefix_link);
    }
}
