<?php

require_once('common/wms_ldap.php');
require_once('classes/multipbx.class.php');
require_once('classes/phonebook/phonebook.class.php');
require_once('classes/acl/acl.class.php');
require_once('features/features.functions.php');
require_once('classes/WMS_Utils.php');

use Wildix\Colleagues\Colleague;
use Wildix\License;

class aclpbx {
    public $base_dn = '';
    private $_current_pbx_ldap_dn = null;
    private $_ad_conf_file = '/rw2/etc/pbx/ad_connect.conf';

    function __construct() {
        $connectParams = WMS_Ldap::getInstance()->getConnectParams();
        $this->base_dn = $connectParams['basedn'];
    }

    public function getSipProxy() : \Wildix\SipProxy {
        return new \Wildix\SipProxy(
            \Cache\FileCache::getInstance()
        );
    }

    /**
     * Perform password change
     *
     * @param array $phonesToSync array with phones to sync
     * @param boolean $forceSshUpdate update SSH password or not
     * @author Igor Kuts <igor.kuts@wildix.com>
     */
    private function performPasswordsChange($phonesToSync, $forceSshUpdate = false) {
        // Sync hardphone configuration
        if (!empty($phonesToSync)) {
            foreach ($phonesToSync as $phone) {
                if (is_numeric($phone)) {
                    $this->synch_hardphone_configuration($phone);
                }
            }
        }
        // Update SSH password
        if ($forceSshUpdate) {
            exec('/usr/sbin/wms_auth_sync');
        }
    }

    function get_current_pbx_ldap_searchObj() {
        $mac = \Models\PBX::getInstance()->getSerial();
        $search = WMS_Ldap::getInstance()->getEntry(WMS_Ldap::PBX, '(pbxSerial=' . $mac . ')', array('pbxSerial', 'dn'));
        return empty($search) ? false : $search;
    }

    function get_current_pbx_ldap_dn(){
        if (!is_null($this->_current_pbx_ldap_dn)) {
            return $this->_current_pbx_ldap_dn;
        }
        if ($search = $this->get_current_pbx_ldap_searchObj()) {
            $this->_current_pbx_ldap_dn = $search['dn'];
            return $this->_current_pbx_ldap_dn;
        }
        return '';
    }

    function get_phones_users($owned_by_pbx = false, $strict_name = false) {
        $ownedPbxExpr = $owned_by_pbx ? '(pbxowner=' . $this->get_current_pbx_ldap_dn() . ')' : '';
        $search = WMS_Ldap::getInstance()->getEntries(WMS_Ldap::PERSONS, '(' . LDAP_EXTEN_NUMBER . '=*)' . $ownedPbxExpr, array('cn', LDAP_EXTEN_NUMBER));

        $output = array();
        foreach ($search as $value){
            if (is_array($value[LDAP_EXTEN_NUMBER])) {
                $value[LDAP_EXTEN_NUMBER] = $value[LDAP_EXTEN_NUMBER][0];
            }
            if (is_array($value['cn'])) {
                $value['cn'] = $value['cn'][0];
            }
            if (!$strict_name) {
                $output[$value[LDAP_EXTEN_NUMBER]] = $value[LDAP_EXTEN_NUMBER] . ' - ' . $value['cn'];
            } else {
                $output[$value[LDAP_EXTEN_NUMBER]] = $value['cn'];
            }
        }
        return $output;
    }

    function getUsersAndPhones($search, $strict_name = false, $limit = 20, $excludeType = false) {

        if(strlen(trim($search))){
            $search = htmlspecialchars($search);
            $filter = "(|(".LDAP_EXTEN_NUMBER."=*".$search."*)(&(".LDAP_EXTEN_NUMBER."=*)(cn=*".$search."*)))";
        }else{
            $filter = "(".LDAP_EXTEN_NUMBER."=*)";
        }

        if($excludeType){
            $filter = '(&'.$filter.'(!(userKind='.$excludeType.')))';
        }

        $search = WMS_Ldap::getInstance()->getEntriesSortLimit(WMS_Ldap::PERSONS, $filter, array('cn', LDAP_EXTEN_NUMBER), 0, $limit, LDAP_EXTEN_NUMBER);
        if( ! $search){
            return false;
        }

        $output = array();
        $output['count'] = intval($search['count']);

        foreach ($search as $value){
            if(! is_array($value)){
                continue;
            }
            if (is_array($value[LDAP_EXTEN_NUMBER])) {
                $value[LDAP_EXTEN_NUMBER] = $value[LDAP_EXTEN_NUMBER][0];
            }
            if (is_array($value['cn'])) {
                $value['cn'] = $value['cn'][0];
            }
            if (!$strict_name) {
                $output[$value[LDAP_EXTEN_NUMBER]] = $value[LDAP_EXTEN_NUMBER] . ' - ' . $value['cn'];
            } else {
                $output[$value[LDAP_EXTEN_NUMBER]] = $value['cn'];
            }
        }

        return $output;
    }

    function getUsersAndMail($search, $strict_name = false, $limit = 20) {

        if(strlen(trim($search))){
            $search = htmlspecialchars($search);
            $filter = "(|(mail=*".$search."*)(&(mail=*)(cn=*".$search."*)))";
        }else{
            $filter = "(mail=*)";
        }

        $search = WMS_Ldap::getInstance()->getEntriesSortLimit(WMS_Ldap::PERSONS, $filter, array('cn', 'mail'), 0, $limit);
        if( ! $search){
            return false;
        }

        $output = array();
        $output['count'] = intval($search['count']);

        foreach ($search as $value){
            if(! is_array($value)){
                continue;
            }
            if (is_array($value['mail'])) {
                $value['mail'] = $value['mail'][0];
            }
            if (is_array($value['cn'])) {
                $value['cn'] = $value['cn'][0];
            }
            if (!$strict_name) {
                $output[$value['mail']] = $value['mail'] . ' - ' . $value['cn'];
            } else {
                $output[$value['mail']] = $value['cn'];
            }
        }

        return $output;
    }

    function getUsersByPhone($search, $strict_name = false) {

        if( ! $search){
            return false;
        }
        if(is_array($search)){
            $filter = "(|";
            foreach ($search as $val){
                $val = htmlspecialchars($val);
                $filter .= "(".LDAP_EXTEN_NUMBER."=".$val.")";
            }

            $filter .= ")";
        }else{
            $filter = "(".LDAP_EXTEN_NUMBER."=".$search.")";
        }


        $search = WMS_Ldap::getInstance()->getEntriesSortLimit(WMS_Ldap::PERSONS, $filter, array('cn', LDAP_EXTEN_NUMBER));
        if( ! $search){
            return false;
        }

        $output = array();

        foreach ($search as $value){
            if(! is_array($value)){
                continue;
            }
            if (is_array($value[LDAP_EXTEN_NUMBER])) {
                $value[LDAP_EXTEN_NUMBER] = $value[LDAP_EXTEN_NUMBER][0];
            }
            if (is_array($value['cn'])) {
                $value['cn'] = $value['cn'][0];
            }
            if (!$strict_name) {
                $output[$value[LDAP_EXTEN_NUMBER]] = $value[LDAP_EXTEN_NUMBER] . ' - ' . $value['cn'];
            } else {
                $output[$value[LDAP_EXTEN_NUMBER]] = $value['cn'];
            }
        }

        return $output;
    }

    /**
     * Export users
     *
     * @return array
     * @author unknown
     * @author Igor Kuts <igor.kuts@wildix.com>
     */
    function get_users_csv_arr() {
        // Get all users
        $user_get_values = array(
            'uid',
            'sourceId',
            'userKind',
            'cn',
            'userPrincipalName',
            LDAP_EXTEN_NUMBER,
            'facsimileTelephoneNumber',
            LDAP_OFFICE_NUMBER,
            'mail',
            'mobile',
            'userDialplan',
            'userFaxDialplan',
            'preferredLanguage',
            'group',
            'owner',
            'ou',
            'imageUrl',
            'userPassword',
            'wuserPasswordSip',
            Colleague::LICENSE_TYPE,
        );

        // Get available groups;
        $groups = $this->get_groups_assoc();

        // need to create proper permissions filter
        $users_filter = '';
        if (!WMS_Permissions::getInstance()->is_root()) {
            foreach ($groups As $gr_dn => $gr_cn) {
                if (WMS_Permissions::getInstance()->is_allowed('group', $gr_dn)) {
                    $users_filter .= '(owner=' . $gr_dn . ')';
                }
            }
        }
        if ($users_filter != '') {
            $users_filter = '(|' . $users_filter .')';
        }

        /* @var $license License */
        $license = $GLOBALS['diContainer']->get(License::class);

        $search = WMS_Ldap::getInstance()->getEntries(WMS_Ldap::PERSONS, $users_filter, $user_get_values);

        $output = array();
        $empty_values = array();
        foreach ($user_get_values as $t_val){
            $empty_values[$t_val] = '';
        }
        $empty_values = array_merge($empty_values, array('group' => ''));

        foreach ($search as $key => $value) {
            foreach ($value As $l_key => $l_val) {
                if (is_array($l_val) && !in_array($l_key, array())) {
                    $output[$key][$l_key] = str_replace('"', '""', $l_val[0]);
                } else {
                    $output[$key][$l_key] = str_replace('"', '""', $l_val);
                }
                if ($l_key == 'owner') {
                    $output[$key]['group'] = $groups[$output[$key][$l_key]];
                }
            }

            if ($output[$key]['sourceId'] === null || $output[$key]['sourceId'] === '') {
                $output[$key]['sourceId'] = $output[$key]['cn'];
            }
            if (empty($output[$key][Colleague::LICENSE_TYPE])) {
                $output[$key][Colleague::LICENSE_TYPE] = $license->getMaximumAvailableLicenseType();
            }

            $output[$key] = array_merge($empty_values, $output[$key]);
            unset($output[$key]['owner']);
            unset($output[$key]['dn']);
        }
        return $output;
    }


    /**
     * Get all users from LDAP
     * The function should be used only to represent the list of users in WMS table
     * It uses Admin permissions ACL to limit the list of users it returns
     *
     * @return array
     */
    public function get_users_for_the_list($pbxSerial, $startIndex, $results, $searchText, $sortKey, $sortDir) {
        $userGetValues = array(
            'userKind',
            'uid',
            'cn',
            'userPrincipalName',
            LDAP_EXTEN_NUMBER,
            'facsimileTelephoneNumber',
            LDAP_OFFICE_NUMBER,
            'mail',
            'mobile',
            'userDialplan',
            'userFaxDialplan',
            'preferredLanguage',
            'group', //Group
            'ou', //Department
            'owner',
            'pbxowner',
            'modifyTimestamp',
            'dn',
            'userPassword',
            Colleague::LICENSE_TYPE,
        );

        $sort = $sortKey;

        if($sortKey == 'extenNumber'){
            $sort = LDAP_EXTEN_NUMBER;
        }else if($sortKey == 'officeNumber'){
            $sort = LDAP_OFFICE_NUMBER;
        }elseif($sortKey == 'group'){
            $sort = 'owner';
        }else if($sortKey == 'pbxgroup'){
            $sort = 'pbxowner';
        }

        if($sortDir != 'desc'){
            $sortDir = 'asc';
        }
        $multipbx_class = new multipbx();
        $pbx_net_mode = $multipbx_class->get_mode();
        if(!($pbx_net_mode==NULL || $pbx_net_mode == '0')){
            // if WMS network enabled
            if(empty($pbxSerial)){
                $pbxDn = $this->get_current_pbx_ldap_dn();
            }elseif($pbxSerial != 'all'){
                $pbxDn = multipbx::getPbxDnBySerial($pbxSerial);
            }
        }

        // Get available groups;
        $groups = $this->get_groups_assoc();

        // Get available pbxes;
        $pbxes = $this->get_pbxes_assoc();

        // need to create proper permissions filter
        $users_filter = '';
        if (!WMS_Permissions::getInstance()->is_root()) {
            foreach ($groups As $gr_dn => $gr_cn) {
                if (WMS_Permissions::getInstance()->is_allowed('group', $gr_dn)) {
                    $users_filter .= '(owner=' . $gr_dn . ')';
                }
            }
            if($users_filter != ''){
                $users_filter = '(|' . $users_filter .')';
            }
        }
        if($pbxDn){
            $users_filter .= '(pbxowner=' . $pbxDn . ')';
        }

        if($searchText AND $searchText != ''){
            $searchKey = array(
                    'cn',
                    'userPrincipalName',
                    LDAP_EXTEN_NUMBER,
                    'facsimileTelephoneNumber',
                    LDAP_OFFICE_NUMBER,
                    'mail',
                    'mobile',
                    'ou', //Department
                    Colleague::LICENSE_TYPE,
            );

            $users_filter .= '(|';
            foreach ($searchKey as $valKey){
                $users_filter .= '(' . $valKey . '=*' . $searchText . '*)';
            }
            $users_filter .= ')';
        }

        if($users_filter != ''){
            $users_filter = '(&' . $users_filter .')';
        }
        $output = array();
        $search = WMS_Ldap::getInstance()->getEntriesSortLimit(WMS_Ldap::PERSONS, $users_filter, $userGetValues, $startIndex, $results, $sort, $sortDir);
        if(empty($search) || !is_array($search)){
            return $output;
        }

        $state_result = array();
        try {
            $state_result = $this->getSipProxy()->getUsersRegistrations();
        } catch (Exception $e) {}

        $totalRecords =  intval($search['count']) ;
        unset($search['count']);

        $usersWithWeakPassword = array();
        $empty_values = array();
        foreach ($userGetValues as $t_val){
            if ($t_val == 'userPassword') {
                continue;
            }
            $empty_values[$t_val] = '';
        }
        $empty_values = array_merge($empty_values, array(
            'extenNumber' => '',
            'group' => '',
            'pbxgroup' => '',
            'officeNumber' => ''
        ));
        foreach ($search as $key => $value) {
            foreach ($value as $l_key => $l_val) {
                //! important do not return password to client side
                if ($l_key == 'userPassword') {
                    if ($this->check_password_strength($l_val, true) == 'weak' ){
                        $usersWithWeakPassword[] = $value[LDAP_EXTEN_NUMBER]?$value[LDAP_EXTEN_NUMBER]:$value['cn'];
                    }
                    continue;
                }
                if (is_array($l_val) && !in_array($l_key, array())) {
                    $output[$key][$l_key] = $l_val[0];
                } else {
                    $output[$key][$l_key] = $l_val;
                }
                if ($l_key == LDAP_EXTEN_NUMBER) {
                    $output[$key]['extenNumber'] = $output[$key][$l_key];
                    if (isset($state_result[$output[$key][$l_key]])) {
                        $output[$key]['registrations'] = $state_result[$output[$key][$l_key]];
                    }
                }
                if ($l_key == LDAP_OFFICE_NUMBER) {
                    $output[$key]['officeNumber'] = $output[$key][$l_key];
                }
                if ($l_key == 'owner') {
                    $output[$key]['group'] = $groups[$output[$key][$l_key]];
                }
                if ($l_key == 'pbxowner') {
                    $output[$key]['pbxgroup'] = $pbxes[$output[$key][$l_key]];
                }
            }
            $output[$key] = array_merge($empty_values, $output[$key]);
            if (!isset($output[$key]['registrations'])) {
                $output[$key]['registrations'] = array('registrations' => array());
            }
        }
        // Check is dialplan exists
        $goodDialplans = array_keys(get_contextnames());
        foreach ($output as &$user) {
            if (!in_array($user['userDialplan'], $goodDialplans)) {
                $user['userDialplan'] = '---';
            }
            if (!in_array($user['userFaxDialplan'], $goodDialplans)) {
                $user['userFaxDialplan'] = '---';
            }
        }

        $output['totalRecords'] = $totalRecords;
        $output['startIndex'] = $startIndex;
        $output['rowsPerPage'] = $results;
        $output['sortDir'] = $sortDir;
        $output['sortKey'] = $sortKey;
        if (count($usersWithWeakPassword)){
            $output['WARNINGS'] = array( _t('aclpbx.PasswordWeakForUsers') . implode(', ', $usersWithWeakPassword));
        } else {
            $output['WARNINGS'] = array();
        }

        return $output;
    }

    function get_sync_attributes() {
        return array('sourceId', 'userKind', 'cn', 'userPrincipalName', 'extenNumber', 'facsimileTelephoneNumber', 'officeNumber', 'mail', 'mobile', 'userDialplan', 'userFaxDialplan', 'preferredLanguage', 'owner', 'ou', 'userPassword','wuserPasswordSip', 'imageUrl', 'licenseType', 'pbxowner');
    }

    function get_sync_attributes_translation() {
        $return = array();
        foreach ($this->get_sync_attributes() As $attr_key){
            $return[$attr_key] = _t('aclpbx.'.$attr_key);
        }
        return $return;
    }

    function get_sync_settings_n_map() {
        $map = array(
            'ldap' => array(
                'sourceId' => 'uid',
                'cn' => 'cn',
                'userPrincipalName' => 'userPrincipalName',
                'extenNumber' => 'ipPhone',
                'facsimileTelephoneNumber' => 'facsimileTelephoneNumber',
                'officeNumber' => 'telephoneNumber',
                'mail' => 'mail',
                'mobile' => 'mobile',
                'preferredLanguage' => 'preferredLanguage',
                'ou' => 'ou',
                'userPassword' => 'userPassword',
                'wuserPasswordSip' => 'wuserPasswordSip'
            ),
            'activeD' => array(
                'sourceId' => 'uid',
                'cn' => 'cn',
                'userPrincipalName' => 'userPrincipalName',
                'extenNumber' => 'ipPhone',
                'facsimileTelephoneNumber' => 'facsimileTelephoneNumber',
                'officeNumber' => 'telephoneNumber',
                'mail' => 'mail',
                'mobile' => 'mobile',
                'preferredLanguage' => 'preferredLanguage',
                'ou' => 'ou',
                'userPassword' => 'userPassword',
                'wuserPasswordSip' => 'wuserPasswordSip'
            ),
            'domino' => array(
                'sourceId' => 'uid',
                'cn' => 'cn',
                'userPrincipalName' => 'userPrincipalName',
                'extenNumber' => 'ipPhone',
                'facsimileTelephoneNumber' => 'facsimileTelephoneNumber',
                'officeNumber' => 'telephoneNumber',
                'mail' => 'mail',
                'mobile' => 'mobile',
                'preferredLanguage' => 'preferredLanguage',
                'ou' => 'ou',
                'userPassword' => 'userPassword',
                'wuserPasswordSip' => 'wuserPasswordSip'
            ),
            'mysql' => array(
                'sourceId' => 'id',
                'cn' => 'name',
                'extenNumber' => 'ip_phone',
                'facsimileTelephoneNumber' => 'fax',
                'officeNumber' => 'office_number',
                'mail' => 'email',
                'mobile' => 'mobile',
                'preferredLanguage' => 'language',
                'owner' => 'group_name',
                'ou' => 'department',
                'userPassword' => 'password',
                'imageUrl' => 'image_url'
            ),
            'mssql' => array(
                'sourceId' => 'id',
                'cn' => 'name',
                'extenNumber' => 'ip_phone',
                'facsimileTelephoneNumber' => 'fax',
                'officeNumber' => 'office_number',
                'mail' => 'email',
                'mobile' => 'mobile',
                'preferredLanguage' => 'language',
                'owner' => 'group_name',
                'ou' => 'department',
                'userPassword' => 'password',
                'imageUrl' => 'image_url'
            ),
            'office365' => array(
                'sourceId' => 'id',
                'cn' => 'displayName',
                'userPrincipalName' => 'userPrincipalName',
                'officeNumber' => 'businessPhones',
                'mail' => 'mail',
                'mobile' => 'mobilePhone',
                'preferredLanguage' => 'preferredLanguage',
                'ou' => 'department'
            ),
            'zohoCrm' => array(
                'sourceId' => 'zuid',
                'cn' => 'fullName',
                'userPrincipalName' => 'firstName',
                'officeNumber' => 'phone',
                'mail' => 'email',
                'mobile' => 'mobile',
                'preferredLanguage' => 'language',
                'facsimileTelephoneNumber' => 'fax',
                'ou' => 'role'
            ),
            'google' => array(
                'sourceId' => 'id',
                'cn' => 'name | login',
                'extenNumber' => '',
                'facsimileTelephoneNumber' => 'phoneWorkFax',
                'officeNumber' => 'phoneWork',
                'mail' => 'email',
                'mobile' => 'phoneMobile',
                'owner' => 'group',
                'userPassword' => 'password',
                'imageUrl' => 'avatar',
                'ou' => 'department'
            ),
            'csv' => array(
                'sourceId' => 'SourceId',
                'userKind' => 'Type',
                'cn' => 'Name',
                'userPrincipalName' => 'Login',
                'extenNumber' => 'Phone',
                'facsimileTelephoneNumber' => 'Fax',
                'officeNumber' => 'OfficePhone',
                'mail' => 'Email',
                'mobile' => 'Mobile',
                'userDialplan' => 'Dialplan',
                'userFaxDialplan' => 'FaxDialplan',
                'preferredLanguage' => 'Lang',
                'owner' => 'Group',
                'ou' => 'Department',
                'userPassword' => 'Password',
                'wuserPasswordSip' => 'SipPassword',
                'imageUrl' => 'ImageUrl',
                'licenseType' => 'LicenseType',
            )
        );

//		'ldap' => array(
//			'host' => '192.168.1.96',
//			'port' => '389',
//			'user' => 'CN=Administrator,CN=Users,DC=test,DC=wildix,DC=com',
//			'password' => 'wildix',
//			'basedn' => 'dc=test,dc=wildix,dc=com',
//			'filter' => '(&(objectCategory=person)(objectClass=user)(!(userAccountControl:1.2.840.113556.1.4.803:=2)))'
//		),
        $settings = array(
            'ldap' => array(
                'host' => '',
                'port' => '389',
                'secure' => 'no',
                'user' => '',
                'password' => '',
                'basedn' => '',
                'filter' => '(&(objectCategory=person)(objectClass=user)(!(userAccountControl:1.2.840.113556.1.4.803:=2)))'
            ),
            'activeD' => array(
                'host' => '',
                'port' => '389',
                'secure' => 'no',
                'user' => '',
                'password' => '',
                'basedn' => '',
                'windomain' => '',
                'fullDomain' => '',
                'signon' => 'yes',
                'signon_only' => 'no',
                'filter' => '(&(objectCategory=person)(objectClass=user)(!(userAccountControl:1.2.840.113556.1.4.803:=2)))'
            ),
            'domino' => array(
                'host' => '',
                'port' => '389',
                'secure' => 'no',
                'user' => '',
                'password' => '',
//                'basedn' => '',
                'signon' => 'yes',
                'signon_only' => 'no',
                'filter' => '(&(objectClass=dominoperson))'
            ),
            'mysql' => array(
                'host' => '',
                'port' => '',
                'user' => '',
                'password' => '',
                'database' => '',
                'timeout' => '',
                'filter' => 'SELECT ${MAP} FROM `users_table` WHERE `type`="local"'
            ),
            'mssql' => array(
                'host' => '',
                'port' => '',
                'user' => '',
                'password' => '',
                'database' => '',
                'timeout' => '',
                'filter' => 'SELECT ${MAP} FROM [users_table] WHERE [type]=\'local\''
            ),
            'csv' => array(
                'import_type' => 'upload',
                'import_mountpoint' => '',
                'import_filepath' => ''
            ),
            'office365' => array(
                'mail' => '',
                'received_token_time' => '',
                'access_token' => '',
                'token_type' => '',
                'expires_in' => '',
                'id_token' => '',
                'id_token_expires_in' => '',
                'refresh_token' => '',
                'signon_only' => 'no'
            ),
            'zohoCrm' => array(
                'full_name' => '',
                'received_token_time' => '',
                'access_token' => '',
                'token_type' => '',
                'expires_in' => '',
                'refresh_token' => '',
                'api_domain' => '',
                'location' => '',
                'accounts_server' => '',
            ),
            'google' => array(
                'mail' => '',
                'received_token_time' => '',
                'access_token' => '',
                'token_type' => '',
                'expires_in' => '',
                'refresh_token' => '',
                'phonebooks' => '',
                'signon_only' => 'no'
            )
        );

        $recurrent_job = array(
            'enabled' => 'no', // yes/no
            'interval' => '2', // in hours
            'email' => ''
        );

        $global_vals = array(
            'backend' => 'ldap',
            'remove_users' => 'no',
            'erase_values' => 'no'
        );

        if (!file_exists('/rw2/etc/users_sync.conf') || ($from_file = parse_ini_file('/rw2/etc/users_sync.conf',true,INI_SCANNER_RAW)) === false){
            return array('map' => $map, 'settings' => $settings, 'recurrent_job' => $recurrent_job, 'global' => $global_vals);
        } else {

            $return = array();

            foreach (array('ldap', 'activeD', 'domino', 'mysql', 'mssql', 'office365', 'google', 'csv', 'zohoCrm') As $backend) {
                if (!is_array($from_file[$backend . '_settings'])) {
                    $return['settings'][$backend] = $settings[$backend];
                } else {
                    $return['settings'][$backend] = array_intersect_key(
                        array_merge($settings[$backend], $from_file[$backend . '_settings']),
                        $settings[$backend]
                    );
                }

                if (!is_array($from_file[$backend . '_map'])) {
                    $return['map'][$backend] = $map[$backend];
                } else {
                    // BC: if user configured custom cn parameter, use it.
                    if (!isset($from_file[$backend . '_map']['sourceId']) || $from_file[$backend . '_map']['sourceId'] === '') {
                        $from_file[$backend . '_map']['sourceId'] = $from_file[$backend . '_map']['cn'];
                    }

                    $return['map'][$backend] = array_intersect_key(
                        array_merge($map[$backend], $from_file[$backend . '_map']),
                        $from_file[$backend . '_map']
                    );
                }
            }

            $return['default'] = array('map' => $map, 'settings' => $settings);

            if(!$from_file['recurrent_job']){
                $from_file['recurrent_job'] = $recurrent_job;
            }
            $return['recurrent_job'] = $from_file['recurrent_job'];

            if(!$from_file['global']){
                $from_file['global'] = $global_vals;
            }
            $return['global'] = $from_file['global'];

            if (!isset($return['global']['remove_users'])) $return['global']['remove_users'] = 'no';
            if (!isset($return['global']['erase_values'])) $return['global']['erase_values'] = 'no';

            if (!isset($return['settings']['csv']['import_type']) || empty($return['settings']['csv'])) {
                $return['settings']['csv'] = $settings['csv'];
            }
            if (!isset($return['settings']['mysql']['timeout'])) {
                $return['settings']['mysql']['timeout'] = '';
            }
            if (!isset($return['settings']['mssql']['timeout'])) {
                $return['settings']['mysql']['timeout'] = '';
            }

            // default 'yes'
            $return['settings']['activeD']['signon'] = 'no';
            $return['settings']['activeD']['signon_only'] = 'no';
            $return['settings']['domino']['signon'] = 'no';
            $return['settings']['domino']['signon_only'] = 'no';
            $return['settings']['office365']['signon_only'] = 'no';
            $return['settings']['google']['signon_only'] = 'no';
            if (!array_key_exists('secure', $return['settings']['ldap'])){
                $return['settings']['ldap']['secure'] = 'no';
                $return['settings']['domino']['secure'] = 'no';
                $return['settings']['activeD']['secure'] = 'no';
            }
            if(!empty($return['settings']['activeD']['host']) || !empty($return['settings']['domino']['host']) ||
                !empty($return['settings']['office365']['mail']) || !empty($return['settings']['google']['mail'])){
                if (file_exists($this->_ad_conf_file)){
                    $ad = parse_ini_file($this->_ad_conf_file, false, INI_SCANNER_RAW);
                    if (! empty($ad['type'])){
                        switch($ad['type']){
                            case 'activeD':
                                $return['settings']['activeD']['windomain'] = $ad['windomain'] ?? '';
                                $return['settings']['activeD']['fullDomain'] = $ad['fullDomain'] ?? '';
                                $return['settings']['activeD']['signon'] = 'yes';
                                if ($ad['signon_only'] == 'yes'){
                                    $return['settings']['activeD']['signon_only'] = 'yes';
                                }
                                break;
                            case 'domino':
                                $return['settings']['domino']['signon'] = 'yes';
                                if ($ad['signon_only'] == 'yes'){
                                    $return['settings']['domino']['signon_only'] = 'yes';
                                }
                                break;
                            case 'office365':
                                if ($ad['signon_only'] == 'yes'){
                                    $return['settings']['office365']['signon_only'] = 'yes';
                                }
                                break;
                            case 'google':
                                if ($ad['signon_only'] == 'yes'){
                                    $return['settings']['google']['signon_only'] = 'yes';
                                }
                                break;
                            default:
                                break;
                        }
                    }
                }
            }

            return $return;
        }
    }

    function set_sync_settings_n_map($settings) {
        $previous_settings = $this->get_sync_settings_n_map();

        $signon = $settings['activeD']['settings']['signon'];
        unset($settings['activeD']['settings']['signon']);

        $signon_domino = $settings['domino']['settings']['signon'];
        unset($settings['domino']['settings']['signon']);

        $to_save = array(
            'global' => $settings['global'],
            'ldap_settings' => $settings['ldap']['settings'],
            'activeD_settings' => $settings['activeD']['settings'],
            'domino_settings' => $settings['domino']['settings'],
            'mysql_settings' => $settings['mysql']['settings'],
            'mssql_settings' => $settings['mssql']['settings'],
            'office365_settings' => $settings['office365']['settings'],
            'zohoCrm_settings' => $settings['zohoCrm']['settings'],
            'google_settings' => $settings['google']['settings'],
            'csv_settings' => $settings['csv']['settings'],
            'ldap_map' => $settings['ldap']['map'],
            'activeD_map' => $settings['activeD']['map'],
            'domino_map' => $settings['domino']['map'],
            'mysql_map' => $settings['mysql']['map'],
            'mssql_map' => $settings['mssql']['map'],
            'office365_map' => $settings['office365']['map'],
            'google_map' => $settings['google']['map'],
            'csv_map' => $settings['csv']['map'],
            'recurrent_job' => $settings['recurrent_job']
        );
        write_ini_file('/rw2/etc/users_sync.conf', $to_save);
        if (($settings['recurrent_job']['enabled'] == 'yes' && $previous_settings['recurrent_job']['enabled'] != 'yes') ||
            ($settings['recurrent_job']['enabled'] == 'yes' && $previous_settings['recurrent_job']['enabled'] == 'yes' && $settings['recurrent_job']['interval'] != $previous_settings['recurrent_job']['interval'])
        ){
            // enable if was disabled
            // or
            // change if interval was changed
            $this->users_sync_set_cron($settings['recurrent_job']['interval']);
        } elseif ($settings['recurrent_job']['enabled'] != 'yes' && $previous_settings['recurrent_job']['enabled'] == 'yes') {
            // disable cron if was enabled
            $this->users_sync_set_cron();
        }

        switch($settings['global']['backend']){
            case 'activeD':

                if($signon == 'yes' && $settings['activeD']['settings']['host'] != '' && $settings['activeD']['settings']['basedn'] != ''){
                    $host = $settings['activeD']['settings']['host'];
                    $secure = filter_var($settings['activeD']['settings']['secure'], FILTER_VALIDATE_BOOLEAN)?'yes':'no';
                    if($settings['activeD']['settings']['port'] != ''){
                        $host .= ':' . $settings['activeD']['settings']['port'];
                    }
                    if (!empty($settings['activeD']['settings']['signon_only']) && $settings['activeD']['settings']['signon_only'] == 'yes'){
                        $signon_only = 'yes';
                    } else {
                        $signon_only = 'no';
                    }

                    $dcParts = $this->getDcPartsFromBaseDn($settings['activeD']['settings']['basedn']);

                    $fullDomain = $settings['activeD']['settings']['fullDomain'] ?? '';
                    if ($fullDomain === '') {
                        $fullDomain = implode('.', $dcParts);
                    }

                    $winDomain = $settings['activeD']['settings']['windomain'] ?? '';
                    if ($winDomain === '') {
                        $winDomain = $dcParts[0] ?? '';
                    }

                    if ($winDomain || $fullDomain) {
                        write_ini_file(
                            $this->_ad_conf_file,
                            [
                                'type' => 'activeD',
                                'signon_only' => $signon_only,
                                'host' => $host,
                                'windomain' => $winDomain,
                                'fullDomain' => $fullDomain,
                                'secure' => $secure
                            ],
                            true
                        );
                    } else {
                        file_put_contents($this->_ad_conf_file, '');
                    }
                } else {
                    file_put_contents($this->_ad_conf_file, '');
                }
                break;
            case 'domino':
                if($signon_domino == 'yes' && $settings['domino']['settings']['host'] != ''){
                    $host = $settings['domino']['settings']['host'];
                    $secure = filter_var($settings['domino']['settings']['secure'], FILTER_VALIDATE_BOOLEAN)?'yes':'no';
                    if($settings['domino']['settings']['port'] != ''){
                        $host .= ':' . $settings['domino']['settings']['port'];
                    }
                    if (!empty($settings['domino']['settings']['signon_only']) && $settings['domino']['settings']['signon_only'] == 'yes'){
                        $signon_only = 'yes';
                    } else {
                        $signon_only = 'no';
                    }
                    write_ini_file($this->_ad_conf_file, array('type'=>'domino', 'signon_only'=>$signon_only, 'host'=>$host, 'secure'=>$secure), true);
                } else {
                    file_put_contents($this->_ad_conf_file, '');
                }
                break;
            case 'google':
                if(!empty($settings['google']['settings']['mail'])){
                    if(!empty($settings['google']['settings']['signon_only']) && $settings['google']['settings']['signon_only'] == 'yes'){
                        $signon_only = 'yes';
                    } else {
                        $signon_only = 'no';
                    }
                    write_ini_file($this->_ad_conf_file, array('type'=>'google', 'signon_only'=>$signon_only));
                } else {
                    file_put_contents($this->_ad_conf_file, '');
                }
                break;
            case 'office365':
                if(!empty($settings['office365']['settings']['mail'])){
                    if(!empty($settings['office365']['settings']['signon_only']) && $settings['office365']['settings']['signon_only'] == 'yes'){
                        $signon_only = 'yes';
                    } else {
                        $signon_only = 'no';
                    }
                    write_ini_file($this->_ad_conf_file, array('type'=>'office365', 'signon_only'=>$signon_only));
                } else {
                    file_put_contents($this->_ad_conf_file, '');
                }
                break;
            case 'zohoCrm':
                if(!empty($settings['zohoCrm']['settings']['full_name'])){
                    write_ini_file($this->_ad_conf_file, array('type'=>'zohoCrm'));
                } else {
                    file_put_contents($this->_ad_conf_file, '');
                }
                break;
            default:
                if(file_exists($this->_ad_conf_file)){
                    file_put_contents($this->_ad_conf_file, '');
                }
                break;
        }

        $_SESSION['authType'] = $settings['global']['backend'];

        return $this->get_sync_settings_n_map();
    }

    function getDcPartsFromBaseDn(string $baseDn): array {
        return array_reduce(
            explode(',', $baseDn),
            function ($acc, $item) {
                $param = explode('=', $item);
                if (strtolower($param[0]) === 'dc') {
                    $acc[] = trim($param[1]);
                }
                return $acc;
            },
            []
        );
    }

    function users_sync_set_cron($interval = false) {
        if ($interval == '24') {
            $interval = '23';
        } else if ($interval !== false) {
            $interval = '*/' . $interval;
        }
        if ($interval !== false) {
            exec('tmp_cron=`mktemp /tmp/session/w_usync_XXXXXXXXXX`; crontab -u wms -l | grep -v wms_users_sync > $tmp_cron && echo \'0 ' . escapeshellarg($interval) . ' * * * /usr/sbin/wms_users_sync > /dev/null\' >> $tmp_cron && if [ -e "$tmp_cron" -a -n "$(cat $tmp_cron)" ]; then crontab -u wms $tmp_cron; fi; rm $tmp_cron');
        } else {
            // disable
            exec('tmp_cron=`mktemp /tmp/session/w_usync_XXXXXXXXXX`; crontab -u wms -l | grep -v wms_users_sync > $tmp_cron && if [ -e "$tmp_cron" -a -n "$(cat $tmp_cron)" ]; then crontab -u wms $tmp_cron; fi; rm $tmp_cron');
        }
    }

    function users_sync_disable_recurrent_sync() {
        $t_settings = $this->get_sync_settings_n_map();
        $save_settings = array();
        $save_settings['global'] = $t_settings['global'];
        foreach ($t_settings['settings'] as $backend => $settings) {
            $save_settings[$backend]['settings'] = $settings;
            if ($backend == 'csv') {
                $save_settings[$backend]['settings']['backend'] = $backend;
            }
        }
        foreach ($t_settings['map'] as $backend => $map) {
            $save_settings[$backend]['map'] = $map;
        }
        $save_settings['recurrent_job'] = $t_settings['recurrent_job'];
        $save_settings['recurrent_job']['enabled'] = 'no';
        return $this->set_sync_settings_n_map($save_settings);
    }

    /**
     * Set user by adding new or editing existing
     * NOTE: don't forget to add 'synch_hardphone' if 'wuserPasswordSip' changed in this function
     *
     * @param array $parameters
     * @param boolean $import
     * @return mixed error message or true
     */
    function set_user($parameters, $import = false) {
        if (!is_array($parameters)) {
            $parameters = [];
        }
        // Normilize fax, mobile and office numbers
        if (!$import) {
            $d_vars = WMS_Utils_get_normalization_variables();
            $parameters['facsimileTelephoneNumber'] = WMS_Utils_normalize_the_number(
                $parameters['facsimileTelephoneNumber'],
                $d_vars['GINTERNATIONAL_PREFIX'],
                $d_vars['GNATIONAL_PREFIX'],
                $d_vars['GCOUNTRY_CODE']
            );
            $parameters['mobile'] = WMS_Utils_normalize_the_number(
                $parameters['mobile'],
                $d_vars['GINTERNATIONAL_PREFIX'],
                $d_vars['GNATIONAL_PREFIX'],
                $d_vars['GCOUNTRY_CODE']
            );
            $parameters['officeNumber'] = WMS_Utils_normalize_the_number(
                $parameters['officeNumber'],
                $d_vars['GINTERNATIONAL_PREFIX'],
                $d_vars['GNATIONAL_PREFIX'],
                $d_vars['GCOUNTRY_CODE']
            );
            unset($d_vars);
        }
        // Trim values
        array_walk(
            $parameters,
            function (&$v) {
                $v = trim($v);
            }
        );
        if (isset($parameters['cn'])) {
            $tmp_cn_arr = explode(' ', $parameters['cn']);
            $parameters['sn'] = $tmp_cn_arr[count($tmp_cn_arr)-1];
            unset($tmp_cn_arr);
            $parameters['givenName'] = trim(substr($parameters['cn'], 0, strrpos($parameters['cn'], $parameters['sn'])));
        }
        if (isset($parameters['extenNumber'])) {
            $parameters[LDAP_EXTEN_NUMBER] = $parameters['extenNumber'];
        }
        if (isset($parameters['officeNumber'])) {
            $parameters[LDAP_OFFICE_NUMBER] = $parameters['officeNumber'];
        }
        if (!WMS_Permissions::getInstance()->is_root()) {
            if (isset($parameters['owner']) && !WMS_Permissions::getInstance()->is_allowed('group', $parameters['owner'])) {
                return _t('strings.permissionsDenied');
            }
        }

        if (!empty($parameters['licenseType']) && !in_array($parameters['licenseType'], License::getLicenseTypes())) {
            $parameters['licenseType'] = License::getDefaultLicenseType();
        }

        // validate
        if($errors = $this->validate_people($parameters)){
            return $errors;
        }

        $attrArray = array(
                        'cn',
                        'userPrincipalName',
                        'sn',
                        'givenName',
                        'mail',
                        LDAP_EXTEN_NUMBER,
                        LDAP_OFFICE_NUMBER,
                        'facsimileTelephoneNumber',
                        'userKind',
                        'userDialplan',
                        'userFaxDialplan',
                        'mobile',
                        'preferredLanguage',
                        'owner',
                        'ou',
                        'imageUrl',
                        'userPassword',
                        'wuserPasswordSip',
                        'sourceId',
                        Colleague::LICENSE_TYPE,
                    );

        // Edit user in LDAP
        if (isset($parameters['uid']) && $parameters['uid'] != '' && $parameters['uid'] != 'new') {
            // Defining the DN we want to fetch;

            $entry = WMS_Ldap::getInstance()->getEntryByDn($parameters['dn'], $attrArray);

            if (empty($entry['licenseType']) && empty($parameters['licenseType'])) {
                $parameters['licenseType'] = License::getDefaultLicenseType();
            }

            // Can not update 'admin' name
            if (isset($parameters['cn'])) {
                if (strtolower($entry['cn']) == strtolower('admin')) {
                    $parameters['cn'] = 'admin';
                    $parameters['userKind'] = 'admin';
                }
            }
            // not main admin cannot change it's own group:
            if (!WMS_Permissions::getInstance()->is_root() && isset($parameters['owner']) && User::getInstance()->getDn() != '' && User::getInstance()->getDn() == $parameters['dn']) {
                $parameters['owner'] = User::getInstance()->getGroupDn();
            }
            if (!WMS_Permissions::getInstance()->is_root() && $parameters['userKind'] == 'admin') {
                if (isset($parameters['userKind'])) {
                    unset($parameters['userKind']);
                }
            }
            $result = array();
            // Changing attributes:
            foreach ($attrArray AS $key) {
                if (isset($parameters[$key]) && (string)$parameters[$key] !== (string)$entry[$key]) {
                    $result[$key] = $parameters[$key];
                }
            }

            if(count($result) < 1){
                return true;
            }

            if(isset($result['cn'])){
                $result['imageUrl'] = '';
            }

            $res = WMS_Ldap::getInstance()->update($parameters['dn'], $result);
            if ($res !== true) {
                return $res;
            }

            unset($entry, $result, $attrArray, $key, $res);

        } else { // Add new user to LDAP
            if (!WMS_Permissions::getInstance()->is_allowed('permissions','add_remove_users'))  {
                return array(_t('strings.permissionsDenied'));
            }
            if (!WMS_Permissions::getInstance()->is_root()) {
                if (isset($parameters['userKind']) && $parameters['userKind'] == 'admin') {
                    $parameters['userKind'] = 'user';
                }
            }
            if (empty($parameters['licenseType'])) {
                $parameters['licenseType'] = License::getDefaultLicenseType();
            }

            // Build new entry
            $uid = rand(1000000, 10000000);
            $com_id     = 'com0';
            $dn         = 'uid=' . $uid . ',o=' . $com_id . ',' . $this->base_dn;
            $attributes = array(
                'dn' => $dn,
                'o'  => $com_id,
                'cn' => $parameters['cn'],
                'sourceId' => $uid,
            );

            foreach($attrArray as $attr) {
                if (isset($parameters[$attr]) && $parameters[$attr] !== '') {
                    $attributes[$attr]	= $parameters[$attr];
                }
            }
            if (!isset($parameters['userPassword'])) {
                $passwd = \Wildix\Generator\StringGenerator::random(10);
                $attributes['userPassword'] = \User::getInstance()->cryptPassword($passwd);
                $attributes['userPIN'] = \User::getInstance()->makeUserPinFromPassword($passwd);
            }
            if (!isset($parameters['wuserPasswordSip'])) {
                $attributes['wuserPasswordSip'] = \Wildix\Generator\StringGenerator::random(10);
            }

            $attributes['pbxowner'] = !empty($parameters['pbxowner']) ? $parameters['pbxowner'] : $this->get_current_pbx_ldap_dn();

            // Add an entry to LDAP
            $res = WMS_Ldap::getInstance()->addUser($attributes);

            if ($res !== true) {
                return $res;
            }

            unset($uid, $com_id, $dn, $attributes, $attrArray, $attr, $res);
        }

        if (!$import) {
            // Remove global roster cache file
            if (file_exists($filename = '/dev/shm/groster.lua')) {
                unlink($filename);
            }
        }

        return true;
    }

    /**
     * Set data for multiedit users
     *
     * @param array $parameters
     * @return mixed error message or false
     * @author unknown
     * @author Igor Kuts <igor.kuts@wildix.com>
     */
    public function setMultiUser($parameters) {

        $phonesToSync = array();

        $attrArray = array(
                    'cn',
                    LDAP_EXTEN_NUMBER,
                    'userPassword',
                    'wuserPasswordSip',
                    'owner',
                    'preferredLanguage',
                    'userDialplan',
                    'userFaxDialplan',
                    Colleague::LICENSE_TYPE,
                    'ou',
                );

        foreach(explode('|', $parameters['dns']) as $userDn) {
            $startO = microtime(1);
            $entry = WMS_Ldap::getInstance()->getEntryByDn($userDn, $attrArray);
            // Changing several attributes
            $result = array();
            if ($parameters['set_owner'] && $parameters['owner'] != $entry['owner']) {
                // not main admin cannot change it's own group:
                if (!WMS_Permissions::getInstance()->is_root() && isset($parameters['owner']) && User::getInstance()->getDn() != '' && User::getInstance()->getDn() == $userDn) {
                    $result['owner'] = User::getInstance()->getGroupDn();
                } else {
                    $result['owner'] = $parameters['owner'];
                }
            }
            if ($parameters['set_ou']  && $parameters['ou'] != $entry['ou']) {
                $result['ou'] = $parameters['ou'];
            }
            if ($parameters['set_preferredLanguage']  && $parameters['preferredLanguage'] != $entry['preferredLanguage']) {
                $result['preferredLanguage'] = $parameters['preferredLanguage'];
            }
            if ($parameters['set_userDialplan']  && $parameters['userDialplan'] != $entry['userDialplan']) {
                $result['userDialplan'] = $parameters['userDialplan'];
            }
            if ($parameters['set_userFaxDialplan']  && $parameters['userFaxDialplan'] != $entry['userFaxDialplan']) {
                $result['userFaxDialplan'] = $parameters['userFaxDialplan'];
            }
            if ($parameters['set_licenseType']  && $parameters[Colleague::LICENSE_TYPE] !== $entry[Colleague::LICENSE_TYPE]) {
                $result[Colleague::LICENSE_TYPE] = $parameters[Colleague::LICENSE_TYPE];
            }

            // validate
            if($errors = $this->validate_people($result)){
                return $errors;
            }

            if (strlen($parameters['userPassword']) > 1  AND $this->check_password_strength($parameters['userPassword'], true)!= 'weak') {
                $result['userPassword'] = \User::getInstance()->cryptPassword($parameters['userPassword']);
                $result['userPIN'] = \User::getInstance()->makeUserPinFromPassword($parameters['userPassword']);
                array_map('unlink', glob("/tmp/session/lighty/sess_*"));
            }
            if (strlen($parameters['wuserPasswordSip']) > 1  AND $this->check_password_strength($parameters['wuserPasswordSip'], false)!= 'weak') {
                $result['wuserPasswordSip'] = $parameters['wuserPasswordSip'];
                array_push($phonesToSync, $entry[LDAP_EXTEN_NUMBER]);
            }

            if (!empty($result)) {
                $res = WMS_Ldap::getInstance()->update($userDn, $result);
                if ($res !== true) {
                    return $res;
                }
            }
        }
        // Remove global roster cache file and sync everything
        if (file_exists($filename = '/dev/shm/groster.lua')) {
            unlink($filename);
        }

        $this->performPasswordsChange($phonesToSync);

        return true;
    }

    function validate_people($values) {

        $checkFields = array(
            //'edit_userKind' => '/^[0-9a-z\-_]{2,50}\z/i',
            'facsimileTelephoneNumber' => '/^[\+]?[0-9]{2,50}\z/',
            'officeNumber' => '/^[\+]?[0-9]{2,50}\z/',
            //'edit_mail' => '/^[^\W][a-zA-Z0-9_]?([\.]?[a-zA-Z0-9_]+)*\@[a-zA-Z0-9_]+(\.[a-zA-Z0-9_]+)*\.[a-zA-Z]{2,4}\z/',
            'mail' => '/^[^\W].*\@.*\.[a-z]{2,}\z/i',
            'ou' => '/^[^@&<>]{1,250}\z/i',
            'mobile' => '/^[\+]?[0-9]{2,50}\z/',/*
            'edit_userDialplan' => '/^[a-z0-9]+[0-9a-z \-\._\+]{0,50}\z/i',
            'edit_userFaxDialplan' => '/^[a-z0-9]+[0-9a-z \-\._\+]{0,50}\z/i',
            'edit_preferredLanguage' => '/^it|en\z/',
            'ou' => '/^[^\"\\\]{1,100}\z/i', */
            'userPrincipalName' => '/^[^^\/\\\|\+\=\}\{\]\[\)\(\*&\?%\$#\!\,\":;<>]{2,50}\z/i',//\'
            Colleague::LICENSE_TYPE => '/^(' . implode('|', License::getLicenseTypes()). ')\z/i',//\'
        );

        $checkFieldsNotEmpty = array(
            'cn' => '/^[^^\/\\\@\|\+\=\}\{\]\[\)\(\*&\?%\$#@\!\,\":;<>]{2,50}\z/i',//\'
            'extenNumber' => '/^[0-9]{2,50}\z/'
        );
        // if it was "admin" user the field extenNumber can be empty
        if ($values['cn'] == 'admin') {
            $checkFields['extenNumber'] = $checkFieldsNotEmpty['extenNumber'];
            unset($checkFieldsNotEmpty['extenNumber']);
        }
        $errors = array();



        if (!$this->isAllowToSavePhones($values['mobile'], $values['officeNumber'])) {
            $errors['officeNumber'] = _t('strings.CanNotEqualMobile');
            $errors['mobile'] = _t('strings.CanNotEqualOffice');
        }

	    foreach ($values as $field => $val) {
		    if (!empty($checkFields[$field]) && $val != '' && !preg_match($checkFields[$field], $val)) {
			    $errors[$field] = _t('strings.Error');
		    } elseif (!empty($checkFieldsNotEmpty[$field]) && !preg_match($checkFieldsNotEmpty[$field], $val)) {
			    $errors[$field] = _t('strings.Error');
		    }
	    }


        // check extenNumber is present
        if (empty($errors)) {
            $t_ret = $this->is_user_extenNumber_present($values['uid'],$values['extenNumber'],$values['userPrincipalName'],$values['mobile'], $values['mail']);

            if ($this->isCnAdminNotAllowed($values)) {
                $t_ret = 'cn';
            }

            if ($t_ret !== false) $errors[$t_ret] = _t('strings.AlreadyPresent');
        }

        return $errors;
    }


    /**
     * Check is allow to save phones phones
     *
     * @param string $phoneOne Phone number.
     * @param string $phoneTwo Phone number.
     *
     * @return boolean
     */
    private function isAllowToSavePhones($phoneOne = '', $phoneTwo = '') {
        return empty($phoneOne)
            || empty($phoneTwo)
            || preg_replace('/\D/', '', strval($phoneOne)) !== preg_replace('/\D/', '', strval($phoneTwo));
    }

    /**
     * Check if allowed to use 'admin' as name.
     *
     * @param array $userData Raw user data.
     *
     * @return bool True if not allowed else false.
     */
    private function isCnAdminNotAllowed(array $userData) {
        $notAllowed = false;
        $userDataCn = mb_strtolower($userData['cn'] || '');
        if ($userDataCn !== 'admin') {
            return $notAllowed;
        }

        $uid        = $userData['uid'] ?? '';
        $isNewUser  = $uid === '' || $uid === 'new';
        if ($isNewUser) {
            $notAllowed = true;
        } else {
            // update user // cn admin only for user who already has admin cn
            $user          = WMS_Ldap::getInstance()->getEntryByDn($userData['dn'], ['cn']);
            $userCurrentCn = $user['cn'] ?? '';
            if ($userCurrentCn !== 'admin') {
                $notAllowed = true;
            }
        }

        return $notAllowed;
    }

    /**
     * Set (edit) user passwords
     *
     * @param string $userDn
     * @param string $passwordSIP
     * @param string $password
     * @return mixed error message or true
     * @author Igor Kuts <igor.kuts@wildix.com>
     */
    public function setUserPasswords($userDn, $passwordSIP, $password, $curPassword) {
        $entry = WMS_Ldap::getInstance()->getEntryByDn(
            $userDn,
            array(
                'cn',
                LDAP_EXTEN_NUMBER,
                'userPassword',
                'wuserPasswordSip'
            )
        );

        // check for password update in session
        $currentUser = User::getInstance();
        $changePass = $currentUser->getExtension() === $entry[LDAP_EXTEN_NUMBER] || $currentUser->getDn() === $userDn;

        if($changePass AND ! ($entry['cn']=='admin' AND ($entry['userPassword']=='wildix' || \User::getInstance()->isEqualPasswords($entry['userPassword'], 'wildix')))
            AND !($entry['userPassword'] == $curPassword || \User::getInstance()->isEqualPasswords($entry['userPassword'], $curPassword))){
                return array(_t('rules.wrongCurrentPassword'));
        }

        $result = array();
        if (strlen($password) > 1 AND $password != $entry['userPassword'] AND $this->check_password_strength($password, true)!= 'weak') {
            $passwordHash = $currentUser->cryptPassword($password);
            $result['userPassword'] = $passwordHash;
            $result['userPIN'] = \User::getInstance()->makeUserPinFromPassword($password);

            if ($changePass) {
                $currentUser->updateSessionPassword($passwordHash);
            }
        }
        if (strlen($passwordSIP) > 1 AND $passwordSIP != $entry['wuserPasswordSip'] AND $this->check_password_strength($passwordSIP, false) != 'weak') {
            $result['wuserPasswordSip'] = $passwordSIP;
        }
        if( ! $result['wuserPasswordSip'] AND  ! $entry['wuserPasswordSip'] AND $entry['cn'] == 'admin'){
            $result['wuserPasswordSip'] = \Wildix\Generator\StringGenerator::random(10);
        }
        if (!empty($result)) {
            $res = WMS_Ldap::getInstance()->update($userDn, $result);
            if ($res !== true) {
                return $res;
            }
        }
        if ($entry['wuserPasswordSip'] != $passwordSIP OR $entry['cn'] == 'admin') {
            $this->performPasswordsChange(array($entry[LDAP_EXTEN_NUMBER]), ($entry['cn'] == 'admin' ? true : false));
        }
        return true;
    }

    function check_password_strength($pass,$noPunction) {
        if ($noPunction) {
            $strongRegex = "/^(?=.{10,})(((?=.*[A-Z])(?=.*[a-z])(?=.*\\W))|((?=.*[A-Z])(?=.*\\W)(?=.*[0-9]))|((?=.*\\W)(?=.*[a-z])(?=.*[0-9]))).*$/";
            $mediumRegex = "/^(?=.{8,})(((?=.*[a-z])(?=.*\\W))|((?=.*\\W)(?=.*[0-9]))|((?=.*[A-Z])(?=.*\\W))).*$/";
            $enoughRegex = "/(?=.{8,}).*/";
        } else {
            $strongRegex = "/^(?=.{10,})(?=.*[A-Z])(?=.*[a-z])(?=.*[0-9])(?=.*\\W).*$/";
            $mediumRegex = "/^(?=.{8,})(((?=.*[A-Z])(?=.*[a-z])(?=.*\\W))|((?=.*[A-Z])(?=.*\\W)(?=.*[0-9]))|((?=.*\\W)(?=.*[a-z])(?=.*[0-9]))).*$/";
            $enoughRegex = "/(?=.{8,}).*/";
        }

        if ($pass == '' || !preg_match($enoughRegex, $pass)) {
            $strength = 'weak';
        } else if (preg_match($strongRegex, $pass)) {
            $strength = 'strong';
        } else if (preg_match($mediumRegex, $pass)) {
            $strength = 'medium';
        } else {
            $strength = 'weak';
        }

        return $strength;
    }

    function getGeneratePassword($pass, $noPunction) {
        if ($this->check_password_strength($pass, $noPunction) == 'weak') {
            return \Wildix\Generator\StringGenerator::random(10, $noPunction);
        } else {
            return $pass;
        }
    }

    function select_userKind() {
        $check_userKind = array(
            'admin' => 'admin',
            'user' => 'user',
            'fax' => 'fax',
            'room' => 'room',
            'park_orbit' => 'park_orbit'
        );
        return $check_userKind;
    }

    // fixme: get the languages from lang class
    function select_preferredLanguage() {
        return array(
            'en' => 'en',
            'en-us' => 'en-us',
            'it' => 'it',
            'fr' => 'fr',
            'de' => 'de',
            'ru' => 'ru',
            'bg' => 'bg',
            'es' => 'es',
            'ee' => 'ee'
        );
    }

    /**
     * Check cn or extenNumber present
     *
     * @param string $uid
     * @param string $extenNumber
     * @param string $userPrincipalName
     * @param string $mobile
     * @param string $mail
     * @return mixed string 'extenNumber' or 'userPrincipalName' or 'mobile' or 'mail' if present or boolean false
     * @author Igor Kuts <igor.kuts@wildix.com>
     */
    function is_user_extenNumber_present($uid, $extenNumber, $userPrincipalName, $mobile, $mail) {
        $uidExpr = $uid != '' ? '(!(uid=' . $uid . '))' : '' ;
        $extenCnExpr = '(|';
        if($extenNumber != '') {
            $extenCnExpr .= '(' . LDAP_EXTEN_NUMBER . '=' . $extenNumber . ')';
        }
        if($userPrincipalName != '') {
            $extenCnExpr .= '(userPrincipalName=' . $userPrincipalName . ')';
        }
        if($mobile != '') {
            $extenCnExpr .= '(mobile=' . $mobile . ')';
        }
        if ($mail != '') {
            $extenCnExpr .= '(mail=' . $mail . ')';
        }
        $extenCnExpr .= ')';
        $search = WMS_Ldap::getInstance()->getEntries(WMS_Ldap::PERSONS, $uidExpr . $extenCnExpr, array('cn', LDAP_EXTEN_NUMBER, 'userPrincipalName', 'mobile', 'mail'));

        if (!empty($search)) {
            if($extenNumber == $search[0][LDAP_EXTEN_NUMBER]){
                return 'extenNumber';
            }else if($userPrincipalName != '' && $userPrincipalName == $search[0]['userPrincipalName']){
                return 'userPrincipalName';
            }else if($mobile != '' && $mobile == $search[0]['mobile']){
                return 'mobile';
            } else if($mail != '' && $mail == $search[0]['mail']){
                return 'mail';
            }
        }
        return false;
    }

    /**
     * Check is wcgp (group id) present
     *
     * @param string $group_gid
     * @param integer $group_wcgrp
     * @return boolean
     * @author Igor Kuts <igor.kuts@wildix.com>
     */
    function is_wcgrp_present($group_gid, $group_wcgrp) {
        if ($group_wcgrp == '') {
            return false;
        }
        $gidExpr = $group_gid != '' ? '(!(gid=' . $group_gid . '))' : '' ;
        $search = WMS_Ldap::getInstance()->getEntries(WMS_Ldap::GROUPS, '(wcgrp=' . $group_wcgrp . ')' . $gidExpr, array('cn'));
        return !empty($search) ? true : false;
    }

    function synch_hardphone_configuration($extenNumber) {
        if (!$extenNumber) {
            return false;
        }
        PBX::getInstance()->sip_notify_check_sync(array($extenNumber));
        logger('Sync ' . $extenNumber, __FUNCTION__, __LINE__);
    }

    /**
     * Get groups
     *
     * @return array
     * @author unknown
     * @author Igor Kuts <igor.kuts@wildix.com>
     */
    public function get_groups() {
        $groupGetValues = array(
            'wcgrp',
            'cn',
            'owner',
            'modifyTimeStamp',
            'gid',
            'wg2gAcl',
            'wg2eAcl',
            'dn'
        );
        $search = WMS_Ldap::getInstance()->getEntries(WMS_Ldap::GROUPS, '', $groupGetValues, array('wg2gAcl','wg2eAcl'));
        // Get available groups;
        $groups = $this->get_groups_assoc();
        // Parse found data
        $output = array();
        $empty_values = array();
        foreach ($groupGetValues as $t_val){
            $empty_values[$t_val] = '';
        }
        $empty_values = array_merge($empty_values, array('inheritsfrom' => ''));
        foreach ($search as $key => $value) {
            foreach ($value As $l_key => $l_val) {
                if (is_array($l_val) && $l_key != 'wg2gAcl' && $l_key != 'wg2eAcl') {
                    $output[$key][$l_key] = $l_val[0];
                } else {
                    $output[$key][$l_key] = $l_val;
                }
                if ($l_key == 'owner') {
                    $output[$key]['inheritsfrom'] = $groups[$output[$key][$l_key]];
                }
            }
            $output[$key] = array_merge($empty_values, $output[$key]);
        }
        return $output;
    }

    /**
     * Get dn=>cn assoc array
     *
     * @return array
     * @author Igor Kust <igor.kuts@wildix.com>
     */
    function get_groups_assoc() {
        $return = array();
        $search = WMS_Ldap::getInstance()->getEntries(WMS_Ldap::GROUPS, '', array('dn', 'cn'));
        if (!empty($search)) {
            foreach ($search as $entry) {
                $return[$entry['dn']] = $entry['cn'];
            }
        }
        return $return;
    }

    /**
     * Get dn=>pbxDomain assoc array
     *
     * @return array
     * @author Igor Kust <igor.kuts@wildix.com>
     */
    function get_pbxes_assoc(){
        $return = array();
        $search = WMS_Ldap::getInstance()->getEntries(WMS_Ldap::PBX, '', array('dn', 'pbxDomain'));
        if (!empty($search) && is_array($search)) {
            foreach ($search as $entry) {
                $return[$entry['dn']] = $entry['pbxDomain'];
            }
        }
        return $return;
    }

    function cmp_group_acl($a, $b) {
        $ret = 1;
        $a_weight = 0;
        $b_weight = 0;

        if ($a['can'] == 'no' || $a['can'] == 'yes') {
            $a_weight = 3;
        } elseif ($a['can'] == 'use' || $a['can'] == 'nouse') {
            $a_weight = 2;
        } elseif ($a['can'] == 'set' || $a['can'] == 'noset') {
            $a_weight = 1;
        } elseif ($a['can'] == 'call' || $a['can'] == 'nocall') {
            $a_weight = 0;
        }

        if ($b['can'] == 'no' || $b['can'] == 'yes') {
            $b_weight = 3;
        } elseif ($b['can'] == 'use' || $b['can'] == 'nouse') {
            $b_weight = 2;
        } elseif ($b['can'] == 'set' || $b['can'] == 'noset') {
            $b_weight = 1;
        } elseif ($b['can'] == 'call' || $b['can'] == 'nocall') {
            $b_weight = 0;
        }

        if ($a_weight == $b_weight) {
            // check all than
            if ($a_weight == 3) {
                // no/yes
                if ($a['dest_group'] != $b['dest_group']) {
                    if ($a['dest_group'] == 'all') {
                        return -1;
                    } elseif ($b['dest_group'] == 'all') {
                        return 1;
                    }
                }
            } else {
                // all others
                if ($a['operation'] != $b['operation']) {
                    if ($a['operation'] == 'all') {
                        return -1;
                    } elseif ($b['operation'] == 'all') {
                        return 1;
                    }
                }
            }
        } else {
            return ($a_weight > $b_weight) ? -1 : 1;
        }

        return $ret;
    }

    function cmp_group_permissions($a, $b) {
        $ret = 1;
        $a_weight = 0;
        $b_weight = 0;

        if ($a['operation'] == 'epbx' || $a['operation'] == 'noepbx') {
            $a_weight = 3;
        } elseif ($a['operation'] == 'egroup' || $a['operation'] == 'noegroup') {
            $a_weight = 2;
        } elseif ($a['operation'] == 'eperm' || $a['operation'] == 'noeperm') {
            $a_weight = 1;
        } elseif ($a['operation'] == 'epage' || $a['operation'] == 'noepage') {
            $a_weight = 0;
        }

        if ($b['operation'] == 'epbx' || $b['operation'] == 'noepbx') {
            $b_weight = 3;
        } elseif ($b['operation'] == 'egroup' || $b['operation'] == 'noegroup') {
            $b_weight = 2;
        } elseif ($b['operation'] == 'eperm' || $b['operation'] == 'noeperm') {
            $b_weight = 1;
        } elseif ($b['operation'] == 'epage' || $b['operation'] == 'noepage') {
            $b_weight = 0;
        }

        if ($a_weight == $b_weight) {
            // check all than
            if ($a['dest_subj'] != $b['dest_subj']) {
                if ($a['dest_subj'] == 'all') {
                    return -1;
                } elseif ($b['dest_subj'] == 'all') {
                    return 1;
                }
            }
        } else {
            return ($a_weight > $b_weight) ? -1 : 1;
        }

        return $ret;
    }

    public function set_group_acl($group_dn, $group_cn, $group_old_cn, $group_owner, $group_wcgrp, $group_acl) {
        $errors = array();

        $group_cn = trim($group_cn);

        $acl_is_root = WMS_Permissions::getInstance()->is_root();
        if ( !$acl_is_root && ( $group_dn == 'new' || !WMS_Permissions::getInstance()->is_allowed('group', $group_dn) ) ) {
            $errors["edit_group_cn"] = _t('strings.permissionsDenied');
            return $errors;
        }

        // Check for already present
        if ($group_cn != $group_old_cn) {
            $search = WMS_Ldap::getInstance()->getEntry(WMS_Ldap::GROUPS, '(cn=' . ldap_escape($group_cn) . ')', array('cn', 'dn'));
            if (!empty($search) && $search['dn'] != $group_dn) {
                $errors["edit_group_cn"] = _t('strings.AlreadyPresent');
            }
        }
        if (!empty($errors)) {
            return $errors;
        }
        if ($group_dn == 'new') {
            $check_group_gid = 'new';
        } else {
            $entry = WMS_Ldap::getInstance()->getEntryByDn($group_dn, array('gid'));
            $check_group_gid = $entry['gid'];
        }
        if ($this->is_wcgrp_present($check_group_gid, $group_wcgrp)) {
            $errors["edit_group_wcgrp"] = _t('strings.AlreadyPresent');
        }
        if (!empty($errors)) {
            return $errors;
        }

        $new_g2g_array = array();

        // Have only unique rows in acl
        $t_group_acl = array();
        if (!empty($group_acl)) {
            $groupAclAll = array(
                'EDIT_PP',
                'DELETE_CALLS',
                'HOTEL_ADMIN',
                'HOTEL_EVENTS',
                'SHARE_STATUS_VIA_KITE',
                'SHARE_STATUS_MESS_VIA_KITE',
                'SHARE_GEO_VIA_KITE',
                'DIRECTORY_LOOKUP',
                'MANAGE_CALLCENTER',
                'CREATE_CONFERENCE',
                'SEE_CDRVIEW_DIGITS',
                'SEE_EXTENSIONS',
                Colleague::TWO_FACTOR_AUTH_OFF,
                Colleague::ENABLE_VIDEO_CALL,
                Colleague::SEE_CALL_RECORDINGS,
            );
            foreach ($group_acl as &$val) {
                if (in_array($val['operation'], $groupAclAll)) {
                    $val['dest_group'] = 'all';
                }
                $t_group_acl[md5(serialize($val))] = $val;
            }
            $group_acl = array_values($t_group_acl);
            unset($t_group_acl);
            // Sort the rows
            usort($group_acl, array($this , 'cmp_group_acl'));
        } else {
            $group_acl = array();
        }

        $i = 1;
        foreach ($group_acl as $val) {
            $add = str_pad($i, 3, '0', STR_PAD_LEFT);
            $new_g2g_array[] = $add . '|' . $val['dest_group'] . '|' . $val['operation'] . '|' . $val['can'];
            ++$i;
        }

        // Add new group
        if ($group_dn == 'new') {
            $gid = rand(1000000, 10000000);
            $com_id     = 'com0';
            $dn         = 'gid=' . $gid . ',o=' . $com_id . ',' . $this->base_dn;
            $attributes = array(
                'dn' => $dn,
                'o'  => $com_id,
                'cn' => $group_cn
            );
            if ($group_owner != '') {
                $attributes['owner'] = $group_owner;
            }
            if ($group_wcgrp != '') {
                $attributes['wcgrp'] = $group_wcgrp;
            }
            if (!empty($new_g2g_array)) {
                $attributes['wg2gAcl'] = $new_g2g_array;
            }
            // checkme: add default permissions
            $attributes['wg2eAcl'] = array(
                '001|all|noepbx',
                '002|'. $this->get_current_pbx_ldap_dn() .'|epbx',
                '003|all|noegroup',
                '004|add_remove_users|noeperm',
                '005|all|noepage',
                '006|users__phonebooks3|epage',
                '007|dialplan__call_groups|epage',
                '008|dialplan__timetables|epage',
                '009|dialplan__ivr|epage',
                '010|settings__utilites__backup|epage',
            );
            $res = WMS_Ldap::getInstance()->addGroup($attributes);
        } else { // Edit group
            $entry = WMS_Ldap::getInstance()->getEntryByDn($group_dn, array('cn', 'owner', 'wcgrp', 'wg2gAcl'), array('wg2gAcl'));
            if ($acl_is_root) {
                $result = array_merge($entry,
                    array(
                        'cn'      => $group_cn,
                        'owner'   => $group_owner,
                        'wcgrp'   => $group_wcgrp,
                        'wg2gAcl' => $new_g2g_array
                    )
                );
            } else {
                $result = array_merge($entry,
                    array(
                        'wg2gAcl' => $new_g2g_array
                    )
                );
            }
            $res = WMS_Ldap::getInstance()->update($group_dn, $result);
        }

        exec('rm /dev/shm/wg*.acl');

        // Remove global roster cache file
        if (file_exists($filename = '/dev/shm/groster.lua')) {
            unlink($filename);
        }

        // Modify user rosters
        if ($group_cn != $group_old_cn) {
            exec('/usr/sbin/user_features_sync ' . escapeshellarg(
                json_encode(array(
                    'type' => 'roster',
                    'action' => 'modify',
                    'parameters' => array($group_old_cn, $group_cn)
                ))
            ));
        }

        $this->clearKamailioCache();

        return $res !== true ? $res : true;
    }

    function set_group_permissions($group_dn, $group_permissions) {
        $errors = array();

        if (!empty($errors)) {
            return $errors;
        }

        $new_g2e_array = array();

        // Have only unique rows in acl
        $t_group_permissions = array();
        if (!empty($group_permissions)) {
            foreach ($group_permissions as &$val) {
                //if ($val['operation'] == 'EDIT_PP' || $val['operation'] == 'HOTEL_ADMIN' || $val['operation'] == 'HOTEL_EVENTS') {
                //$val['dest_group'] = 'all';
                //}
                $t_group_permissions[$val['operation'].$val['dest_subj']] = $val;
            }
            ksort($t_group_permissions);
            $group_permissions = array_values($t_group_permissions);
            unset($t_group_permissions);
            // Sort the rows
            //usort($group_permissions, array($this , 'cmp_group_permissions'));
        } else {
            $group_permissions = array();
        }

        $i = 1;
        foreach ($group_permissions as $val) {
            $add = str_pad($i, 3, '0', STR_PAD_LEFT);
            $new_g2e_array[] = $add . '|' . $val['dest_subj'] . '|' . $val['operation'];
            ++$i;
        }

        $entry = WMS_Ldap::getInstance()->getEntryByDn($group_dn, array('wg2eAcl'), array('wg2eAcl'));
        $result = array_merge($entry,
            array(
                'wg2eAcl' => $new_g2e_array
            )
        );
        $res = WMS_Ldap::getInstance()->update($group_dn, $result);

        $this->clearKamailioCache();

        return $res !== true ? $res : true;
    }

    /**
     * Remove group
     *
     * @param string $group_dn
     * @return boolean
     * @author unknown
     * @author Igor Kuts <igor.kuts@wildix.com>
     */
    public function remove_group($group_dn) {
        // Aditional check for group contains users
        if (empty($group_dn)) {
            return false;
        }
        $search = WMS_Ldap::getInstance()->getEntries(WMS_Ldap::PERSONS, '(owner=' . $group_dn . ')', array('dn', 'cn'));
        if (!empty($search)) {
            $search = WMS_Ldap::getInstance()->getEntryByDn($group_dn, array('dn', 'cn') );
            return htmlentities(_t('aclpbx.GroupWithUsersCanNotBeDeleted', $search['cn']));
        }
        // Remove group from owner field of child groups
        $search = WMS_Ldap::getInstance()->getEntries(WMS_Ldap::GROUPS, '(owner=' . $group_dn . ')', array('dn'));
        if (!empty($search)) {
            foreach ($search as $owner) {
                $res = WMS_Ldap::getInstance()->deleteAttrs($owner['dn'], array('owner' => $group_dn));
                if ($res !== true) {
                    return $res;
                }
            }
        }

        exec('rm /dev/shm/wg*.acl');

        // Remove global roster cache file
        if (file_exists($filename = '/dev/shm/groster.lua')) {
            unlink($filename);
        }
        // Remove group
        $res = WMS_Ldap::getInstance()->deleteEntryByDn($group_dn);
        return $res !== true ? $res : true;
    }

    function is_group_present($groupname) {
        return false;
    }

    function get_pbxes() {
        $result['pbxs']      =  multipbx::getAllPbxes();
        $result['failovers'] = \Wildix\Failovers\Failovers::getInstance()->getAllFailovers();
        return $result;
    }

    function get_phonebooks() {
        $phonebooks = new phonebook();
        $res = $phonebooks->getAll(true);
        $phonebooks->close();
        return $res;
    }

    function remove_phonebook($id) {
        if ($id == '') return true;
        $phonebooks = new phonebook();
        $res = $phonebooks->remove($id);
        $phonebooks->close();
        return $res;
    }

    function clear_phonebook($id) {
        if ($id == '') {
            return true;
        }
        $phonebooks = new phonebook();
        $res = $phonebooks->clearPhonebook($id);
        $phonebooks->close();
        return $res;
    }

    function set_phonebook($parameters) {
        $phonebooks = new phonebook();
        $res = $phonebooks->set($parameters);
        $phonebooks->close();
        return $res;
    }

    /**
     * Clear Kamailio cache (needs after group changed)
     *
     * @return void
     */
    public function clearKamailioCache() {
        exec('curl -X DELETE --url http://127.0.0.1:5060/v1/acls/cache/');
    }
}

if (isset($_REQUEST['newclass']) && $_REQUEST['newclass'] == 'aclpbx') {
    require_once('classes/WMSProxy.class.php');
    $proxy = new WMSProxy();

    // Users
    if (WMS_Permissions::getInstance()->is_allowed('page','users__users')) {
        $proxy->wrap_function('getUsers', 'get_users_for_the_list',
            array(
                empty($_REQUEST['pbxSerial']) ? false : $_REQUEST['pbxSerial'],
                intval($_REQUEST['startIndex'] ?? 0),
                intval($_REQUEST['results'] ?? 0),
                htmlspecialchars($_REQUEST['search'] ?? ''),
                htmlspecialchars($_REQUEST['sortKey'] ?? ''),
                htmlspecialchars($_REQUEST['sortDir'] ?? '')
            )
        );

        $proxy->wrap_function('setUser', 'set_user', array(json_decode($_POST['data'] ?? '{}', true)));
        $proxy->wrap_function('setUserPasswordSip', 'setUserPasswords', array($_POST['dn'] ?? '', $_POST['wuserPasswordSip'] ?? '', $_POST['userPassword'] ?? '', $_POST['curUserPassword'] ?? ''));
        $proxy->wrap_function('setMultiUser', 'setMultiUser', array(json_decode($_POST['data'] ?? '{}', true)));
    } else {
        $proxy->register_function('getUsers', 'fn_admin_permissions_denied');
    }

    // Groups
    if (WMS_Permissions::getInstance()->is_allowed('page','users__groups') || WMS_Permissions::getInstance()->is_allowed('page','users__users')) {

        $proxy->register_function('getGroups','getGroupsACL');
        function getGroupsACL($obj,&$response) {
            $response['BODY'] = $obj->get_groups();
            $response['ACLBODY'] = array();
            $t_all_groups = $response['BODY'];
            foreach ($t_all_groups As $t_group_arr) {
                if (WMS_Permissions::getInstance()->is_allowed('group', $t_group_arr['dn'])) {
                    $response['ACLBODY'][] = $t_group_arr;
                }
            }
            if (!WMS_Permissions::getInstance()->is_allowed('page','users__groups')) {
                $response['ACL'] = _t('strings.permissionsDenied');
                $response['ACL_EMPTY'] = array();
            }
            $response['totalRecords'] = count($response['ACLBODY']);
        }
    } else {
        $proxy->register_function('getGroups', 'fn_admin_permissions_denied');
    }

    // Groups
    if (WMS_Permissions::getInstance()->is_allowed('page','users__groups')) {
        $proxy->wrap_function('setGroupAcl', 'set_group_acl', array(
            $_POST['group_dn'] ?? '',
            $_POST['group_cn'] ?? '',
            $_POST['group_old_cn'] ?? '',
            $_POST['group_owner'] ?? '',
            $_POST['group_wcgrp'] ?? '',
            json_decode(($_POST['group_acl'] ?? '[]'), true)
        ));
        if(WMS_Permissions::getInstance()->is_root()) {
            $proxy->wrap_function('setGroupPermissions', 'set_group_permissions', array(
                $_POST['group_dn'] ?? '',
                json_decode($_POST['group_permissions'] ?? '[]', true)
            ));

            $proxy->register_function('removeGroups', 'remove_groups', array($_GET['entries']));
            function remove_groups($obj, &$response, $ids) {
                $response['BODY'] = [];
                if (sizeof($ids = explode('|', $ids)) == 1){
                    $result = $obj->remove_group($ids[0]);
                    if ($result === true) {
                        $obj->clearKamailioCache();
                        return $response['BODY'] = true;
                    } else {
                        $response['BODY'] = false;
                        $response['ERRORS'] = $result;
                        return false;
                    }
                } else {
                    $needClearCache = false;
                    foreach ($ids as $id){
                        $result = $obj->remove_group($id);
                        if ($result === true) {
                            $response['BODY'][$id] = true;
                            $needClearCache = true;
                        } else {
                            if (!is_array($response['ERRORS'])) {
                                $response['ERRORS'] = [];
                            }
                            $response['BODY'][$id] = false;
                            $response['ERRORS'][$id] = $result;
                        }
                    }
                    if ($needClearCache) {
                        $obj->clearKamailioCache();
                    }
                }
            }
        }
    }

    // PBXes
    if (WMS_Permissions::getInstance()->is_allowed('page','users__pbxs')) {
        $proxy->wrap_function('getPBXes','get_pbxes');
    } else {
        $proxy->register_function('getPBXes', 'fn_admin_permissions_denied');
    }

    // Phonebooks
    if (WMS_Permissions::getInstance()->is_allowed('page','users__phonebooks3')) {
        $proxy->wrap_function('getPhonebooks','get_phonebooks');
        $proxy->wrap_function('setPhonebook', 'set_phonebook', array(json_decode($_POST['data'] ?? '{}', true)));
        $proxy->wrap_function('clearPhonebook','clear_phonebook', array($_POST['phonebookId']));
        $proxy->register_function('removePhonebooks', 'remove_phonebooks', array($_GET['entries']));

        function remove_phonebooks($obj, &$response, $ids) {
            $response['BODY']   = [];
            $ids = explode('|', $ids);
            $idsToSync = $ids;

            // Remove phonebook(s) from user features
            array_walk(
                $idsToSync,
                function (&$v) {
                    $v = 'new.' . $v;
                }
            );
            exec('/usr/sbin/user_features_sync ' . escapeshellarg(
                json_encode(array(
                    'type' => 'phonebook',
                    'action' => 'remove',
                    'parameters' => $idsToSync
                ))
            ));

            if (sizeof($ids) == 1) {
                $result = $obj->remove_phonebook($ids[0]);
                if ($result === true) {
                    return $response['BODY'] = true;
                } else {
                    $response['BODY'] = false;
                    $response['ERRORS'] = $result;
                    return false;
                }
            } else {
                foreach ($ids as $id) {
                    $result = $obj->remove_phonebook($id);
                    if ($result === true) {
                        $response['BODY'][$id] = true;
                    } else {
                        if (!is_array($response['ERRORS'])) {
                            $response['ERRORS'] = [];
                        }
                        $response['BODY'][$id] = false;
                        $response['ERRORS'][$id] = $result;
                    }
                }
            }
        }
    } else {
        $proxy->register_function('getPhonebooks', 'fn_admin_permissions_denied');
    }

    if (!function_exists('fn_admin_permissions_denied')) {
        function fn_admin_permissions_denied($obj, &$response) {
            $response['BODY'] = array();
            $response['ACLBODY'] = array();
            $response['ACL'] = _t('strings.permissionsDenied');
        }
    }

    $proxy->processing();
}
