<?php

use Wildix\DependencyInjection\Container;
use Wildix\TlsSecurity\Service;

class backuper {
	private $path = '/mnt/backups';
	private $upload_max_filesize = 5242880; // 5MB

	function __construct() {
		$this->upload_max_filesize = min(let_to_num(ini_get('post_max_size')), let_to_num(ini_get('upload_max_filesize')));
	}

	public function getList() {
		$result = array();
		foreach (glob($this->path . '/*.tar.gz') as $fname) {
			$filesize = round((filesize($fname) / 1024), 2);
			if($filesize > 1000){
				$filesize = round(($filesize / 1024), 2) . '&nbsp;MB';
			}else{
				$filesize .= '&nbsp;KB';
			}
			$result[] = array(
				'name' => substr($fname, strlen($this->path) + 1),
				'filesize' => $filesize,
				'modified' => date('M d Y H:i:s', filemtime($fname)),
			);
		}
		return $result;
	}

	/**
	 * Check sounds weight
	 *
	 * @return mixed string error message in case of error or array with sounds weight in bytes
	 * @author Igor Kuts <igor.kuts@wildix.com>
	 */
	static public function checkSoundsWeight($with_sounds = false) {
		$soundsSize = 0;
		exec("du -B1 -s -X /var/lib/wms/exclude_custom_sounds.txt /var/lib/callweaver/sounds/00000/ 2>/dev/null | awk -F' ' '{print $1}'", $out);

		if ((isset($out[0]) && $out[0] < 10485760) OR (!isset($out[0]) && $with_sounds === true)) {
		    // 1 - its hack for btrfs file system
		    $soundsSize = ($out[0] == '0')? '1': $out[0];
		    return array('size' => $soundsSize);
		}
		return _t('backup.err.BackupProcedureCompleted') . '<br>Due to 10mb limitation custom sounds were not included, please download them from sounds menu...';
	}

	/**
	 * Check approximate backup size
	 *
	 * @param string $where path where to check
	 * @param integer $soundsSize sounds weight
	 * @return boolean true in case of backup can be created
	 * @author Igor Kuts <igor.kuts@wildix.com>
	 */
	static public function checkApproxBackupWeight($where, $soundsSize) {
		logger($soundsSize);
		$toCalculate = array(
			'/rw2/var/lib/wmsdb.d/devdb',
			'/rw2/var/kamailio/htables.db',
			'/mnt/cticonnect/cticonnectdb',
            \Wildix\Databases\Database::WILDIX_WMSDB
		);
		if ($userdDir = get_users_settings_dir()) {
			$toCalculate[] = $userdDir . '[0-9]*.lua';
		}
		$cmd = 'du -cDb ' . implode(' ', $toCalculate) . ' 2>/dev/null | tail -1 | awk -F" " \'{print $1}\'';
		exec($cmd, $out);
		$need = ($out[0] + $soundsSize) / 4 + $out[0] + $soundsSize + 204800;
		$out = false;
		$cmd = 'df -P -B 1 ' . $where . ' | awk -F" " \'{print $((NF-2))}\' | tail -1';
		exec($cmd, $out);
		$free = $out[0];
		return $need > $free ? false : true;
	}

	public function createBackup($download) {
		$return = array(
			'filename' => '',
			'message' => ''
		);
		$comm = 'sudo /usr/sbin/wms_backup_create with_host' . ($download == 'true' ? ' to_ram' : '') . ' no_verbose 2>&1';
		exec($comm, $output, $return_value);
		logger('Synchronizing file system with RAM...', __CLASS__, __FUNCTION__, __LINE__);
		exec('sync');
		logger('Synchronization file system with RAM completed.', __CLASS__, __FUNCTION__, __LINE__);
		$filename = trim(@file_get_contents('/dev/shm/.backup'));
		$return['filename'] = file_exists($filename) ? $filename : '';
		if(file_exists('/rw2/var/backup.flag')){
			return _t('backup.err.createLdapBase');
		}else if ($return_value <= 10) {
			$return['message'] = _t('backup.err.BackupProcedureCompleted');
			return $return;
		} else {
			return _t('backup.err.ErrorDuringBackup') . '<br>' . implode('<br>', $output);
		}
	}

	static function apply($fname, $network = false) {
		// FIXME: bad audio quality while applying backup
		$comm = "nohup sudo /usr/sbin/wms_applybackup " . escapeshellarg($fname) . " " . escapeshellarg($_COOKIE['PHPSESSID']) . " " . escapeshellarg($network) . " > /dev/null &";
		exec($comm);
	}


	/**
	 * Check backup archive before apply it
	 *
	 * @param string $filename archive path
	 * @param boolean $getType affects to return value
	 * @return mixed true|WRONG_FORMAT ($getType == false) or [sound, wms]|WRONG_FORMAT
	 * @author Yuri Sklar
	 * @author Igor Kuts <igor.kuts@wildix.com>
	 */
	public static function check_archive($filename, $getType = false) {
		$important = array(
			'wmsdb.sql',
			'ldapcat.ldif',
			'cust_sounds.tar',
			'configs.tar'
		);
		$soundsCheck = array(
			'./RingTones/',
			'./MusicOnHold/'
		);
		exec('tar tf ' . escapeshellarg($filename), $files);
		if (count(array_intersect($files, $soundsCheck)) == 2) {
			return $getType ? 'sound' : true;
		}
		foreach ($important as $file) {
			if (!in_array($file, $files)) {
				return 'WRONG_FORMAT';
			}
		}
		return $getType ? 'wms' : true;
	}

	// check !reset! archive
	static function check_reset($filename) {
		if (!file_exists($filename)) {
			return 'NOT_EXISTS';
		}
		if (!is_readable($filename)) {
			return 'NOT_READABLE';
		}
		if (!is_writeable(BASEPATH)) {
			return 'BPATH_NOT_WRITABLE';
		}
		exec('tar tf ' . escapeshellarg($filename), $files);
		if (!is_array($files) || empty($files)) {
			return 'WRONG_FORMAT';
		}
		return true;
	}

	static function reset() {
        $diContainer        = new Container();
        $tlsSecurityService = $diContainer->get(Service::class);

		$comm = "sudo /usr/sbin/wmsreset > /dev/null";
		system($comm, $retval);
		if ($retval == ''){
            $tlsSecurityService->save(['enabled' => 0], true);
			return 0; // Ok!
		} else {
			return 1; // False
		}

	}

	function cronizeGetValues() {
		$return = array(
			'share'=>array(
				'sharesounds' => 'no',
				'sharehowly' => '',
				'sharecronized'=>'no'
			),
			'ftp'=>array(
				'ftpsounds' => 'no',
				'ftphost' => '',
				'ftpport' => '',
				'ftplogin' => '',
				'ftppass' => '',
				'ftpdir' => '',
				'ftppasv' => '',
				'ftphowly' => '',
				'ftpcronized'=>'no'
			),
			'mail'=>array(
				'mailsounds' => 'no',
				'mailemail' => '',
				'mailhowly' => '',
				'mailcronized'=>'no'
			)
		);



		if (file_exists('/rw2/etc/default/sharebkp.ini')) {
			$smbini = parse_ini_file('/rw2/etc/default/sharebkp.ini', false, INI_SCANNER_RAW);
			$return['share']['sharesounds'] = $smbini['SOUNDS'] ? $smbini['SOUNDS'] : 'no';
			$return['share']['sharehowly'] = trim($smbini['HOWLY']);
            if(trim($smbini["HOWLY"])!="")$return['share']['sharecronized'] = 'yes';

        }
		if (file_exists('/rw2/etc/default/ftpbkp.ini')) {
			$ret_ftp_ini = array();
			$ftpini = parse_ini_file('/rw2/etc/default/ftpbkp.ini', false, INI_SCANNER_RAW);
			$ret_ftp_ini['ftpsounds'] = $ftpini['SOUNDS'] ? $ftpini['SOUNDS'] : 'no';
			$ret_ftp_ini['ftphost'] = trim($ftpini['SERVER']);
			$ret_ftp_ini['ftpport'] = trim($ftpini['PORT']);
			$ret_ftp_ini['ftplogin'] = trim($ftpini['USERNAME']);
			$ret_ftp_ini['ftppass'] = trim($ftpini['PASSWORD']);
			$ret_ftp_ini['ftpdir'] = trim($ftpini['FTPDIR']);
			$ret_ftp_ini['ftppasv'] = $ftpini['PASV'] != '' ? 'yes' : 'no';
			$ret_ftp_ini['ftphowly'] = trim($ftpini['HOWLY']);
            if(trim($ftpini["HOWLY"])!="")$return['ftp']['ftpcronized'] = 'yes';

            foreach ($ret_ftp_ini as $key => $val) {
				$return['ftp'][$key] = $val;
			}
		}
		if (file_exists('/rw2/etc/default/mailbkp.ini')) {
			$ret_mail_ini = array();
			$mailini = parse_ini_file('/rw2/etc/default/mailbkp.ini', false, INI_SCANNER_RAW);
			$ret_mail_ini['mailsounds'] = $mailini['SOUNDS'] ? $mailini['SOUNDS'] : 'no';
			$ret_mail_ini['mailemail'] = trim($mailini['EMAIL']);
			$ret_mail_ini['mailhowly'] = trim($mailini['HOWLY']);
            if(trim($mailini["HOWLY"])!="")$return['mail']['mailcronized'] = 'yes';

            foreach ($ret_mail_ini as $key => $val) {
				$return['mail'][$key] = $val;
			}
		}
		return $return;
	}

	function shareCronize($period, $includeSounds, $mode) {
		$return = array(
			'success' => false,
			'msg' => _t('backup.err.UnknownError')
		);

		$fcontent_sharebkp_ini = 'SOUNDS="' . $includeSounds . '"
HOWLY='.$period.'
';

		// Temporary write config (trick to avoid flash wearing)
		$writeConfig = false;
		if (file_exists('/rw2/etc/default/sharebkp.ini') && filesize('/rw2/etc/default/sharebkp.ini') > 0) {
			$fh = fopen('/tmp/sharebkp.ini', 'w');
			fwrite($fh, $fcontent_sharebkp_ini);
			fclose($fh);
			// Check MD5 sums of old and new configs
			if (filesize('/tmp/sharebkp.ini') > 0) {
				if (md5_file('/tmp/sharebkp.ini') != md5_file('/rw2/etc/default/sharebkp.ini')) {
					$writeConfig = true;
				}
			} else {
				$writeConfig = true;
			}
			unlink('/tmp/sharebkp.ini');
		} else {
			$writeConfig = true;
		}

		// Write confid if need
		if ($writeConfig) {
			$fh = fopen('/rw2/etc/default/sharebkp.ini', 'w');
			fwrite($fh, $fcontent_sharebkp_ini);
			fclose($fh);
		}

        $return['success'] = true;
		if($mode == 'save'){
			$return['msg'] = _t('strings.SavedSuccessfully');
		}else{
			$return['msg'] = _t('backup.msg.PeriodicJobSet');
		}


        return $return;
	}

	/**
	 * Make backup to FTP server
	 * Once or set periodical cron job
	 *
	 * @param array $values
	 * @param string $mode can take on of 2 values: 'once' or 'cronize'
	 * @return array
	 */
	function ftpCronize($values, $mode) {
		$return = array(
			'success' => false,
			'msg' => _t('backup.err.UnknownError')
		);
        $cronizeData=$this->cronizeGetValues();
        $ftphowly="";

        switch($mode)
        {
            case "once":
                $ftphowly = 'HOWLY='.$cronizeData["ftp"]["ftphowly"]."\n";

                break;

            case "cronize":
               $ftphowly = 'HOWLY='.$values["ftphowly"]."\n";

                break;
            case "save":
                $ftphowly = 'HOWLY='.$values["ftphowly"]."\n";

                break;
            default:
                break;
        }



		$fcontent_ftpbkp_ini = 'SOUNDS="' . $values['ftpsounds'] . '"
SERVER="' . $values['ftphost'] . '"
PORT="' . ($values['ftpport'] == '' ? '21' : $values['ftpport']) . '"
USERNAME="' . ($values['ftplogin'] == '' ? 'anonymous' : $values['ftplogin']) . '"
PASSWORD="' . ($values['ftppass'] == '' ? 'anonymous@anonymous.com' : $values['ftppass']) . '"
FTPDIR="' . $values['ftpdir'] . '"
'.$ftphowly.'';

		if ($values['ftppasv'] == 'yes') {
			$fcontent_ftpbkp_ini .= 'PASV="-p"
';
		}

		// Temporary write config (trick to avoid flash wearing)
		$writeConfig = false;
		if (file_exists('/rw2/etc/default/ftpbkp.ini') && filesize('/rw2/etc/default/ftpbkp.ini') > 0) {
			$fh = fopen('/tmp/ftpbkp.ini', 'w');
			fwrite($fh, $fcontent_ftpbkp_ini);
			fclose($fh);
			// Check MD5 sums of old and new configs
			if (filesize('/tmp/ftpbkp.ini') > 0) {
				if (md5_file('/tmp/ftpbkp.ini') != md5_file('/rw2/etc/default/ftpbkp.ini')) {
					$writeConfig = true;
				}
			} else {
				$writeConfig = true;
			}
			unlink('/tmp/ftpbkp.ini');
		} else {
			$writeConfig = true;
		}

		// Write confid if need
		if ($writeConfig) {
			$fh = fopen('/rw2/etc/default/ftpbkp.ini', 'w');
			fwrite($fh, $fcontent_ftpbkp_ini);
			fclose($fh);
		}

		switch ($mode) {
			case 'once':
				exec('/usr/sbin/recurrent_backup ftp', $output, $result);
				if ($result === 0) {
					$return['success'] = true;
					if (!is_array($msg = self::checkSoundsWeight())) {
						$return['msg'] = $msg;
					} else {
						$return['success'] = true;
						$return['msg'] = _t('backup.msg.BackupSuccessfullyCreated');
					}
				} else {
					$return['msg'] = _t('backup.err.BackupCreationFailed');
				}
				break;
			case 'cronize':

                $return['success'] = true;
                $return['msg'] = _t('backup.msg.PeriodicJobSet');
				break;
			case 'save':
				$return['success'] = true;
				$return['msg'] = _t('strings.SavedSuccessfully');
				break;
		}
		return $return;
	}

	/**
	 * Make backup to e-mail
	 * Once or set periodical cron job
	 *
	 * @param array $values
	 * @param string $mode can take on of 2 values: 'once' or 'cronize'
	 * @return array
	 */
	function mailCronize($values, $mode) {
		$return = array(
			'success' => false,
			'msg' => _t('backup.err.UnknownError')
		);
		$mailhowly = ($values["mailcronized"] == 'no') ? 'HOWLY='.$values['mailhowly'].'
' : '';


        $cronizeData=$this->cronizeGetValues();
        $mailhowly="";

        switch($mode)
        {
            case "once":
                $mailhowly = 'HOWLY='.$cronizeData["mail"]["mailhowly"]."\n";

                break;

            case "cronize":
                $mailhowly = 'HOWLY='.$values["mailhowly"]."\n";

                break;
            case "save":
                $mailhowly = 'HOWLY='.$values["mailhowly"]."\n";

                break;
            default:
                break;
        }


		$fcontent_mailbkp_ini = 'SOUNDS="' . $values['mailsounds'] . '"
EMAIL="' . $values['mailemail'] . '"
'.$mailhowly.'';

		// Temporary write config (trick to avoid flash wearing)
		$writeConfig = false;
		if (file_exists('/rw2/etc/default/mailbkp.ini') && filesize('/rw2/etc/default/mailbkp.ini') > 0) {
			$fh = fopen('/tmp/mailbkp.ini', 'w');
			fwrite($fh, $fcontent_mailbkp_ini);
			fclose($fh);
			// Check MD5 sums of old and new configs
			if (filesize('/tmp/mailbkp.ini') > 0) {
				if (md5_file('/tmp/mailbkp.ini') != md5_file('/rw2/etc/default/mailbkp.ini')) {
					$writeConfig = true;
				}
			} else {
				$writeConfig = true;
			}
			unlink('/tmp/mailbkp.ini');
		} else {
			$writeConfig = true;
		}

		// Write confid if need
		if ($writeConfig) {
			$fh = fopen('/rw2/etc/default/mailbkp.ini', 'w');
			fwrite($fh, $fcontent_mailbkp_ini);
			fclose($fh);
		}

		switch ($mode) {
			case 'once':
				exec('/usr/sbin/recurrent_backup mail', $output, $result);
				if ($result === 0) {
					$return['success'] = true;
					if (!is_array($msg = self::checkSoundsWeight())) {
						$return['msg'] = $msg;
					} else {
						$return['success'] = true;
						$return['msg'] = _t('backup.msg.BackupSuccessfullyCreated');
					}
				} elseif (!in_array($result, array(13, 14))) {
					$return['msg'] = _t('backup.err.BackupCreationFailedSMTP');
				} else {
					$return['msg'] = _t('backup.err.BackupCreationFailed');
				}
				break;
			case 'cronize':

                $return['success'] = true;
                $return['msg'] = _t('backup.msg.PeriodicJobSet');

				break;
			case 'save':

                $return['success'] = true;
                $return['msg'] = _t('strings.SavedSuccessfully');

				break;
		}
		return $return;
	}

	/**
	 * Stop recurrent backup cron job
	 *
	 * @param string $type job type: share, ftp or mail
	 * @return array
	 */
	function unCronize($type) {
		$return = array(
			'success' => false,
			'msg' => _t('backup.err.UnknownError')
		);

		if (!in_array($type, array('share', 'ftp', 'mail'))) {
			return $return;
		}
        $data=file_get_contents("/rw2/etc/default/".$type."bkp.ini");
        $search="/(HOWLY=.*)/";
        $replace="HOWLY=";
        $data=preg_replace($search,$replace,$data);
        file_put_contents("/rw2/etc/default/".$type."bkp.ini",$data);
        $return['success'] = "true";
        $return['msg'] = _t('backup.msg.PeriodicJobUnset');

		return $return;
	}

	/** Delete Backup file
	 * @param 	string	$name	Backup`s name
	 */
	function del($name) {
		$fname = $this->path . '/' . $name;
		@unlink($fname);
		return file_exists($fname) ? 'Problem with removing ' . $name : true;
	}
}

require_once('classes/WMSProxy.class.php');
$proxy = new WMSProxy();

if (WMS_Permissions::getInstance()->is_allowed('page','settings__utilites__backup')) {
	$proxy->wrap_function('getTarballsList', 'getList');
	$proxy->wrap_function('createBackup', 'createBackup', array($_REQUEST['download']));
	$proxy->wrap_function('deleteBackup', 'del', array($_GET['name']));
	$proxy->wrap_function('shareCronize', 'shareCronize', array($_POST['period'], $_POST['sounds'], $_POST['mode']));
	$proxy->wrap_function('ftpCronize', 'ftpCronize', array(json_decode($_POST['values'], true), $_POST['mode']));
	$proxy->wrap_function('mailCronize', 'mailCronize', array(json_decode($_POST['values'], true), $_POST['mode']));
	$proxy->wrap_function('unCronize', 'unCronize', array($_POST['type']));
	$proxy->register_function('deleteBackups', 'fn_delete_backups', array($_GET['names']));

	function fn_delete_backups($obj, &$response, $backups) {
		$names = explode(',', $backups);
		foreach ($names as $name) {
			$result = $obj->del($name);
			$response['BODY'][$name] = array();
			$response['ERRORS'][$name] = array();
			$response[($result === true || trim($result) == '') ? 'BODY' : 'ERRORS'][$name] = $result;
		}
	}
}

$proxy->processing();
