<?php

/** Class multipbx
 * @package 	multipbx
 * @copyright 	Wildix
 * @author 		ITeem[Odessa]
 */

use Logger\LoggerFactory;
use Services\Helpers;
use Wildix\DependencyInjection\Container;
use Wildix\PBXes\Network\Server;

require_once('classes/network/network.class.php');
require_once('network/netfunctions.php');
require_once('common/wms_ldap.php');
require_once('classes/aclpbx/aclpbx.class.php');

class multipbx {
    const LDAP_UNSET_SLAVE_OUT = '/tmp/ldap_unset_slave.out';
    const REMOVE_PBX_OUT       = '/tmp/wms_network_remove_pbx.out';

    const DEFAULT_PORT = 443;

	var $err;
	var $errors;
	var $pbxes_table;
	var $base_dn;
	var $master_ip;

	function __construct() {
		global $wmsErr;
		$connectParams    = WMS_Ldap::getInstance()->getConnectParams();
		$this->base_dn    = $connectParams['basedn'];
		$this->master_ip  = '5.15.0.1';
		if (is_object($wmsErr)) {
			$this->err = &$wmsErr;
		}
		return true;
	}

	static public function getAllPbxes() {
        $diContainer = new Container();

		$pbxGetValues = ['dn', 'pbxid', 'pbxIp', 'pbxSerial', 'pbxDomain', 'modifyTimeStamp', 'pbxPublicIp', 'pbxPublicPort', 'description', 'pbxIsMaster'];
		$search       = WMS_Ldap::getInstance()->getEntries(WMS_Ldap::PBX, '', $pbxGetValues);
		$return       = [];
		if(is_array($search)){
			$empty_values = [];
			foreach ($pbxGetValues As $t_val) {
				$empty_values[$t_val] = '';
			}

			foreach ($search as $pbx) {
                $pbx['pbxVersion']      = key_exists('description', $pbx) ? Helpers::makePbxVersionByDescription($pbx['description']) : '';
                $pbx['isPbxNeedUpdate'] = version_compare($diContainer->get(Server::class)->getVersion(), $pbx['pbxVersion']) > 0;
				$return[] = array_merge($empty_values, $pbx);
			}
		}
		return $return;
	}

	static public function selectPbxes() {
		$search = WMS_Ldap::getInstance()->getEntries(WMS_Ldap::PBX, '', array('pbxDomain', 'dn'));
		$return = array();
		if(is_array($search)){
			foreach ($search as $pbx) {
				$return[$pbx['dn']] = $pbx['pbxDomain'];
			}
		}
		return $return;
	}

	private function get_pbx_parameters() {
		$return = array('serial' => '', 'hostname' => '');
		$return['serial'] = \Models\PBX::getInstance()->getSerial();
		$return['hostname'] = trim(@file_get_contents('/etc/hostname'));
		return $return;
	}

    public function runLdapUnsetSlave() {
        $this->setUnsetSlaveProgress(0);

        logger("WMS Net: stoping WMS Network VPN");
        $this->set_pbx_net_conf(array('STARTUP' => 0), array('NCOMMUNITY', 'NSECRET'));

        logger("WMS Net: stoping WMS Network monitoring");

        $this->unset_ldap_slave();

        logger("WMS Net: restarting PBX SIP Proxy");

        $this->restart_kamailio();

        file_put_contents('/rw2/etc/pbx/wmsnetip', $this->master_ip);
        $this->clean_ejabberd_slave();
    }

	function unset_ldap_slave() {
		logger("WMS Net: changing LDAP configuration");

		exec('fname=/etc/ldap/slapd.d/cn\=config/olcDatabase\=\{1\}'.WMS_Ldap::getInstance()->getLDAPBackend().'.ldif; filetmp=`mktemp` && sudo /bin/cat $fname | sed \'/olcSyncrepl/d;/cridentials/d;/credentials/d;/searchbase/d;/refreshAndPersist/d;/olcMirrorMode/d;/CRC32/d;\' > $filetmp && sudo /bin/cp $filetmp $fname && rm $filetmp');
		$this->set_ldap_connect_conf(array('host_rw' => 'localhost'));
		WMS_Ldap::getInstance()->closeInstance(); // close instance for next re-read config after changes on previous step

		logger("WMS Net: restarting LDAP");
		exec('sudo /etc/init.d/slapd restart');
		logger("WMS Net: LDAP is restarted");
		sleep(5);

		logger("WMS Net: Remove all pbxes except the one belonging to this pbx");
		// Remove all pbxes except the one belongs to this pbx
		$mac = \Models\PBX::getInstance()->getSerial();
		$search = WMS_Ldap::getInstance()->getEntries(WMS_Ldap::PBX, '(!(pbxSerial=' . $mac . '))', array('dn'));
		if (!empty($search)) {
			foreach ($search as $pbx) {
				$res = WMS_Ldap::getInstance()->deleteEntryByDn($pbx['dn']);
				if ($res !== true) {
					logger($res);
				}
			}
		}

		$searchCurPbx = WMS_Ldap::getInstance()->getEntries(WMS_Ldap::PBX, '(pbxSerial=' . $mac . ')', array('dn'));
 		$setIp = array('pbxIp' => $this->master_ip);
 		if (!is_array($searchCurPbx)) {
 			logger("WMS Net: Warning: Search of the current Pbx set returned non array");
 		} else {
 			foreach ($searchCurPbx as $entry) {
 			$curPbx = $entry['dn'];
 			$res = WMS_Ldap::getInstance()->update($curPbx, $setIp);
	 		}
		}

		logger("WMS Net: Fetching the entry of current PBX");

		$entry = WMS_Ldap::getInstance()->getEntry(WMS_Ldap::PBX, '(pbxSerial=' . $mac . ')', array('dn', 'pbxSerial'));//'member',
		if (!is_array($entry)) {
			// Insert current pbx to LDAP
			$pbx_pars = $this->get_pbx_parameters();
			$attributes = array(
				'pbxid' => $pbx_pars['serial'],
				'pbxSerial' => $pbx_pars['serial'],
				'pbxHostname' => $pbx_pars['hostname'],
				'pbxDomain' => $pbx_pars['hostname'] . '.wildixin.com',
				'pbxIp' => $this->master_ip
			);
			$res = WMS_Ldap::getInstance()->addPbx($attributes);
			if ($res !== true) {
				echo '-- Was not added to ldap: ' . $res;
				return false;
			}
                        logger("WMS Net: Added current PBX to ldap");
			// get new added pbx dn
			$entry = WMS_Ldap::getInstance()->getEntry(WMS_Ldap::PBX, '(pbxSerial=' . $mac . ')', array('dn'));
			$current_pbx_ldap_dn = $entry['dn'];
		} else {
		$current_pbx_ldap_dn = $entry['dn'];
		}
		unset($entry['dn']);
		$current_pbx_entry = $entry;

		logger("WMS Net: Substitude all pbxowners of users to this PBX");
		// Substitude all pbxowners of users to this pbx
        $search = WMS_Ldap::getInstance()->getEntriesPaged('(&(objectClass=' . WMS_Ldap::PERSONS . ')(!(pbxowner=' . $current_pbx_ldap_dn . ')))', ['dn', 'pbxowner', 'cn', 'uid', 'telephoneNumber'], 1000);
		if (!is_array($search)) {
			logger($search, __LINE__);
		}

		try {
            $ldapConnect = WMS_Ldap::getInstance()->getConfigurationConnect();
            $this->setLdapConfigAttributes($ldapConnect, ['olcDbNoSync' => 'TRUE']);

            $usersCount = 0;

            foreach ($search as $entry) {
                $usersCount++;
                $res = WMS_Ldap::getInstance()->update($entry['dn'], ['pbxowner' => $current_pbx_ldap_dn]);

                if ($res !== true) {
                    logger($res, __LINE__);
                }

                if (($usersCount % 3000) === 0) {
                    $this->setUnsetSlaveProgress($usersCount);
                }
            }
        } finally {
            $this->setLdapConfigAttributes($ldapConnect, ['olcDbNoSync' => '']);
        }

        $this->setUnsetSlaveProgress($usersCount, 'completed');

		// Set members for this pbx
		/*$result = array_merge($current_pbx_entry, array('member' => $user_dns));
		$res = WMS_Ldap::getInstance()->update($current_pbx_ldap_dn, $result);
		if ($res !== true) {
			logger($res, __LINE__);
		}*/

		return true;
	}

	function clean_ejabberd_slave() {
		exec("(sudo /etc/init.d/ejabberd stop; sudo /bin/rm -f /rw/var/lib/ejabberd/*; sudo /etc/init.d/ejabberd start) > /dev/null &");
	}

	function restart_kamailio() {
		exec('nohup sudo /etc/init.d/kamailio restart > /dev/null &');
	}

	function get_pbx_information() {
		$filename = '/rw2/etc/pbx/company.conf';
		$vals = parse_ini_file($filename, false, INI_SCANNER_RAW);
		return $vals;
	}

	function set_pbx_information($vals) {
		$filename = '/rw2/etc/pbx/company.conf';
		$vals_init = parse_ini_file($filename, false, INI_SCANNER_RAW);
		$vals = array_merge($vals_init, $vals);
		write_ini_file($filename, $vals);
	}

	function get_mode() {
        $filename = '/rw2/etc/pbx/net.conf';
        $vals = parse_ini_file($filename, false, INI_SCANNER_RAW);

        $mode = $vals['STARTUP'];

        // New LDAP doesn't have shared modules
        exec('sudo /bin/cat /etc/ldap/slapd.d/cn\=config/cn\=module\{0\}.ldif', $out);
        if (count($out) > 0) {
            if ($mode == '2') {
                $syncprov_present = exec('sudo /bin/cat /etc/ldap/slapd.d/cn\=config/cn\=module\{0\}.ldif | grep syncprov | wc -l', $out);
                if ($syncprov_present == '0')
                    $mode = '0';

                $syncprov_present = exec('sudo /bin/cat /etc/ldap/slapd.d/cn\=config/olcDatabase\=\{1\}'.WMS_Ldap::getInstance()->getLDAPBackend().'/olcOverlay\=\{0\}syncprov.ldif 2>/dev/null | wc -l', $out);
                if ($syncprov_present == '0')
                    $mode = '0';
            }
        }

        return $mode;
    }

	function get_pbx_net_conf() {
		$filename = '/rw2/etc/pbx/net.conf';
		return parse_ini_file($filename, false, INI_SCANNER_RAW);
	}

	/** set n2n config */
	function set_pbx_net_conf(array $vals, array $exclude_vals = []): bool {
		$filename = '/rw2/etc/pbx/net.conf';
		$vals_init = parse_ini_file($filename, false, INI_SCANNER_RAW);
		$vals = array_merge($vals_init, $vals);

        $pbx = \Models\PBX::getInstance();

        if ($pbx->isEnabledWmsNetwork()
            && !$this->isCredentialsSecure(($vals_init['NCOMMUNITY'] ?? ''), ($vals_init['NSECRET'] ?? ''))
            && $this->isCredentialsSecure(($vals['NCOMMUNITY'] ?? ''), ($vals['NSECRET'] ?? ''))
        ) {
            $logger = LoggerFactory::getInstance();
            $logger->info(
                __LINE__,
                \sprintf(
                    'Secure credentials are set in wms network, current role %s, Number of PBXs in WMS-network %d, Server serial %s',
                    ($pbx->isMaster() ? 'Server' : 'Client'),
                    count(self::getAllPbxes()),
                    ($pbx->isMaster() ? $pbx->getSerial() : $this->getNetworkServerPbxSerial())
                )
            );
        }
		if (!empty($exclude_vals)) {
		    $vals = array_diff_key($vals, array_flip($exclude_vals));
        }
		return write_ini_file($filename, $vals);
	}

	function set_sip_wms_network_conf($vals) {
        $filepath = '/etc/callweaver/sip-wms-network.conf';

        if (!isset($vals['username']) || !isset($vals['secret']) ) {
            echo '-- Error. ' . _t('strings.doesNotExist', 'Username or Secret');
            return false;
        }

        $content = "[WMS_NETWORK_PEER]
username={$vals['username']}
secret={$vals['secret']}
host=127.0.0.1
insecure=invite,port
allow=opus:20,g729:60,alaw:20,ulaw:20,g722:20,h264,h263
type=friend
dtmfmode=info
session-expires=7200";

        $recorded = file_put_contents($filepath, $content);

        if ($recorded) {
            \Wildix\CallweaverManager::getInstance()->reloadModule('sip');

            try {
                \Wildix\Databases\HTABLES::getInstance()->beginTransaction();
                \Wildix\Databases\HTABLES::getInstance()->exec("DELETE FROM host_specific WHERE key_name = 'wmsPassword'");
                \Wildix\Databases\HTABLES::getInstance()->exec("INSERT INTO host_specific (key_name, key_value) VALUES ('wmsPassword', '" . $vals['secret'] . "');");
                \Wildix\Databases\HTABLES::getInstance()->endTransaction();
            } catch(\Exception $e) {
                \Wildix\Databases\HTABLES::getInstance()->rollbackTransaction();
            }

            exec("sudo /usr/sbin/kamcmd htable.reload host_specific");
        } else {
            echo '-- Error. ' . _t('strings.isNotWriteable', '/etc/callweaver/sip-wms-network.conf');
        }

        return $recorded;
    }

	function set_ldap_connect_conf($vals) {
		$filename = '/rw2/etc/pbx/ldap_connect.conf';
		$vals_init = parse_ini_file($filename, false, INI_SCANNER_RAW);
		$vals = array_merge($vals_init, $vals);
		return write_ini_file($filename, $vals);
	}

	function get_master_connect_login_pass() {
		$vals = $this->get_pbx_net_conf();
        $return = array(
            'master_login' => 'w' . substr(md5(time()), 0, 12),
            'master_password' => \Wildix\Generator\StringGenerator::random(24, true, true)
        );
        if ($this->get_mode() == 0) {
            return $return;
        }
		if (isset($vals['NCOMMUNITY']))
			$return['master_login'] = $vals['NCOMMUNITY'];
		if (isset($vals['NSECRET']))
			$return['master_password'] = $vals['NSECRET'];
		return $return;
	}

	function master_check_ip_not_present($ip) {
		$search = WMS_Ldap::getInstance()->getEntry(WMS_Ldap::PBX, '(pbxIp=' . $ip . ')', array('pbxSerial'));
		return!empty($search) ? $search['pbxSerial'] : true;
	}

	function send_file($fullpath, $filename) {
		header("Content-type: application/x-gzip");
		header("Content-Disposition: attachment; filename=\"" . $filename . "\"");
		readfile($fullpath);
	}

	function send_txt($txt, $filename) {
		header("Content-type: application/x-gzip");
		header("Content-Disposition: attachment; filename=\"" . $filename . "\"");
		echo $txt;
	}

	static public function getPbxDnBySerial($serial){
		$search = WMS_Ldap::getInstance()->getEntry(WMS_Ldap::PBX, '(pbxSerial=' . $serial . ')', array('dn'));
		return empty($search)? '' : $search['dn'];
	}

	static public function moveUserSettings($user, $oldPBXdn, $curPbx){
		$oldPBX = WMS_Ldap::getInstance()->getEntryByDn($oldPBXdn , array('pbxSerial','cn','pbxDomain','pbxid','dn', 'pbxIp', 'pbxPublicPort', 'pbxPublicIp', 'pbxIsMaster'));
        $vals = parse_ini_file('/rw2/etc/pbx/net.conf', false, INI_SCANNER_RAW);
		$customSecurePort = $oldPBX['pbxPublicPort'] ? $oldPBX['pbxPublicPort'] : self::DEFAULT_PORT;
		$srvIp = ($vals['STARTUP'] === '1' && $vals['SRV_RESOLVE'] === '1') ? $oldPBX['pbxPublicIp'] : $vals['SRV_IP'];
        $destPbxIp = !empty($oldPBX['pbxIsMaster']) ? $srvIp : $oldPBX['pbxIp'];
        $pbxip = $destPbxIp . ':' . $customSecurePort;

        $luaService = new Services\LuaService();

        return $luaService->moveUser([$user['uid'], $user[LDAP_EXTEN_NUMBER], $pbxip]);
	}

    /**
     * Remove PBX from WMS network.
     *
     * @param string $oldPbxSerial Old PBX serial.
     * @param string $newPbxSerial New PBX serial.
     *
     * @return void
     */
    public function removePbx(string $oldPbxSerial, string $newPbxSerial) {
	    if (is_file(self::REMOVE_PBX_OUT)) {
            unlink(self::REMOVE_PBX_OUT);
        }

        $wmsLdap = WMS_Ldap::getInstance();

        // get dn of old PBX
        $oldPbxDn = $wmsLdap->getEntry(WMS_Ldap::PBX, '(pbxSerial=' . $oldPbxSerial . ')', ['dn', 'pbxIp']);

        if (empty($oldPbxDn) || empty($oldPbxDn['dn'])) {
            $this->saveRemovePbxError(__LINE__, _t('multipbx.pbxNotFound', $oldPbxSerial));
            return;
        }

        $oldPbxIp = $oldPbxDn['pbxIp'];
        $oldPbxDn = $oldPbxDn['dn'];

        // get dn of new PBX
        $newPbxDn = $wmsLdap->getEntry(WMS_Ldap::PBX, '(pbxSerial=' . $newPbxSerial . ')', ['dn']);
        if (empty($newPbxDn) || empty($newPbxDn['dn'])) {
            $this->saveRemovePbxError(__LINE__, _t('multipbx.pbxNotFound', $newPbxSerial));
            return;
        }
        $newPbxDn = $newPbxDn['dn'];

        $moveAllUsersResult = false;

        $ldapConnectParams = $wmsLdap->getConnectParams();
        $ldapConnect       = $wmsLdap->getConfigurationConnect();
        $ldapConnectRw     = $wmsLdap->getConfigurationConnect($ldapConnectParams['host_rw']);

        try {
            $ldapConfigAttributes = ['olcDbNoSync' => 'TRUE'];
            $this->setLdapConfigAttributes($ldapConnect, $ldapConfigAttributes);
            $this->setLdapConfigAttributes($ldapConnectRw, $ldapConfigAttributes);

            $moveAllUsersResult = $wmsLdap->moveUsers($oldPbxDn, $newPbxDn);
        } catch (\Exception $e) {
            $this->saveRemovePbxError(__LINE__, $e->getMessage());
        } finally {
            logger('WMS Net: LDAP remove param olcDbNoSync');
            $ldapConfigAttributes = ['olcDbNoSync' => ''];
            $this->setLdapConfigAttributes($ldapConnect, $ldapConfigAttributes);
            $this->setLdapConfigAttributes($ldapConnectRw, $ldapConfigAttributes);
        }

        if ($moveAllUsersResult !== true) {
            $this->saveRemovePbxError(__LINE__, _t('multipbx.errorMoveUser', $moveAllUsersResult));
            return;
        }

        $res = $wmsLdap->deleteEntryByDn($oldPbxDn);

        if ($res !== true) {
            $this->saveRemovePbxError(__LINE__, _t('multipbx.errorDeletePBX', $res));
            return;
        }

        // clear users avatar cache
        exec('exec /usr/sbin/cleanup_avatar_cache.php > /dev/null &');
    }

    /**
     * Update LDAP config attributes.
     *
     * @param resource $connect
     * @param array    $attributes
     *
     * return void
     */
    private function setLdapConfigAttributes($connect, array $attributes) {
        $wmsLdap     = WMS_Ldap::getInstance();
        $ldapBackend = $wmsLdap->getLDAPBackend();

        logger('WMS Net: LDAP config set param - ' . json_encode($attributes));
        $wmsLdap->update('olcDatabase={1}' . $ldapBackend . ',cn=config', $attributes, '(olcDatabase=' . $ldapBackend . ')', $connect);
    }

    /**
     * Save unset slave progress to file.
     *
     * @param int $count
     * @param string $state
     *
     * return void
     */
    private function setUnsetSlaveProgress(int $count, string $state = 'in progress') {
        file_put_contents(self::LDAP_UNSET_SLAVE_OUT, sprintf('state:%s;objects_expected:%d;objects_actual:%d;', $state, $count, $count));
    }

    /**
     * Save error message to file.
     *
     * @param int    $line    Row line.
     * @param string $message Error message.
     *
     * return void
     */
    private function saveRemovePbxError(int $line, string $message) {
        logger($message, $line);
        file_put_contents(self::REMOVE_PBX_OUT, $message);
    }

    /**
     * Check WMS network login and password complexity
     *
     * @param string $login    WMS network login.
     * @param string $password WMS network password.
     *
     * @return boolean
     */
    public function isCredentialsSecure(string $login = '', string $password = '') : bool {
        $validator = new \Wildix\Validator();

        $validationFields = ['login', 'password'];

        $validator->rule('alphaNum', 'login');
        $validator->rule('LengthMin', 'login', 13);

        $validator->rule('NetworkPassword', 'password');

        $validator->rule('required', $validationFields);

        return [] === $validator->validateData(
            [
                'login' => $login,
                'password' => $password,
            ],
            $validationFields
        );
    }

    /**
     * Return current WMS network Server PBX serial
     *
     * @return string
     */
    public function getNetworkServerPbxSerial() : string {
        foreach (self::getAllPbxes() as $pbx) {
            if (!empty($pbx['pbxIsMaster'])) {
                return $pbx['pbxSerial'];
            }
        }
    }
}
