<?php
/** Class network
 * @author ITeam[Odessa]
 * @copyright wildix
 *
 * TODO:
 * 1. prepare /etc/networking/interfaces file
 * 	- read file
 * 		- get array [ interface - type - state ]
 *  - read ifconfig && ifplugstate
 * 2. cashe  /etc/networking/interfaces after init && and store after destruct class
 */

require_once('network/netfunctions.php');


class network
{
	/* TODO:
	 * 	# auto eth0 eth1
		# mapping eth0 eth1
		#     script /path/to/get-mac-address.sh
		#     map 11:22:33:44:55:66 lan
		#     map AA:BB:CC:DD:EE:FF internet
		# iface lan inet static
		#     address 192.168.42.1
		#     netmask 255.255.255.0
		#     pre-up /usr/local/sbin/enable-masq $IFACE
		# iface internet inet dhcp
		#     pre-up /usr/local/sbin/firewall $IFACE
	*/

	/** System config file of interfaces */
	var $bootfile = '/etc/network/interfaces';

	/** System config file of hostnames */
	var $hostfile = '/etc/hosts';
	var $wmsHostfile = '/etc/dnsmasq.d/hosts-wms.conf';

	/** System hostname file */
	var $sysnamefile = '/etc/hostname';

	/** System config file of dns servers */
	var $dnsserversfile = '/etc/dnsmasq.d/resolv.conf';

	/** System config file of ifplugd */
	var $ifplugdfile =  '/etc/default/ifplugd';

	/** WMS network config file*/
	var $wnetfile = '/rw2/etc/pbx/net.conf';

	/** Link to WMSErrors Object*/
	var $err;

	/** array of $bootfile */
	var $__cache_bootfile;

	/** array of interfaces at boot time */
	var $boot_interfaces = array();

	/** array of interfaces realtime */
	var $active_interfaces = array();

	/** array of dns servers */
	var $dns_servers = array();

	/** array of hostnames */
	var $hostnames = array();
	var $wmsHostnames = array();

	/** */
	var $systemname;

	var $EA = '';

	var $__default_store_after_destruct = false;

	var $bridged_interfaces = array();

	/** Constructor
	 */
	function __construct() {
		global $wmsErr;
		require_once("common/errors.php");
		$this->err = (is_object($wmsErr)) ? $wmsErr : new WMSErrors();

		$this->__prepare_ifconfig_info();
		$this->__prepare_boot_file();
		$this->__prepare_wnet_info();
		$this->__prepare_hostnames_dns();

		return true;
	}

	/** Destructor
	 */
	function __destruct(){
		if($this->__default_store_after_destruct == true){
			$this->__store_boot_file();
			$this->__store_wnet_info();
		}

		return true;
	}

	//----//

	/** Parse /etc/network/interfaces
	 * @param 	void
	 * @return 	bool
	 */
	function __prepare_boot_file(){
		if (0 == sizeof($this->boot_interfaces)){
			if (!file_exists($this->bootfile)){
				$this->err->_set('','error',_t('net.doesNotExist',$this->bootfile));
				return false;
			}
			if (!is_writeable($this->bootfile)){
				$this->err->_set('','error',_t('net.isNotWriteable',$this->bootfile));
				return false;
			}

			$__cache_bootfile = file($this->bootfile);
			array_push($__cache_bootfile, ''); /* possible without newline at the end */

			$__exclude_interfaces = array('lo');

			$search = array();
			$tmp = array();

			//get only iface config
			foreach ($__cache_bootfile as $line){
				if(strpos($line,'up route ') !== false ||
				  strpos($line,'down route ') !== false ||
				  strpos($line,'wshaper ') !== false ||
				  strpos($line,'iface lo ') !== false ||
				  strpos($line,'auto ') !== false ||
				  strpos($line,'allow-hotplug ') !== false ||
				  strpos($line,'mapping ') !== false ||
				  strpos($line,'script ') !== false ||
				  strpos($line,'map ') !== false ||
				  strpos($line,'grep ') !== false){
					continue;
				}

				if (trim($line) === ''){ // finish defenition
					if (! empty($tmp)) {
						$search[] = $tmp;
						$tmp = array();
					}
				} else {
					$tmp[] = trim($line);
				}
			}

			$key = '';
			$interfaces = array();
			foreach ($search as $block) {
				foreach ($block as $str) {
					if (strpos($str, 'iface ') !== false && preg_match('/iface\s+([^\s]+)\s+inet\s+(static|dhcp|manual)/',$str,$matches)) {

						$al =& $this->get_alias($key = $matches[1]);

						$interfaces[$key]['type'] = $matches[2];
						$interfaces[$key]['activate'] = 'disabled';
						$interfaces[$key]['alias'] = $al['alias'];

					} elseif ($key != '' && preg_match('/([^\s]+)\s+(.*)/',$str,$matches)) {
						$interfaces[$key][$matches[1]] = $matches[2];
					}
				}
			}

			// normalize & extend interface information
			foreach ($interfaces as $key => $interface) {
				// static
				if ($interface['type'] == 'static') {

					$network =& $this->generate_net($interfaces[$key]['address'],$interfaces[$key]['netmask']);

					$interfaces[$key]['network']   = $network['network'];
					$interfaces[$key]['broadcast'] = $network['broadcast'];

					if (isset($interfaces[$key]['gateway'])){
						// gateway = array([distenation], [genmask])
						$interfaces[$key]['gateway'] = array($interfaces[$key]['gateway'] => array('0.0.0.0','0.0.0.0'));
					}

					if (preg_match('/(eth[0-9]*)\.([0-9]*)/',$key, $matches)) { // vlan
						$interfaces[$key]['vlan_raw_device'] = $matches[1];
					}
				}
			}

			//get dhcp routes
			exec('/sbin/route -vn', $output);
			array_splice($output,0,2);

			foreach ($output as $line){
				$tmp = $this->array_normal(explode(' ',$line));
				if(trim($tmp[0]) == 'default' || (trim($tmp[0]) == '0.0.0.0' && trim($tmp[2]) == '0.0.0.0')){
					if($interfaces[trim($tmp[sizeof($tmp)-1])]['type'] == 'dhcp'){
						/* $interfaces[trim($tmp[sizeof($tmp)-1])]['gateway'][$tmp[1]] = array('0.0.0.0','0.0.0.0'); */
						$interfaces[trim($tmp[sizeof($tmp)-1])]['gateway'][] = array($tmp[1],'0.0.0.0','0.0.0.0');
					}
				}
			}

			$status_iface_string      = '/auto (.+)/';
			$status_iface_string_dhcp = '/allow-hotplug (.+)/';

			//get gateways
			$ereg_string   = '/^iface\s+([^\s]+)(.*gateway\s+([^\s][0-9.]+))?.*/';
			$ereg_route    = '/.*up\s+route\s+add\s+-net\s+([^\s][0-9.]+)\s+netmask\s+([^\s][0-9.]+)\s+gw\s+([^\s][0-9.]+).*/';
			$ereg_wshaper  = '!.*up\s+/usr/sbin/wshaper\s+([^\s]+)\s+([^\s][0-9.]*)\s+([^\s][0-9.]*)!';

			$flag = false;
			foreach ($__cache_bootfile as $line){

				if (strpos($line,'#') === false && strpos($line,"auto") === false && preg_match($ereg_string,$line,$tmpfc)) {
					$flag = true;
					$key = $tmpfc[1];
				}

				if ($flag === true){
					if(preg_match($ereg_route,$line,$tmpgw)){
						/* $interfaces[$key]['gateway'][$tmpgw[3]] = array(trim($tmpgw[1]),trim($tmpgw[2])); */
						$interfaces[$key]['gateway'][] = array($tmpgw[3],trim($tmpgw[1]),trim($tmpgw[2]));
					}

					if (strpos($line, 'wshaper') !== false && preg_match ($ereg_wshaper, $line, $matches)) {
						$interfaces[$key]['wshaper'] = array($matches[1],$matches[2],$matches[3]);
					}

					if (strpos($line, 'wshaper') !== false) {
						if (preg_match ($ereg_wshaper, $line, $matches)) {
							$interfaces[$key]['wshaper'] = array($matches[1],$matches[2],$matches[3]);
						}
					}

					if (trim($line) === '')  $flag = false;
				}
			}



			//get status
			foreach ($__cache_bootfile as $line){
				if (strpos($line,"#") === false){
					if(preg_match($status_iface_string,$line,$tmpfc) ||
					  preg_match($status_iface_string_dhcp,$line,$tmpfc)){
						$interfaces[$tmpfc[1]]['activate'] = 'enabled';
					}
				}
			}

			foreach($__exclude_interfaces as $interface){
				if(@array_key_exists($interface,$interfaces) !== false){
					unset($interfaces[$interface]);
				}
			}

			$this->boot_interfaces = $interfaces;
		}

		return true;
	}

	/** Parse /rw2/etc/pbx/net.conf
	 * @param 	void
	 * @return 	bool
	 */
	function __prepare_wnet_info(){
		if (! file_exists($this->wnetfile)) return false;

		$interface = 'wtun0';
		$wnet_interface = array();

		$wnet_settings = parse_ini_file($this->wnetfile,false,INI_SCANNER_RAW);
		if (isset($wnet_settings['CLIENT_IP'])) {
			$wnet_interface[$interface] = array();
			$wnet_interface[$interface]['address'] = $wnet_settings['CLIENT_IP'];
			$wnet_interface[$interface]['netmask'] = '255.255.255.0';
			$wnet_interface[$interface]['type'] = 'static';

			if (isset($wnet_settings['ROUTE']) && trim($wnet_settings['ROUTE']) != '') {
				foreach (explode(',', $wnet_settings['ROUTE']) as $route) {
					list($destination, $bitmask, $gateway) = explode('/',$route);
					$netmask = $bitmask != '0'? $this->cidr2netmask($bitmask): '0.0.0.0';

					if (! isset($wnet_interface[$interface]['gateway'])) {
						$wnet_interface[$interface]['gateway'] = array();
					}

					$wnet_interface[$interface]['gateway'][] = array($gateway, $destination, $netmask);
				}
			}

			$wnet_interface[$interface]['alias'] = 'DMZ';

			$t = $this->generate_net($wnet_interface[$interface]['address'], $wnet_interface[$interface]['netmask']);
			$wnet_interface[$interface]['network'] = $t['network'];
			$wnet_interface[$interface]['broadcast'] = $t['broadcast'];
		}

		$this->boot_interfaces = array_merge($this->boot_interfaces, $wnet_interface);

		return true;
	}

	/** Read ifconfig command
	 * @param 	void
	 * @return 	bool
	 */
	function __prepare_ifconfig_info(){
		if(empty($this->active_interfaces)){
			$result       = array();
			$ereg_string  = '/([^\s][a-zA-Z0-9:.]+)?:.*<(UP|<DOWN)?.*inet\s([0-9.]*)?.*netmask\s([0-9.]*)?.*broadcast\s([0-9.]*)?.*ether\s([a-zA-Z0-9][^\s]*)?.*(Ethernet).*/';
			$newstr       = '';
			$__for_search = array();

			exec('/sbin/ifconfig -a', $output);

			foreach ($output as $str){
				$newstr .= $str;
				if (chop($str) === ''){
					$__for_search[] = $newstr;
					$newstr = '';
				}
			}

			for ($i=0,$max = sizeof($__for_search); $i<$max; $i++){
				$tmp = explode('~', preg_replace($ereg_string, '$1~$7~$3~$4~$2~$5', $__for_search[$i]));
				if (empty($tmp[1])) {
                    // WMS-4581. parse not configured interface
                    $regexStr = '/([^\s][a-zA-Z0-9:.]+)?:.*<(UP|DOWN|).*(Ethernet).*/';
					$tmp = explode('~', preg_replace($regexStr, '$1~$3~$6~$4~$2~$5', $__for_search[$i]));
				}

				if (trim($tmp[1] ?? '') !== 'Ethernet') continue;

				$aliases = network::get_alias($tmp[0]);
				if ($tmp[0] !== "lo") {
					$n = network::generate_net($tmp[2],$tmp[3]);
					$name = $aliases['name'];
					$result[$name] = array(
						'type' => $tmp[1],
						'address' => $tmp[2],
						'netmask' => $tmp[3],
						'activate' => trim($tmp[4]) == '' ? 'DOWN' : strtoupper($tmp[4]),
						'broadcast' => $tmp[5],
						'network' => $n['network'],
						'alias' => $aliases['alias'],
					);
				}
			}

			// read ifplugstatus
			$command = '/usr/sbin/ifplugstatus';
			$output = array();
			exec($command, $output);
			foreach ($output as $line){
				if(preg_match('/(.+):(.+)/',$line,$tmp)){
					if(!isset($result[$tmp[1]])) continue;
					if(strpos($tmp[2],'unplugged') !== false){
						$result[$tmp[1]]['link'] = 'unplug';
					} elseif(strpos($tmp[2],'link beat detected') !== false){
							$result[$tmp[1]]['link'] = 'plug';
						}
				}
			}

			// read duplex mode
			$command = 'sudo /sbin/mii-tool 2>/dev/null';
			$output = array();
			exec($command, $output);

			foreach ($output as $line){
				if(preg_match('/(.+):(.+)/',$line,$tmp)){
					if(strpos($tmp[2],'link ok') !== false && isset($result[$tmp[1]])){
						foreach (array('1000baseT-FD','100baseT4','100baseTx-FD','100baseTx-HD','10baseT-FD','10baseT-HD') as $speed){
							if(strpos($tmp[2],$speed) !== false){
								$result[$tmp[1]]['type'] = $result[$tmp[1]]['type'].' '.$speed;
								break;
							}
						}
					}
				}
			}

			$this->active_interfaces = $result;
		}
		return true;
	}

	/** Read /etc/dnsmasq.d/resolv.conf, /etc/hostname, /etc/hosts
	 * @param 	void
	 * @return 	bool
	 */
	function __prepare_hostnames_dns(){
		if(file_exists($this->sysnamefile) && $this->systemname == ''){
			$this->systemname = trim(file_get_contents($this->sysnamefile));
		}

		if (file_exists($this->dnsserversfile) && empty($this->dns_servers)){
			foreach(file($this->dnsserversfile) as $line){
				if(preg_match("/^nameserver ([^\s][0-9.]+).*/i",$line,$host))
					$this->dns_servers[] = $host[1];
			}
		}

		if (file_exists($this->hostfile)){
			foreach(file($this->hostfile) as $line){
				if(preg_match("/^([0-9.]+)\s(.+)/",$line,$tmphst)){
					$this->hostnames[$tmphst[1]] = array_unique(explode(' ',strtolower($tmphst[2])));
				}
			}

			if(!@in_array('localhost',$this->hostnames['127.0.0.1'])){
				@array_unshift($this->hostnames['127.0.0.1'],'localhost');
			}

			if(!@in_array($this->systemname,$this->hostnames['127.0.0.1'])){
				$this->hostnames['127.0.0.1'][] = $this->systemname;
			}

		}
		if (file_exists($this->wmsHostfile)){
			foreach(file($this->wmsHostfile) as $line){
				if(preg_match("/^([0-9.]+)\s(.+)/",$line,$tmphst)){
					$this->wmsHostnames[$tmphst[1]] = array_unique(explode(' ',strtolower($tmphst[2])));
				}
			}
		}

		// get EA
		$sipgenfile = PATH_TO_CW_CONF."sip-wms.conf";
		if(file_exists($sipgenfile) && $this->EA == ''){
			$regex_ip   = '/^externip=([0-9.]+)/';
			$regex_host = '/^externhost=([^\s][a-zA-Z0-9\-\_\.]+)/';
			foreach(file($sipgenfile) as $line){
				if(preg_match($regex_ip,$line,$tmp) || preg_match($regex_host,$line,$tmp)){
					$this->EA = $tmp[1];
					break;
				}
			}
		}

		return true;

	}

	//----//

	/** Function for find all active interfaces filtred by $interface param
	 * @param 	string	$interface	interface
	 * @return 	array	Assoc array
	 */
	function get_active_network_interfaces($interface = null){
		return (!is_null($interface)) ? $this->active_interfaces[$interface] : $this->active_interfaces;
	}

	/** Function for find all interfaces which loading at boot time filtred by $interface param
	 * @param 	string	$interface	interface
	 * @return 	array 	Assoc array;
	 */
	function get_boot_network_interfaces($interface = null){
		return (!is_null($interface)) ? $this->boot_interfaces[$interface] : $this->boot_interfaces;
	}

	/** Return active interafces in table view
	 * @param 	void
	 * @return 	array	Assoc array
	 */
	function get_active_network_interfaces_as_table(){
		$result = array();
		$tmp = $this->active_interfaces;
		foreach ($tmp as $key => $value){
			$result[] = array_merge(array('interface'=>$key),$value);
		}
		return $result;
	}

	/** Return boot interafces in table view
	 * @param 	void
	 * @return 	array	Assoc array
	 */
	function get_boot_network_interfaces_as_table(){
		$result = array();
		$tmp = $this->boot_interfaces;
		foreach ($tmp as $key => $value){
			$result[] = array_merge(array('interface'=>$key),$value);
		}
		return $result;
	}

	//----//

	/** Add a new interface
	 * @param	array 	$interface_store	Params of interface
	 * @param 	bool 	$enabled	Status of interface
	 * @return 	bool
	 */
	function add_interface($interface_store = array(), $enabled = true){
		if (0 == sizeof($interface_store)) return false;

		if (array_key_exists($interface_store['interface'],$this->boot_interfaces) !== false) return false;

		$aliases = network::get_alias($interface_store['interface']);

		if ($interface_store['type'] == 'dhcp'){
			$configuration = array(
				'type'     => 'dhcp',
				'alias'    => $aliases['alias'],
				'activate' => $enabled ? 'enabled' : 'disabled'
			);
		} else {
			if (!is_ip($interface_store['address']) || !is_ip_mask($interface_store['netmask'])) return false;

			$network = $this->generate_net($interface_store['address'],$interface_store['netmask']);

			$configuration = array(
				'type'      => 'static',
				'alias'     => $aliases['alias'],
				'address'   => $interface_store['address'],
				'netmask'   => $interface_store['netmask'],
				'broadcast' => $network['broadcast'],
				'network'   => $network['network'],
				'activate'  => $enabled ? 'enabled' : 'disabled'
			);
		}

		if (preg_match('/(eth[0-9]*)\.([0-9]*)/',$interface_store['interface'], $matches)) { // vlan
			if ($interface_store['type'] == 'dhcp') return false;

			$configuration['vlan_raw_device'] = $matches[1];
		}

		$this->boot_interfaces[$interface_store['interface']] = $configuration;

		return true;
	}

	/** Modify param of interface
	 * @param	array 	$interface_store	Assoc array of param of interface
	 * @param 	bool 	$interface_status	Status of interface
	 * @return 	bool
	 */
	function modify_interface($interface_store = array(),$interface_status = true){
		if(empty($interface_store)) return false;

		if(array_key_exists($interface_store['interface'],$this->boot_interfaces) === false) return false;

		if (isset($interface_store['wshaper_uplink']) && $this->boot_interfaces[$interface_store['interface']]['wshaper']) {
			$this->boot_interfaces[$interface_store['interface']]['wshaper'][1] = $interface_store['wshaper_uplink'];
			$this->boot_interfaces[$interface_store['interface']]['wshaper'][2] = $interface_store['wshaper_downlink'];
		}

		if($interface_store['type'] == 'dhcp'){
			$this->boot_interfaces[$interface_store['interface']]['type'] = 'dhcp';
			$this->boot_interfaces[$interface_store['interface']]['activate'] = $interface_status ? 'enabled' : 'disabled';

			return true;
		}

		if(!is_ip($interface_store['address']) || !is_ip_mask($interface_store['netmask'])) return false;
		else {
			$network = $this->generate_net($interface_store['address'],$interface_store['netmask']);

			$this->boot_interfaces[$interface_store['interface']]['type'] = 'static';
			$this->boot_interfaces[$interface_store['interface']]['address'] = $interface_store['address'];
			$this->boot_interfaces[$interface_store['interface']]['netmask'] = $interface_store['netmask'];
			$this->boot_interfaces[$interface_store['interface']]['broadcast'] = $network['broadcast'];
			$this->boot_interfaces[$interface_store['interface']]['network'] = $network['network'];
			$this->boot_interfaces[$interface_store['interface']]['activate'] =  $interface_status ? 'enabled' : 'disabled';

			return true;
		}
	}

	/** Remove interface
	 * @param	string 	$interface  Interface shoukd be removed
	 * @return 	bool
	 */
	function remove_interface ($interface = null){
		if(is_null($interface)) return false;

		if(array_key_exists($interface,$this->boot_interfaces) === false) return false;

		// check is it a bridge interface
		if (strpos($interface, 'wbr') !== false) {
			$restore = explode(' ', $this->boot_interfaces[$interface]['bridge_ports']);
			$restore_configuration = $this->boot_interfaces[$interface];
			unset($restore_configuration['bridge_ports']);
			unset($restore_configuration['wshaper']);

			$this->boot_interfaces[$restore[0]] = $restore_configuration;

			// restore virtual intererfaces
			foreach (array_keys($this->boot_interfaces) as $key) {
				if (strpos($key,$interface . ':') !== false) {
					$virt = str_replace($interface, $restore[0], $key);

					$this->boot_interfaces[$virt] = $this->boot_interfaces[$key];
					unset($this->boot_interfaces[$key]);
				}
			}
		}

		unset($this->boot_interfaces[$interface]);

		return true;
	}

	/** Bridge interfaces
	 * @usage in configuration:
	 * auto wbr0
	 * allow-hotplug wbr0
	 * iface wbr0 inet static
	 *         bridge_ports eth0 eth2
	 *         address 192.168.1.223
	 *         netmask 255.255.255.0
	 *         network 192.168.1.0
	 *         broadcast 192.168.1.255
	 * up route add -net 0.0.0.0 netmask 0.0.0.0 gw 192.168.1.254 dev $IFACE
	 * down route add -net 0.0.0.0 netmask 0.0.0.0 gw 192.168.1.254 dev $IFACE
	 *
	 * @param	array  $interfaces  Interfaces should be bridget
	 * @param	string  $brname  Name of a bridge interface
	 * @return 	bool
	 */
	function add_bridge_interface ($interfaces = array(), $brname = null){
		if(0 == sizeof($interfaces)) return false;

		// generate brname
		if (is_null($brname)) {
			$tmp = array_keys($this->boot_interfaces);

			for ($i=0; $i<100; $i++) {
				if (! in_array($brname = 'wbr'.$i, $tmp))
					break;
			}
		}

		if (array_key_exists($brname,$this->boot_interfaces) !== false) return false;

		//1. add new defination into boot_interfaces array
		if (! isset($this->boot_interfaces[$interfaces[0]])) {
			return false;
		}

		$br_configuration = $this->boot_interfaces[$interfaces[0]];
		$br_configuration['bridge_ports'] = implode(' ', $interfaces);
		$br_configuration['wshaper'] = array(
			/*interface*/$interfaces[0], /* uplink */100000, /* downlink */100000);

		$this->boot_interfaces[$brname] = $br_configuration ;

		//2. remove defination of bridget interfaces
		foreach ($interfaces as $key) {
			unset($this->boot_interfaces[$key]);
		}

		//3. move virtual eth0 interfaces back to bridge interface
		foreach (array_keys($this->boot_interfaces) as $key) {
			if (strpos($key,$interfaces[0] . ':') !== false) {
				$brvirt = str_replace($interfaces[0], $brname, $key);

				$this->boot_interfaces[$brvirt] = $this->boot_interfaces[$key];
				unset($this->boot_interfaces[$key]);
			}

			//4. remove any virtual interfaces from eth2
			if (strpos($key,$interfaces[1] . ':') !== false) {
				unset($this->boot_interfaces[$key]);
			}
		}

		return true;
	}

	//----//

	/** Change param of active interface
	 * @param	array 	$interface_store	Assoc array of param of interface
	 * @return 	bool
	 */
	function update_active_interface($interface_store = array()){
		if(empty($interface_store)) return false;

		if(array_key_exists($interface_store['interface'],$this->active_interfaces) === false) return false;

		if(!is_ip($interface_store['address']) || !is_ip_mask($interface_store['netmask'])) return false;
		else {
			$network = $this->generate_net($interface_store['address'],$interface_store['netmask']);
			$this->active_interfaces[$interface_store['interface']]['address'] = $interface_store['address'];
			$this->active_interfaces[$interface_store['interface']]['type'] = 'Ethernet';
			$this->active_interfaces[$interface_store['interface']]['netmask'] = $interface_store['netmask'];
			$this->active_interfaces[$interface_store['interface']]['broadcast'] = $network['broadcast'];
			$this->active_interfaces[$interface_store['interface']]['network'] = $network['network'];
			$this->active_interfaces[$interface_store['interface']]['activate'] = 'UP';

			$this->add_interface($interface_store, true);

			exec("sudo /sbin/ifconfig {$interface_store['interface']} {$interface_store['address']} netmask {$interface_store['netmask']} broadcast {$network['broadcast']}");

			return true;
		}
	}

	/** Change status of interface
	 * @param 	string	$interface			Interface
	 * @param	bool 	$interface_status 	Status
	 * @return 	bool
	 */
	function change_status_interface($interface = null, $interface_status = false) {
		if(is_null($interface)) return false;

		if(array_key_exists($interface,$this->boot_interfaces) === false) return false;

		$this->boot_interfaces[$interface]['activate'] = $interface_status ? 'enabled' : 'disabled';

		return false;
	}

	/** Get routes for interfaces as table view filtred by $interface param
	 * @param 	string	$interface	Interface
	 * @return 	array	Assoc array
	 */
	function get_routes_interfaces_as_table($interface = null) {
		$result = array();
		$__tmp_boot_interfaces = is_null($interface) ?
		  $this->boot_interfaces : $this->boot_interfaces[$interface];

		foreach (array_keys($__tmp_boot_interfaces) as $key){
			if(!isset($__tmp_boot_interfaces[$key]['gateway'])) continue;

			foreach ($__tmp_boot_interfaces[$key]['gateway'] as $route){
				$result[] = array('alias'		=> $__tmp_boot_interfaces[$key]['alias'],
					'interface'   => $key,
					'gateway'     => $route[0],
					'destination' => $route[1],
					'genmask'     => $route[2],
					'network'     => $__tmp_boot_interfaces[$key]['network'],
					'type'        => $__tmp_boot_interfaces[$key]['type']
				);
			}
		}

		return $result;
	}

	/** Checks if gateway is not going out of the interface subnet
	 * @param 	array	assoc array of route param
	 * @return 	bool
	 */
	function check_gateway($interface_store = array()){
		if(empty($interface_store)) return false;

		if(array_key_exists($interface_store['interface'],$this->boot_interfaces) === false) return false;


		$interface = $this->boot_interfaces[$interface_store['interface']];

		$network = get_subnet($interface["address"],$interface["netmask"]);

		$long_ip_gateway = ip2long($interface_store['gateway']);
		return ($long_ip_gateway >= ip2long($network["first"]) && $long_ip_gateway <= ip2long($network["last"]));
	}

	/** Add new route for interface
	 * @param 	array	assoc array of route param
	 * @return 	bool
	 */
	function add_route($interface_store = array()){
		if(empty($interface_store)) return false;

		if(array_key_exists($interface_store['interface'],$this->boot_interfaces) === false) return false;

		$routes = $this->boot_interfaces[$interface_store['interface']]['gateway'];

		foreach ($routes as $route) {
			if ( // check if such entry is already present
				$route[0] == $interface_store['gateway'] &&
				$route[1] == $interface_store['destination'] &&
				$route[2] == $interface_store['genmask']
			) {
				return false;
			}
		}

		$this->boot_interfaces[$interface_store['interface']]['gateway'][] = array(
		  $interface_store['gateway'],
		  $interface_store['destination'],
		  $interface_store['genmask']
		);

		return true;
	}

	/** Remove route for interface
	 * @param 	array	Assoc array of route param
	 * @return 	bool
	 */
	function remove_route($interface_store = array()){
		if (empty($interface_store)) return false;

		if (array_key_exists($interface_store['interface'],$this->boot_interfaces) === false) return false;

		$routes = $this->boot_interfaces[$interface_store['interface']]['gateway'];

		foreach ($routes as $key => $route) {
			if ( // check if such entry is already present
				$route[0] == $interface_store['gateway'] &&
				$route[1] == $interface_store['destination'] &&
				$route[2] == $interface_store['genmask']
			) {
				unset($this->boot_interfaces[$interface_store['interface']]['gateway'][$key]);
				return true;
			}
		}

		return false;
	}

	/** Get hostnames in table view
	 * @param  string 	$address 	ip address
	 * @return array 	Assoc array of hostnames
	 */
	function get_hostnames_as_table($address = null){
		$result = array();
		foreach (array_keys($this->hostnames) as $key){
			$result[] = array('address' => $key, 'aliases' => implode(' ', $this->hostnames[$key]), 'readonly' => 1);
		}

		foreach (array_keys($this->wmsHostnames) as $key){
			$result[] = array('address' => $key, 'aliases' => implode(' ', $this->wmsHostnames[$key]), 'readonly' => 0);
		}
		return $result;
	}

	/** Add new hostname
	 * @param  array $hostname_store	Assoc array of hostname
	 * @return bool
	 */
	function add_hostname($hostname_store = array()){
		if(empty($hostname_store)){
			return false;
		}

		if(array_key_exists($hostname_store['address'], $this->wmsHostnames) !== false){
			return false;
		}

		$this->wmsHostnames[$hostname_store['address']] = $hostname_store['aliases'];
		if(!is_array($hostname_store['aliases'])){
			$this->wmsHostnames[$hostname_store['address']] = explode(' ', $hostname_store['aliases']);
		}

		return true;
	}

	/** Remove hostname by ip
	 * @param  string $address	ip address
	 * @return bool
	 */
	function remove_hostname($address){
		if(array_key_exists($address,$this->wmsHostnames) === false){
			return false;
		}

		unset($this->wmsHostnames[$address]);

		return true;
	}

	/** Modify information of aliases of address
	 * @param  array $hostname_store	Assoc array of hostname
	 * @return bool
	 */
	function modify_hostname($hostname_store = array()){
		if(empty($hostname_store)){
			return false;
		}

		if(array_key_exists($hostname_store['address'], $this->wmsHostnames) === false){
			return false;
		}

		$this->wmsHostnames[$hostname_store['address']] = $hostname_store['aliases'];
		if(!is_array($hostname_store['aliases'])){
			$this->wmsHostnames[$hostname_store['address']] = explode(' ', $hostname_store['aliases']);
		}

		return true;
	}

	//---//

	/** */
	function set_dns_servers($servers = array()){
		if(empty($servers)) return false;

		$this->dns_servers = $servers;

		// force change owner to wms
		exec('sudo /bin/chown wms.wms '.$this->dnsserversfile.' >/dev/null 2>&1');

		if (is_writable($this->dnsserversfile)){
			$fp = fopen($this->dnsserversfile,"w");
			foreach ($this->dns_servers as $server){
				if ( trim($server) !== '') {
					fputs($fp,"nameserver $server\n");
				}
			}
			fclose($fp);
		}

		return true;
	}

	/** */
	function set_sysname($sysname, $restart_dns = false){
		$this->__default_store_after_destruct = true;
		$sysname = strtolower($sysname);
		$domain =  $sysname.'.wildixin.com';
		$serial = \Models\PBX::getInstance()->getSerial();
		$pbx = \Wildix\PBXes\PBXes::getInstance()->getPBXBySerial($serial);
		if($pbx->getDomain() !== false && $pbx->getDomain() != $domain){
			\Wildix\PBXes\PBXes::getInstance()->updatePBXProperty(array(\Wildix\PBXes\PBX::DOMAIN => $domain, \Wildix\PBXes\PBX::HOSTNAME => $sysname), $pbx);

			$filename = '/rw2/etc/pbx/company.conf';
			$vals_init = parse_ini_file($filename, false, INI_SCANNER_RAW);
			$vals = array('pbx_domain' => $domain);
			$vals = array_merge($vals_init, $vals);
			write_ini_file($filename, $vals);
		}
		if($this->systemname != $sysname){
			if($this->systemname != $serial && ($key = array_search($this->systemname, $this->hostnames['127.0.0.1'])) !== false){
				if($sysname != $serial){
					$this->hostnames['127.0.0.1'][$key] = $sysname;
				}else{
					unset($this->hostnames['127.0.0.1'][$key]);
				}
			}elseif($sysname != $serial){
				$this->hostnames['127.0.0.1'][] = $sysname;
			}

			$this->systemname = $sysname;

			if (is_writable($this->sysnamefile)){
				$fp = fopen($this->sysnamefile,"w");
				fputs($fp,$this->systemname);
				fclose($fp);
			}

			if($restart_dns){
				$this->restart_dns();
			}

			$ejabberdSettings = \Wildix\Ejabberd::getInstance()->getSettings();
			if(!empty($ejabberdSettings['host']) && $ejabberdSettings['host'] != $domain){
				$ejabberdSettings['host'] = $domain;
				\Wildix\Ejabberd::getInstance()->setSettings($ejabberdSettings);
			}

		}
		return true;
	}

	//---//

	/** */
	function __store_boot_file(){
		if( $this->__default_store_after_destruct == false ) return;

		//TODO: store /etc/network/interfaces
		$to_file = str_repeat('#',72) . "\n# INTERFACES FILE WAS GENERATED BY WMS. PLEASE DO NOT CHANGE IT MANUALY\n\n" ;

		// set localhost
		$to_file .= "auto lo\niface lo inet loopback\n\n";

		foreach (array_keys($this->boot_interfaces) as $key){
			if (strpos($key, 'wtun') !== false) continue;

			if ($this->boot_interfaces[$key]['type'] == 'dhcp'){
				$set = array();

				if($this->boot_interfaces[$key]['activate'] == 'enabled'){
					$set[] = 'auto '.$key;
					$set[] = "allow-hotplug $key";
				}

				$set[] = "iface $key inet dhcp";

				if (isset($this->boot_interfaces[$key]['bridge_ports'])) {
					// bridge
					$set[] = "\tbridge_ports ".$this->boot_interfaces[$key]['bridge_ports'];

					if (isset($this->boot_interfaces[$key]['wshaper'])) {
						list($shaper_interface, $up, $down) = $this->boot_interfaces[$key]['wshaper'];

						$set[] = "up /usr/sbin/wshaper $shaper_interface $up $down";
						$set[] = "down /usr/sbin/wshaper $shaper_interface stop";
					}
				}

				if (isset($this->boot_interfaces[$key]['gateway'])){
					foreach ($this->boot_interfaces[$key]['gateway'] as $route){
						if(!($route[1] == '0.0.0.0' && $route[2] == '0.0.0.0')){
							$set[] = 'up route add -net ' . $route[1] .' netmask '. $route[2] .' gw '.$route[0].' dev $IFACE';
							$set[] = 'down route del -net ' . $route[1] .' netmask '. $route[2] .' gw '.$route[0].' dev $IFACE';
						}
					}
				}

				$set[] = str_repeat(PHP_EOL, 2);
				$to_file .= implode(PHP_EOL, $set) . PHP_EOL;

			} elseif ($this->boot_interfaces[$key]['type'] == 'static'){
				$set = array();

				if($this->boot_interfaces[$key]['activate'] == 'enabled'){
					$set[] = 'auto '.$key;
					$set[] = 'allow-hotplug '.$key;
				}

				$set[] = 'iface '.$key.' inet static';
				$set[] = "\taddress ".$this->boot_interfaces[$key]['address'];
				$set[] = "\tnetmask ".$this->boot_interfaces[$key]['netmask'];
				$set[] = "\tbroadcast ".$this->boot_interfaces[$key]['broadcast'];
				$set[] = "\tnetwork ".$this->boot_interfaces[$key]['network'];

				if (isset($this->boot_interfaces[$key]['vlan_raw_device'])) {
					// vlan
					$set[] = "\tvlan_raw_device ".$this->boot_interfaces[$key]['vlan_raw_device'];
				}

				if (isset($this->boot_interfaces[$key]['bridge_ports'])) {
					// bridge
					$set[] = "\tbridge_ports ".$this->boot_interfaces[$key]['bridge_ports'];

					if (isset($this->boot_interfaces[$key]['wshaper'])) {
						list($shaper_interface, $up, $down) = $this->boot_interfaces[$key]['wshaper'];

						$set[] = "up /usr/sbin/wshaper $shaper_interface $up $down";
						$set[] = "down /usr/sbin/wshaper $shaper_interface stop";
					}

				}

				if (isset($this->boot_interfaces[$key]['gateway'])){
					foreach ($this->boot_interfaces[$key]['gateway'] as $route){
						$set[] = 'up route add -net ' . $route[1] .' netmask '. $route[2] .' gw '.$route[0].' dev $IFACE';
						$set[] = 'down route del -net ' . $route[1] .' netmask '. $route[2] .' gw '.$route[0].' dev $IFACE';
					}
				}

				$set[] = str_repeat(PHP_EOL, 2);

				$to_file .= implode(PHP_EOL, $set) . PHP_EOL;

			}
		}

		if (trim($to_file) !== '' && is_writable($this->bootfile)){
			$fp = fopen($this->bootfile,'w');
			fputs($fp, $to_file);
			fclose($fp);
		}

	}

	/** */
	function __store_wnet_info(){
		if ($this->__default_store_after_destruct == false) return false;

		$interface = 'wtun0';

		if (! isset($this->boot_interfaces[$interface])) return false;
		if (! isset($this->boot_interfaces[$interface]['gateway'])) return false;
		if (! file_exists($this->wnetfile)) return false;

		// set route
		$wnet_settings = parse_ini_file($this->wnetfile,false,INI_SCANNER_RAW);
		$routes = array();

		foreach ($this->boot_interfaces[$interface]['gateway'] as $route){
			$routes[] = $route[1] . '/' . ($route[2] == '0.0.0.0'?'0':$this->netmask2cidr($route[2])) . '/' . $route[0];
		}

		$wnet_settings['ROUTE'] = implode(',', $routes);

		if (is_writable($this->wnetfile)) {
			return write_ini_file($this->wnetfile, $wnet_settings);
		}

		return false;
	}

	/** */
	function __store_resolv_file(){
		if(is_writable($this->wmsHostfile)){
			$hosts = '';
			foreach (array_keys($this->wmsHostnames) as $key){
				$hosts.= $key."\t".implode(' ', $this->wmsHostnames[$key])."\n";
			}
			file_put_contents($this->wmsHostfile, $hosts);
		}
	}

	//---//

	/** */
	function restart_network(){
		$this->__store_boot_file();

		$this->__default_store_after_destruct = false;

		//TODO: need create check which ifaces enabled/disabled and remove from /etc/defaults/ifplugd

		if(is_writable($this->ifplugdfile)){
			$hotplugged_interfaces = array();
			foreach (array_keys($this->boot_interfaces) as $key ){
				if($this->boot_interfaces[$key]['activate'] == 'enabled'){
					$hotplugged_interfaces[] = $key;
				}
			}

			//stop ifplug daemon
			exec('sudo /etc/init.d/ifplugd stop > /dev/null 2>&1');
			exec('sudo /usr/bin/pkill -9 ifplugd > /dev/null 2>&1');

			for($i=0,$cnt=sizeof($ifplug_conf = file($this->ifplugdfile));$i<$cnt;$i++){
				if(preg_match("/^HOTPLUG_INTERFACES\=/",$ifplug_conf[$i])){
					$ifplug_conf[$i] = "HOTPLUG_INTERFACES='".implode(' ',$hotplugged_interfaces)." lo'\n";
				}

				if(preg_match("/^INTERFACES\=/",$ifplug_conf[$i])){
					$ifplug_conf[$i] = "INTERFACES='".implode(' ',$hotplugged_interfaces)." lo'\n";
				}
			}

			$fp = fopen($this->ifplugdfile,'w');
			fputs($fp,implode('',$ifplug_conf));
			fclose($fp);

		} else return "$this->ifplugdfile is not writeable!";

		// kill all dhcp clients
		exec('sudo /usr/bin/pkill -u root dhclient3 > /dev/null 2>&1'); // kill dhcpclient

		// stop wshaper
		exec('sudo /usr/sbin/wshaper eth2 stop > /dev/null 2>&1');

		//logger(array_keys($this->active_interfaces),__FUNCTION__,__LINE__);

		foreach (array_keys($this->active_interfaces) as $key ){
			// do not down wtun interface
			if (strpos($key, 'wtun') !== false) continue;

			exec("sudo /sbin/ifconfig " . escapeshellarg($key) . " down  > /dev/null 2>&1");

			if (strpos($key, '.') !== false) {
				exec("sudo /sbin/vconfig rem " . escapeshellarg($key) . " > /dev/null 2>&1");

			} elseif (strpos($key, 'wbr') !== false) {
				exec("sudo /sbin/brctl delbr " . escapeshellarg($key) . " > /dev/null 2>&1");
			}
			// In Debian 9 restart of network does not flush the old IP/netmask settings
			exec('sudo /sbin/ip addr flush ' . escapeshellarg($key)  . ' > /dev/null 2>&1');
		}

		exec('sudo /etc/init.d/networking restart > /dev/null 2>&1');

		// need restart again (strange situation for dhcp->static ip)
		//exec('sudo /etc/init.d/networking restart');

		exec('sudo /etc/init.d/ifplugd restart > /dev/null 2>&1');

		// re-read active interfaces
		$this->active_interfaces = array();
		$this->__prepare_ifconfig_info();

		return true;
	}

	/** */
	public function restart_dns(){
		$this->__store_resolv_file();

		$this->__default_store_after_destruct = false;

		exec("sudo /bin/hostname -F $this->sysnamefile > /dev/null 2>&1");
		exec("sudo /etc/init.d/dnsmasq restart > /dev/null 2>&1");
		exec("sudo /etc/network/if-up.d/hosts update");
		return true;
	}

	/** Get state of routing
	 * @param 	void
	 * @return 	bool
	 */
	function is_masquerading(){
		return ( trim( exec('sudo /sbin/iptables -t nat -L POSTROUTING | grep "MASQUERADE" | wc -l' ) ) !== '0' );
	}

	/** Activate routing on eth0
	 * @param  void
	 * @return bool
	 */
	function set_masquerading(){
		if( network::is_masquerading() === true ){
			return false;
		}

		$interface = isset($this->active_interfaces['wbr0']) ? 'wbr0': 'eth0';

		// get WAN is active
		if( $this->active_interfaces[$interface]['activate'] == 'DOWN' ){
			return false;
		}

		exec("echo '/sbin/sysctl -q -w net.ipv4.conf.all.forwarding=1' > /etc/default/iptables");
        exec("sudo /sbin/sysctl -q -w net.ipv4.conf.all.forwarding=1");

        $dir = "/proc/sys/net/ipv4/conf/";
        $dh  = opendir($dir);
        while (false !== ($filename = readdir($dh))) {

            if (preg_match("/eth[1-9]/", $filename)) {

                exec("sudo /sbin/iptables -t mangle -A PREROUTING  -i ".$filename." -j MARK --set-mark 1");
                exec("echo '/sbin/iptables -t mangle -A PREROUTING  -i ".$filename." -j MARK --set-mark 1' >> /etc/default/iptables");
            }
        }
        exec("sudo /sbin/iptables -t nat -A POSTROUTING --out-interface eth0 -m mark --mark 1 -j MASQUERADE");
        exec("echo '/sbin/iptables -t nat -A POSTROUTING --out-interface eth0 -m mark --mark 1 -j MASQUERADE' >> /etc/default/iptables");

		return true;
	}

	/** Disable routing on eth0
	 * @param  void
	 * @return bool
	 */
	function remove_masquerading(){
		if( network::is_masquerading() === false ){
			return false;
		}

		exec("echo '' > /etc/default/iptables && sudo /sbin/iptables -t nat -F POSTROUTING && sudo /sbin/iptables -t mangle -F PREROUTING");
		exec('sudo /sbin/sysctl -q -w net.ipv4.conf.all.forwarding=0');

		return true;
	}

    public function forward_5060_port($port, $new = true)
    {
        try {
            Wildix\Databases\DEVDB::getInstance()->setSystemVariable('SIP_REDIRECT_PORT', $port);

            if ($new === true) {
                exec("sudo /sbin/iptables -t nat -N UDP-SIP");
            }

            exec("sudo /sbin/iptables -t nat -F UDP-SIP");
            exec("sudo /sbin/iptables -t nat -A UDP-SIP -p udp --dport $port -j REDIRECT --to-port 5060");
            exec("sudo /sbin/iptables -t nat -A UDP-SIP -j RETURN");
            return true;
        } catch (Exception $e) {
            return false;
        }
    }

	/** */
	function generate_net($address,$netmask){
		$result = get_subnet($address,$netmask);
		return array('broadcast' => $result["bcast"],
		             'network'   => $result["subnet"]
		);
	}

	/** */
	function mac2delim($mac,$delimiter = ':'){
		return (is_mac($mac)) ? rtrim(chunk_split($mac,2,$delimiter),$delimiter) : false;
	}

	/** */
	static protected function delim2mac($string,$delimiter = ':'){
		return (is_mac($string = str_replace($delimiter,'',$string))) ? $string : false;
	}

	/** */
	function ip2interface($address){
		if(is_ip($address)){
			foreach(array_keys($this->active_interfaces) as $key){
				if($this->active_interfaces[$key]['address'] === $address) return $key;
			}
		}
		return false;
	}

	/** */
	function interface2ip($interface){
		return $this->active_interfaces[$interface]['address'];
	}

	/** */
	public function cidr2netmask($cidr) {
		return long2ip(ip2long("255.255.255.255") << (32 - $cidr));
	}

	/** */
	public function netmask2cidr($netmask) {
		$netmaskArr = array_map('intval', explode('.', $netmask));
		return 32 - log((ip2long(implode('.', $netmaskArr)) ^ ip2long('255.255.255.255')) + 1, 2);
	}

	/** */
	function array_normal($array){
		$result = array();
		if(is_array($array)){
			foreach ($array as $val){
				if(!empty($val)){
					$result[] = $val;
				}
			}
		}
		return $result;
	}

	/** */
	function get_alias($interaface){
		if (preg_match("/(eth0|wbr):?.*/",$interaface))	{
			$alias = "WAN";
		} elseif (preg_match("/(eth1):?.*/",$interaface)) {
			$alias = "LAN";
		} elseif (preg_match("/(eth2):?.*/",$interaface)) {
			$alias = "DMZ";
		} elseif (preg_match("/(lo)/",$interaface)) {
			$interaface = "lo";
			$alias = "lo";
		} else {
			$interaface = ($interaface=='') ? "unknown": $interaface;
			$alias = "DMZ";
		}

		return array('name'=>$interaface,'alias'=>$alias);
	}

	/** Get default gateway
	 * @param 	string	$interface		Interface: eth0,eth1...
	 * @return 	string/IS_ERROR false	Default gateway
	 */
	function get_default_gateway($interface){
		if(! isset($this->boot_interfaces[$interface]['gateway'])) return '';

		$routes = $this->boot_interfaces[$interface]['gateway'];

		foreach ($routes as $route){
			if( $route[1] == '0.0.0.0' && $route[2] == '0.0.0.0')
				return $route[0];
		}
		return '';
	}

	static function getInstance(){
		static $instance;
		if (!is_object($instance)){
			$instance = new network();
		}

		return $instance;
	}

	/** */
	function compare_subnets($ipaddress){
		foreach (array_keys($this->active_interfaces) as $key){
			if($this->active_interfaces[$key]['address'] == '' &&
			  $this->active_interfaces[$key]['netmask'] == '') continue;

			$current = get_subnet($this->active_interfaces[$key]['address'],$this->active_interfaces[$key]['netmask']);
			$device = get_subnet($ipaddress,$this->active_interfaces[$key]['netmask']);

			if($current['subnet'] == $device['subnet']){
				return array(
				  'address' => $this->active_interfaces[$key]['address'],
				  'bitmask' => $current['mask_l'],
				  'netmask' => $current['mask'],
				  'gateway' => $this->get_default_gateway($key)
				);
			}
		}
		return false;
	}

	/** */
	function get_default_routed_interface (){
		foreach (array_keys($this->active_interfaces) as $key){
			if( ($gateway = $this->get_default_gateway($key)) !== '') {
				$current = get_subnet($this->active_interfaces[$key]['address'],$this->active_interfaces[$key]['netmask']);
				return array(
				  'address' => $this->active_interfaces[$key]['address'],
				  'netmask' => $current['mask'],
				  'bitmask' => $current['mask_l'],
				  'gateway' => $gateway
				);
			}
		}
		return false;
	}

	/** */
	function is_nat_ip($ipaddress){
		return is_ip($ipaddress) && preg_match('/^(10\.|172\.1[6-9]|172\.2[0-9]|172\.3[0-1]|192\.168\.).*$/',$ipaddress);
	}
};

if (isset($_REQUEST['newclass']) && in_array($_REQUEST['newclass'], array('network', 'dhcp'))) {
	require_once('classes/WMSProxy.class.php');
	$proxy = new WMSProxy();

	//network
	$proxy->register_function('getInterfaces','get_all_interfaces');
	$proxy->register_function('setInterface','set_interface');
	$proxy->register_function('delInterfaces','del_interfaces');

	$proxy->register_function('setRoute','set_route');
	$proxy->register_function('delRoutes','del_routes');
	$proxy->wrap_function('getRoutes','get_routes_interfaces_as_table');

	$proxy->wrap_function('getHosts','get_hostnames_as_table');
	$proxy->register_function('setHost','set_host');
	$proxy->register_function('delHosts','del_hosts');

	$proxy->register_function('updateBridge','update_bridge');
	$proxy->register_function('updateMasquarding','update_masquarading');

	$proxy->register_function('restartNetwork','restart_network');
	$proxy->register_function('restartDns','restart_dns');


	function get_all_interfaces($obj, &$response){
		// merge tables
		$result = array();

		$boot_interfaces = $obj->boot_interfaces;

		foreach ($obj->active_interfaces as $key => $value) {
			$result[$key]['address:inuse'] = $value['address']; unset($value['address']);
			$result[$key]['netmask:inuse'] = $value['netmask']; unset($value['netmask']);
			$result[$key]['broadcast:inuse'] = $value['broadcast']; unset($value['broadcast']);
			$result[$key]['kind'] = $value['type']; unset($value['type']);

			$result[$key] = array_merge($value, $result[$key]);

			if (strpos($key, 'wbr') !== false && ! isset($boot_interfaces[$key])) {
				unset($boot_interfaces[$key]);
				unset($result[$key]);
			}
		}

		foreach ($boot_interfaces as $key => $value) {

			$result[$key]['enabled'] = $value['activate']; unset($value['activate']);
			$result[$key] = array_merge($value, $result[$key]);

			// need to skip bridget interfaces and do not show in table
			if (strpos($key, 'wbr') !== false) {
				foreach (explode(' ',$value['bridge_ports']) as $k) {
					unset($boot_interfaces[$k]);
					unset($result[$k]);
				}
			}
		}

		$return = array();

		foreach ($result as $key => $value) {
			$value['interface'] = $key;
			$return[] = $value;
		}

		$response['BODY'] = $return;
	}

	function set_interface($obj,&$response){
		if (! isset($_POST['settings'])) {
			return;
		}

		$t = json_decode($_POST['settings'],true);
		$settings = $t['settings'];

		$interface_store = array();
		if ($settings['interface_id'] == 'new_virtual') {
			$interface_store['interface'] = $settings['virt_interface'] . ':' . $settings['virt_interface_number'];
		} elseif ($settings['interface_id'] == 'new_vlan') {
			$interface_store['interface'] = $settings['vlan_interface'] . '.' . $settings['vlan_interface_id'];
		} else {
			$interface_store['interface'] = $settings['interface'];
		}

		if (strpos($settings['interface_id'],'wbr') !== false && isset($settings['wshaper_uplink'])) {
			$interface_store['wshaper_uplink'] = $settings['wshaper_uplink'];
			$interface_store['wshaper_downlink'] = $settings['wshaper_downlink'];
		}

		if (0 != sizeof($interface_store)) {
			$interface = $obj->boot_interfaces[$settings['interface']];
			$is_addr_changed = ip2long($interface['interface']) !== ip2long($settings['address']);

			// allow bitmask format
			if (strpos($settings['netmask'],'.') === false) {
				$settings['netmask'] = $obj->cidr2netmask($settings['netmask']);
			}

			$interface_store['address'] = $settings['address'];
			$interface_store['netmask'] = $settings['netmask'];
			$interface_store['type'] = $settings['get_dhcp'] == '1'? 'dhcp': 'static';

			$obj->__default_store_after_destruct = true;

			if (strpos($settings['interface_id'], 'new_') !== false ||
			  ! array_key_exists($interface_store['interface'],$obj->boot_interfaces)) {

				$obj->add_interface($interface_store, $settings['status'] == 'enabled');

			} else {
				$obj->modify_interface($interface_store, $settings['status'] == 'enabled');
			}
		}

		$response['BODY'] = true;
	}

	function update_bridge($obj, &$response){
		$obj->__default_store_after_destruct = true;

		if (! isset($obj->boot_interfaces['wbr0'])) {
			$obj->add_bridge_interface(array('eth0', 'eth2'));
		} else {
			$obj->remove_interface('wbr0');
		}

		$response['BODY'] = true;
	}

	function update_masquarading($obj, &$response){
		if ($obj->is_masquerading()) {
			$obj->remove_masquerading();
		} else {
			$obj->set_masquerading();
		}

		$response['BODY'] = true;
	}

	function del_interfaces($obj,&$response){
		$obj->__default_store_after_destruct = true;

		foreach(explode('|',$_GET['interfaces']) as $interface) {
			// we can remove only vlan, virtual interfaces
			if (preg_match('/eth\d+(\.|\:)\d+/',$interface)) {
				$obj->remove_interface($interface);
			}
		}

		$response['BODY'] = true;
	}

	function set_route($obj,&$response){
		if (! isset($_POST['settings'])) {
			return;
		}

		$t = json_decode($_POST['settings'],true);
		$settings = $t['settings'];

		// allow bitmask format
		if (strpos($settings['genmask'],'.') === false) {
			$settings['genmask'] = $obj->cidr2netmask($settings['genmask']);
		}

		if ($settings['default_gateway'] == '1') {
			$settings['genmask'] = $settings['destination'] = '0.0.0.0';
			if(!$obj->check_gateway($settings)){
				$response['BODY'] = array('routes_settings_form' => _t('net.gatewayOutOfSubnet'));
				return;
			}
		} else {
			// grenerate network
			$tnet = $obj->generate_net($settings['destination'],$settings['genmask']);
			$settings['destination'] = $tnet['network'];
		}

		$obj->__default_store_after_destruct = true;

		if ($settings['routes_id'] != 'new') {
			$to_remove = array(
			  'interface' => $settings['old_interface'],
			  'gateway' => $settings['old_gateway'],
			  'genmask' => $settings['old_genmask'],
			  'destination' => $settings['old_destination'],
			);

			$obj->remove_route($to_remove);
		}

		$obj->add_route($settings);

		$response['BODY'] = true;
	}

	function del_routes($obj,&$response) {
		$obj->__default_store_after_destruct = true;

		$t = json_decode($_GET['routes'],true);

		foreach($t as $to_remove) {
			$obj->remove_route($to_remove);
		}

		$response['BODY'] = true;
	}

	function set_host($obj,&$response){
		if (! isset($_POST['settings'])) {
			return;
		}

		$t = json_decode($_POST['settings'],true);
		$settings = $t['settings'];

		$settings['aliases'] = str_replace(array("\t","\n"),' ',$settings['aliases']);

		// preprocessing; remove dublicated hostnames & html tags
		$settings['aliases'] = strtolower(strip_tags(implode(' ',array_unique(explode(' ',$settings['aliases'])))));

		$obj->remove_hostname($settings['old_address']);
		$obj->add_hostname($settings);

		$obj->__store_resolv_file();

		$response['BODY'] = true;
	}

	function del_hosts($obj,&$response){

		foreach(explode('|',$_GET['addresses']) as $address) {
			$obj->remove_hostname($address);
		}

		$obj->__store_resolv_file();

		$response['BODY'] = true;
	}

	function restart_network($obj,&$response){
		//stop dhcp server if it worked on interface with different ip in boot and realtime parts
        $dhcpServerManager = $GLOBALS['diContainer']->get(\Wildix\System\Dhcp\ServerManager::class);

        $dhcpConfig = $dhcpServerManager->getActualServerConfig();
        $currentInterface = $dhcpConfig['currentInterface'];
        $dhcpStatus      = $dhcpConfig['status'];

        if((
		  $obj->boot_interfaces[$currentInterface]['activate'] === 'disabled' ||
		  $obj->boot_interfaces[$currentInterface]['address'] !== $obj->active_interfaces[$currentInterface]['address'] ||
		  $obj->boot_interfaces[$currentInterface]['netmask'] !== $obj->active_interfaces[$currentInterface]['netmask'])
		  && $dhcpStatus === true){

            $dhcpServerManager->stopDhcpServer();

			// remove settings
			$filename = '/etc/dnsmasq.d/config';

			if (file_exists($filename)) {
				file_put_contents($filename,'');
			}
		}

		if ( isset($_POST['settings'])) {
			restart_dns($obj,$response);
		}

		$obj->restart_network();

		// update masquarading (re-set actual WAN interface)
		if ($obj->is_masquerading()) {
			$obj->remove_masquerading();
			$obj->set_masquerading();
		}

		$response['BODY'] = true;
	}

	function restart_dns($obj,&$response){
		$obj->__default_store_after_destruct = true;

		if (! isset($_POST['settings'])) {
			return false;
		}

		$t = json_decode($_POST['settings'],true);
		$settings = $t['settings'];
        $needRenewCertificate = false;
		if($obj->systemname != $settings['hostname']){
            $_portalApiUrl = env('SERVICE_PORTAL_API_URI');
            $_portalUrl    = env('SERVICE_UPGRADE_PORTAL_URI');
            $portalService = new \Wildix\Services\Portal(\Logger\Log::ERROR, $_portalApiUrl, $_portalUrl);

			$check = $portalService->checkDomain($settings['hostname']);
			if($check['success'] !== true && ($check['error']['code'] > 300 && $check['error']['code'] < 400)){
				$response['BODY'] = array('hostname'=>$check['error']['message']);
				return;
			}
			$obj->set_sysname($settings['hostname']);
			if($check['success'] === true){
				$portalService->setDomain($settings['hostname']);
                $needRenewCertificate = true;
			}
		}


		$servers = array();
		for($i = 1; $i <= 3; $i++) {
			if (is_ip($settings['dns_server'.$i])) {
				$servers[] = $settings['dns_server'.$i];
			}
		}

		$obj->set_dns_servers($servers);

		$obj->restart_dns();

        if ($needRenewCertificate) {
            \Wildix\Certificate\SSLCertificate::runBackgroundRenew();
        }

		$response['BODY'] = true;
	}

	// ----------------------------------------------------------------------

	$proxy->processing();
}
