<?php

class PBX extends AGI_AsteriskManager {
	var $connected = false;
	var $pbx_name = 'callweaver';

    /**
     * @var \Logger\Log|null
     */
	private $_log;

	private static $_Instances = null;
	public static function getInstance(){
		if (self::$_Instances === null) {
			self::$_Instances = new self();
		}
		return self::$_Instances;
	}

	public function __construct() {
		parent::__construct(NULL, array('server'=>'127.0.0.1','port'=>5039,'username'=>'root','secret'=>'wildix'));
		$this->connect();
	}

	//static
	static private function is_running(){
		$pbx_name = 'callweaver';
		$command = '[ "`pgrep '.$pbx_name.'`" != "" ] && echo 0 || echo 1';
		$code = exec($command); // code = 0 if asterisk is running, 1 - if instead
		if ($code != 0){
			return false;
		}
		return true;
	}

	// static func
	static public function init_operation($value){
		if (!in_array($value,array('start','stop','restart','reload'))) return false;
		$pbx_name = 'callweaver';
		//$pbx_name = 'asterisk';
		return exec("sudo /etc/init.d/$pbx_name $value");
	}

	public function set_error($error){

	}

	function connect($server = NULL, $username = NULL, $secret = NULL){
		if ($this->connected) return true;
		if (! parent::connect()){
			if (!self::is_running()){
				$this->set_error(_t('pbxclass.JS.PbxIsNotStarted'));
				return false;
			}
			$this->set_error(_t('pbxclass.JS.CannotConnectToPbx'));
			return false;
		}
		$this->connected = true;
		return true;
	}

	function get_channels_capacity(){
		if ( ! $this->connected) return 0;
		$data = $this->Command('show channels');
		if (isset($data['data']) && preg_match('/.*\( *(\d{1,2}\.\d{1,2})\% of capacity\).*/s',$data['data'],$matches)){
			return $matches[1];
		}
		return 0;
	}

	function get_channels_count(){
		if ( ! $this->connected) return 0;
		$data = $this->Command('show channels');
		if (isset($data['data']) && preg_match('/.*(\d+) active channel.*/s',$data['data'],$matches)){
			return $matches[1];
		}
		return 0;
	}

	function Command($command, $actionid=NULL){
		if ( ! $this->connected) return '';

        try {
            return parent::Command($command, $actionid);
        } catch (\Exception $e) {
            $this->_getLog()->error(
                __LINE__,
                sprintf(
                    "PBX Command '%s' with action id '%s' is failed. Error: '%s'\nTrace:\n%s",
                    $command,
                    $actionid,
                    $e->getMessage(),
                    $e->getTraceAsString()
                )
            );
        }

        return '';
	}

	function CommandResponce($command){
		$return = array();
		if ( ! $this->connected) return $return;
		$data = $this->Command($command);
		if (!isset($data['data'])) return $return;

		$expl = explode("\n",$data['data']);
		if (strstr($expl[0],'Privilege: Command')) unset($expl[0]);

		foreach ($expl as $val){
			$val = trim($val);
			if ($val != '') $return[] = $val;
		}

		return $return;
	}

	function send_event($eventname, $parameters = array()){
		$body = array();
		foreach($parameters as $k => $v){
			$body[] = $k.': '.$v;
		}
		/* important thing is to get response */
		return $this->send_request('UserEvent',
			array('EventName' => $eventname,
				'EventBody' => rawurlencode(implode("\n",$body))
			));
	}

	/**
	 * Get IP's of devices behind the NAT
	 *
	 * @return array
	 * @author Igor Kuts <igor.kuts@wildix.com>
	 */
	public function getNatIps() {
		$devicesNatIps = array();

		$result = \Wildix\Databases\USRLOC::getInstance()->query('SELECT contact, received FROM location');
		if($result){
			while ($device = $result->fetchArray(SQLITE3_ASSOC)) {
				preg_match('/(\d+)\.(\d+)\.(\d+)\.(\d+)/', $device['received'], $deviceIp);
				if (strpos($device['contact'], $deviceIp[0]) === false) {
					$devicesNatIps[] = $deviceIp[0];
				}
			}
		}
		return array_unique($devicesNatIps);
	}

	public function put_cli_reload($what){
		if ( ! $this->connected) return false;

		if (!in_array($what,array('ael','dnsmgr','iax2','logger','moh','wmspbx','sip','rtp','features', 'pbx_lua', 'pbx_config')))
			return false;

		switch($what){
			case 'wmspbx': $command = 'reload'; break;
			case 'sip': $command = 'sip reload'; break;
			case 'moh': $command = 'moh reload'; break;
			case 'pbx_lua': $command = 'reload pbx_lua.so'; break;
			case 'pbx_config': $command = 'reload pbx_config.so'; break; // same as dialplan reload
			default: $command = 'reload '.$what; break;
		}
		return $this->Command($command);
	}

	public function set_devstate($feature,$phone,$featState){
		return $this->Command('devstate change Custom:DS/'.$feature.$phone.' '.$featState);
	}

	function get_channeltypes($case = false){
		if (!$this->connected) return array();

		$channeltypes = '';
		$data = $this->Command('show channeltypes');
		if (isset($data['data'])) $channeltypes = $data['data'];

		$available_channels = array();
		$all_channels = explode("/","SIP/IAX2/H323/Zap");
		foreach ($all_channels as $value){
			if (stristr($channeltypes,$value)){
				if ($case == 'lowercase'){
					$value = strtolower($value);
				}
				$available_channels[$value] = $value;
			}
		}

		return $available_channels;
	}

	function sip_expire_registration($phones){
		if ( ! $this->connected) return false;

		foreach ($phones as $phone){
			$this->Command("sip expire registration $phone");
		}

		return true;
	}

    /**
     * Send SIP notify check-sync to devices.
     *
     * @param array $peers  List of user names assigned to devices. Username can be user extension or in format "unknown<unique number>".
     * @param bool  $reboot Flag indicating whether the devices needs to be rebooted.
     *
     * @return bool
     */
	function sip_notify_check_sync(array $peers, $reboot = false){
		if (!$this->connected || empty($peers)) {
		    return false;
        }

        $type = $reboot === false ? 'check-sync' : 'reboot-phone';

		// check registration to avoid kamailio retransmission
        $sipProxy = new \Wildix\SipProxy(\Cache\FileCache::getInstance());
        $activePeers  = $sipProxy->getUsersRegistrations();
        $activeTrunks = $sipProxy->getTrunksRegistrations();

        foreach ($peers as $peer) {
            $haveUserRegistration  = isset($activePeers[$peer]);
            $haveTrunkRegistration = isset($activeTrunks[$peer]);

            if (!$haveUserRegistration && !$haveTrunkRegistration) {
                continue;
            }

            if ($haveUserRegistration) {
                $peerRegistrations = $activePeers[$peer]['registrations'];
                if (count($peerRegistrations) === 1 && strpos($peerRegistrations['useragent'], 'Wildix Zero Distance') !== false) {
                    continue;
                }
            }

            $this->Command('sip notify ' . $type . ' ' . $peer);
            sleep(2);
        }

		return true;
	}

	/**
	 * function just checks if module is loaded or not.
	 */
	function test_module($modulename){
		if ( ! $this->connected) return 'PBX not started.';

		$module_path = '/usr/lib/callweaver/modules/';
		if(! file_exists($module_path.$modulename) ) return 'No such module.';

		$data = $this->Command("show modules like ".$modulename);
		if (!isset($data['data'])) return 'PBX bad output.';

		$string = $data['data'];

		if (strstr($string,$modulename)){
			return true;
		}
		return false;
	}

	function pbxdb_get_tree($valpath){
		if ( ! $this->connected) return array();

		$tree = array();
		$i = 0;

		$res = $this->CommandResponce('database show '.$valpath);

		foreach ($res as $row){
			$ttmp = explode(": ",$row);

			$dbkey = trim($ttmp[0]);
			$dbvalue = trim($ttmp[1]);

			$temp = explode('/',$dbkey);
			$key = $temp[(count($temp)-1)];
			$path = rtrim($dbkey,$key);

			$tree[$i]['path'] = ltrim($path,'/');
			$tree[$i]['key'] = $key;
			$tree[$i]['value'] = $dbvalue;

			$i++;
		}

		return $tree;
	}

	function pbxdb_del($family, $key){
		if ( ! $this->connected) return false;
		$this->Command('database del '.$family.' '.$key);
		return true;
	}

    /**
     * @return \Logger\Log
     */
    private function _getLog() {
        if (!isset($this->_log)) {
            $this->_log = \Logger\LoggerFactory::getInstance();
        }

        return $this->_log;
    }
}
