<?php

/**
 * Permissions class
 *
 * @copyright Wildix
 * @package Base
 * @version 1.0
 */
class WMS_Permissions {

	private static $object = false;

	private $root_user = 'admin';

	private $pages = array(
		'users__users',
		'users__groups',
		'users__pbxs',
		'users__phonebooks3',
		'trunks__trunks',
		'trunks__hunt_groups',
		'trunks__pricelists',
		'devices',
		'dialplan__dialplan',
		'dialplan__call_groups',
		'dialplan__paging_groups',
		'dialplan__timetables',
		'dialplan__ivr',
		'dialplan__feature_code',
		'dialplan__general_settings',
		'settings__pbx',
		'settings__system',
		'settings__utilites__remote_support',
		'settings__utilites__backup',
		'settings__utilites__upgrade',
		'settings__utilites__activation',
		'settings__utilites__generate_trace',
		'top_control__generate_call',
		'top_control__sounds',
		'top_control__debug',
		'top_control__halt'
	);

	private $perms_values = array(
		'add_remove_users',
	);

	private $permissions_arr;

	private function __construct() {
		$this->connect();
	}

	public static function getInstance() {
		return self::$object == false ? self::$object = new WMS_Permissions() : self::$object;
	}

	private function connect() {
		return true;
	}

	public function getPermissions() {
		if (!empty($this->permissions_arr)) {
			return $this->permissions_arr;
		}

		$t_empty_permissions = array(
			'main_is_root' => 'yes',
			'manage_pbx' => 'yes',
			'manage_groups' => array(
				'all' => 'yes'
			),
			'manage_pages' => array(
				'all' => 'yes'
			),
			'manage_pbxs' => array(
				'all' => 'yes'
			),
			'permissions' => array(
				'all' => 'yes'
			)
		);

		$t_disabled_permissions = array(
			'main_is_root' => 'no',
			'manage_pbx' => 'no',
			'manage_groups' => array(
				'all' => 'no'
			),
			'manage_pages' => array(
				'all' => 'no'
			),
			'manage_pbxs' => array(
				'all' => 'no'
			),
			'permissions' => array(
				'all' => 'no'
			)
		);

		if (defined('STDIN')) {
			// called from CLI
			$this->permissions_arr = $t_empty_permissions;
			return $this->permissions_arr;
		}

        $currentUserName = User::getInstance()->getName();
		if ($currentUserName === $this->root_user) {
			$this->permissions_arr = $t_empty_permissions;
			return $this->permissions_arr;
		} else {
			$t_empty_permissions['main_is_root'] = 'no';
		}

		if (!\User::getInstance()->isLogged()) {
			logger('Permissions:: User ' . $currentUserName . ' is not found in LDAP. All operations are disabled.');
			$this->permissions_arr = $t_disabled_permissions;
			return $this->permissions_arr;
		}

		if (\User::getInstance()->getGroupDn() == '') {
			logger('Permissions:: Group is not selected for user ' . $currentUserName . '. All operations are disabled.');
			$this->permissions_arr = $t_disabled_permissions;
			return $this->permissions_arr;
		}


		if(!\User::getInstance()->isAdministrator()) {
            $this->permissions_arr = $t_disabled_permissions;
		    return $t_disabled_permissions;
        }
		// look up for group of the user
		$search = WMS_Ldap::getInstance()->getEntryByDn(\User::getInstance()->getGroupDn(),array('cn','wg2eAcl'),array('wg2eAcl'));
		if (!is_array($search) || empty($search)) {
			logger('Permissions:: Group of user ' . $currentUserName . ' is not found in LDAP. All operations are disabled.');
			$this->permissions_arr = $t_disabled_permissions;
			return $this->permissions_arr;
		}

		if (!isset($search['wg2eAcl']) || empty($search['wg2eAcl'])) {
			$this->permissions_arr = $t_empty_permissions;
			return $this->permissions_arr;
		}

		// group permissions is $search['wg2eAcl']

		/*

		[wg2eAcl] => Array
		(
			[0] => 001|all|noepbx
			[1] => 002|pbxid=080027718686,dc=wildix|epbx
			[2] => 003|all|noegroup
			[3] => 004|gid=1875910716,o=com0,dc=wildix|egroup
			[4] => 005|gid=282927775,o=com0,dc=wildix|egroup
			[5] => 006|all|noepage
			[6] => 007|backups|epage
			[7] => 008|dialplan_call_groups|epage
			[8] => 009|users_phonebooks|epage
			[9] => 010|sounds|epage
			[10] => 011|dialplan_timetables|epage
			[11] => 012|dialplan_ivr|epage
			[12] => 013|users_phonebooks3|epage
		)
		*/

		foreach ($search['wg2eAcl'] As $t_row) {
			$t_row = explode('|', $t_row);
			$subject = $t_row[1];
			switch($t_row[2]){
				case 'epbx': case 'noepbx':
					$yes_no = ($t_row[2] == 'epbx')?'yes':'no';
					$perm_key = 'manage_pbxs';
					break;
				case 'egroup': case 'noegroup':
					$yes_no = ($t_row[2] == 'egroup')?'yes':'no';
					$perm_key = 'manage_groups';
					break;
				case 'epage': case 'noepage':
					$yes_no = ($t_row[2] == 'epage')?'yes':'no';
					$perm_key = 'manage_pages';
					break;
				case 'eperm': case 'noeperm':
					$yes_no = ($t_row[2] == 'eperm')?'yes':'no';
					$perm_key = 'permissions';
					break;
			}
			$t_empty_permissions[$perm_key][$subject] = $yes_no;
		}

		// get local PBX
		$mac = \Models\PBX::getInstance()->getSerial();
		$search = WMS_Ldap::getInstance()->getEntry(WMS_Ldap::PBX, '(pbxSerial=' . $mac . ')', array('pbxSerial', 'dn'));
		if (!is_array($search) || empty($search)) {
			logger('Permissions:: Entry of local PBX is not found in LDAP. All operations are disabled.');
			$this->permissions_arr = $t_disabled_permissions;
			return $this->permissions_arr;
		}

		// setting the permissions_arr to check PBX is allowed
		$this->permissions_arr = $t_empty_permissions;

		if (!$this->is_allowed('pbx',$search['dn'])) {
			logger('Permissions:: Managing of this PBX is not allowed for user ' . $currentUserName . '. All operations are disabled.');
			$this->permissions_arr = $t_disabled_permissions;
			return $this->permissions_arr;
		}

		return $t_empty_permissions;

	}


	public function is_allowed($subj_type, $subject) {
        global $got_userPasswordIsDefault, $licenseNotActivated;
		if (empty($this->permissions_arr)) {
			$this->getPermissions();
		}

		if ($this->permissions_arr['main_is_root'] == 'yes') {
            // if license not activated or admin has default password, he can't add/remove users
            if($subj_type == 'permissions' && $subject == 'add_remove_users' && ($got_userPasswordIsDefault || $licenseNotActivated)){
                return false;
            }
			return true;
		}

		if ($this->permissions_arr['manage_pbx'] != 'yes') {
			return false;
		}

		switch ($subj_type) {
			case 'pbx':
				$perm_key = 'manage_pbxs';
				break;
			case 'group':
				$perm_key = 'manage_groups';
				break;
			case 'page':
				$perm_key = 'manage_pages';
				break;
			case 'permissions':
				$perm_key = 'permissions';
				break;
			default:
				logger('Permissions:: wrong subject type used: '. $subj_type);
				return false;
				break;
		}

		if (isset($this->permissions_arr[$perm_key][$subject])) {
			return ($this->permissions_arr[$perm_key][$subject] == 'yes') ? true : false;
		} else if (isset($this->permissions_arr[$perm_key]['all'])) {
			return ($this->permissions_arr[$perm_key]['all'] == 'yes') ? true : false;
		}

		return true;

	}

	public function is_root() {
		if (empty($this->permissions_arr)) {
			$this->getPermissions();
		}

		if ($this->permissions_arr['main_is_root'] == 'yes') {
			return true;
		}

		return false;
	}

	public function admin_can_manage_pbx() {
		if (empty($this->permissions_arr)) {
			$this->getPermissions();
		}

		if ($this->permissions_arr['manage_pbx'] == 'yes') {
			return true;
		}

		return false;
	}

	public function getPagesForEditor() {

		$t_pages = array();

		foreach ($this->pages As $page) {
			$t_pages[$page] = _t('pages.'.$page);
		}

		return $t_pages;

	}

	public function getPermsValuesForEditor() {

		$t_perms = array();

		foreach ($this->perms_values As $perm) {
			$t_perms[$perm] = _t('perms.'.$perm);
		}

		return $t_perms;

	}
}
