<?php

class phonebook {

    var $contacts_table;
    var $err;
    var $nofile = true;

    function __construct() {
        global $wmsErr;
        $this->err = &$wmsErr;

        $database = '/mnt/cticonnect/cticonnectdb';
        $this->table = 'cti_phonebooks';
        $this->contacts_table = 'cti_contacts';

        if (!is_cti_mounted()){
            $this->nofile = true;
            return false;
        } elseif (!file_exists($database) || !is_writable($database)) {
            // CTIconnect is mounted
            exec('/usr/sbin/init_cticonnectdb', $out, $ret);
            if (!file_exists($database) || !is_writable($database)) {
                $this->nofile = true;
                $this->setError(_t('strings.isNotWriteable', $database));
                return false;
            }
        }
        $this->db = new DB_SQLite3( $database );
        $this->nofile = false;
    }

    function setError($msg, $type = 'error') {
        if (is_object($this->err)) {
            $this->err->_set('', $type, $msg);
        }
    }

    /**
     * Get all phonebooks
     *
     * @return array
     * @author unknown
     * @author Igor Kuts <igor.kuts@wildix.com>
     */
    public function getAll($wrapped = false) {
        $result = array();
        if ($this->nofile) {
            return $result;
        }

        $res = $this->db->query('SELECT name, rid, sync_set, sync_interval, sync_params FROM `' . $this->table . '` WHERE type="2";'); // only public phonebooks

        if (!is_object($res)) {
            if ($wrapped) {
                echo _t('import.phonebooksImportIsInProgress');
            } else {
                $this->setError(_t('import.phonebooksImportIsInProgress'),'notification');
            }
            return $result;
        }

        while ($tmp = $res->fetchRow(DB_FETCHMODE_ASSOC)) {
            if (array_key_exists('sync_params', $tmp)) {
                $tmp['sync_params'] = $this->get_sync_settings_n_map($tmp['sync_params'], 'no_sql_get');
            }

            $result[] = $tmp;
        }

        if (is_object($res)) {
            $res->free();
        }

        // optimize me

        foreach ($result as $k => $row) {
            $res = $this->db->query("SELECT count(*) AS cnt FROM `$this->contacts_table` WHERE phonebook_id=${row['rid']};");
            $tmp = $res->fetchRow(DB_FETCHMODE_ASSOC);
            $cnt = $tmp ? $tmp['cnt'] : 0;
            $result[$k]['count'] = $cnt;
        }
        return $result;
    }

    public function get_phonebook_records($pbook_id, $attrs) {
        $result = array();
        if ($this->nofile) {
            return $result;
        }

        $attrs[] = 'rid';

        $sql = 'SELECT `'.implode('`, `',$attrs).'` FROM `' . $this->contacts_table . '` WHERE phonebook_id="'.intval($pbook_id).'";';

        if($res = $this->db->query($sql)){
        	while ($tmp = $res->fetchRow(DB_FETCHMODE_ASSOC)) {
        		$result[] = $tmp;
        	}
        	if (is_object($res)) {
        		$res->free();
        	}
        }
        return $result;
    }

    function select_phonebooks() {
        $result = array();
        if ($this->nofile) {
            return $result;
        }

        if($res = $this->db->query('SELECT name, rid FROM `' . $this->table . '` WHERE type="2";')){ // only public phonebooks
	        while ($tmp = $res->fetchRow(DB_FETCHMODE_ASSOC)) {
	            $result[$tmp['rid']] = $tmp['name'];
	        }
	        if (is_object($res)) {
	            $res->free();
	        }
        }
        return $result;
    }

    function get($id){
    	$result = array();
		if ($this->nofile){
			return $result;
		}

        if (!is_numeric($id)){
        	return "id is not a number";
        }

		if($res = $this->db->query('SELECT name FROM `'.$this->table.'` WHERE rid='.$id.';')){
			$result = $res->fetchRow(DB_FETCHMODE_ASSOC);
			if (is_object($res)){
				$res->free();
			}
		}
        return $result;
    }

    function remove($id){
		if ($this->nofile){
			return 'cannot find phonebook';
		}

        if (!is_numeric($id)){
        	return "id is not a number";
        }

        if ($id < 0){
        	return "cannot remove";
        }

		$this->db->query('DELETE FROM `'.$this->table.'` WHERE rid='.$id.';');
		$this->db->query('DELETE FROM `'.$this->contacts_table.'` WHERE phonebook_id='.$id.';');
		if ($this->db->hasError()) {
			$t_err = $this->db->errorNative();
			if ($t_err == 'database is locked') {
				$t_err = _t('import.phonebooksImportIsInProgress');
			}
			return array('remove' => $t_err);
		}
		return true;
    }

    function set($parameters){
        if ($this->nofile){
        	return 'cannot find phonebook';
        }

        $id = $parameters['rid'];
        if ($id!="new" && !is_numeric($id)){
        	return "rid is not a number";
        } else {
            $id = intval($id);
        }
        if (!strlen(trim($parameters['name']))){
        	return "name not valid";
        }

        if($res = $this->db->query('SELECT name FROM `'.$this->table.'` WHERE name=\''.$this->db->realEscapeString($parameters['name']).'\' AND  rid !='.$id.';')){
            if($res->fetchRow(DB_FETCHMODE_ASSOC)){
        		return _t('strings.AlreadyPresent');
        	}
        }

        if ($parameters['rid'] == "new"){
            $this->db->query('INSERT INTO `'.$this->table.'`(name,type,owner_id) VALUES(\''.$this->db->realEscapeString($parameters['name']).'\',"2","0");');
            return $this->db->hasError() ? $this->db->errorNative() : true;
        }else{
            $this->db->query('UPDATE `'.$this->table.'` SET name=\''.$this->db->realEscapeString($parameters['name']).'\' WHERE rid='.$id.';');
            return $this->db->hasError() ? $this->db->errorNative() : true;
        }

    }

    function removeContact($rid){
        if ($this->nofile){
        	return false;
        }

        if (!is_numeric($rid)){
        	return "row id is not a number";
        }

        $this->db->query('DELETE FROM `'.$this->contacts_table.'` WHERE rid='.$rid.';');
        return $this->db->hasError() ? $this->db->errorNative() : true;
    }

    function removeContacts($rids){
        if ($this->nofile){
        	return false;
        }

        $this->db->query('DELETE FROM `'.$this->contacts_table.'` WHERE rid IN ('.implode(',',$rids).');');
        return $this->db->hasError() ? $this->db->errorNative() : true;
    }

    function clearPhonebook($phonebookId) {
        if ($this->nofile) {
            return false;
        }

        $this->db->query('DELETE FROM `' . $this->contacts_table . '` WHERE phonebook_id = ' . intval($phonebookId) . ';');
        return $this->db->hasError() ? $this->db->errorNative() : true;
    }

    function dbQuery($query){
        if ($this->nofile){
        	return false;
        }

        $this->db->query($query);
        return $this->db->hasError() ? $this->db->errorNative() : true;
    }

    function close(){
        if (!$this->nofile){
        	$this->db->disconnect();
        }
    }

    function get_sync_attributes(){
        return array('source_id', 'owner_id', 'name_prefix', 'username', 'extension', 'phone', 'office', 'home', 'home_mobile', 'email', 'fax', 'mobile', 'organization', 'shortcut', 'user_class', 'address', 'born_in', 'postal_code', 'city', 'province', 'license_plate', 'document_from', 'vat_id', 'user_passport_type', 'user_passport_id', 'image_url', 'note');
    }

    function get_sync_attributes_translation(){
        $return = array();
        foreach ($this->get_sync_attributes() as $attr_key){
            $return[$attr_key] = _t('phonebooks.'.$attr_key);
        }
        return $return;
    }

    function get_sync_settings_n_map($param1, $kind='pbook_id'){
    	$sync_params = '';

        if ($kind == 'pbook_id'){
            $pbook_id = $param1;

			if (!$this->nofile) {
				if($res = $this->db->query('SELECT sync_params FROM `' . $this->table . '` WHERE rid="'.intval($pbook_id).'";')){
					$tmp = $res->fetchRow(DB_FETCHMODE_ASSOC);
					$sync_params = $tmp['sync_params'];
				}

				if (is_object($res)){
					$res->free();
				}
			}
        }else{
            $sync_params = $param1;
        }

        $map = array(
            'ldap' => array(
        		'source_id' => 'uid',
                'username' => 'cn',
                'fax' => 'facsimileTelephoneNumber',
                'extension' => 'telephoneNumber',
        		'office' => 'wOfficePhone',
                'email' => 'mail',
                'mobile' => 'mobile'
            ),
            'activeD' => array(
        		'source_id' => 'uid',
                'username' => 'cn',
                'fax' => 'facsimileTelephoneNumber',
                'extension' => 'telephoneNumber',
        		'office' => 'wOfficePhone',
                'email' => 'mail',
                'mobile' => 'mobile'
            ),
            'domino' => array(
                'source_id' => 'uid',
                'username' => 'cn',
                'fax' => 'facsimileTelephoneNumber',
                'extension' => 'telephoneNumber',
                'office' => 'wOfficePhone',
                'email' => 'mail',
                'mobile' => 'mobile'
            ),
            'mysql' => array(
            	'source_id' => 'id',
                'username' => 'name',
                'office' => 'phone',
                'email' => 'email',
                'fax' => 'fax',
                'mobile' => 'mobile',
                'image_url' => 'image_url'
            ),
            'hanaDb' => array(
                'source_id' => 'CardCode',
                'username' => 'CardName',
                'office' => 'Phone1',
                'email' => 'E_Mail',
                'fax' => 'Fax',
                'mobile' => 'Phone2',
                'image_url' => ''
            ),
            'mssql' => array(
            	'source_id' => 'id',
                'username' => 'name',
                'office' => 'phone',
                'email' => 'email',
                'fax' => 'fax',
                'mobile' => 'mobile',
                'image_url' => 'image_url'
            ),
            'csv' => array(
            	'source_id' => 'Id',
                'shortcut' => 'Shortcut',
                'name_prefix' => 'NamePrefix',
                'username' => 'Name',
            	'extension' => 'Extension',
            	'office' => 'Office',
                'mobile' => 'Mobile',
            	'home' => 'Home',
            	'home_mobile' => 'HomeMobile',
            	'phone' => 'Phone',
                'fax' => 'Fax',
                'email' => 'Email',
                'organization' => 'Organization',
                'user_class' => 'Type',
                'address' => 'Address',
                'vat_id' => 'VatId',
                'user_passport_type' => 'DocumentType',
                'user_passport_id' => 'DocumentId',
                'image_url' => 'ImageUrl',
                'note' => 'Note'
            ),
        	'office365' => array(
        			'source_id' => 'id',
        			//'shortcut' => 'Shortcut',
        			'name_prefix' => 'nameTitle',
        			'username' => 'name | company',
        			//'extension' => 'work',
        			'office' => 'phoneBusiness1',
        			'mobile' => 'phoneMobile1',
        			'home' => 'phoneHome1',
        			'home_mobile' => 'phoneHome2',
        			//'phone' => 'Phone',
        			'fax' => 'phoneBusiness2',
        			'email' => 'email1 | email2 | email3',
        			'organization' => 'company',
        			//'user_class' => 'Type',
        			'address' => 'addressWork | addressHome | addressOther',
        			//'vat_id' => 'VatId',
        			//'user_passport_type' => 'DocumentType',
        			//'user_passport_id' => 'DocumentId',
        			//'image_url' => 'ImageUrl',
        			'note' => 'notes',
                    'postal_code' => 'postcodeHome | postcodeWork',
                    'city' => 'cityHome | cityWork',
                    'province' => 'regionHome | regionWork',
        	),
            'google' => array(
                    'source_id' => 'id',
                    //'shortcut' => 'Shortcut',
                    'name_prefix' => 'namePrefix',
                    'username' => 'name | organization',
                	//'extension' => 'work',
                	'office' => 'phoneWork',
                    'mobile' => 'phoneMobile',
                	'home' => 'phoneHome',
                	'home_mobile' => 'phoneMain',
                	//'phone' => 'Phone',
                    'fax' => 'phoneWorkFax',
                    'email' => 'emailWork | emailHome',
                    'organization' => 'organization',
                    //'user_class' => 'Type',
                    'address' => 'addressWork | addressHome',
                    //'vat_id' => 'VatId',
                    //'user_passport_type' => 'DocumentType',
                    //'user_passport_id' => 'DocumentId',
                    //'image_url' => 'ImageUrl',
                    'note' => 'notes',
                    'postal_code' => 'postcodeHome | postcodeWork',
                    'city' => 'cityHome | cityWork',
                    'province' => 'regionHome | regionWork',
            ),
            'infusionsoft' => array(
                    'source_id' => 'id',
                    'owner_id' => 'owner',
                    'name_prefix' => 'namePrefix',
                    'username' => 'name | company',
                    'office' => 'workPhone1 | workPhone2 | workPhone3 | workPhone4 | workPhone5',
                    'mobile' => 'mobilePhone1 | mobilePhone2 | mobilePhone3 | mobilePhone4 | mobilePhone5',
                    'home' => 'homePhone1 | homePhone2 | homePhone3 | homePhone4 | homePhone5',
                    'home_mobile' => 'homePhone2 | homePhone3 | homePhone4 | homePhone5',
                    'phone' => 'otherPhone1 | otherPhone2 | otherPhone3 | otherPhone4 | otherPhone5',
                    'fax' => 'workFax1 | workFax2 | homeFax1 | homeFax2 | otherFax1 | otherFax2',
                    'email' => 'email1 | email2 | email3',
                    'organization' => 'company',
                    'user_class' => 'contactType',
                    'address' => 'billingStreetAddress1 | shippingStreetAddress1',
                    'note' => 'notes',
                    'postal_code' => 'billingPostalCode | shippingPostalCode',
                    'city' => 'billingCity | shippingCity',
                    'province' => 'billingState | shippingState',
            ),
            'exchange' => array(
                    'source_id' => 'id',
                    //'shortcut' => 'Shortcut',
                    //'name_prefix' => 'namePrefix',
                    'username' => 'name | companyName',
                	//'extension' => 'work',
                	'office' => 'phoneCompanyMain | phoneAssistant | phoneBusiness | phoneBusiness2',
                    'mobile' => 'phoneMobile | phoneCar',
                	'home' => 'phoneHome',
                	'home_mobile' => 'phoneHome2',
                	'phone' => 'phonePrimary | phoneRadio | phoneOther',
                    'fax' => 'phoneBusinessFax | phoneHomeFax | phoneOtherFax',
                    'email' => 'email1 | email2 | email3',
                    'organization' => 'companyName',
                    //'user_class' => 'Type',
                    'address' => 'addressBusiness | addressHome | addressOther',
                    //'vat_id' => 'VatId',
                    //'user_passport_type' => 'DocumentType',
                    //'user_passport_id' => 'DocumentId',
                    //'image_url' => 'ImageUrl',
                    //'note' => 'notes'
                    'postal_code' => 'addressBusinessPostalCode | addressHomePostalCode | addressOtherPostalCode',
                    'city' => 'addressBusinessCity | addressHomeCity | addressOtherCity',
                    'province' => 'addressBusinessState | addressHomeState | addressOtherState',
            )
        );



        $settings = array(
            'ldap' => array(
                'host' => '',
                'port' => '389',
                'secure' => 'no',
                'user' => '',
                'password' => '',
                'basedn' => '',
                'filter' => '(&(objectCategory=person)(|(objectClass=user)(objectClass=contact))(!(userAccountControl:1.2.840.113556.1.4.803:=2)))'
            ),
            'activeD' => array(
                'host' => '',
                'port' => '389',
                'secure' => 'no',
                'user' => '',
                'password' => '',
                'basedn' => '',
                'filter' => '(&(objectCategory=person)(|(objectClass=user)(objectClass=contact))(!(userAccountControl:1.2.840.113556.1.4.803:=2)))'
            ),
            'domino' => array(
                'host' => '',
                'port' => '389',
                'secure' => 'no',
                'user' => '',
                'password' => '',
                'basedn' => '',
                'filter' => '(&(objectClass=dominoperson))'
            ),
            'mysql' => array(
                'host' => '',
                'port' => '',
                'user' => '',
                'password' => '',
                'database' => '',
                'timeout' => '',
                'filter' => 'SELECT ${MAP} FROM `contacts_table` WHERE `type`="customer"'
            ),
            'mssql' => array(
                'host' => '',
                'port' => '',
                'user' => '',
                'password' => '',
                'database' => '',
                'timeout' => '',
                'filter' => 'SELECT ${MAP} FROM [contacts_table] WHERE [type]="customer"'
            ),
            'hanaDb' => array(
                'host' => '127.0.0.1',
                'port' => '30015',
                'user' => '',
                'password' => '',
                'database' => '',
                'timeout' => '0',
                'filter' => 'select ${MAP} from ${DBNAME}."OCRD"'
            ),
            'csv' => array(
                'import_type' => 'upload',
                'import_mountpoint' => '',
                'import_filepath' => ''
            ),
        	'office365' => array(
        			'access_to_directory' => '',
        			'mail' => '',
        			'received_token_time' => '',
        			'access_token' => '',
        			'token_type' => '',
        			'expires_in' => '',
        			'id_token' => '',
        			'id_token_expires_in' => '',
        			'refresh_token' => '',
        			'phonebooks' => ''
        		),
            'google' => array(
                    'mail' => '',
                    'received_token_time' => '',
                    'access_token' => '',
                    'token_type' => '',
                    'expires_in' => '',
                    'refresh_token' => '',
                    'phonebooks' => ''
            ),
            'infusionsoft' => array(
                    'mail' => '',
                    'app' => '',
                    'received_token_time' => '',
                    'access_token' => '',
                    'token_type' => '',
                    'expires_in' => '',
                    'refresh_token' => '',
            ),
            'exchange' => array(
                    'host' => '',
                    'user' => '',
                    'password' => '',
            		'phonebooks' => ''
            )
        );

        $recurrent_job = array(
            'enabled' => 'no', // yes/no
            'interval' => '2', // in hours
            'email' => ''
        );

        $global_vals = array(
            'backend' => 'ldap',
            'remove_users' => 'no',
            'erase_values' => 'no'
        );

        if ($sync_params == ''){
            return array('map' => $map, 'settings' => $settings, 'recurrent_job' => $recurrent_job, 'global' => $global_vals);
        }else{
            $return = array();

            $map_attrs = $this->get_sync_attributes_translation();

            $from_file = json_decode($sync_params,true);

            foreach (array('ldap','activeD','domino','mysql','hanaDb','mssql','office365','google','infusionsoft','exchange','csv') as $backend) {
            	if (!is_array($from_file[$backend.'_settings'])) {
                    $from_file[$backend.'_settings'] = $settings[$backend];
                }
                if ($from_file[$backend.'_settings']) {
                	foreach ($settings[$backend] as $key => $val){
                		if (isset($from_file[$backend.'_settings'][$key])){
                			$return['settings'][$backend][$key] = $from_file[$backend.'_settings'][$key];
                		}else{
                			$return['settings'][$backend][$key] = $val;
                		}
                	}
                }

            	if (!is_array($from_file[$backend.'_map'])) {
                    $from_file[$backend.'_map'] = $map[$backend];
                }
                if($from_file[$backend.'_map']){
                	if(empty($from_file[$backend.'_map']['source_id'])){
                		// for backward compatibility with the old logic, when the name was unique key
                		$from_file[$backend.'_map']['source_id'] = $from_file[$backend.'_map']['username'];
                	}
	                foreach ($from_file[$backend.'_map'] as $key => $val){
	                    if (isset($map_attrs[$key])){
	                        $return['map'][$backend][$key] = $val;
	                    }
	                }
                }
            }

            $return['recurrent_job'] = $from_file['recurrent_job'];
            $return['global'] = $from_file['global'];

            $return['default'] = array('map' => $map);

            if (!isset($return['settings']['csv']['import_type']) || empty($return['settings']['csv'])) {
                $return['settings']['csv'] = $settings['csv'];
            }
            if (!isset($return['settings']['mysql']['timeout'])) {
                $return['settings']['mysql']['timeout'] = '';
            }
            if (!isset($return['settings']['hanaDb']['timeout'])) {
                $return['settings']['hanaDb']['timeout'] = '';
            }
            if (!isset($return['settings']['mssql']['timeout'])) {
                $return['settings']['mssql']['timeout'] = '';
            }
            return $return;
        }
    }

    function set_sync_settings_n_map($pbook_id, $settings){
        $to_save = array(
            'global' => $settings['global'],
            'ldap_settings' => $settings['ldap']['settings'],
        	'activeD_settings' => $settings['activeD']['settings'],
            'domino_settings' => $settings['domino']['settings'],
            'mysql_settings' => $settings['mysql']['settings'],
            'mssql_settings' => $settings['mssql']['settings'],
            'hanaDb_settings' => $settings['hanaDb']['settings'],
            'csv_settings' => $settings['csv']['settings'],
        	'office365_settings' => $settings['office365']['settings'],
            'google_settings' => $settings['google']['settings'],
            'infusionsoft_settings' => $settings['infusionsoft']['settings'],
        	'exchange_settings' => $settings['exchange']['settings'],
            'ldap_map' => $settings['ldap']['map'],
        	'activeD_map' => $settings['activeD']['map'],
            'domino_map' => $settings['domino']['map'],
            'mysql_map' => $settings['mysql']['map'],
            'hanaDb_map' => $settings['hanaDb']['map'],
            'mssql_map' => $settings['mssql']['map'],
            'csv_map' => $settings['csv']['map'],
        	'office365_map' => $settings['office365']['map'],
            'google_map' => $settings['google']['map'],
            'infusionsoft_map' => $settings['infusionsoft']['map'],
        	'exchange_map' => $settings['exchange']['map'],
            'recurrent_job' => $settings['recurrent_job']
        );

        $t_sync_set = '0';
        $t_sync_interval = '0';
        if ($settings['recurrent_job']['enabled'] == 'yes'){
            $t_sync_set = '1';
            $t_sync_interval = $settings['recurrent_job']['interval'];
        }

        $this->db->query(
            'UPDATE `' . $this->table .
            '` SET sync_params=\'' . $this->db->realEscapeString(json_encode($to_save))
            . '\', sync_set="' . $t_sync_set
            . '", sync_interval="' . $t_sync_interval
            . '" WHERE rid=' . (int)$pbook_id . ';'
        );

        if ($this->db->hasError()){
            logger($this->db->errorNative());
        }
    }


    function pbooks_sync_reset_cron(){
        if (!$this->nofile){
            $this->db->query('UPDATE `'.$this->table.'` SET sync_params="", sync_set="0", sync_interval="0";');
        }
    }

	function check_shortcut($record, $phonebook_id){
		$result = array();
		$shortcut = $this->db->realEscapeString($record['shortcut']);
		$source_id = $this->db->realEscapeString($record['source_id']);
		$query = "SELECT * FROM ".$this->contacts_table." WHERE shortcut = '".$shortcut."'";

		$response = $this->db->query($query);
		if($response) {
			while ($row = $response->fetchRow(DB_FETCHMODE_ASSOC)) {
				$result[] = $row;
			}
			if (count($result) > 1 || (count($result) == 1 && !($result[0]['source_id'] == $source_id && $result[0]['phonebook_id'] == $phonebook_id))) {
				return false;
			}
		}
		return true;
	}

};
