<?php

class XMLForm {

    public $xmlform;
    public $stylesheet;

    /**
     * XMLForm constructor
     *
     * @param string $filename Path of filename.
     */
    public function __construct($filename = '/var/www/common/XmlForm.xslt') {
        if (file_exists($filename)) {
            $this->stylesheet = $filename;
        }

        $this->xmlform[] = '<page>';
    }

    /**
     * Buil XML format
     *
     * @param string $type        Type of tag.
     * @param string $elementData Data of tag.
     *
     * @return void
     */
    public function add($type, $elementData) {
        $xml = '';

        foreach ($elementData as $tagname => $value) {
            $xml .= $this->wrapToTag($value, $tagname);
        }

        $this->xmlform[] = '<ctl><' . $type . '>' . $xml . '</' . $type . '></ctl>';
    }

    /**
     * Output XML forms
     *
     * @return string
     */
    public function show() {
        return print($this->form());
    }

    /**
     * Build XML form
     *
     * @return string
     */
    public function form() {
        $this->xmlform[] = '</page>';

        $xmldoc = new DOMDocument();
        $xmldoc->loadXML(implode("\n", $this->xmlform));
        $xslt   = new XSLTProcessor();
        $xsldoc = new DOMDocument();
        $xsldoc->load($this->stylesheet);

        $xslt->importStylesheet($xsldoc);

        return $xslt->transformToXML($xmldoc);
    }

    /**
     * Build XML tags
     *
     * @param string|array $subject Subject of body tags.
     * @param string       $tagname Name of tag.
     *
     * @return string
     */
    private function wrapToTag($subject, $tagname) {
        if (is_array($subject)) {
            $isAssoc = is_assoc($subject);
            $output  = '';

            foreach ($subject as $k => $value) {
                $output .= '<' . $tagname . (!$isAssoc ? '>' : ' value="' . $k . '">') . htmlspecialchars($value) . '</' . $tagname . '>' . PHP_EOL;
            }

        } else {
            $output = '<' . $tagname . '>' . htmlspecialchars($subject) . '</' . $tagname . '>' . PHP_EOL;
        }

        return $output;
    }
}
