<?php
require_once('/var/www/init.php');

define('DB_FETCHMODE_ASSOC',0);
define('DB_FETCHMODE_ORDERED',1);

// names of function were taken from PEAR DB library

class xDB_result {
	/*
	 * @var DB_SQLite3
	 */
	private $db = false;

	public function __construct($db){
		if( is_object($db) ) {
			if (version_compare('5.0.0', phpversion(), '<=')) $this->db = clone $db;
			else $this->db = $db;
		}
		return true;
	}

	public function fetchRow($fetchmode=DB_FETCHMODE_ASSOC){
		if($this->db){
			$t = array();

			if($this->db->fetchInto($this->db->result, $t, $fetchmode) ) {
				return $t;
			}
		}

		return false;
	}

	public function fetchInto(&$row,$fetchmode){
		$row = $this->fetchRow($fetchmode);
		return $row ? true: false;
	}

	public function free(){
		if ($this->db && is_object($this->db->result)){
			$this->db->result->finalize();
		}
	}
}

class DB_SQLite3 {
	/*
	 * connection to the current database
	 * @var SQLite3
	 */
	public $connection;

	/*
	 * full name of the current database
	 * @var string
	 */
	private $dbPath = false;

	public $result;

	private $fetchmode = null;

	public function __construct($database = null){
		if(! is_null($database) ) return $this->connect($database);
		return true;
	}

	protected function connect($database){
		$this->dbPath = $database;
		$this->connection = new SQLite3($database);
		if (!$this->connection) return $this->errorNative();

		return true;
	}

	public function disconnect(){
		if($this->connection)
			return $this->connection->close();
		return true;
	}

	public function getPathDB(){
		return $this->dbPath;
	}

	public function getAll($query, $fetchmode=DB_FETCHMODE_ASSOC){
		$res = $this->query($query);

		$results = array();
		$row = array();

		while($res->fetchInto($row, $fetchmode)){
			if($fetchmode !== DB_FETCHMODE_ASSOC){
				foreach($row as $key => $val){
					$results[$key][] = $val;
				}
			}else{
				$results[] = $row;
			}
		}

		$res->free();

		return $results;
	}

	public function query($query, $fetchmode=DB_FETCHMODE_ASSOC){
		// return an object
		if( $this->simpleQuery($query)) {
			return new xDB_result($this);
		}

		return new xDB_result(false);
	}

	public function fetchInto($result, &$arr, $fetchmode=DB_FETCHMODE_ASSOC){
		switch ($fetchmode) {
			case DB_FETCHMODE_ORDERED:
				$fetchfunc=SQLITE3_NUM;
				break;
			case DB_FETCHMODE_ASSOC:
			default:
				$fetchfunc=SQLITE3_ASSOC;
				break;
		}

		$arr = $result->fetchArray($fetchfunc);

		return !!$arr;
	}

	public function simpleQuery($query){
		$times = 30;
		$isManip = $this->isManip($query);
		$restored = false;

		do{
			$repeat = false;
			if ( $isManip )
				@$this->result = $this->connection->exec($query);
			else
				@$this->result = $this->connection->query($query);

			if($this->connection->lastErrorCode()){
				openlog('WMS 3.0', LOG_PID, LOG_LOCAL0);
				syslog(LOG_ERR, 'iteration: '.$times);
				syslog(LOG_ERR, 'timestamp: '.microtime());
				syslog(LOG_ERR, 'error_code: '.$this->connection->lastErrorCode());
				syslog(LOG_ERR, 'error: '.$this->errorNative());
				syslog(LOG_ERR, 'query: '.$query);
				closelog();

                                if($this->connection->lastErrorCode() == 14){ // unable to open database file
                                    if ($this->removeJournal()){
                                        $repeat = true;
                                    }
				}
				if(!$restored && $this->connection->lastErrorCode() == 11){ // The database disk image is malformed
					if($this->restoreDB()){
						$repeat = true;
					}
					$restored = true;
				}
				if($this->connection->lastErrorCode() == 6){ // database is locked
					$repeat = true;
				}
			} else {
				if (!$this->result)
					return $this->errorNative();
				return $this->result;
			}

			usleep( rand(10,100) * 1000 );

		} while ($repeat && $times-- > 0);
		return false;
	}

	public function affectedRows(){
		return $this->connection->changes();
	}

	public function lastInsertRowID(){
		return $this->connection->lastInsertRowID();
	}

	public function errorNative(){
		if($this->connection){
			return $this->connection->lastErrorMsg();
		}else{
			return 'Can\'t open database';
		}
	}

	private function isManip($query){
		$manips = 'INSERT|UPDATE|DELETE|REPLACE|'
		. 'CREATE|DROP|'
		. 'LOAD DATA|SELECT .* INTO .* FROM|COPY|'
		. 'ALTER|GRANT|REVOKE|'
		. 'BEGIN|COMMIT|'
		. 'LOCK|UNLOCK';
		return preg_match('/^\s*"?(' . $manips . ')\s+/i', $query);
	}

	public function setFetchMode($fetchmode){
		return $this->fetchmode = $fetchmode;
	}

	public function hasError(){
		return $this->errorNative() !== 'not an error';
	}

        private function removeJournal() {
            if (file_exists($this->dbPath.'-journal') ){
                //Used sudo rm due to sometimes not enough rights
                exec('sudo rm '.$this->dbPath.'-journal', $out, $ret);
                openlog('WMS 3.0', LOG_PID, LOG_LOCAL0);
                syslog(LOG_ERR, 'Sqlite journal file exists: '.$this->dbPath.'-journal - '. ($ret==0?'deleted':'can not delete it') );
                closelog();
                return $ret==0;
            }
            return false;
        }

	/*
	 * Restoring DB from the backup if exists. Also send to user notification about restoration
	 */
	public function restoreDB(){
		global $wmsErr;
		$path = dirname($this->dbPath);
		$name = basename($this->dbPath);
		$backup = $path.DIRECTORY_SEPARATOR.$name.'.dmp.gz';
		$schemaRestore = '/usr/sbin/init_'.$name;
		$ret = false;
		$msg = '';
		if(file_exists($backup)){
			$this->disconnect();
			unlink($this->dbPath);
			exec('zcat "'.$backup.'" | sqlite3 "'.$this->dbPath.'"');
			$this->connect($this->dbPath);
			$msg = _t('sqlite.db_restored',$name);

			Logger::getInstance('db_sqlite3.php')->info(__LINE__, 'Database '.$name.' was restored from daily backup over corrupted database image');

			$ret = true;
		}elseif(file_exists($schemaRestore)){
			$this->disconnect();
			unlink($this->dbPath);
			exec('/bin/sh '.$schemaRestore);
			$this->connect($this->dbPath);
			$msg = _t('sqlite.db_recreated',$name);

			Logger::getInstance('db_sqlite3.php')->info(__LINE__, 'Schema of the database '.$name.' was recreated over corrupted database image');

			$ret = true;
		}else{
			Logger::getInstance('db_sqlite3.php')->error(__LINE__, 'Database '.$name.' not restored');
		}

		if (!empty($msg) && is_object($wmsErr)) {
			$wmsErr->_set('','error',$msg);
		}

		return $ret;
	}

    public function realEscapeString($str) {
        return \SQLite3::escapeString($str);
    }
}

function sqlite3FastManip($queries,&$sqlite3_db_obj){
	if(is_array($queries) && 0 != sizeof($queries)){
		$sqlite3_db_obj->simpleQuery('BEGIN TRANSACTION;');
		foreach ($queries as $query){
			$sqlite3_db_obj->simpleQuery($query);
		}
		$sqlite3_db_obj->simpleQuery('COMMIT ;'); // don't remove the space char - in other case it doesn't see it's manip
	}
	return true;
}

