<?php
namespace CTI;
use Api\Translation\Interfaces\TranslationStrategyInterface;

/**
 * Class main CTI application
 *
 * @copyright Wildix
 * @version 1.0
 * @package Base
 */
class Application {
    /**
     * Static template instance
     * @var object
     */
    public static $templater = false;
    public $isIe, $isFirefox, $isWebKit, $isiPad, $isGalaxy = null;

    /**
     * Wildix DI container class.
     *
     * @var \Wildix\DependencyInjection\Container
     */
    private $_diContainer;

    public function  __construct() {
        $this->_diContainer = new \Wildix\DependencyInjection\Container();

        \CTI\Session::getInstance()->start();
    }

    /**
     * Get DI container.
     *
     * @return \Wildix\DependencyInjection\Container
     */
    private function getContainer(): \Wildix\DependencyInjection\Container {
        return $this->_diContainer;
    }

    /**
     * Method initializes Templater, creates root tag
     * @param string $stylesheet Stylesheet name. Default index.xsl
     */
    public function init() {
        $this->isLoggingOut();
        if (!$this->isLogged()) {
            throw new \CTI\Exception('USER NOT LOGGED IN', \CTI\Exception::ERROR_NOTICE);
        }
        $lang = \CTI\User::getInstance()->get(\CTI\User::USER_DATA, 'preferredLanguage');
        $lang = ($lang === 'es-us') ? 'es' : $lang;

        self::$templater = new Templater();
        self::$templater->newDocument('root', $this->getRootParams(), $lang);

        $this->addLicensies();
        $this->addUserData();
        $this->addUserFeatures();
        $this->addUserACL();
        $this->addPBXConfigs();
    }

    public function getTemplate(){
        return self::$templater;
    }

    private function getRootParams() {
        $userLang = \CTI\User::getInstance()->get(\CTI\User::USER_DATA, 'preferredLanguage');
        $userLang = ($userLang === 'es-us') ? 'es' : $userLang;

        $params = array(
            'debug' => \CTI\Config::getInstance()->get('DEBUG') ? "true" : "false",
            'lang' => $userLang,
        	'full_lang' => \CTI\Langs::getInstance()->get('main.lang_' . $userLang),
            'userKind' => \CTI\User::getInstance()->get(\CTI\User::USER_DATA, 'userKind'),
            'server_time' => time(),
            'version' => WMS_VERSION,
            'version_full' => WMS_VERSION_FULL,
        	'logo' => \Wildix\WhiteLabel::getInstance()->getSmallLogo(),
        	'big_logo' => \Wildix\WhiteLabel::getInstance()->getBigLogo(),
        	'favicon' => \Wildix\WhiteLabel::getInstance()->getFavicon(),
        	'site' => \Wildix\WhiteLabel::getInstance()->getSite(),
        	'custom_css' => \Wildix\WhiteLabel::getInstance()->getCss(),
        	'isTopLinkEnabled' => \Wildix\WhiteLabel::getInstance()->isTopLinkEnabled(),
        	'isHelpLinkEnabled' => \Wildix\WhiteLabel::getInstance()->isHelpLinkEnabled(),
        	'helpLink' => \Wildix\WhiteLabel::getInstance()->getHelpLink(),
        	'collaboration' => \Wildix\WhiteLabel::getInstance()->getCollaboration(),
            'legal' => \Wildix\WhiteLabel::getInstance()->getLegal(),
            'licenseType' => \CTI\User::getInstance()->get(\CTI\User::USER_DATA, \Wildix\Colleagues\Colleague::LICENSE_TYPE),
            'licenseLink' => \Wildix\WhiteLabel::getInstance()->getLicenseLink(),
            'googleTagManager' => \CTI\Config::getInstance()->get('GOOGLE_TAG_MANAGER') ?? '',
            'integrationHost' => env('INTEGRATION_CONFIG_URL'),
            'echoCancellation' => env('ECHO_CANCELLATION'),
            'noiseSuppression' => env('NOISE_SUPPRESSION'),
            'serviceAuthUri' => env('SERVICE_AUTH_URI'),
            'serviceGeoLocationUri' => env('SERVICE_GEO_URI'),
            'serviceWebinarUri' => env('SERVICE_WEBINAR_URI'),
            'serviceBacktraceUri' => env('SERVICE_BACKTRACE_URI'),
            'serviceTextToSpeechUri' => env('SERVICE_TEXT_TO_SPEECH_URI'),
            'serviceKiteUri' => env('SERVICE_KITE_URI'),
            'serviceKiteHost' => env('SERVICE_KITE_HOST'),
            'serviceKiteDomain' => parse_url(env('SERVICE_KITE_HOST'), PHP_URL_HOST),
            'serviceUrlPreviewUri' => env('SERVICE_URL_PREVIEW_URI'),
            'serviceFsUri' => env('SERVICE_FS_URI'),
            'colleaguesChunkLimit' => env('COLLABORATION_COLLEAGUES_CHUNK_LIMIT', 5000),
            'serviceSMSUri' => env('SERVICE_SMS_URI'),
            'fileTransferAllow' => env('COLLABORATION_FILE_TRANSFER_ALLOW'),
            'chatAllow' => env('COLLABORATION_CHAT_ALLOW', true),
            \Session\Session::CSRF_TOKEN_HEADER => \Session\Session::getCsrfToken(),
            'showAllColleagues' => env('COLLABORATION_SHOW_ALL_COLLEAGUES', false),
            'collaborationPresenceService' => env('COLLABORATION_PRESENCE_SERVICE', 'xmpp'),
            'serviceWdaUri' => env('SERVICE_WDA_URI'),
            'dictionary' => json_encode(\CTI\Langs::getInstance()->getAllJson()),
            'quickStatusAllow' => \CTI\User::getInstance()->get(\CTI\User::ACL, 'QUICK_STATUS')
        );
        if (\CTI\Config::getInstance()->get('LICENSE_JABBER') == 1) {
            $params['jabber'] = 1;
        }
        if (\CTI\Config::getInstance()->get('LICENSE_JABBER') == 1 && \CTI\User::getInstance()->get(\CTI\User::ACL, 'CTI_PRO') == 1) {
            $params['screen_sharing'] = 1;
        }
        if (\CTI\Config::getInstance()->get('LICENSE_CALL_MAN') == 1 && \CTI\User::getInstance()->get(\CTI\User::ACL, 'CTI_PO') == 1) {
            $params['attendant_console'] = 1;
        }
        if (\CTI\Config::getInstance()->get('LICENSE_CDRVIEW') == 1 && \CTI\User::getInstance()->get(\CTI\User::ACL, 'CTI_CDR_VIEW') == 1) {
            $params['cdrview'] = 1;
        }
        if (\CTI\Config::getInstance()->get('LICENSE_FAXES') == 1 && \CTI\User::getInstance()->get(\CTI\User::ACL, 'FAX') == 1) {
            $params['faxes'] = 1;
        }
        if (\CTI\Config::getInstance()->get('LICENSE_SMS') == 1 && \CTI\User::getInstance()->get(\CTI\User::ACL, 'SMS') == 1) {
            $params['sms'] = 1;
        }
        if (\CTI\Config::getInstance()->get('LICENSE_GEOLOCATION') == 1 && \CTI\User::getInstance()->get(\CTI\User::ACL, 'CTI_PRO') == 1) {
            $params['geolocation'] = 1;
        }
        if (\CTI\Config::getInstance()->get('LICENSE_POSTIT') == 1 && \CTI\User::getInstance()->get(\CTI\User::ACL, 'CTI_PRO') == 1) {
            $params['postit'] = 1;
        }
        if (\CTI\Config::getInstance()->get('LICENSE_PRIVATE_PHONEBOOK') == 1) {
            $params['private_phonebook'] = 1;
        }
        if (\CTI\Config::getInstance()->get('LICENSE_PUBLIC_PHONEBOOK') == 1) {
            $params['public_phonebook'] = 1;
        }
        if (\CTI\User::getInstance()->get(\CTI\User::ACL, 'HOTEL_ADMIN') == 1) {
            $params['hotel_admin'] = 1;
        }
        if (\CTI\User::getInstance()->get(\CTI\User::ACL, 'HOTEL_EVENTS') == 1) {
            $params['hotel_events'] = 1;
        }
        if (\CTI\Config::getInstance()->get('USERS_SHARE_AVAILABLE') == 1) {
            $params['users_share_available'] = 1;
        }

        if ($this->isIe == null) {
            $this->checkBrowser();
        }
        if ($this->isIe == true) {
            $params['browser_ie'] = 1;
        } else if ($this->isFirefox == true) {
            $params['browser_firefox'] = 1;
        } else if ($this->isWebKit == true) {
            $params['browser_webkit'] = 1;
        }
        if ($this->isiPad == 1) {
            $params['ipad'] = 1;
        } else {
            $params['ipad'] = 0;
        }
        if ($this->isGalaxy == 1/* || 1*/) {
            $params['galaxy'] = 1;
        } else {
            $params['galaxy'] = 0;
        }

        if (\Wildix\Certificate\SSLCertificate::isFailedToRenew()) {
            $params['sslCertificateExpireDays'] = \Wildix\Certificate\SSLCertificate::getRemainingDaysCount();
        }

        return $params;
    }

    /**
     * Method checks browser and adds to cookie if browser is supported.
     * Otherwise method shows update browser page
     * @return bool Returns only true.
     */
    public function checkBrowser() {
        $known = array('msie', 'trident', 'firefox', 'safari', 'webkit', 'opera', 'netscape', 'konqueror', 'gecko');

        if (strpos($_SERVER['HTTP_USER_AGENT'], 'iPad')) {
            $this->isiPad = 1;
        }
        if (strpos($_SERVER['HTTP_USER_AGENT'], 'Android')) {
            $this->isiPad = 1;
        }
        if (strpos($_SERVER['HTTP_USER_AGENT'], 'Galaxy')) {
            $this->isGalaxy = 1;
        }
        if (strpos($_SERVER['HTTP_USER_AGENT'], 'Android') && strpos($_SERVER['HTTP_USER_AGENT'], 'GT-')) {
            $this->isGalaxy = 1;
        }
        $agent = strtolower($_SERVER['HTTP_USER_AGENT']);
        $pattern = '#(?<browser>' . join('|', $known) . ')[/ ]+(?<version>[0-9]+(?:\.[0-9]+)?)#';

        preg_match_all($pattern, $agent, $matches);

        $i = count($matches['browser'])-1;
        $browser =  array($matches['browser'][$i] => $matches['version'][$i]);

        if (isset($browser['msie']) || isset($browser['trident'])) {
            $this->isIe = true;
        } else {
            $this->isIe = false;
        }

        if (isset($browser['firefox'])) {
            $this->isFirefox = true;
        } else {
            $this->isFirefox = false;
        }

        if (isset($browser['safari']) || isset($browser['webkit'])) {
            $this->isWebKit = true;
        } else {
            $this->isWebKit = false;
        }

        return true;
    }

    /**
     * Method checks is current application created by ajax query
     * @return bool Result of checking. True - ajax. False - standart.
     */
    public function ifAjax() {
        return \CTI\Request::getInstance()->getReqInt('ajax_request') != null ? true : false;
    }

    /**
     * Method shows html by using templater.
     */
    public function show() {
        if(!\CTI\User::getInstance()->isOwnedThisPBX() && !isset($_GET['forced'])){
            self::$templater->addTag('pbxowner_domain', \CTI\User::getInstance()->getPbxOwnerDomain(), self::$templater->getRootElement());
            $stylesheet = 'user_not_on_this_pbx.xsl';
        }else{
            $stylesheet = \CTI\Config::getInstance()->get('DB_NOT_EXISTS') == 1 ? 'error.xsl' : 'index.xsl';
        }

        echo self::$templater->generateHTML($stylesheet);
    }

    /**
     * Method checks logged or not user
     * @return bool Result checking
     */
    public function isLogged() {

        if (\CTI\Session::getInstance()->get('UNAUTORIZE') == 1) {
            \CTI\Session::getInstance()->clear();
            header('WWW-Authenticate: Basic realm="CTICONNECT"');
            $_SERVER = array();
            header('HTTP/1.0 401 Unauthorized');
            echo '<html><head><title>401 - Unauthorized</title></head><body><h1>401 - Unauthorized</h1></body></html>';
            exit();
        }

        return \User::getInstance()->isLogged();
    }

    /**
     * Method checks logiing out button and doing logout if _GET[logout] is present
     */
    public function isLoggingOut() {
        if (\CTI\Request::getInstance()->getReqInt('logout') == 1) {
            //\CTI\Session::getInstance()->clear();
            \CTI\Session::getInstance()->set('UNAUTORIZE', 1);

            if ((strstr($_SERVER['HTTP_USER_AGENT'], 'AppleWebKit') && strstr($_SERVER['HTTP_USER_AGENT'], 'Chrome')) || strstr($_SERVER['HTTP_USER_AGENT'], 'Firefox') || strstr($_SERVER['HTTP_USER_AGENT'], 'MSIE') ) {
                    header('WWW-Authenticate: Basic realm="CTICONNECT"');
                    header('HTTP/1.0 401 Unauthorized');
                    echo '<html><head><title>401 - Unauthorized</title></head><body><h1>401 - Unauthorized</h1></body></html>';
                    header('Location: /collaboration/');
                    exit();
            }else{
                $schema = isset($_SERVER['HTTPS']) ? 'https://' : 'http://';
                die('<script>document.location.href="' . $schema .  ':@' . $_SERVER['HTTP_HOST'] . ':' . $_SERVER['SERVER_PORT'] . '/collaboration"</script>');
            }
        }
    }

    /**
     * Method creates xml tags with js and css modules names and creates xml tag with modules names splitted with ",".
     * @param array $modules Modules names
     */
    public function addModules($modules) {
        $modulesNames = '';
        foreach ($modules as $moduleName => $v) {
            $modulesNames .= $moduleName . ',';
        }
        $modulesNames = substr($modulesNames, 0, -1);

        self::$templater->addTag('js_modules_names', $modulesNames, self::$templater->getRootElement());
    }


    private function addLicensies() {
        $data = \CTI\Config::getInstance()->get();
        $data = base64_encode(json_encode($data));
        self::$templater->addCData('licensies', $data, self::$templater->getRootElement());
    }

    private function addUserData() {
        $data = \CTI\User::getInstance()->get(\CTI\User::USER_DATA);
        $data['myHost'] = trim(end(explode(',', $_SERVER['REMOTE_ADDR'])));
        $data = base64_encode(json_encode($data));
        self::$templater->addCData('user_data', $data, self::$templater->getRootElement());
    }

    private function addUserFeatures() {
        $data = \CTI\User::getInstance()->get(\CTI\User::FEATURES);
        $data = base64_encode(json_encode($data));
        self::$templater->addCData('user_features', $data, self::$templater->getRootElement());
    }

    private function addUserACL() {
        $data = \CTI\User::getInstance()->get(\CTI\User::ACL);
        $data = base64_encode(json_encode($data));
        self::$templater->addCData('user_acl', $data, self::$templater->getRootElement());
    }

    private function addPBXConfigs() {
        $data['contact_notes_available'] = \CTI\Config::getInstance()->get('CONTACT_NOTES_AVAILABLE');
        $data['chat_history_of_pbx'] = \CTI\Config::getInstance()->get('CHAT_HISTORY_OF_PBX');
        $data['cdr_tags'] = \CTI\Config::getInstance()->get('CDR_TAGS');
        $data['version'] = WMS_VERSION_FULL;
        $data['serial'] = \Models\PBX::getInstance()->getSerial();
        $data['video_conference'] = \CTI\Config::getInstance()->get('VIDEO_CONFERENCE');
        $data['kite'] = \CTI\Config::getInstance()->get('KITE');

        $data['country_code'] = \Wildix\Dialplan\ExtensionsVariables::getInstance()->get(\Wildix\Dialplan\ExtensionsVariables::COUNTRY_CODE);

        $data['external_line_prefix'] = \Models\PBX::getInstance()->getExternalLinePrefix();

        $data['feature_codes'] = array(
        		'CONFERENCE' => \Models\PBX::getInstance()->getFeatureCode('CONFERENCE'),
        		'SHORTNUM' => \Models\PBX::getInstance()->getFeatureCode('SHORTNUM'),
        		'LOGIN' => \Models\PBX::getInstance()->getFeatureCode('LOGIN')
        );

        $hostParts = parse_url($_SERVER['HTTP_HOST']);
        $data['HTTP_HOST'] = $hostParts['host'] ? $hostParts['host'] : $_SERVER['HTTP_HOST'];
        $data['HTTP_PORT'] = '443';

        $configs = getTProxyPortConfigs();
        if(!empty($configs['external_https_port'])){
            $data['HTTP_PORT'] = $configs['external_https_port'];
        }

        $data['DOMAIN'] = $data['serial'].".wildixin.com";
        $pbx = \Wildix\PBXes\PBXes::getInstance()->getPBXBySerial($data['serial']);
		if($pbx){
			$data['DOMAIN'] = $pbx->getDomain();
		}

		$data['audio_conference_domain'] = "conference.".$data['DOMAIN'];

		$groupChatService = $this->getContainer()->get(\Wildix\Services\GroupChat::class);
        // check if the cloud group chat is configured (chats.meet.wildix.com)
        $chatDomain = $groupChatService->getGroupChatDomain();

        if (!empty($chatDomain)) {
            $data['audio_conference_domain'] = $chatDomain;
        }

        $smsBotDomain = $groupChatService->getSmsBotDomain();

        if ($smsBotDomain !== '') {
            $data['sms_bot_domain'] = $smsBotDomain;
        }

        $data['WMS_NETWORK'] = array();
        foreach (\Wildix\PBXes\PBXes::getInstance()->getPBXes() as $pbx){
        	$data['WMS_NETWORK'][$pbx->getDn()] = array(
        			'serial' => $pbx->getSerial(),
        			'domain' => $pbx->getDomain()
        	);
        }

        $data['IS_FAILOVER'] = \CTI\User::getInstance()->isPbxFailover() ? 1 : 0;
        $data['googleMapsApiKey'] = \Wildix\WhiteLabel::getInstance()->getGoogleMapsApiKey();
        $data['sms_header'] = \CTI\Config::getInstance()->get('SMS_HEADER');

        $mailOption = $this->getContainer()->get(\Wildix\Smtp::class)->getMailOptions();
        $data['has_smtp_host'] = !empty($mailOption['host']);

        $data = base64_encode(json_encode($data));
        self::$templater->addCData('pbx_configs', $data, self::$templater->getRootElement());
    }
}
