<?php
namespace CTI;
/**
 * Class for loading modules, executing them and firing ajax events to needed modules.
 * Class uses singleton pattern (can be called without creating object)
 *
 * @copyright Wildix
 * @version 1.0
 * @package Base
 */
class Builder {
    private static $object = false;
    /**
     * All loaded modules
     * @var array
     */
    private $modules = array();

    private function  __construct() {
    }

    public static function getInstance() {
        return self::$object == false ? self::$object = new \CTI\Builder() : self::$object;
    }

    /**
     * Method loads module and check filesystem for file modules/module name/module.php
     * @param string $moduleName Module name
     */
    public function load($moduleName, $lModuleName) {

    	if (isset($this->modules[$moduleName]) && $this->modules[$moduleName] != null) {
    		throw new \CTI\Exception('MODULE '.$moduleName.' ALREADY EXISTS', \CTI\Exception::ERROR_WARNING);
    	}

    	$modulePath = 'modules/' . $lModuleName. '/' . $lModuleName. '.php';

    	if (!file_exists($modulePath)) {
            throw new \CTI\Exception('MODULE '.$moduleName.' NOT FOUND', \CTI\Exception::ERROR_WARNING);
        }

        require_once($modulePath);
        $className = '\CTI\Module' . $moduleName;
        if (!class_exists($className)) {
            throw new \CTI\Exception('WRONG MODULE '.$moduleName.' STRUCTURE: class '.$className.' not extsts. ', \CTI\Exception::ERROR_WARNING);
        }
        $this->modules[$moduleName] = $className;
    }

    /**
     * Method excecuted all loaded modules
     */
    public function make() {
        if (count($this->modules) == 0) {
            throw new \CTI\Exception('EMPTY MODULES LIST', \CTI\Exception::ERROR_WARNING);
        }
        foreach ($this->modules as $moduleName => $className) {
            $module = new $className();
            if ($module instanceof \CTI\Templater) {
                $module->generate();
            } else {
                throw new \CTI\Exception('WRONG MODULE '.$moduleName.' STRUCTURE: class '.$className.' not extends from \CTI\Templater.', \CTI\Exception::ERROR_WARNING);
            }
        }
    }

    /**
     * Ajax method. It calls needed module and excecuted ajax.
     * @param string $event Event name
     * @param array $params Input data
     * @param string $moduleName Called module name
     */
    public function fireEvent($event, $params, $moduleName) {
        if (count($this->modules) == 0) {
            throw new \CTI\Exception('EMPTY MODULES LIST', \CTI\Exception::ERROR_WARNING);
        }
        $className = '\CTI\Module' . $moduleName;
        if (!class_exists($className)) {
            throw new \CTI\Exception('MODULE NOT FOUND.', \CTI\Exception::ERROR_WARNING);
        }
        $module = new $className();
        if ($module instanceof \CTI\Ajax) {
            echo $module->execute($event, $params);
            exit();
        } else {
            throw new \CTI\Exception('WRONG MODULE '.$moduleName.' STRUCTURE: class '.$className.' not implements from \CTI\Ajax.', \CTI\Exception::ERROR_WARNING);
        }
    }

    public function getModules() {
        return $this->modules;
    }
}
