<?php
namespace CTI;
use Logger\Log;
use Logger\LoggerFactory;
use Wildix\License;
use Wildix\Services\Portal;
use Wildix\Services\WizyWebinar;
use Wildix\Webinar\WebinarService;

/**
 * Class gets and sets basic params
 * Class uses singleton pattern (can be called without creating object)
 *
 * @copyright Wildix
 * @version 1.0
 * @uses WMS features/features.functions.php
 * @package Base
 */
class Config {
    private static $object;
    /**
     * Options params
     * @var array
     */
    private $options = array();

    private function __construct() {
        $this->init();
    }

    public static function getInstance() {
        return self::$object == false ? self::$object = new \CTI\Config() : self::$object;
    }

    /**
     * Initing basic options and license
     */
    public function init() {

        $this->set('MAX_FAXES_IN_QUERY', 100);
        $this->set('MAX_UPLOAD_FILE_SIZE', 5 * 1024 * 1024);
        $this->set('MAX_LOGO_FILE_SIZE', 5 * 1024 * 1024);

        $this->set('FAXCOVER_PATH', '/tmp/session/');
        $this->set('FAXCOVER_SHARE_PATH', '/mnt/faxes');
        $this->set('FAX_SPOOL_PATH', '/tmp/mail2fax/0/');
        $this->set('FAX_SPOOL_URL', '../api/v1/fax/queue/');
        $this->set('CTICONNECT_SHARE', '/mnt/cticonnect/');
        $this->set('CTICONNECT_SHARE_UPLOADS', '/mnt/cticonnect/uploads/');
        $this->set('CTICONNECT_INVOICE_QUALITY', 90);

        $this->set('CONTACTS_DB_PATH', '/mnt/cticonnect/cticonnectdb');
        $this->set('WMS_DB_PATH', \Wildix\Databases\Database::WILDIX_WMSDB);

        if (\CTI\Helper::getInstance()->isCTIMounted()) {
            $checkDb = @file_exists($this->get('CONTACTS_DB_PATH'));
            if ($checkDb != true) {
                $this->set('DB_NOT_EXISTS', 1);
            } else {
                $this->set('DB_NOT_EXISTS', 0);
            }
            if (!is_dir($this->get('CTICONNECT_SHARE_UPLOADS'))) {
                $this->set('DB_NOT_EXISTS', 1);
            }
        } else {
            $this->set('DB_NOT_EXISTS', 1);
        }
        $this->set('IS_FAX_SHARE_MOUNTED', \CTI\Helper::getInstance()->isCustomShareMounted($this->get('FAXCOVER_SHARE_PATH')));
        $this->set('LICENSE', 0);
        $this->set('LICENSE_JABBER', 0);
        $this->set('LICENSE_CALL_MAN', 0);
        $this->set('LICENSE_CDRVIEW', 0);
        $this->set('LICENSE_GEOLOCATION', 0);
        $this->set('LICENSE_POSTIT', 0);
        $this->set('LICENSE_CONFERENCE', 0);
        $this->set('LICENSE_PRO', 0);
        $this->set('LICENSE_FAXES', 0);
        $this->set('LICENSE_SMS', 0);
        if (\Wildix\License::getInstance()->haveLicense('cti_cdr_view')) {
            $this->set('LICENSE', 3);
            $this->set('LICENSE_CDRVIEW', true);
        }
        if (\Wildix\License::getInstance()->haveLicense('cti_operator_panel')) {
            $this->set('LICENSE', 2);
            $this->set('LICENSE_CALL_MAN', true);
        }
        if (\Wildix\License::getInstance()->haveLicense('cti_conference')) {
            $this->set('LICENSE_CONFERENCE', true);
        }
        if (\Wildix\License::getInstance()->haveLicense('faxes')) {
            $this->set('LICENSE_FAXES', 1);
            $this->set('LICENSE_SMS', 1);
        }

        $this->set('LICENSE_CALLGROUPS_VIEW', true);

        if (\Wildix\License::getInstance()->haveLicense('hotel')) {
            $this->set('LICENSE_HOTELS', 1);
        } else {
            $this->set('LICENSE_HOTELS', 0);
        }
        $this->set('LICENSE_HOTELS', 0);



        if (\Wildix\License::getInstance()->haveLicense('cti_connect_pro')) {
            $this->set('LICENSE', 1);
            $this->set('LICENSE_PRO', 1);
            $this->set('LICENSE_JABBER', true);
            $this->set('LICENSE_GEOLOCATION', true);
            $this->set('LICENSE_POSTIT', 1);
        }

        $this->set('LICENSE_PRIVATE_PHONEBOOK', 1);
        $this->set('LICENSE_PUBLIC_PHONEBOOK', 1);
        $this->set('LICENSE_RECORD', \CTI\User::getInstance()->get(\CTI\User::ACL, 'PERSONALRECORD'));
        $this->checkTrial();

        $res = get_users_settings_dir();
        if ($res != false) {
            $this->set('USERS_SHARE_AVAILABLE', 1);
        }

        $settings = \CDR::getInstance()->getSettings();

        if ($settings['general']['enable_contact_notes']
            && $settings['general']['enable_contact_notes'] == 'yes'
            && $settings[$settings['general']['ctibackend']]
            && $settings[$settings['general']['ctibackend']]['enabled'] == 'yes') {
            $this->set('CONTACT_NOTES_AVAILABLE', 1);
        }else{
            $this->set('CONTACT_NOTES_AVAILABLE', 0);
        }

    	if ($settings['general']['save_history_base']
            && $settings['general']['save_history_base'] == 'yes') {
            $this->set('CHAT_HISTORY_OF_PBX', 1);
        }else{
            $this->set('CHAT_HISTORY_OF_PBX', 0);
        }

        $this->set('CDR_TAGS', false);

        if(!empty($settings['general']['tags'])){
            $tags = explode(',', $settings['general']['tags']);

            $tags = array_map ( function($a) use ($searchWord, $fields) {
                return trim($a);
            }, $tags);

            $tags = array_filter($tags, function($a) use ($searchWord, $fields) {
                if(!empty($a)){
                    return true;
                }
                return false;
            });

            $this->set('CDR_TAGS', join(',', $tags));
        }


        $this->getVideoConferenceHost();
        $this->getKiteHost();
        $this->getSmsHeader();
        $this->getTemplateConfig();
        $this->getWebinarConfig();
    }

    private function getWebinarConfig() {
        $haveLicense = \Wildix\License::getInstance()->haveLicense(License::TYPE_WIZYWEBINAR);
        $this->set('LICENSE_WEBINAR', $haveLicense);

        $userAllowedWebinar = false;
        $email              = \CTI\User::getInstance()->get(\CTI\User::USER_DATA, 'mail');
        if ($haveLicense && $email) {
            $_wizyWebinarApiUri = env('SERVICE_WIZYWEBINAR_URI');

            $httpClient = new WizyWebinar(\Logger\Log::ERROR, $_wizyWebinarApiUri);
            $webinar    = new WebinarService($httpClient, true, \Cache\FileCache::getInstance(), LoggerFactory::getInstance());

            $userAllowedWebinar = $webinar->isAllowedForEmail($email);
        }
        $this->set('USER_ALLOWED_WEBINAR', $userAllowedWebinar);
    }

    /**
     * Method gets param
     * @param string $name Param name
     * @return string|array|int Param data
     */
    public function get($name = false) {
        if ($name === false) {
            return $this->options;
        } else {
            return $this->options[$name] === null ? null : $this->options[$name];
        }
    }

    /**
     * Method sets param
     * @param string $name Param name
     * @param string|int|array $val Param value
     */
    public function set($name, $val) {
        $this->options[$name] = $val;
    }

    private function checkTrial() {
        $expired = array();

        $range = \Wildix\License::getInstance()->getActiveDay('cti_connect_pro');
        if($range <= 7 && $range >= -30){
        	$expired[$range][] = 'Collaboration';
    	}

    	$range = \Wildix\License::getInstance()->getActiveDay('cti_cdr_view');
        if($range <= 7 && $range >= -30){
        	$expired[$range][] = 'CDR-View';
    	}

        $this->set('LICENSES_EXPIRED', $expired);
    }

    private function getVideoConferenceHost() {
        $cfg['host'] = parse_url(env('SERVICE_CONFERENCE_URI'), PHP_URL_HOST);

        if ($cfg === false) {
            throw new \Exception('Videoconference config parse failed');
        }

        if (!isset($cfg['host']) || !$cfg['host']) {
            error_log('Videoconference config exists, but host cannot be read.');
        }

        $this->set('VIDEO_CONFERENCE', $cfg);
    }

    private function getKiteHost() {
        $cfg = [
            'domain' => parse_url(env('SERVICE_KITE_URI'), PHP_URL_HOST),
            'host' => env('SERVICE_KITE_HOST'),
        ];

        $this->set('KITE', $cfg);
    }

    private function getTemplateConfig() {
        $file = '/rw2/etc/pbx/template.conf';
        if (!file_exists($file)) {
            return;
        }

        $data = parse_ini_file($file, true);
        if (!empty($data['gtm'])) {
            $this->set('GOOGLE_TAG_MANAGER', trim($data['gtm']));
        }
    }

    private function getSmsHeader()
    {
        $smsHeader = '';

        $setting = parse_ini_file('/rw2/etc/companies.d/0/variables.conf', false, INI_SCANNER_RAW);

        if (!empty($setting['GSMSTEXT_0'])) {
            $smsHeader = base64_decode($setting['GSMSTEXT_0']);
        }

        $this->set('SMS_HEADER', $smsHeader);
    }
}
