<?php
namespace CTI;
/**
 * Class parses input data by needed type
 * Class uses singleton pattern (can be called without creating object)
 *
 * @copyright Wildix
 * @version 1.0
 * @package Base
 */
class Request {
    private static $object = false;

    private function  __construct() {
    }

    public static function getInstance() {
        return self::$object == false ? self::$object = new \CTI\Request() : self::$object;
    }

    /**
     * Method gets string from _POST or _GET
     * @param string $name Variable name
     * @return string Variable value
     */
    public function getReqString($name) {
        $data = $this->switchData($name);
        if ($data == null) {
            return null;
        }
        return $data;
    }

    /**
     * Method gets int from _POST or _GET
     * @param string $name Variable name
     * @return int Variable value
     */
    public function getReqInt($name) {
        $data = $this->switchData($name);
        if ($data == null) {
            return null;
        }
        return (int)$data;
    }

    /**
     * Method creates object from json from _POST or _GET
     * @param string $name Variable name
     * @return object Variable value
     */
    public function getReqJson($name) {
        $data = $this->switchData($name);
        if ($data == null) {
            return null;
        }
        return json_decode($data, true);
    }

    /**
     * Method returns array from _POST or _GET
     * @param string $name Variable name
     * @return array Variable value
     */
    public function getReqArray($name) {
        $data = $this->switchData($name);
        return $data;
    }

    /**
     * Method parses input value as string
     * @param string $val String to parse
     * @return string Result string
     */
    public function getString($val) {
        return $val;
    }

    /**
     * Method parses input value as int
     * @param string $val String to parse
     * @return int Result int
     */
    public function getInt($val) {
        return (int)$val;
    }

    /**
     * Method creates object from json
     * @param string $val Json string
     * @return object Result object
     */
    public function getObjectFromJson($val) {
        return json_decode($val, true);
    }

    /**
     * Method checks _POST and _GET array for a variable and returns first available
     * @param string $name Variable name
     * @return string Variable value
     */
    private function switchData($name) {
        if (isset($_POST[$name])) {
            $data = $_POST[$name];
        } else if (isset($_GET[$name])) {
            $data = $_GET[$name];
        } else {
            $data = null;
        }
        return $data;
    }
}
