<?php
namespace CTI;
/**
 * Class for using session
 * Class uses singleton pattern (can be called without creating object)
 *
 * @copyright Wildix
 * @version 1.0
 * @package Base
 */
class Session {
    private static $object = false;
    private $sessionId;


    public static function getInstance() {
        return self::$object == false ? self::$object = new \CTI\Session() : self::$object;
    }

    /**
     * Method starts session if it hadn't already started
     */
    public function start() {
        if (session_id() == '') {
            $this->sessionId = session_id();
        }
    }

    /**
     * Method gets variable from session with using currect protocol
     * @param string $name Variable name
     * @return string|int|array Session variable value
     */
    public function get($name) {
        return isset($_SESSION[$name]) ? $_SESSION[$name] : null;
    }

    /**
     * Method sets variable from session with using currect protocol
     * @param string $name Variable name
     * @param string|int|array $val Variable value
     */
    public function set($name, $val) {
         $_SESSION[$name] = $val;
    }

    /**
     * Method gets cookie with using currect protocol
     * @param string $name Variable name
     * @return string Variable value
     */
    public function getCookie($name) {
        return isset($_COOKIE[$name]) ? $_COOKIE[$name] : null;
    }

    /**
     * Method sets in cookie variable with using currect protocol fro one month
     * @param string $name Variable name
     * @param string $val Variable value
     */
    public function setCookie($name, $val) {
        //one month
        setcookie($name, $val, time() + 2592000);
        $_COOKIES[$name] = $val;
    }

    /**
     * Method deletes cookie
     * @param string $name Variable name
     */
    public function deleteCookie($name) {
        setcookie($name, "", time() - 3600);
        $_COOKIES[$name] = null;
    }

    public function clear() {
        session_destroy();
    }
}
