<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
    <xsl:output method="html"/>

    <!-- Modules -->
    <xsl:include href="../../modules/main/main.xsl"/>
    <xsl:include href="../../modules/settings/settings.xsl"/>
    <xsl:include href="../../modules/chat/chat.xsl"/>
    <xsl:include href="../../modules/calls/calls.xsl"/>
    <xsl:include href="../../modules/roster/roster.xsl"/>
    <xsl:include href="../../modules/function_keys/function_keys.xsl"/>
    <xsl:include href="../../modules/phonebook/phonebook.xsl"/>
    <xsl:include href="../../modules/history/history.xsl"/>
    <xsl:include href="../../modules/voicemail/voicemail.xsl"/>
    <xsl:include href="../../modules/web_app/web_app.xsl"/>
    <xsl:include href="../../modules/cdrview/cdrview.xsl"/>
    <xsl:include href="../../modules/screen_sharing/screen_sharing.xsl"/>
    <xsl:include href="../../modules/webrtc_zero_distance/webrtc_zero_distance.xsl"/>
    <xsl:include href="../../modules/calendar/calendar.xsl"/>
    <xsl:include href="../../modules/video_sharing/video_sharing.xsl"/>
    <xsl:include href="../../modules/webinar/webinar.xsl"/>
    <xsl:include href="../../modules/x_caracal/x_caracal.xsl"/>

    <xsl:template match="/">
        <html>
            <xsl:attribute name="lang"><xsl:value-of select="/root/@lang" /></xsl:attribute>
            <xsl:attribute name="xml:lang"><xsl:value-of select="/root/@lang" /></xsl:attribute>
            <head>
                <xsl:if test="/root/@googleTagManager != ''">
                    <!-- Google Tag Manager -->
                    <script>(function(w,d,s,l,i){w[l]=w[l]||[];w[l].push({'gtm.start':
                        new Date().getTime(),event:'gtm.js'});var f=d.getElementsByTagName(s)[0],
                        j=d.createElement(s),dl=l!='dataLayer'?'&amp;l='+l:'';j.async=true;j.src=
                        'https://www.googletagmanager.com/gtm.js?id='+i+dl;f.parentNode.insertBefore(j,f);
                        })(window,document,'script','dataLayer','<xsl:value-of select="/root/@googleTagManager" />');</script>
                    <!-- End Google Tag Manager -->
                </xsl:if>
                <meta name="language">
                     <xsl:attribute name="content">
                             <xsl:value-of select="/root/@full_lang" />
                     </xsl:attribute>
                </meta>
                <meta http-equiv="Content-Language">
                    <xsl:attribute name="content"><xsl:value-of select="/root/@lang" /></xsl:attribute>
                </meta>

                <meta http-equiv="content-type" content="text/html; charset=utf-8"/>
                <meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1"/>

                <meta name="X-CSRF-Token">
                    <xsl:attribute name="content">
                        <xsl:value-of select="/root/@X-CSRF-Token" />
                    </xsl:attribute>
                </meta>

                <link rel="manifest" href="../manifest.json" />

                <link rel="shortcut icon" type="image/x-icon">
                	    <xsl:attribute name="href">../<xsl:value-of select="/root/@favicon" />?version-<xsl:value-of select="/root/@version" /></xsl:attribute>
                </link>

                <title>
                    <xsl:value-of select="/root/@collaboration"/>
                </title>


                <link rel="chrome-webstore-item" href="https://chrome.google.com/webstore/detail/lobgohpoobpijgfegnlhdnppegdbomkn"></link>

                <link rel="stylesheet" type="text/css">
                    <xsl:attribute name="href">dist/collaboration.css?version=<xsl:value-of select="/root/@version" /></xsl:attribute>
                </link>

                <xsl:if test="/root/@custom_css != ''">
                    <link href="" rel="stylesheet" type="text/css">
                        <xsl:attribute name="href">../<xsl:value-of select="/root/@custom_css" />?version-<xsl:value-of select="/root/@version" /></xsl:attribute>
                    </link>
                </xsl:if>


                <script type="text/javascript">
                    window.env = {
                        debug: <xsl:value-of select="/root/@debug"/>,
                        echoCancellation: Boolean('<xsl:value-of select="/root/@echoCancellation"/>'),
                        noiseSuppression: Boolean('<xsl:value-of select="/root/@noiseSuppression"/>'),
                        integration: '<xsl:value-of select="/root/@integrationHost"/>',
                        colleaguesChunkLimit: parseInt(<xsl:value-of select="/root/@colleaguesChunkLimit"/>),
                        serviceAuthUri: '<xsl:value-of select="/root/@serviceAuthUri"/>',
                        serviceGeoLocationUri: '<xsl:value-of select="/root/@serviceGeoLocationUri"/>',
                        serviceWebinarUri: '<xsl:value-of select="/root/@serviceWebinarUri"/>',
                        serviceBacktraceUri: '<xsl:value-of select="/root/@serviceBacktraceUri"/>',
                        serviceTextToSpeechUri: '<xsl:value-of select="/root/@serviceTextToSpeechUri"/>',
                        serviceUrlPreviewUri: '<xsl:value-of select="/root/@serviceUrlPreviewUri"/>',
                        serviceFsUri: '<xsl:value-of select="/root/@serviceFsUri"/>',
                        serviceSMSUri: '<xsl:value-of select="/root/@serviceSMSUri"/>',
                        fileTransferAllow: Boolean('<xsl:value-of select="/root/@fileTransferAllow"/>'),
                        chatAllow: Boolean('<xsl:value-of select="/root/@chatAllow"/>'),
                        showAllColleagues: Boolean('<xsl:value-of select="/root/@showAllColleagues"/>'),
                        collaborationPresenceService: '<xsl:value-of select="/root/@collaborationPresenceService"/>',
                        serviceWdaUri: '<xsl:value-of select="/root/@serviceWdaUri"/>',
                    }
                    function log() {
                        console.log.apply(console, arguments);
                    }
                    var video_conference_host = '<xsl:value-of select="/root/modules/module_video_conference/host" />';
                    var application_lang = '<xsl:value-of select="/root/@lang" />';

                    var serverTimeDiff = parseInt('<xsl:value-of select="/root/@server_time" />')*1000 - new Date().getTime();
                        getServerTime = function(){
                            if (Date.now)
                                return Date.now() + serverTimeDiff;
                            else
                                return new Date().getTime() + serverTimeDiff;
                        };

                    var translation = JSON.parse(<xsl:value-of select="/root/@dictionary"/>);

                        if (window.navigator.userAgent.indexOf("MSIE ") != -1|| !!navigator.userAgent.match(/Trident.*rv\:11\./)) {
                            var head = document.getElementsByTagName('head')[0];
                            var script = document.createElement('script');
                            script.setAttribute('src', '../js/bluebird.min.js');
                            script.setAttribute('type', 'text/javascript');
                            script.setAttribute('async', 'false');
                            head.appendChild(script);
                        }

                </script>

                <script type="text/javascript">
                    <xsl:attribute name="src">dist/common.js?version=<xsl:value-of select="/root/@version" /></xsl:attribute>
                </script>

                <script type="text/javascript">
                    <xsl:attribute name="src">dist/collaboration.js?version=<xsl:value-of select="/root/@version" /></xsl:attribute>
                </script>
                <script type="text/javascript">
                    <xsl:attribute name="src">../js/firebase/firebase-app-messaging.packed.js?version=<xsl:value-of select="/root/@version" /></xsl:attribute>
                </script>

                <script type="text/javascript">
                    <xsl:attribute name="src">data/js/index.js?version=<xsl:value-of select="/root/@version" /></xsl:attribute>
                </script>

                <script type="text/javascript">
                    var mainMenuTabDisabled = [];
                    <xsl:if test="/root/modules/module_webinar/@active != '1'">
                        mainMenuTabDisabled.push('#cti_main_tabs_webinar');
                    </xsl:if>
                </script>
            </head>

            <body class="main">
                <xsl:if test="/root/@googleTagManager != ''">
                    <!-- Google Tag Manager (noscript) -->
                    <noscript>
                        <iframe height="0" width="0" style="display:none;visibility:hidden">
                            <xsl:attribute name="src">https://www.googletagmanager.com/ns.html?id=<xsl:value-of select="/root/@googleTagManager" /></xsl:attribute>
                        </iframe>
                    </noscript>
                    <!-- End Google Tag Manager (noscript) -->
                </xsl:if>

                <div id="cti_loaded_modules" class="hidden_block">
                    <xsl:value-of select="/root/js_modules_names" />
                </div>

                <noscript><div style="width: 100%; text-align: center; color: #FFF">Your browser does not support JavaScript or JavaScript turned off</div></noscript>

                <div valign="top">
	                <div id="cti_main_tabs">
	                	<div id="top_Header_main" class="top_Header_main">
	                		<div id="top_Header">

                                <div id="Logo">
                                    <xsl:choose>
                                        <xsl:when test="/root/@isTopLinkEnabled = 1">
                                            <a class="logo_link flex-container" href="" target="_blank">
                                                <xsl:attribute name="href"><xsl:value-of select="/root/@site" /></xsl:attribute>
                                                <img src="">
                                                    <xsl:attribute name="src">../<xsl:value-of select="/root/@logo" /></xsl:attribute>
                                                </img>
                                            </a>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <img src="">
                                                <xsl:attribute name="src">../<xsl:value-of select="/root/@logo" /></xsl:attribute>
                                            </img>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </div>

			                    <div class="searchbox flex-container">
			                        <xsl:apply-templates select="/root/modules/module_roster/searchbox"/>
			                        <xsl:apply-templates select="/root/modules/module_roster/click2call"/>
                                    <div class="select-device-wrap"><div id="select-device" tabindex="-1"></div></div>
                                    <div id="click2call_noconnection" >
                                        <i class="fa fa-ban"></i>
                                    </div>
                                    <xsl:if test="((/root/modules/module_sms/@enabled = '1') or (/root/modules/module_fax/@enabled = '1') or (/root/modules/module_postit/button_icon/@enabled = '1'))">
                                        <button id="module_roster_more_actions_btn" class="tooltip">
                                            <div class="tooltip-text tooltip-bottom">
                                                <xsl:value-of select="/root/trans_texts/buttons.Add"/>
                                            </div>
                                        </button>
                                    </xsl:if>
                                    <xsl:if test="/root/modules/module_video_conference/@enabled = '1'">
                                        <button id="module_video_conference_list_btn" class="roster-video-conference-btn-icon tooltip">
                                            <div class="tooltip-text tooltip-bottom">
                                                <xsl:value-of select="/root/trans_texts/conference.create_video_conference"/>
                                            </div>
                                        </button>
                                    </xsl:if>
			                    </div>

                                <div class="main-menu-col-wrap">
                                    <ul class="main-menu-col flex-container">

                                        <xsl:if test="/root/modules/module_roster/@enabled = '1'">
                                            <xsl:apply-templates select="/root/modules/module_roster/tab"/>
                                            <xsl:apply-templates select="/root/modules/module_function_keys/tab"/>
                                            <xsl:apply-templates select="/root/modules/module_chat/tab"/>
                                        </xsl:if>

                                        <xsl:if test="/root/modules/module_phonebook">
                                            <xsl:apply-templates select="/root/modules/module_phonebook/tab"/>
                                        </xsl:if>
                                        <xsl:if test="/root/modules/module_history/@enabled = '1'">
                                            <xsl:apply-templates select="/root/modules/module_history/tab"/>
                                        </xsl:if>
                                        <xsl:if test="/root/modules/module_voicemail/@enabled = '1'">
                                            <xsl:apply-templates select="/root/modules/module_voicemail/tab"/>
                                        </xsl:if>
                                        <xsl:if test="/root/modules/module_webinar/@enabled = '1'">
                                            <xsl:apply-templates select="/root/modules/module_webinar/tab"/>
                                        </xsl:if>
                                        <xsl:if test="/root/modules/module_web_app/@enabled = '1'">
                                            <xsl:apply-templates select="/root/modules/module_web_app/tab"/>
                                        </xsl:if>
                                        <xsl:if test="/root/modules/module_settings">
                                            <xsl:apply-templates select="/root/modules/module_settings/tab"/>
                                        </xsl:if>
                                        <li id="cti_main_tabs_other_tab">
                                            <a href="#cti_main_tabs_other" class="cti_main_tabs_other_tab_a tooltip">
                                                <div class="tooltip-text tooltip-bottom">
                                                    <xsl:value-of select="/root/trans_texts/link.Other"/>
                                                </div>
                                                <svg class="icon fa-sort-desc sort-desc" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
                                                    <use xlink:href="../css/icons-sprite.svg#icon_arrow_main"/>
                                                </svg>
                                            </a>
                                        </li>
                                    </ul>
                                </div>

                                 <div class="profile-wrap flex-container">
                                     <div class="user_login_info flex-container">
                                         <div class="avatar">
                                             <a href='#' id="userpic" class="avatar_exists tooltip-multiline">
                                                 <xsl:if test="/root/modules/module_main/avatar">
                                                     <img id="module_main_avatar_image">
                                                         <xsl:attribute name="src"><xsl:value-of select="/root/modules/module_main/avatar"/></xsl:attribute>
                                                     </img>
                                                 </xsl:if>
                                             </a>
                                             <div class="status-box">
                                                 <xsl:apply-templates select="/root/modules/module_roster/my-icon"/>
                                             </div>
                                         </div>
                                         <div class="nickname_div">
                                             <div id="myNickname" class="nickName user-info-item"><xsl:value-of select="/root/modules/module_main/texts/user_name"/></div>
                                             <div id="myHeaderStatus" class="user-info-item"></div>
                                             <div id="myHeaderLocation" class="user-info-item"></div>
                                         </div>
                                         <a class="status-arrow" href="#">
                                             <svg class="icon" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
                                                 <use xlink:href="../css/icons-sprite.svg#icon_arrow_dropdown"/>
                                             </svg>
                                         </a>

                                         <div id="main-options-select" class="dropdown-wrap block_shadow_header">
                                             <div class="user-info">
                                                 <div class="nickName">
                                                     <xsl:value-of select="/root/modules/module_main/texts/user_name"/>
                                                 </div>
                                                 <div class="myHeaderLocation"></div>
                                                 <span class="myHeaderStatus"></span>
                                             </div>

                                             <ul>
                                                 <xsl:if test="/root/@quickStatusAllow = '1'">
                                                     <li class="change-status">
                                                         <a href="#">
                                                             <div class="advanced-btn flex-container">
                                                                 <span class="myStatusImg flex-container">
                                                                     <span class="stat"></span>
                                                                 </span>

                                                                 <span class="label item-text">
                                                                     <xsl:value-of select="/root/trans_texts/hint.ChangeOnlineStatus"/>
                                                                 </span>
                                                             </div>
                                                         </a>
                                                     </li>

                                                     <li><hr></hr></li>

                                                     <xsl:if test="/root/@ipad != '1'">
                                                         <li>
                                                             <a href="javascript:void(0)" id="user_settings_image_edit_btn">
                                                                 <svg class="icon" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
                                                                     <use xlink:href="../css/icons-sprite.svg#icon_edit"/>
                                                                 </svg>
                                                                 <span class="item-text">
                                                                     <span>
                                                                         <xsl:value-of select="/root/trans_texts/buttons.Edit" />
                                                                     </span>
                                                                     <span>
                                                                         <xsl:value-of select="/root/trans_texts/settings.avatar_editor.LabelAvatar" />
                                                                     </span>
                                                                 </span>
                                                             </a>
                                                         </li>
                                                     </xsl:if>
                                                 </xsl:if>

                                                 <li><hr></hr></li>

                                                 <li>
                                                     <a target="_top" id="logout_btn" onclick="return false">
                                                         <svg class="icon" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
                                                             <use xlink:href="../css/icons-sprite.svg#icon_logout"/>
                                                         </svg>
                                                         <span class="item-text"><xsl:value-of select="/root/trans_texts/buttons.Logout"/></span>
                                                     </a>
                                                 </li>
                                             </ul>
                                         </div>
                                     </div>

                                     <div class="custom_logo_wrapper flex-container">
                                         <xsl:if test="/root/modules/module_main/custom_logo">
                                             <img class="custom_logo">
                                                 <xsl:attribute name="src"><xsl:value-of select="/root/modules/module_main/custom_logo"/></xsl:attribute>
                                                 <xsl:attribute name="title"><xsl:value-of select="/root/trans_texts/strings.providedBy" /></xsl:attribute>
                                             </img>
                                         </xsl:if>
                                     </div>
                                 </div>

		                	</div>

		                <div id="cti_main_tabs_map" style="display:none;"></div>
		                <div id="cti_main_tabs_other" class="cti_main_tabs_other dropdown-wrap block_shadow_header">
		                	<ul>
			                	<xsl:if test="/root/modules/module_cdrview/@enabled = '1'">
		                            <xsl:if test="/root/@ipad != 1">
		                                <xsl:apply-templates select="/root/modules/module_cdrview/tab"/>
		                            </xsl:if>
			                    </xsl:if>

                                <xsl:if test="/root/modules/module_x_caracal/@enabled = '1'">
                                    <xsl:apply-templates select="/root/modules/module_x_caracal/tab"/>
                                </xsl:if>

                                <xsl:if test="/root/modules/module_roster/@enabled = '1'">
                                     <li>
                                         <a href="javascript:void(0)" class="link-map">
                                             <svg class="icon icon_indent" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
                                                 <use xlink:href="../css/icons-sprite.svg#icon_location"/>
                                             </svg>
                                             <span class="item-text"><xsl:apply-templates select="/root/trans_texts/roster.MapView"/></span>
                                         </a>
                                     </li>
                                 </xsl:if>

                                <li><hr></hr></li>

			                    <xsl:if test="/root/modules/module_roster/@enabled = '1'">
                                    <xsl:if test="/root/modules/module_roster/@see_colleague = '1'">
                                        <li>
                                            <a href='javascript:void(0)' class="link-edit-colleagues">
                                                <svg class="icon" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
                                                    <use xlink:href="../css/icons-sprite.svg#icon_edit-colleagues"/>
                                                </svg>
                                                <span class="item-text"><xsl:value-of select="/root/trans_texts/roster.menu.EditColleagues" /></span>
                                            </a>
                                        </li>
                                    </xsl:if>
                                    <li>
                                        <a href='javascript:void(0)' class="link-offline-users">
                                            <svg class="icon" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
                                                <use xlink:href="../css/icons-sprite.svg#icon_hide"/>
                                            </svg>
                                            <span class="item-text"><xsl:value-of select="/root/trans_texts/Options.HideOfflineUsers" /></span>
                                        </a>
                                    </li>

                                    <li><hr></hr></li>

                                    <li>
                                        <a href='javascript:void(0)' class="link-show-post-it">
                                            <svg class="icon icon_indent" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
                                                <use xlink:href="../css/icons-sprite.svg#icon_postit-hide"/>
                                            </svg>
                                            <span class="item-text"><xsl:value-of select="/root/trans_texts/roster.ConfigBtn.ShowPostIt" /></span>
                                        </a>
                                    </li>
				                    <li>
                                        <a href='javascript:void(0)' class="link-history-post-it">
                                            <svg class="icon icon_indent" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
                                                <use xlink:href="../css/icons-sprite.svg#icon_postit"/>
                                            </svg>
                                            <span class="item-text"><xsl:value-of select="/root/trans_texts/roster.ConfigBtn.HistoryPostIt" /></span>
                                        </a>
                                    </li>

                                    <li><hr></hr></li>
			                    </xsl:if>
			                    <xsl:if test="/root/@userKind='admin'">
			                    	<li>
			                    		<a id="managePBX_icon" href="../wms?" target="_blank">
			                    			<i class="fa fa-wrench fa-fw  flex-container"></i>
                                            <span class="item-text"><xsl:value-of select="/root/trans_texts/label.managePBX" /></span>
	                                    </a>
			                    	</li>
                                </xsl:if>

                                <xsl:if test="/root/@screen_sharing = 1">
                                    <xsl:apply-templates select="/root/modules/module_screen_sharing/room_manager_button"/>
                                </xsl:if>
                                <xsl:if test="/root/modules/module_attendant_console/@enabled = '1'">
                                    <li>
                                        <a id="attendant_console_btn" href="javascript:void(0)">
                                            <svg class="icon" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
                                                <use xlink:href="../css/icons-sprite.svg#icon_attendant-console"/>
                                            </svg>
                                            <span class="item-text"><xsl:value-of select="/root/trans_texts/AttendantConsole.open" /></span>
                                        </a>
                                    </li>
                                </xsl:if>
                                <xsl:if test="/root/modules/module_fax">
                                    <xsl:if test="/root/modules/module_fax/@enabled = '1'">
                                        <li>
                                            <a id="fax_queue_icon" href="javascript:void(0)">
                                                <svg class="icon" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
                                                    <use xlink:href="../css/icons-sprite.svg#icon_faxes"/>
                                                </svg>
                                                <span class="item-text"><xsl:value-of select="/root/trans_texts/label.OutgoingFaxes" /></span>
                                            </a>
                                        </li>
                                    </xsl:if>
                                </xsl:if>
                                <xsl:if test="((/root/modules/module_fax and /root/modules/module_fax/@enabled = '1') or /root/@userKind='admin' or /root/@screen_sharing = 1 or /root/modules/module_attendant_console/@enabled = '1')">
                                	<li><hr></hr></li>
                                </xsl:if>
                                <xsl:if test="/root/@isHelpLinkEnabled = 1">
                                    <li>
                                        <a target="_blank" href="" >
                                            <xsl:attribute name="href"><xsl:value-of select="/root/@helpLink" /></xsl:attribute>
                                            <svg class="icon" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
                                                <use xlink:href="../css/icons-sprite.svg#icon_help"/>
                                            </svg>
                                            <span class="item-text"><xsl:value-of select="/root/trans_texts/main.help"/></span>
                                        </a>
                                    </li>
                                </xsl:if>
                                <li>
                                    <a target="_blank" href="">
                                        <xsl:attribute name="href"><xsl:value-of select="/root/@licenseLink" /></xsl:attribute>
                                        <svg class="icon" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
                                            <use xlink:href="../css/icons-sprite.svg#icon_license"/>
                                        </svg>
                                        <span class="item-text"><xsl:value-of select="/root/trans_texts/main.license"/></span>&#160;

                                        <span class="license-title">
                                            <xsl:choose>
                                                <xsl:when test="/root/@licenseType = 'basic'">
                                                    <xsl:value-of select="/root/trans_texts/license.type.basic" />
                                                </xsl:when>
                                                <xsl:when test="/root/@licenseType = 'essential'">
                                                    <xsl:value-of select="/root/trans_texts/license.type.essential" />
                                                </xsl:when>
                                                <xsl:when test="/root/@licenseType = 'business'">
                                                    <xsl:value-of select="/root/trans_texts/license.type.business" />
                                                </xsl:when>
                                                <xsl:when test="/root/@licenseType = 'premium'">
                                                    <xsl:value-of select="/root/trans_texts/license.type.premium" />
                                                </xsl:when>
                                                <xsl:when test="/root/@licenseType = 'wizyconf'">
                                                    <xsl:value-of select="/root/trans_texts/license.type.wizyconf" />
                                                </xsl:when>
                                            </xsl:choose>
                                        </span>
                                    </a>
                                </li>
                                <li>
                                    <a target="_blank" href="" title="">
                                        <xsl:attribute name="title"><xsl:value-of select="/root/@version_full" /></xsl:attribute>
                                	    <xsl:attribute name="href"><xsl:value-of select="/root/@legal" /></xsl:attribute>
                                        <svg class="icon" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
                                            <use xlink:href="../css/icons-sprite.svg#icon_about"/>
                                        </svg>
                                        <span class="item-text"><xsl:value-of select="/root/trans_texts/main.About"/>&#160;<xsl:value-of select="/root/@version" /></span>
                                    </a>
                                </li>
		                    </ul>
		                    </div>
		                </div>
		                <div id="content_center">
		                    <xsl:if test="/root/modules/module_roster/@enabled = '1'">
		                        <xsl:apply-templates select="/root/modules/module_roster"/>
		                        <xsl:apply-templates select="/root/modules/module_function_keys"/>
		                        <xsl:apply-templates select="/root/modules/module_chat/tab_content"/>
		                    </xsl:if>

		                    <xsl:if test="/root/modules/module_phonebook">
		                        <xsl:apply-templates select="/root/modules/module_phonebook/tab_content"/>
		                    </xsl:if>
		                    <xsl:if test="/root/modules/module_history/@enabled = '1'">
		                        <xsl:apply-templates select="/root/modules/module_history/tab_content"/>
		                    </xsl:if>
							<xsl:if test="/root/modules/module_voicemail/@enabled = '1'">
		                        <xsl:apply-templates select="/root/modules/module_voicemail/tab_content"/>
		                    </xsl:if>
							<xsl:if test="/root/modules/module_webinar/@enabled = '1'">
		                        <xsl:apply-templates select="/root/modules/module_webinar/tab_content"/>
		                    </xsl:if>
		                    <xsl:if test="/root/modules/module_web_app/@enabled = '1'">
		                        <xsl:apply-templates select="/root/modules/module_web_app/tab_content"/>
		                    </xsl:if>
		                    <xsl:if test="/root/modules/module_cdrview/@enabled = '1'">
		                        <xsl:if test="/root/@ipad != 1">
		                            <xsl:apply-templates select="/root/modules/module_cdrview/tab_content"/>
		                        </xsl:if>
		                    </xsl:if>
		                    <xsl:if test="/root/modules/module_settings">
		                        <xsl:apply-templates select="/root/modules/module_settings"/>
		                    </xsl:if>
	                    </div>
	                </div>
	            </div>

                <div id="main_popup_dialogs_div" class="hidden_block"></div>

                <div id="user_data" class="hidden_block">
                    <xsl:value-of select="/root/user_data" />
                </div>

                <div id="licensies" class="hidden_block">
                    <xsl:value-of select="/root/licensies" />
                </div>

                <div id="user_features" class="hidden_block">
                    <xsl:value-of select="/root/user_features" />
                </div>

                <div id="user_acl" class="hidden_block">
                    <xsl:value-of select="/root/user_acl" />
                </div>

                <div id="pbx_configs" class="hidden_block">
                    <xsl:value-of select="/root/pbx_configs" />
                </div>

                <xsl:if test="/root/modules/module_main">
                   <xsl:apply-templates select="/root/modules/module_main"/>
                </xsl:if>

                <xsl:if test="/root/modules/module_chat">
                   <xsl:apply-templates select="/root/modules/module_chat"/>
                </xsl:if>

                <xsl:if test="/root/modules/module_calls">
                   <xsl:apply-templates select="/root/modules/module_calls"/>
                </xsl:if>

                <xsl:if test="/root/modules/module_roster">
                   <xsl:apply-templates select="/root/modules/module_roster/context-menu"/>
                </xsl:if>
				<xsl:if test="/root/modules/module_function_keys">
                   <xsl:apply-templates select="/root/modules/module_function_keys/context-menu"/>
                </xsl:if>
                <xsl:if test="/root/modules/module_chat">
                   <xsl:apply-templates select="/root/modules/module_chat/context-menu"/>
                </xsl:if>
                <xsl:if test="/root/modules/module_screen_sharing">
                    <xsl:apply-templates select="/root/modules/module_screen_sharing"/>
                </xsl:if>
                <xsl:if test="/root/modules/module_webrtc_zero_distance">
                    <xsl:apply-templates select="/root/modules/module_webrtc_zero_distance"/>
                </xsl:if>
                <xsl:if test="/root/modules/module_video_sharing">
                    <xsl:apply-templates select="/root/modules/module_video_sharing"/>
                </xsl:if>
				<xsl:if test="/root/modules/module_calendar">
                    <xsl:apply-templates select="/root/modules/module_calendar"/>
                </xsl:if>
                <xsl:if test="/root/@sslCertificateExpireDays >= 0">
                    <div id="ssl_certificate_expire_days" class="hidden_block">
                        <xsl:value-of select="/root/@sslCertificateExpireDays" />
                    </div>
                </xsl:if>
                <div id="preload_div" class="hidden_block">
                    <div class='img_48' rel="error_48"></div>
                </div>

                <link rel="stylesheet" type="text/css">
                    <xsl:attribute name="href">dist/app.css?version=<xsl:value-of select="/root/@version" /></xsl:attribute>
                </link>
                <script type="text/javascript">
                    <xsl:attribute name="src">dist/app.js?version=<xsl:value-of select="/root/@version" /></xsl:attribute>
                </script>

                <script type="text/javascript">
                    <xsl:attribute name="src">https://addons.wildix.com/collaboration/main.js?version=<xsl:value-of select="/root/@version" /></xsl:attribute>
                    <xsl:attribute name="async" />
                </script>

            </body>
        </html>
    </xsl:template>
</xsl:stylesheet>
