<?php

use Wildix\Core\Container;
use Wildix\System\ADSingleSignOnService;

define("DEBUG", (bool)isset($_GET['debug']));

require_once('init.php');

if (!\User::getInstance()->isLogged()) {
    $adSingleSignOn = Container::get(ADSingleSignOnService::class);

    if ($adSingleSignOn->isEnabled()) {
        // Kerberos auth: send Negotiate header at first request
        if (strpos($_SERVER['HTTP_AUTHORIZATION'], 'Negotiate ') !== 0) {

            $kerberos = Container::get(\Wildix\Auth\Kerberos\Negotiate::class);;

            $headers = $kerberos->getNegotiateHeaders();
            foreach ($headers as $header){
                header($header);
            }
        }
        // make fallback page
        $thrownData = _t('security.adSingleSignOnUnauthorized');
        require_once('../no_permissions/index.php');
        die();
    } else {
        header(sprintf('Location: ../logout/%s', $_SERVER['QUERY_STRING'] !== '' ? '?' . $_SERVER['QUERY_STRING'] : ''));
        exit;
    }
}

try {
    \CTI\Config::getInstance()->set('DEBUG', DEBUG);

    if (DEBUG) {
        error_reporting(E_ALL ^ E_NOTICE);
        ini_set('display_errors','On');
    }

    $application = new \CTI\Application();
    $application->checkBrowser();

    if ($application->isIe && empty($_COOKIE['iWantThisBrowser'])) {
        header('Location: ../not_supported_browser/');

        exit(1);
    }

    $application->init();


    /*Loading modules*/
    \CTI\Builder::getInstance()->load('Main', 'main');
    \CTI\Builder::getInstance()->load('Geolocation', 'geolocation');
    \CTI\Builder::getInstance()->load('Settings', 'settings');
    \CTI\Builder::getInstance()->load('Chat', 'chat');
    \CTI\Builder::getInstance()->load('Roster', 'roster');
    \CTI\Builder::getInstance()->load('Sms', 'sms');
    \CTI\Builder::getInstance()->load('Postit', 'postit');
    \CTI\Builder::getInstance()->load('ScreenSharing', 'screen_sharing');
    \CTI\Builder::getInstance()->load('Jabber', 'jabber');
    \CTI\Builder::getInstance()->load('Fax', 'fax');
    \CTI\Builder::getInstance()->load('Phonebook', 'phonebook');
    \CTI\Builder::getInstance()->load('ChangeStatus', 'change_status');
    \CTI\Builder::getInstance()->load('FunctionKeys', 'function_keys');
    if (!$application->isiPad) {
        \CTI\Builder::getInstance()->load('AttendantConsole', 'attendant_console');
    }
    \CTI\Builder::getInstance()->load('Calls', 'calls');
    \CTI\Builder::getInstance()->load('History', 'history');
    \CTI\Builder::getInstance()->load('Voicemail', 'voicemail');
    \CTI\Builder::getInstance()->load('WebApp', 'web_app');
    \CTI\Builder::getInstance()->load('Cdrview', 'cdrview');
    \CTI\Builder::getInstance()->load('Notes', 'notes');
    \CTI\Builder::getInstance()->load('VideoConference', 'video_conference');
    \CTI\Builder::getInstance()->load('WebRTCZeroDistance', 'webrtc_zero_distance');
    \CTI\Builder::getInstance()->load('Calendar', 'calendar');
    \CTI\Builder::getInstance()->load('VideoSharing', 'video_sharing');
    \CTI\Builder::getInstance()->load('Webinar', 'webinar');
    \CTI\Builder::getInstance()->load('Xcaracal', 'x_caracal');

    /*Check ajax request*/
    if ($application->ifAjax()) {
        if(!\Wildix\HttpSecurity\Service::isCsrf([
            'method' => $_SERVER["REQUEST_METHOD"],
            'host' => $_SERVER["HTTP_HOST"],
            'origin' => $_SERVER["HTTP_ORIGIN"],
            'referer' => $_SERVER["HTTP_REFERER"]
        ])) {
                throw new \CTI\Exception("ERROR QUERY", \CTI\Exception::ERROR_WARNING);
        }
        \CTI\Builder::getInstance()->fireEvent(
            \CTI\Helper::getInstance()->request()->getReqString('event'),
            \CTI\Helper::getInstance()->request()->getReqArray('data'),
            \CTI\Helper::getInstance()->request()->getReqString('module_name'));
    } else {
        /*Generate xml*/
        \CTI\Builder::getInstance()->make();
    }

    $application->addModules(\CTI\Builder::getInstance()->getModules());
    $application->show();

} catch (\CTI\Exception $exeption) {
    if ($exeption->getCode() == \CTI\User::ERROR_CANT_GET_USER_DATA) {
        header('Location: ../logout/');
        exit;
    }
    $exeption->printError();
}
