<?php
namespace CTI;

use Wildix\Faxes\Faxes;

/**
 * ModuleFax Class.
 */
class ModuleFax extends \CTI\DefaultModule implements \CTI\Ajax {

    public function __construct() {
        parent::__construct('Fax');
    }

    public function execute($event, $data) {
        $result = '';
        switch ($event) {
            case 'UPLOAD_FAXCOVER':
                $result = $this->uploadFaxcover();
                break;
            case 'SHOW_FAXCOVER':
                $result = $this->showFaxcover();
                break;
            case 'DELETE_FAXCOVER':
                $result = $this->deleteFaxcover();
                break;
            case 'DELETE_FAX':
                $result = $this->deleteFax($data);
                break;
            case 'DELETE_FAXES':
                $result = $this->deleteFaxes($data);
                break;
            default:
                $result = true;
                break;
        }
        return $result;
    }

    public function generate() {
        if (\CTI\Config::getInstance()->get('LICENSE_FAXES') == 1 && \CTI\User::getInstance()->get(\CTI\User::ACL, 'FAX') == 1) {
            $this->moduleTag->setAttribute('enabled', 1);
        } else {
            $this->moduleTag->setAttribute('enabled', 0);
        }

        list($faxcoverStatus, $faxcoverUrl) = $this->getFaxcoverImage();

        $this->addTag('send_fax', null, $this->moduleTag);
        $this->addTag('faxcover', null, $this->moduleTag);
        $this->addTag('fax_faxcover', null, $this->moduleTag);
        $this->addTag('fax_faxcover_status', $faxcoverStatus, $this->moduleTag);
        $this->addTag('fax_faxcover_url', $faxcoverUrl, $this->moduleTag);
        $this->addTag('fax_queue', null, $this->moduleTag);
        $this->addTag('fax_queue_icon', null, $this->moduleTag);
        $this->addTag('button', null, $this->moduleTag);
        $this->addTag('button_icon', null, $this->moduleTag);
    }

    public function getFaxcoverPath() {
        $faxcoverPath  = \CTI\Config::getInstance()->get('FAXCOVER_PATH');
        $faxcoverShare = \CTI\Config::getInstance()->get('FAXCOVER_SHARE_PATH');
        $faxShare      = \CTI\Helper::getInstance()->isCustomShareMounted($faxcoverShare);

        if ($faxShare) {
            // construct faxcover path
            $faxcoverPath = $faxcoverShare . '/';

            // add exten to path
            $extenNumber = \CTI\User::getInstance()->get(\CTI\User::USER_DATA, 'extenNumber');
            if (intval($extenNumber) != 0) {
                $faxcoverPath .= $extenNumber . '/';
            }

            // create path if not exists
            if (!file_exists($faxcoverPath)) {
                mkdir($faxcoverPath);
            }
        }
        return $faxcoverPath;
    }

    private function uploadFaxcover() {
        if (empty($_FILES['qqfile'])) {
            return json_encode(array('success' => 'fail', 'type' => 'limit'));
        }

        if ($_FILES['qqfile']['size'] == 0 && $_FILES['qqfile']['error'] == 7) {
            return json_encode(array('success' => 'true', 'filename' => '', 'type' => 'error_disk'));
        }

        if ($_FILES['qqfile']['size'] > \CTI\Config::getInstance()->get('MAX_UPLOAD_FILE_SIZE')) {
            return json_encode(array('success' => 'fail', 'type' => 'limit'));
        }
        if ($_FILES['qqfile']['type'] != 'image/jpeg') {
            return json_encode(array('success' => 'true', 'filename' => '', 'type' => 'error_type'));
        }
        if (getimagesize($_FILES['qqfile']['tmp_name']) == false) {
            return json_encode(array('success' => 'true', 'filename' => '', 'type' => 'error_type'));
        }

        $imageInfo = getimagesize($_FILES['qqfile']['tmp_name']);
        if (!$imageInfo || $imageInfo['mime'] != 'image/jpeg') {
            return json_encode(array('success' => 'true', 'filename' => '', 'type' => 'error_type', 'warn' => $_FILES['qqfile']['type']));
        }

        $filename = 'faxcover_user_' . \CTI\User::getInstance()->get(\CTI\User::USER_DATA, 'uid') . '.jpg';

        move_uploaded_file($_FILES['qqfile']['tmp_name'], $this->getFaxcoverPath() . $filename);

        list($status, $url) = $this->getFaxcoverImage();

        $result = array(
                'success' => 'true',
                'filename' => $filename,
                'faxcover_file_name' => $filename,
                'faxcover_status' => $status,
                'faxcover_url' => $url,
        );
        return json_encode();
    }

    private function showFaxcover() {
        header('Content-Type: image/jpeg');

        $filename     = 'faxcover_user_' . \CTI\User::getInstance()->get(\CTI\User::USER_DATA, 'uid') . '.jpg';
        $faxcoverPath = $this->getFaxcoverPath();

        if (file_exists($faxcoverPath . $filename)) {
            return file_get_contents($faxcoverPath . $filename);
        } else {
            return file_get_contents('data/images/blank_no_faxcover.jpg');
        }
    }

    private function getFaxcoverImage() {
        $path      = \CTI\Config::getInstance()->get('FAXCOVER_SHARE_PATH');
        $extension = \CTI\User::getInstance()->get(\CTI\User::USER_DATA, 'extenNumber');
        $uid       = \CTI\User::getInstance()->get(\CTI\User::USER_DATA, 'uid');
        $name      = 'faxcover_user_' . $uid . '.jpg';

        if (intval($extension) != 0) {
            $path .= '/' . $extension . '/' . $name;
        } else {
            $path .= '/' . $name;
        }

        if (file_exists($path)) {
            if (intval($extension) != 0) {
                return array(1, '../spoolview/faxin/' . $extension . '/' . $name);
            }

            return array(1, '../spoolview/faxin/' . $name);
        } else {
            return array(0, 'data/images/blank_no_faxcover.jpg');
        }
    }

    private function getFaxcoverFilePath() {
        $path      = \CTI\Config::getInstance()->get('FAXCOVER_SHARE_PATH');
        $extension = \CTI\User::getInstance()->get(\CTI\User::USER_DATA, 'extenNumber');
        $uid       = \CTI\User::getInstance()->get(\CTI\User::USER_DATA, 'uid');
        $name      = 'faxcover_user_' . $uid . '.jpg';

        if (intval($extension) != 0) {
            $path .= '/' . $extension . '/' . $name;
        } else {
            $path .= '/' . $name;
        }

        if (file_exists($path)) {
            return $path;
        }
        return false;
    }

    private function deleteFaxcover() {
        $path = $this->getFaxcoverFilePath();
        if ($path) {
            unlink($path);
        }

        list($status, $url) = $this->getFaxcoverImage();

        $result = array(
                'success' => 'true',
                'faxcover_status' => $status,
                'faxcover_url' => $url
        );
        return json_encode($result);
    }

    private function deleteFax($data) {
        $idFax = explode('-', urldecode($data['filename']))[3];

        return (int)(exec(sprintf('rm -f %s*%s*', Faxes::FAX_QUEUE, escapeshellarg($idFax))) !== false);
    }

    private function deleteFaxes($data) {
        $result = array(
                'status' => 'success',
                'error' => array(),
        );

        foreach ($data as $item) {
            if ($this->deleteFax(array('filename' => $item['name'])) == 0) {
                $result['error'][] = $item['name'];
            }
        }

        if (!empty($result['error'])) {
            $result['status'] = 'fail';
        }

        return json_encode($result);
    }
}
