<?php
namespace CTI;

use Wildix\Slim\Slim;
use Wildix\Core\Jabber;
use Api\Translation\Enums\LanguagesEnum;
use Api\Dictionary\Services\DictionaryService;

/**
 * ModuleSettings Class.
 */
class ModuleSettings extends \CTI\DefaultModule implements \CTI\Ajax {

    private const ALLOWED_AVATAR_MIME_TYPES = [
        'image/png',
        'image/jpeg',
    ];

    public function __construct() {
        parent::__construct('Settings');
    }

    public function execute($event, $data) {
        switch ($event) {
            case 'UPDATE_USER':
                $result = $this->saveSettings($data);
                break;
            case 'UPDATE_USER_OPTIONS':
                $result = $this->saveUserOptions($data);
                break;
            case 'UPLOAD_AVATAR':
                $result = $this->uploadAvatar($data);
                break;
            case 'REMOVE_AVATAR':
                $result = $this->removeAvatar();
                break;
            case 'GET_BASE64':
                $result = $this->getBase64();
                break;
            default:
                $result = true;
                break;
        }
        return $result;
    }

    public function getAvatarShare() {
        $avatarShare = \CTI\Config::getInstance()->get('CTICONNECT_SHARE_UPLOADS');
        return $avatarShare;
    }

    private function getBase64() {
        if (empty($_FILES['qqfile'])) {
            return json_encode(array('success' => 'fail', 'type' => 'limit'));
        }

        if ($_FILES['qqfile']['size'] == 0 && $_FILES['qqfile']['error'] == 7) {
            return json_encode(array('success' => 'true', 'filename' => '', 'type' => 'error_disk'));
        }

        if ($_FILES['qqfile']['size'] > \CTI\Config::getInstance()->get('MAX_UPLOAD_FILE_SIZE')) {
            return json_encode(array('success' => 'fail', 'type' => 'limit'));
        }
        if (getimagesize($_FILES['qqfile']['tmp_name']) == false) {
            return json_encode(array('success' => 'true', 'filename' => '', 'type' => 'error_type'));
        }
        // Where is filename var ????
        $filename = false;
        move_uploaded_file($_FILES['qqfile']['tmp_name'], $this->getAvatarShare() . $filename);

        $base = base64_encode(file_get_contents($_FILES['qqfile']['tmp_name']));

        return json_encode(array('success' => 'true', 'filename' => 'data:' . $_FILES['qqfile']['type'] . ';base64,' . $base));
    }

    private function removeAvatar() {
        $path = 'user_avatar_' . \CTI\User::getInstance()->get(\CTI\User::USER_DATA, 'uid');

        $filename = $path . '.png';
        if (file_exists($filename)) {
            unlink($filename);
        }
        $filename = $path . '.jpg';
        if (file_exists($filename)) {
            unlink($filename);
        }
        \WMS_Ldap::getInstance()->update(\CTI\User::getInstance()->get(\CTI\User::USER_DATA, 'dn'), array('imageUrl' => ''));
        return json_encode(array('success' => 'true'));
    }

    private function uploadAvatar($data) {
        $filename = 'user_avatar_' . \CTI\User::getInstance()->get(\CTI\User::USER_DATA, 'uid') . '.png';

        if (!empty($data['filebase64'])) {
            $patch = $this->getAvatarShare() . $filename;
            if (file_put_contents($patch, base64_decode($data['filebase64'])) !== false) {
                $fileInfo = new \finfo(FILEINFO_MIME);
                $fileType = $fileInfo->file($patch, FILEINFO_MIME_TYPE);
                if (!in_array($fileType, self::ALLOWED_AVATAR_MIME_TYPES, true)) {
                    return json_encode(array('success' => 'fail', 'type' => 'error_file_type'));
                }

                // del old avatar
                $oldAvatar = $this->getAvatarShare() . 'user_avatar_' . \CTI\User::getInstance()->get(\CTI\User::USER_DATA, 'uid') . '.jpg';
                if (file_exists($oldAvatar)) {
                    unlink($oldAvatar);
                }

                $avatarUrl = '/cticonnect/cticonnect_share/' . $filename . '?' . rand(10000, 99999);
                \WMS_Ldap::getInstance()->update(\CTI\User::getInstance()->get(\CTI\User::USER_DATA, 'dn'), array('imageUrl' => $avatarUrl));
                return json_encode(array('success' => 'true', 'filename' => $avatarUrl));
            }
            return json_encode(array('success' => 'fail', 'type' => 'error_save_avatar' ));
        }
    }

    public function generate() {
        $this->addTag('user_options', $this->getUserOptions(), $this->moduleTag);
        $this->addTag('tab', null, $this->moduleTag);

        $textsTag = $this->addTag('texts', null, $this->moduleTag);

        $ctiUser     = \CTI\User::getInstance();
        $ctiConfig   = \CTI\Config::getInstance();
        $wmsSettings = \Wildix\SipRtp::getInstance()->getGeneralSip();
        $this->moduleTag->setAttribute('WMS_TOS', $wmsSettings['tos']);

        $this->moduleTag->setAttribute('fax_share_enabled', (bool)$ctiConfig->get('IS_FAX_SHARE_MOUNTED'));
        $this->moduleTag->setAttribute('pro_license_enabled', (bool)$ctiConfig->get('LICENSE_PRO'));
        $this->moduleTag->setAttribute('chat_history_import_export_acl_enabled', (bool)$ctiUser->get(\CTI\User::ACL, 'CTI_PRO'));
        $this->moduleTag->setAttribute('personal_info_acl_enabled', (bool)$ctiUser->get(\CTI\User::ACL, 'P_INFO'));
        $this->moduleTag->setAttribute('fax_server_acl_enabled', (bool)$ctiUser->get(\CTI\User::ACL, 'FAXSERVERSET'));
        $this->moduleTag->setAttribute('function_keys_acl_enabled', (bool)$ctiUser->get(\CTI\User::ACL, 'FKEYS'));
        $this->moduleTag->setAttribute('defstatus_settings_enabled', (bool)$ctiUser->get(\CTI\User::ACL, 'QUICK_STATUS'));
        $this->moduleTag->setAttribute('callgroups_settings_enabled', (bool)$ctiUser->get(\CTI\User::ACL, 'CONTACT_CENTER'));
        $this->moduleTag->setAttribute('force_call_forward_acl_enabled', (bool)$ctiUser->get(\CTI\User::ACL, 'FCF'));
        $this->moduleTag->setAttribute('busy_call_forward_acl_enabled', (bool)$ctiUser->get(\CTI\User::ACL, 'BCF'));
        $this->moduleTag->setAttribute('unavailable_call_forward_acl_enabled', (bool)$ctiUser->get(\CTI\User::ACL, 'UCF'));
        $this->moduleTag->setAttribute('call_waiting_acl_enabled', (bool)$ctiUser->get(\CTI\User::ACL, 'CW'));
        $this->moduleTag->setAttribute('dial_timeout_acl_enabled', (bool)$ctiUser->get(\CTI\User::ACL, 'TOUT'));
        $this->moduleTag->setAttribute('enable_mobility_with_timeout_acl_enabled', (bool)$ctiUser->get(\CTI\User::ACL, 'MEXT'));
        $this->moduleTag->setAttribute('mobility_confirmation_acl_enabled', (bool)$ctiUser->get(\CTI\User::ACL, 'MOBCONFIRMATION'));
        $this->moduleTag->setAttribute('do_not_disturb_acl_enabled', (bool)$ctiUser->get(\CTI\User::ACL, 'DND'));
        $this->moduleTag->setAttribute('timetable_acl_enabled', (bool)$ctiUser->get(\CTI\User::ACL, 'STIME'));
        $this->moduleTag->setAttribute('state_3_switch_acl_enabled', (bool)$ctiUser->get(\CTI\User::ACL, '3SWITCH'));
        $this->moduleTag->setAttribute('switch_acl_enabled', (bool)$ctiUser->get(\CTI\User::ACL, 'SWITCH'));
        $this->moduleTag->setAttribute('see_extensions', (bool)$ctiUser->get(\CTI\User::ACL, 'SEE_EXTENSIONS'));
        $this->moduleTag->setAttribute('notify_missed_calls_via_email_acl_enabled', (bool)$ctiUser->get(\CTI\User::ACL, 'EMAILMCN'));
        $this->moduleTag->setAttribute('notify_missed_calls_via_sms_acl_enabled', (bool)$ctiUser->get(\CTI\User::ACL, 'SMSMCN'));
        $this->moduleTag->setAttribute('custom_ringtone_acl_enabled', (bool)$ctiUser->get(\CTI\User::ACL, 'RING'));
        $this->moduleTag->setAttribute('use_and_see_voicemail_acl_enabled', $this->canUseSeeVoicemails($ctiUser));

        if ($ctiUser->get(\CTI\User::ACL, 'CTI_PO') != 1 && $ctiConfig->get('LICENSE_CALL_MAN') != 1) {
            $this->moduleTag->setAttribute('po_license_enabled', false);
        } else if ($ctiConfig->get('LICENSE_CALL_MAN') != 1) {
            $this->moduleTag->setAttribute('po_license_enabled', false);
        } else if ($ctiUser->get(\CTI\User::ACL, 'CTI_PO') != 1) {
            $this->moduleTag->setAttribute('po_acl_enabled', false);
        } else {
            $this->moduleTag->setAttribute('po_license_enabled', true);
            $this->moduleTag->setAttribute('po_acl_enabled', true);
        }
        if ($ctiConfig->get('LICENSE_FAXES') != 1 && $ctiUser->get(\CTI\User::ACL, 'FAX') != 1) {
            $this->moduleTag->setAttribute('fax_license_enabled', false);
        } else if ($ctiConfig->get('LICENSE_FAXES') != 1) {
            $this->moduleTag->setAttribute('fax_license_enabled', false);
        } else if ($ctiUser->get(\CTI\User::ACL, 'FAX') != 1) {
            $this->moduleTag->setAttribute('fax_acl_enabled', false);
        } else {
            $this->moduleTag->setAttribute('fax_license_enabled', true);
            $this->moduleTag->setAttribute('fax_acl_enabled', true);
        }

        if ($ctiConfig->get('LICENSE_CONFERENCE') == 1
            && $ctiConfig->get('LICENSE_PRO') == 1
            && $ctiUser->get(\CTI\User::ACL, 'BROWSER_PHONE') == 1
        ) {
            $this->moduleTag->setAttribute('webrtc_zero_distance_settings_enabled', true);
        } else {
            $this->moduleTag->setAttribute('webrtc_zero_distance_settings_enabled', false);
        }

        $this->addTag('user_uid', $ctiUser->get(\CTI\User::USER_DATA, 'uid'), $textsTag);

        $this->addTag('edit_user_block', null, $this->moduleTag);
        $this->addTag('options', null, $this->moduleTag);
        $this->addTag('features', null, $this->moduleTag);
        $this->addTag('phone', null, $this->moduleTag);
        $this->addTag('defstatus', null, $this->moduleTag);
        $this->addTag('contacts', null, $this->moduleTag);
        $this->addTag('call_groups', null, $this->moduleTag);
        $this->addTag('faxcover_options', null, $this->moduleTag);
        $this->addTag('callgroups', null, $this->moduleTag);

        $this->addTag('webrtc_zero_distance', null, $this->moduleTag);
        $this->addTag('tools', null, $this->moduleTag);
        $this->addTag('extensions', null, $this->moduleTag);

        // if signon active direct, hide edit password
        $enable = true;
        if (file_exists('/rw2/etc/pbx/ad_connect.conf')) {
            $ad = parse_ini_file('/rw2/etc/pbx/ad_connect.conf', false, INI_SCANNER_RAW);
            if (!empty($ad['host'])) {
                $enable = false;
            }
        }
        $this->moduleTag->setAttribute('password_edit_enabled', $enable);
    }

    private function canUseSeeVoicemails($ctiUser) {
        $aclCanUseVoicemail = $ctiUser->get(\CTI\User::ACL, \Wildix\Colleagues\Colleague::VOICEMAIL);

        if (!$aclCanUseVoicemail) {
            return false;
        }

        $aclCanSeeVoicemail = $ctiUser->get(\CTI\User::ACL, \Wildix\Colleagues\Colleague::SEE_VOICEMAIL);

        if (!is_array($aclCanSeeVoicemail)) {
            return false;
        }

        $canSee = false;

        foreach ($aclCanSeeVoicemail as $groupAcl) {
            if ($groupAcl) {
                $canSee = true;
                break;
            }
        }

        return $canSee;
    }

    private function saveSettings($data) {
        $ldapData = array();
        $user     = User::getInstance();
        \User::getInstance()->clearSessionCache();

        if (isset($data['fax'])) {
            $ldapData['facsimileTelephoneNumber'] = $data['fax'];
        }
        $ldapData['mobile']            = $data['mobile'];
        $ldapData['mail']              = $data['email'];
        $ldapData['preferredLanguage'] = $data['lang'];

        $_SESSION['email'] = $data['email'];

        $id = $user->get(\CTI\User::USER_DATA, 'uid');

        $features = getUserFeatures($id);

        if (!is_array($features)) {
            throw new \CTI\Exception('CAN`T GET FEATURES', \CTI\Exception::ERROR_WARNING);
        }

        $features['POPUPURL'] = $data['POPUPURL'];
        $features['WEBAPP']   = $data['WEBAPP'];
        $features['WEBPUSH']  = $data['WEBPUSH'];
        $features['HOTKEY']   = $data['HOTKEY'];
        $features['DATETIME'] = $data['DATETIME'];
        $features['ROAD']     = $data['ROAD'];
        $features['THEME']    = $data['THEME'] === 'dark' ? 'dark' : 'default';

        saveFeaturesToUserFile($id, $features);

        if (!$this->isAllowToSavePhones($user->get($user::USER_DATA, 'wOfficePhone'), $data['mobile'])) {
            throw new \CTI\Exception(\CTI\Helper::getInstance()->lng('strings.CanNotEqualOffice'), \CTI\Exception::ERROR_WARNING);
        }

        if ($this->_isUserDataPresent($data['mobile'], $data['email']) === 'mobile') {
            throw new \CTI\Exception(\CTI\Helper::getInstance()->lng('settings.personal.MobileNumber.AlreadyExists'), \CTI\Exception::ERROR_WARNING);
        }

        if ($this->_isUserDataPresent($data['mobile'], $data['email']) === 'mail') {
            throw new \CTI\Exception(\CTI\Helper::getInstance()->lng('settings.personal.MailAddress.AlreadyExists'), \CTI\Exception::ERROR_WARNING);
        }

        if (!in_array($data['lang'], LanguagesEnum::getEnumKeys(), true)) {
            throw new \CTI\Exception(\CTI\Helper::getInstance()->lng('settings.personal.InvalidLanguage'), \CTI\Exception::ERROR_WARNING);
        }

        return \WMS_Ldap::getInstance()->update(\CTI\User::getInstance()->get($user::USER_DATA, 'dn'), $ldapData);
    }

    /**
     * Check is allow to save phones phones
     *
     * @param string $phoneOne Phone number.
     * @param string $phoneTwo Phone number.
     *
     * @return boolean
     */
    private function isAllowToSavePhones($phoneOne = '', $phoneTwo = '') {
        return empty($phoneOne)
            || empty($phoneTwo)
            || preg_replace('/\D/', '', strval($phoneOne)) !== preg_replace('/\D/', '', strval($phoneTwo));
    }

    /**
     * Check whenever another user has the same mobile number.
     *
     * @param string $mobile Mobile number.
     * @param string $mail   Mail address.
     *
     * @return mixed
     */
    private function _isUserDataPresent($mobile = '', $mail = '') {
        $uidExpr = '(!(uid=' . \CTI\User::getInstance()->get(\CTI\User::USER_DATA, 'uid') . '))';
        $addExpr = '(|';
        if ($mobile != '') {
            $addExpr .= '(mobile=' . $mobile . ')';
        }
        if ($mail != '') {
            $addExpr .= '(mail=' . $mail . ')';
        }
        $addExpr .= ')';
        $search   = \WMS_Ldap::getInstance()->getEntries(\WMS_Ldap::PERSONS, $uidExpr . $addExpr, array('cn', 'mobile', 'mail'));
        if (!empty($search)) {
            if ($mobile != '' && $mobile == $search[0]['mobile']) {
                return 'mobile';
            }
            if ($mail != '' && $mail == $search[0]['mail']) {
                return 'mail';
            }
        }
        return false;
    }

    private function getUserOptions() {
        $data = \CTI\User::getInstance()->get(\CTI\User::FEATURES, 'CTIOPTIONS');
        if ($data) {
            return $data;
        }
        $data = array(
                'hide_offline_users' => 0,
                'fax_options_from_company' => '',
                'fax_options_stationid' => '',
                'fax_options_headerinfo' => '',
                'show_notifications_in_dnd' => 0,
                'unread_messages_via_email' => 0
        );
        return base64_encode(json_encode($data));
    }

    private function _isCallGroupEmpty($callGroupList) {
        return empty($callGroupList) || $callGroupList === [1 => [ 'id' => '' ]];
    }

    private function _arrayValues($array) {
        if ($this->_isCallGroupEmpty($array)) {
            return $array;
        }
        $arrayValues = [];
        arsort($array);
        foreach ($array as $key => $item) {
            array_push($arrayValues, $item);
        }

        return $arrayValues;
    }

    private function saveUserOptions($data) {
        $id = \CTI\User::getInstance()->get(\CTI\User::USER_DATA, 'uid');

        $user = \Wildix\Colleagues\Colleagues::getInstance()->getUserByID($id);

        $features = getUserFeatures($id);

        if (!is_array($features)) {
            throw new \CTI\Exception('CAN`T GET FEATURES', \CTI\Exception::ERROR_WARNING);
        }

        $defaultCallGroups = empty($features['CALLCENTER']['callGroups']) ? [] : [1 => [ 'id' => '' ]];

        $newSettings = [
            'enable'     => $data['callCenterMode'],
            'statusSync' => $data['callsChat'],
            'callGroups' => $data['callGroups'] ?? $defaultCallGroups,
        ];

        $ctioptions = json_decode(base64_decode($features['CTIOPTIONS']), true);

        if (((int)$data['unread_messages_via_email'] !== (int)$ctioptions['unread_messages_via_email'])
            && ($data['unread_messages_via_email'] !== null)
            && ($user !== null)
        ) {
            $ctioptions['unread_messages_via_email'] = (int)$data['unread_messages_via_email'];
            \Wildix\Ejabberd::getInstance()->setUnreadMessagesViaEmail($user->getExtension(), $data['unread_messages_via_email']);
        }

        $features['CTIOPTIONS'] = base64_encode(json_encode($ctioptions));

        if (isset($data['callCenterMode'])) {
            $isCallGroupsDifferent = $this->_arrayValues($newSettings['callGroups']) !== $this->_arrayValues($features['CALLCENTER']['callGroups']);

            if (count(array_diff_assoc($newSettings, $features['CALLCENTER'])) !== 0 || $isCallGroupsDifferent) {
                $contactCenter = new \Wildix\ContactCenter\ContactCenter(\Wildix\CallweaverManager::getInstance());

                if ($data['callCenterMode'] == '1') {
                    if ($data['callsChat'] == 1 && ($data['status'] == 'away' || $data['status'] == 'dnd')) {
                        $paused = 1;
                    } else {
                        $paused = 0;
                    }

                    $contactCenter->enable($data['userExtension'], $data['callGroups'], $paused);
                } else if ($data['callCenterMode'] == '0') {
                    $contactCenter->disable($data['userExtension']);
                }

                Jabber::setCallcenterMode($data['userExtension'], $data['callsChat']);

                $features['CALLCENTER']['enable']          = $data['callCenterMode'];
                $features['CALLCENTER']['statusSync']      = $data['callsChat'];
                $features['CALLCENTER']['callGroups']      = $newSettings['callGroups'];
                $features['CALLCENTER']['CALLCENTER_MODE'] = $data['callCenterMode'];
            }
        } else if (isset($data['show_notifications_in_dnd'])) {
            $features['AUTOAWAY'] = $data['AUTOAWAY'];

            $ctioptions = json_decode(base64_decode($features['CTIOPTIONS']), true);
            $ctioptions['show_notifications_in_dnd'] = intval($data['show_notifications_in_dnd']);

            $features['CTIOPTIONS'] = base64_encode(json_encode($ctioptions));
            $features['DEFSTATUS']  = array();

            if (isset($data['DEFSTATUS'])) {
                $features['DEFSTATUS'] = $data['DEFSTATUS'];
            }
        } else {
            $settings   = json_decode(base64_decode($data['settings']), true);
            $ctioptions = json_decode(base64_decode($features['CTIOPTIONS']), true);
            $result     = array_merge($ctioptions, $settings);


            unset(
                $result['call_type'],
                $result['play_sounds'],
                $result['show_calls_notifications']
            );

            $features['CTIOPTIONS'] = base64_encode(json_encode($result));
            // Trying to save options in lua file. (function included from wms)
        }
        saveFeaturesToUserFile($id, $features);
        return 1;
    }
}
