<?php
namespace CTI;

use Api\Analytics\Caracal\Services\CaracalService;
use Services\ShellHelper;
use Wildix\License;

/**
 * ModuleXcaracal Class.
 */
class ModuleXcaracal extends \CTI\DefaultModule {

    const ACL_NAME = 'CTI_CDR_VIEW';

    const ALLOWED_USER_LICENSES = [
        License::TYPE_PREMIUM,
        License::TYPE_WIZYCONF,
    ];

    const ALLOWED_PBX_LICENSES = [
        License::TYPE_BUSINESS,
        License::TYPE_PREMIUM,
        License::TYPE_WIZYCONF,
    ];

    const MIN_ALLOWED_LICENSES = 11;

    const MIN_ALLOWED_PREMIUM_LICENSES = 1;

    public function __construct() {
        parent::__construct('X_Caracal');
    }

    public function generate() {
        $enabled = $this->isCaracalInstalled()
            && $this->isAllowedUserLicense()
            && $this->isAllowedPbxLicenses()
            && $this->isAllowedPermission()
            && License::getInstance()->haveLicense(License::TYPE_XCARACAL);

        $this->moduleTag->setAttribute('enabled', $enabled);
        $this->addTag('tab', null, $this->moduleTag);
        $this->addTag('tab_content', null, $this->moduleTag);
    }

    private function isCaracalInstalled(): bool {
        return ShellHelper::isActiveService(CaracalService::PROCESS_NAME);
    }

    private function isAllowedUserLicense() {
        $licenseType = User::getInstance()->get(User::USER_DATA, 'licenseType');
        return in_array($licenseType, self::ALLOWED_USER_LICENSES);
    }

    private function isAllowedPbxLicenses() {
        $pbxLicenses        = License::getInstance()->getLimitations();
        $licensesLimitation = $pbxLicenses[License::LIMITATION_LICENSE_TYPE];

        $countAvailable = 0;
        foreach (self::ALLOWED_PBX_LICENSES as $typeLicense) {
            $countAvailable += $licensesLimitation[$typeLicense];
        }

        return $licensesLimitation[License::TYPE_PREMIUM] >= self::MIN_ALLOWED_PREMIUM_LICENSES
            && $countAvailable >= self::MIN_ALLOWED_LICENSES;
    }

    private function isAllowedPermission(): bool {
        return User::getInstance()->get(User::ACL, self::ACL_NAME);
    }
}
