<?php

use Api\Trunks\Fxo\Interfaces\FxoTrunkServiceInterface;
use Api\Trunks\Pstn\Interfaces\PstnTrunkServiceInterface;
use Api\Trunks\Sip\Builder\SettingsKamailioBuilder;
use Api\Trunks\Sip\Interfaces\SipTrunkServiceInterface;
use Logger\Log;
use Services\LdapService;
use Wildix\Core\Container;
use Wildix\Databases\AvatarCache;
use Wildix\Dialplan\ExtensionsVariables;
use Wildix\Dialplan\IncomingCalls;
use Wildix\HttpSecurity\Service;
use Wildix\LanguageAndRegion;
use Wildix\License;
use Wildix\PBXes\Network\Client;
use Wildix\PBXes\Network\NetRepository;
use Wildix\PBXes\Network\NetworkServices;
use Wildix\PBXes\PBX as PBXModel;
use Wildix\Settings\Env\EnvConfig;
use Wildix\SipRtp;
use Wildix\Sms\SmsService;
use Wildix\TlsSecurity\ModelSettings as TlsModelSettings;
use Wildix\TlsSecurity\Repository as TlsRepository;

require_once('init.php');
require_once('classes/network/network.class.php');
require_once('classes/aclpbx/aclpbx.class.php');
require_once('features/features.functions.php');
require_once('classes/multipbx.class.php');
require_once('pbx_settings/sip_rtp.functions.php');

// ----------------- functions to upgrade structure and others from WMS2 to WMS3 ---------------------
function update_devdb(){
    if(!file_exists(\Wildix\Databases\Database::WILDIX_DEVDB)){
        exec('/usr/sbin/init_devdb');
    }
    \Wildix\Databases\DEVDB::getInstance()->createTable(\Wildix\Databases\DEVDB::TABLE_WAIR_NETWORKS);
    \Wildix\Databases\DEVDB::getInstance()->createTable(\Wildix\Databases\DEVDB::TABLE_WAIR_GATEWAYS);
    \Wildix\Databases\DEVDB::getInstance()->createTable(\Wildix\Databases\DEVDB::TABLE_WAIR_USERS);

    //--------------Checking Autoprov DB structure
    $autoprovInfo = \Wildix\Databases\DEVDB::getInstance()->getTableInfo(\Wildix\Databases\DEVDB::TABLE_AUTOPROV);
    if(empty($autoprovInfo['token'])){
        \Wildix\Databases\DEVDB::getInstance()->exec('ALTER TABLE `autoprov` ADD COLUMN `token` varchar(32);');
    }

    //--------------Checking W-AIR DB structure
    $queriesUID = array();
    $wairUsersInfo = \Wildix\Databases\DEVDB::getInstance()->getTableInfo(\Wildix\Databases\DEVDB::TABLE_WAIR_USERS);
    if(empty($wairUsersInfo['uid']) && !empty($wairUsersInfo['display_name'])){
        $res = array();
        try {
            $result = \Wildix\Databases\DEVDB::getInstance()->query('SELECT `slot_id`,`display_name`,`mac` FROM wair_users ORDER BY slot_id');
            while ($row = $result->fetchArray(SQLITE3_ASSOC)){
                $res[] = $row;
            }
            if($result){
                $result->finalize();
            }
        } catch (Exception $e) {

        }
        $isColumnIPEIExists = false;
        foreach ($res as $value) {
            if (isset($value['name'])) {
                if ($value['name'] == 'ipei') {
                    $isColumnIPEIExists = true;
                    continue;
                }
            }
        }

        $insertQuery ='INSERT INTO `wair_users` (`slot_id`,`uid`,`mac`) VALUES ';
        $increment = 0;

        foreach ($res as $value) {
            if ($value['slot_id'] === 0) {
                $increment = 1;
            }

            $slot_id = $value['slot_id'] + $increment;
            $uid = - ($slot_id);

            $matches = Array();
            if (preg_match("/login(\d+)/", $value['display_name'], $matches)) {
                $uid = - ((int)$matches[1] + $increment);
            } else {
                $entry = WMS_Ldap::getInstance()->getEntry(WMS_Ldap::PERSONS, '(cn=' . $value['display_name'] . ')', array( 'uid' ));
                if(isset($entry['uid'])){
                    $uid = (int)$entry['uid'];
                }
            }

            $queriesUID[] = $insertQuery.'('.(int)$slot_id.','.(int)$uid.',"'.sqlite3Escape($value['mac']).'");';
        }
    }

    \Wildix\Databases\DEVDB::getInstance()->exec('BEGIN TRANSACTION;');

    if(!empty($queriesUID)){
        \Wildix\Databases\DEVDB::getInstance()->dropTable(\Wildix\Databases\DEVDB::TABLE_WAIR_USERS);
        \Wildix\Databases\DEVDB::getInstance()->createTable(\Wildix\Databases\DEVDB::TABLE_WAIR_USERS);
        foreach ($queriesUID as $key=>$value){
            \Wildix\Databases\DEVDB::getInstance()->exec($value);
        }
    }
    \Wildix\Databases\DEVDB::getInstance()->exec('CREATE INDEX IF NOT EXISTS `wair_gateways_mac` ON `wair_gateways`(`mac`);');
    \Wildix\Databases\DEVDB::getInstance()->exec('CREATE INDEX IF NOT EXISTS `idx_wair_uid` on `wair_users`(`uid`);');
    \Wildix\Databases\DEVDB::getInstance()->exec('CREATE INDEX IF NOT EXISTS `wair_users_mac` ON `wair_users`(`mac`);');
    \Wildix\Databases\DEVDB::getInstance()->exec('CREATE INDEX IF NOT EXISTS `wair_gateways_mac` ON `wair_gateways`(`mac`);');

    \Wildix\Databases\DEVDB::getInstance()->exec('UPDATE wair_users SET uid = -slot_id WHERE uid < 0;');//In some cases old tables could contain incorrect data for uid column, this query fixes it

    \Wildix\Databases\DEVDB::getInstance()->exec('COMMIT;');

    $wairNetworksInfo = \Wildix\Databases\DEVDB::getInstance()->getTableInfo(\Wildix\Databases\DEVDB::TABLE_WAIR_NETWORKS);
    if(empty($wairNetworksInfo['sipproxy'])){
        \Wildix\Databases\DEVDB::getInstance()->exec('ALTER TABLE `'.\Wildix\Databases\DEVDB::TABLE_WAIR_NETWORKS.'` ADD `sipproxy` varchar(255)  default \'\' NOT NULL;');
    }
    if(empty($wairNetworksInfo['primarybase'])){
        \Wildix\Databases\DEVDB::getInstance()->exec('ALTER TABLE `'.\Wildix\Databases\DEVDB::TABLE_WAIR_NETWORKS.'` ADD `primarybase` varchar(255)  default \'\' NOT NULL;');
    }
    if(empty($wairNetworksInfo['autodecttree'])){
        \Wildix\Databases\DEVDB::getInstance()->exec('ALTER TABLE `'.\Wildix\Databases\DEVDB::TABLE_WAIR_NETWORKS.'` ADD `autodecttree` int(1)  default \'1\' NOT NULL;');
    }
    if (! isset($wairNetworksInfo['sync_plus_via_ethernet'])) {
        \Wildix\Databases\DEVDB::getInstance()->exec('ALTER TABLE `' . \Wildix\Databases\DEVDB::TABLE_WAIR_NETWORKS . '` ADD `sync_plus_via_ethernet` int(1) default 0 NOT NULL;');
    }
    if (!$isColumnIPEIExists) {
        $wairUsersInfo = \Wildix\Databases\DEVDB::getInstance()->getTableInfo(\Wildix\Databases\DEVDB::TABLE_WAIR_USERS);
        if(empty($wairUsersInfo['ipei'])){
            \Wildix\Databases\DEVDB::getInstance()->exec('ALTER TABLE `'.\Wildix\Databases\DEVDB::TABLE_WAIR_USERS.'` ADD `ipei` varchar(10) default \'FFFFFFFFFF\' NOT NULL;');
        }
    }
}


function update_cdr_conf(){
    $settings = \CDR::getInstance()->getSettings();
    if(!$settings){
        return false;
    }

    // always enable chat history (WMS-2868), changed.
    if ($settings['general']['ctibackend'] == '') {
        // set sqlite db for chat history
        CDR::getInstance()->SetSqliteDB($settings);
    }

    $settings['general']['save_history_base'] = 'yes';

    \CDR::write_cdr_conf($settings);
    exec('sudo chown wms:wms /etc/callweaver/cdr_mysql.conf');
    exec('sudo chown wms:wms /etc/callweaver/cdr_tds.conf');
}

function update_extensions_variables(){
    $set_extensions_vars_file = false;
    $filename = PATH_TO_CW_CONF.'extensions-variables.conf';
    $d_parameters = array(
        'GINTDIAL_TIMEOUT' => 'notpresent',
        'DYNAMIC_FEATURES' => 'notpresent',
        'GCTICONNECT3_PHONEBOOKS' => 'no',
        'GATTACH_FORMAT_REC' => 'wv',
        'GATTACH_FORMAT_VM' => 'wv',
    );

    $lines = file($filename);
    foreach ($lines As $line){
        if(strpos($line, '#') !== false) continue;
        [$option, $value] = explode('=',$line);
        $d_parameters[$option] = trim($value);
    }

    if ($d_parameters['GINTDIAL_TIMEOUT'] == 'notpresent'){
        $d_parameters['GINTDIAL_TIMEOUT'] = '65';
        $set_extensions_vars_file = true;
    }
    if (in_array($d_parameters['DYNAMIC_FEATURES'], ['notpresent', 'a_callrec', 'a_callswitch#a_callrec'], true)) {
        $d_parameters['DYNAMIC_FEATURES'] = 'a_callswitch#a_callrec#a_callrecpause';
        $set_extensions_vars_file = true;
    }
    if ($d_parameters['GCTICONNECT3_PHONEBOOKS'] == 'no'){
        $d_parameters['GCTICONNECT3_PHONEBOOKS'] = 'yes';
        $set_extensions_vars_file = true;
    }

    if ($d_parameters['GATTACH_FORMAT_REC'] == 'wv') {
        $d_parameters['GATTACH_FORMAT_REC'] = 'mp3';
        $set_extensions_vars_file = true;
    }
    if ($d_parameters['GATTACH_FORMAT_VM'] == 'wv') {
        $d_parameters['GATTACH_FORMAT_VM'] = 'mp3';
        $set_extensions_vars_file = true;
    }

    if ($set_extensions_vars_file){
        $to_file = "#include \"/etc/companies.d/*/variables.conf\"\n";
        foreach ($d_parameters as $key => $value)
            $to_file .= $key . '=' . $value . "\n";
        $fp = @fopen($filename, 'w');
        if ($fp) {
            fputs($fp, $to_file);
            fclose($fp);
        }
        PBX::getInstance()->put_cli_reload('pbx_config');
    }
}

function update_global_variables(){
    $filename = '/rw2/etc/companies.d/0/variables.conf';

    $GFAXPDFREPORT = '';

    if(! file_exists($filename)) {
        @touch($filename);
    }
    else{
        $GFAXPDFREPORT = exec ("awk -F= '/GFAXPDFREPORT_0/ {print\$2}' $filename");
    }

    if( ! $GFAXPDFREPORT){

        $param = 'GFAXPDFREPORT';
        $com_id = 0;
        $value = 'yes';

        exec("if [ -z \"`sed -n '/{$param}_{$com_id}/p' $filename`\" ]; then echo {$param}_{$com_id}=$value >> $filename; \
else filetmp=`mktemp`; sed '/{$param}_{$com_id}/ c {$param}_{$com_id}=$value' $filename > \$filetmp; \
cp \$filetmp $filename; rm \$filetmp; \
fi");
    }
}

function change_features_conf() {
    $dirty = false;
    $features_conf = get_features_conf();
    if($features_conf){
        if (empty($features_conf['general']['transferdigittimeout']) ||
            $features_conf['general']['transferdigittimeout'] == '3'){
            // set transferdigittimeout to 600 seconds (10 mins)
            $features_conf['general']['transferdigittimeout'] = '600';
            $dirty = true;
        }
        if(empty($features_conf['general']['atxferdropcall'])){
            // set atxferdropcall
            $features_conf['general']['atxferdropcall'] = 'yes';
            $dirty = true;
        }
        if (empty($features_conf['general']['transferinterdigittimeout'])){
            // set transferinterdigittimeout to 2 seconds
            $features_conf['general']['transferinterdigittimeout'] = '2';
            $dirty = true;
        }
        if (empty($features_conf['applicationmap']['a_callswitch'])){
            $features_conf['applicationmap']['a_callswitch'] = '*5,self,Macro,autocallswitch';
            $dirty = true;
        }
        if (empty($features_conf['general']['xferfailsound']) ||
            trim($features_conf['general']['xferfailsound']) == 'beeperr'){

            $features_conf['general']['xferfailsound'] = 'beepbusyit1';
            $dirty = true;
        }

        if(empty($features_conf['applicationmap']['a_callrec']) ||
            strpos($features_conf['applicationmap']['a_callrec'], 'caller,Macro,apprecord') !== false){
            $key = '*1';
            if(!empty($features_conf['applicationmap']['a_callrec'])){
                $a_callrec = explode(',', $features_conf['applicationmap']['a_callrec']);
                if(!empty($a_callrec) && isset($a_callrec[0])){
                    $key = $a_callrec[0];
                }
            }
            $features_conf['applicationmap']['a_callrec'] = $key.',caller,Macro,autocallrec';
            $dirty = true;
        }

        if (($features_conf['applicationmap']['a_callrecpause'] ?? '') === '') {
            $features_conf['applicationmap']['a_callrecpause'] = '*2,caller,Macro,autocallrecpause';
            $dirty = true;
        }

        if(empty($features_conf['general']['atxferdropcall'])){
            $features_conf['general']['atxferdropcall'] = 'yes';
            $dirty = true;
        }

        if(empty($features_conf['general']['atxfernoanswertimeout'])){
            $features_conf['general']['atxfernoanswertimeout'] = '30';
            $dirty = true;
        }

        if(empty($features_conf['general']['featuredigittimeout']) ||
            $features_conf['general']['featuredigittimeout'] != '1000'){
            $features_conf['general']['featuredigittimeout'] = '1000';
            $dirty = true;
        }

        if(isset($features_conf['general']['atxfer'])){
            unset($features_conf['general']['atxfer']);
            $dirty = true;
        }
    }

    if ($dirty) {
        set_features_conf($features_conf);
        PBX::getInstance()->put_cli_reload('features');
    }
}

function update_kamailio_cfg(){
    $network_class = new network();

    // set defaults parameters
    exec('cfgfile=/rw2/etc/kamailio/host_specific.cfg;

       # change ipcheck_url
    if [ "$(grep checkip.wildix.com "$cfgfile" -c 2>/dev/null)" = "0" ]; then
        ftmp=$(mktemp);
        sed \'s/.*ipcheck_url.*/modparam("via_tool", "ipcheck_url", "http:\/\/checkip.wildix.com\/")/g\' "$cfgfile" > $ftmp;
        if [ "$(cat $ftmp | wc -l )" -gt 0 ]; then
            cat $ftmp > $cfgfile;
        fi
        [ -f "$ftmp" ] && rm --preserve-root $ftmp;
    fi

    # correct localnet parameter
    . /usr/sbin/update_kamailio_cfg.sh localnets >/dev/null 2>&1
    ');

    return true;
}

function update_kamailio_static_peers($updateDynamic = false){
    $sipTrunkService = $GLOBALS['diContainer']->get(SipTrunkServiceInterface::class);
    foreach ($sipTrunkService->getItems() as $trunk) {
        $kamailio = SettingsKamailioBuilder::build($trunk->getSettingsPbx(), $trunk->getSettingsWms());

        if (!$trunk->getSettingsPbx()->isDynamicHost()) {
            $sipTrunkService->createPeer($trunk->getId(), $trunk->getSettingsPbx()->getPeerName(), $kamailio, false, false);
        } elseif ($updateDynamic) {
            $sipTrunkService->createPeer($trunk->getId(), $trunk->getSettingsPbx()->getUserName(), $kamailio, true, false);
        }
    }

    if ($updateDynamic) {
        $fxoService = $GLOBALS['diContainer']->get(FxoTrunkServiceInterface::class);
        foreach ($fxoService->getItems() as $trunk) {
            foreach ($trunk->getAuthNamesByPorts() as $index => $name) {
                $fxoService->getPeerService()->deleteDynamicPeer($trunk->getId());
                $fxoService->getPeerService()->createDynamicPeer($trunk->getId(), $name. '::authname', $name);
                $fxoService->getPeerService()->createDynamicPeer($trunk->getId(), $name . '::secret', $trunk->generateKamailioSecret($index));
            }
        }

        $pstnService = $GLOBALS['diContainer']->get(PstnTrunkServiceInterface::class);
        foreach ($pstnService->getItems() as $trunk) {
            foreach ($trunk->getAuthNamesByPorts() as $index => $name) {
                $pstnService->getPeerService()->deleteDynamicPeer($trunk->getId());

                $pstnService->getPeerService()->createDynamicPeer($trunk->getId(), $name. '::authname', $name);

                if (!$trunk->isGsm()) {
                    $pstnService->getPeerService()->createDynamicPeer($trunk->getId(), $name. '::secret', $trunk->generateKamailioSecret($index));
                }

                if ($trunk->getSettingsMgw()->getLanguage()) {
                    $language = $trunk->getSettingsMgw()->getLanguage();
                    $pstnService->getPeerService()->createDynamicPeer($trunk->getId(), $name. '::language', $language);
                }
            }
        }
    }
}

function update_kamailio_cfg_localnet(){ // CONVENTION-4364
    exec("sudo /usr/sbin/update_kamailio_cfg.sh localnets");
}

function update_res_features() {

    $features = getGlobalFeatures();
    $result = array();

    if (0 != sizeof($features)) {
        foreach ($features as $key => $value) {
            $result[$key] = $value['access'];
        }

        if(isset($result['DND'])){
            $result['STATUS'] = $result['DND'];
            unset($result['DND']);
        }
        saveGlobalFeatures($result);
    }
}

function update_dnsmasq_config() {
    if (\Models\PBX::getInstance()->isMaster()){
        $parameters = array( 'pbxid', 'pbxIp');
        $entry = WMS_Ldap::getInstance()->getEntries(WMS_Ldap::PBX, '', $parameters);
        $buffer = '';
           if (is_array($entry)){
            foreach ($entry as $onePBX){
                $buffer.= $onePBX['pbxIp'].' '.$onePBX['pbxid'].".conf.wld\n";
            }
        }
        $handle = fopen('/etc/dnsmasq.d/hosts','w');
        fwrite($handle,$buffer);
        fclose($handle);
        $network = new network();
        $network->restart_dns();
    }

    // move customers domain in separate hosts file
    exec('sudo /etc/network/if-up.d/hosts move > /dev/null 2>&1');

    // WMS-4239. modify dhcp ntp-server options. Debian 9 does not support the FQDN ;-(
    convertDhcpConfig();
}

function convertDhcpConfig() {
    exec('sudo chown wms:wms /etc/dnsmasq.d/dhcp.conf');
    if (!is_file('/etc/dnsmasq.d/config')) {
        exec('sudo touch /etc/dnsmasq.d/config');
    }
    exec('sudo chown wms:wms /etc/dnsmasq.d/config');

    $dhcpServerManager = $GLOBALS['diContainer']->get(\Wildix\System\Dhcp\ServerManager::class);

    $storage   = \Wildix\Databases\WMSDB::getInstance();
    $logger    = \Logger\LoggerFactory::getInstance();
    $newConfig = json_decode($storage->getSystemVariable(\Wildix\System\Dhcp\ServerManager::DHCP_SETTINGS_STORAGE), true);
    if ($newConfig === null) {
        include_once 'DhcpConfigConverter.php';

        $converterClass = new DhcpConfigConverter(new \Wildix\System\Dhcp\Converter());
        if ($converterClass->isFoundConfig()) {
            $dhcpServerManager->saveConfig($converterClass->convert());
            $dhcpServerManager->removeOldConfigFile();
            $logger->info(__LINE__, 'Convert DHCP config to new format');
        }
    }
}

function remove_user_mount(){
    $mount      = new \Wildix\System\Mount();
    $sys_mounts = $mount->getMountsByType();
    if(isset($sys_mounts['/mnt/users'])){
        $storageDevices = new \Wildix\System\Storage\StorageDevices();
        $storage        = new \Wildix\System\Storage\Storage($mount, $storageDevices);
        $storage->unMount('/mnt/users', 'usb');
    }
}

function updateDialplans(){

    $queries = array();
    $queries[] = 'CREATE TABLE IF NOT EXISTS '.IncomingCalls::RULES_LINKS_TABLE.'(
        id INTEGER PRIMARY KEY AUTOINCREMENT,
        object_from_type INTEGER,
        object_from_id INTEGER,
        object_to_type INTEGER,
        object_to_id VARCHAR(80)
    );';
    $queries[] = 'CREATE INDEX if not exists `idx_dialplan_links_object_to_type_object_to_id` ON `dialplan_links` (`object_to_type`, `object_to_id`)';
    foreach ($queries as $query){
        \Wildix\Databases\WMSDB::getInstance()->exec($query);
    }

    $transforms = array(
        'AuthenticateUser' => array('old' => '/^([^,]+),([^,"]*),([^,"]*)$/', 'new' => '"$2","$3"', 'appname' => 'app-authenticate-user'),
        'CorrectOutgoingNumber' => array('old' => '/^([^,]+),([^,"]*),([^,"]*),([^,"]*)$/', 'new' => '"$3","$2","$4"', 'appname' => 'app-correct-outgoing-number'),
        'DialHuntGroup' => array('old' => '/^([^,]+),"?([^,"]*)"?,"?([^,"]*)"?,"?([^,"]*)"?,"?([^,"]*)"?,"?([^,"]*)"?$/', 'new' => '"$3","$2","$4","$5","$6"', 'appname' => 'app-dial-hunt-group'),
        'DialPhone' => array('old' => '/^([^,]+),([^,"]*),([^,"]*),([^,"]*)$/', 'new' => '"$2","$3","$4"', 'appname' => 'app-dial-internalcall'),
        'DialRemotePbx' => array('old' => '/^([^,]+),([^,"]*),([^,"]*),([^,"]*),([^,"]*),([^,"]*)$/', 'new' => '"$4","$2","$3","$5","$6"', 'appname' => 'app-dial-remote-pbx'),
        'DialTrunk' => array('old' => '/^([^,]+),([^,\/"]*)\/([^,"]*),([^,"]*),([^,"]*),([^,"]*)$/', 'new' => '"$3","$2","$4","$5","$6"', 'appname' => 'app-dial-trunk'),
        'Hangup' => array('old' => '/(.+)/', 'new' => '$1', 'appname' => 'app-hangup'),
        'Callback' => array('old' => '/.+/', 'new' => '', 'appname' => 'app-callback'),
        'Conference' => array('old' => '/^([^,]+),([^,"]*)$/', 'new' => '"$2"', 'appname' => 'app-conference'),
        'FaxToEmail' => array('old' => array(
        		'/^([^,]+),"?([^,"]*)"?,"?([^,"]*)"?,"?([^,"]{2,})"?,"?([^,"]*)"?$/',
        		'/^([^,]+),"?([^,"]*)"?,"?([^,"]*)"?,(.{0}),"?([^,"]*)"?$/'
        ), 'new' => '"$2","$3","$4",e,"$5"', 'appname' => 'app-fax2email'), // '"$2","$3","$4",e,"$5"' falls under the pattern, the cycle turns, added {2,}
        'FeatureIntercom' => array('old' => '/^([^,]+),([^,"]*),([^,"]*),([^,"]*)$/', 'new' => '"$2","$3","$4"', 'appname' => 'app-service-intercom'),
        'FeaturePaging' => array('old' => '/^([^,]+),([^,"]*)$/', 'new' => '"$2"', 'appname' => 'app-service-paging'),
        'MuxMon' => array('old' => '/^([^,]+),([^,"]*),([^,"]*)$/', 'new' => '"$3","$2"', 'appname' => 'app-dial-internalcall'),
        'Queue' => array('old' => '/^([^,]+),([^,"]*),"?([^,"]*)"?,([^,"]*),([^,"]*),([^,"]*),([^,"]*)$/', 'new' => '"$2","$3","$4","$5","$6","$7"', 'appname' => 'app-queue'),
        'VoiceMail' => array('old' => '/^([^,]+),([^,"]*),([^,"]*)$/', 'new' => '"$2","$3"', 'appname' => 'app-voicemail'),
        'VoiceMailMain' => array('old' => '/^([^,]+),([^,"]*),([^,"]*)$/', 'new' => '"$2","$3"', 'appname' => 'app-voicemail-main'),
        'GoToIfFaxDetected' => array('old' => '/^([^,]+),([^,"]*),([^,"]*),([^,"]*),([^,"]*)$/', 'new' => '"$2","$4","$3","$5",""', 'appname' => 'app-faxdetect'),
        'Goto' => array('old' => '/^([^,]+),([^,"]*),([^,"]*),([^,"]*),([^,"]*)$/', 'new' => '"$3","$2","$4","$5"', 'appname' => 'app-goto-general'),
        'GotoIf3SwitchIsOnOrBlinking' => array('old' => '/^([^,]+),([^,"]*),([^,"]*),([^,"]*),([^,"]*),([^,"]*),([^,"]*),([^,"]*),([^,"]*),([^,"]*)$/', 'new' => '"$2","$4","$3","$5","$6","$8","$7","$9","${10}"', 'appname' => 'app-goto-if-three-switch-is-on-or-blinking'),
        'GotoIfBusyCongested' => array('old' => '/^([^,]+),([^,"]*),([^,"]*),([^,"]*),([^,"]*),([^,"]*)$/', 'new' => '"$2","$4","$3","$5","$6"', 'appname' => 'app-goto-if-dialstatus'),
        'GotoIfCallType' => array('old' => '/^([^,]+),([^,"]*),([^,"]*),([^,"]*),([^,"]*),([^,"]*)$/', 'new' => '"$2","$4","$3","$5","$6"', 'appname' => 'app-goto-if-call-type'),
        'GotoIfSwitchIsOn' => array('old' => '/^([^,]+),([^,"]*),([^,"]*),([^,"]*),([^,"]*),([^,"]*)$/', 'new' => '"$2","$4","$3","$5","$6"', 'appname' => 'app-goto-if-switch-is-on'),
        'GotoIfGroupCount' => array('old' => '/^([^,]+),([^,"]*),([^,"]*),([^,"]*),([^,"]*),([^,"]*),([^,"]*)$/', 'new' => '"$2","$3","$5","$4","$6","$7"', 'appname' => 'app-goto-if-group-count'),
        'Timetable' => array('old' => '/^([^,]+),([^,"]*),([^,"]*),([^,"]*),([^,"]*)$/', 'new' => '"$2","$4","$3","$5"', 'appname' => 'app-timetable'),
        'VerifyCaller' => array('old' => '/^([^,]+),([^,"]*),([^,"]*),([^,"]*),([^,"]*),([^,"]*)$/', 'new' => '"$2","$4","$3","$5","$6"', 'appname' => 'app-verify-caller'),
        'LookUpCidNameInPhonebook' => array('old' => '/^([^,]+),([^,"]*),([^,"]*),([^,"]*),([^,"]*)$/', 'new' => '"$3","$2","$4","$5"', 'appname' => 'app-lookup-in-phonebook'),
        'LookUpDestCidNameInPhonebook' => array('old' => '/^([^,]+),([^,"]*),([^,"]*),([^,"]*),([^,"]*)$/', 'new' => '"$3","$2","$4","$5"', 'appname' => 'app-lookup-in-phonebook'),
        'MobilityExtensionLookUp' => array('old' => '/^([^,]+),([^,"]*),([^,"]*)$/', 'new' => '"$2","$3"', 'appname' => 'app-lookup-mobility-ext'),
        'Background' => array('old' => '/^([^"]*)$/', 'new' => '"$1",""', 'appname' => 'app-playback-waitDigits'),
        'IVR' => array('old' => '/^([^,]+),([^,"]*)$/', 'new' => '"$2"', 'appname' => 'app-ivr'),
        'Playback' => array('old' => '/^([^"]*)$/', 'new' => '"$1",""', 'appname' => 'app-playback'),
        'WaitExten' => array('old' => '/^([^"]*)$/', 'new' => '"$1"', 'appname' => 'WaitExten'),
        'Set' => array('old' => '/^([^,]+),([^,"]*),([^,"]*)$/', 'new' => '"$2","$3"', 'appname' => 'app-set'),
        'GenerateDtmf' => array('old' => '/^([^,]+),([^,"]*)$/', 'new' => '"$2"', 'appname' => 'SendDTMF'),
        'GenerateFlashHook' => array('old' => '/^(.*)$/', 'new' => '"f"', 'appname' => 'SendDTMF'),
        'FastAGI' => array('old' => '/^([^"]*)$/', 'new' => '"$1"', 'appname' => 'OGI'),
    );

    $queries = array(
    		'DELETE from dialplan_rules where application="GoToCallCostLimit"',
            'DELETE from dialplan_rules where application="GoToIfCallCostLimit"'
    );
    foreach ($queries as $query){
        \Wildix\Databases\WMSDB::getInstance()->exec($query);
    }

    $sql = "SELECT * from dialplan_rules where application='%s'";
    $update = "UPDATE dialplan_rules SET parameters='%s', dialplanappname='%s' where id = %d";

    foreach($transforms as $key => $transform){
        $queries = array();
        if ($rows = \Wildix\Databases\WMSDB::getInstance()->query(sprintf($sql, $key))) {
            while($row = $rows->fetchArray(SQLITE3_ASSOC)){
                $row['parameters'] = str_replace('\\,','---change-coma---', $row['parameters']);
                if(is_array($transform['old'])){
                	foreach($transform['old'] as $transf){
                		if(preg_match($transf, $row['parameters'])){
                			$params = preg_replace($transf, $transform['new'],$row['parameters']);

                			$params = str_replace('---change-coma---', '\\,', $params);
                			$queries[] = sprintf($update, $params, $transform['appname'], $row['id']);
                		}
                	}
                }else{
	                if(preg_match($transform['old'], $row['parameters'])){
	                    $params = preg_replace($transform['old'], $transform['new'],$row['parameters']);

	                    $params = str_replace('---change-coma---', '\\,', $params);
	                    $queries[] = sprintf($update, $params, $transform['appname'], $row['id']);
	                }
                }

            }
            $rows->finalize();
        }
        if(count($queries)){
            foreach ($queries as $query){
                \Wildix\Databases\WMSDB::getInstance()->exec($query);
            }
        }
    }
}

function updateDialplansNew($backup = false){
    $table = ($backup ? '_bkp_' : '').'dialplan_rules';
    $queries = array();
    $transforms = array(
        'GoToIfFaxDetected' => array('old' => '/^([^,]*),([^,]*),([^,]*),([^,]*)$/', 'new' => '$1,$2,$3,$4,""', 'appname' => 'app-faxdetect'),
        'FaxToEmail' => array('old' => '/^([^,]+),([^,]*),([^,]*),e,([^,]*)$/', 'new' => '$1,$2,$3,e', 'appname' => 'app-fax2email'),
        'Background' => array('old' => '/^([^,]*)$/', 'new' => '$1,""', 'appname' => 'app-playback-waitDigits'),
        'Playback' => array('old' => '/^([^,]*)$/', 'new' => '$1,""', 'appname' => 'app-playback'),
        'DialPhone' => array('old' => '/^([^,]*),([^,]*),([^,]*)$/', 'new' => '$1,$2,$3,""', 'appname' => 'app-dial-internalcall'),
        'FeatureIntercom' => array('old' => '/^([^,]+),([^,]*),([^,]*)$/', 'new' => '$1,$2,$3,""', 'appname' => 'app-service-intercom'),
        'DialTrunk' => array('old' => '/^([^,]*),([^,]*),([^,]*),([^,]*),([^,]*)$/', 'new' => '$1,$2,$3,$4,$5,"auto"', 'appname' => 'app-dial-trunk'),
        'GotoIfUserStatus' => array('old' => '/^([^,]*),([^,]*),([^,]*),([^,]*),([^,]*)$/', 'new' => '"${EXTEN}",$1,$2,$3,$4,$5', 'appname' => 'app-goto-if-userstatus')
    );



    $update = "UPDATE ".$table." SET parameters='%s', dialplanappname='%s' where id = %d";

    $sql = "SELECT * from ".$table." where application in ('".implode("','", array_keys($transforms))."')";
    if ($rows = \Wildix\Databases\WMSDB::getInstance()->query($sql)) {
        while($row = $rows->fetchArray(SQLITE3_ASSOC)){
            $params = preg_replace($transforms[$row['application']]['old'], $transforms[$row['application']]['new'],$row['parameters']);
            $params = \Wildix\Databases\WMSDB::getInstance()->realEscapeString($params);

            $queries[] = sprintf($update,$params,$transforms[$row['application']]['appname'], $row['id']);
        }
        $rows->finalize();
    }
    if(count($queries)){
        foreach ($queries as $query){
            \Wildix\Databases\WMSDB::getInstance()->exec($query);
        }

        if(! $backup){
            $dialplan_class = $GLOBALS['diContainer']->get(IncomingCalls::class);
            $dialplan_class->set_extensions_incomingcalls();
            $dialplan_class->set_queues_conf();
        }
    }
}

function changeDialplanCallThroughPbxRules() {
    $confIsDirty = false;

    $query = 'SELECT id, object_to_id
    FROM '.IncomingCalls::RULES_LINKS_TABLE.'
    WHERE object_to_type = '.IncomingCalls::PBX_LINK;

    $links = array();
    if ($rows = \Wildix\Databases\WMSDB::getInstance()->query($query)) {
        while ($row = $rows->fetchArray(SQLITE3_ASSOC)) {
            $links[$row['id']] = $row['object_to_id'];
        }
        $rows->finalize();
    }

    foreach ($links as $id => $pbxSerial) {
        $dn = 'pbxid='.$pbxSerial.',dc=wildix';
        $pbx = \Wildix\PBXes\PBXes::getInstance()->getPBXByDN($dn);
        if ($pbx === null) {
            $pbx = \Wildix\PBXes\PBXes::getInstance()->getPBXBySerial($pbxSerial);
        }

        if ($pbx !== null) {
            $query = 'UPDATE '.IncomingCalls::RULES_LINKS_TABLE.'
            SET object_to_id = "'.$pbx->getDn().'"
            WHERE id = '.$id;
            \Wildix\Databases\WMSDB::getInstance()->exec($query);
            $confIsDirty = true;
        }
    }


    $query = 'SELECT id, parameters
    FROM dialplan_rules
    WHERE application = "DialRemotePbx"';

    $rules = array();
    if ($rows = \Wildix\Databases\WMSDB::getInstance()->query($query)) {
        while ($row = $rows->fetchArray(SQLITE3_ASSOC)) {
            $rules[$row['id']] = $row['parameters'];
        }
        $rows->finalize();
    }

    foreach ($rules as $id => $parameters) {
        $paramsArray = explode('","', $parameters);
        $pbxSerial = $paramsArray[1];
        if (strpos($pbxSerial, 'pbxid=') === false) {
            $dn = 'pbxid='.$pbxSerial.',dc=wildix';
            $pbx = \Wildix\PBXes\PBXes::getInstance()->getPBXByDN($dn);
            if ($pbx === null) {
                $pbx = \Wildix\PBXes\PBXes::getInstance()->getPBXBySerial($pbxSerial);
            }

            if ($pbx !== null) {
                $paramsArray[1] = $pbx->getDn();
                $paramsArray[1] = str_replace(',', '\,', $paramsArray[1]); // , becomes \,
                $parametersUpdated = implode('","', $paramsArray);

                $query = "UPDATE dialplan_rules
                SET parameters = '" . $parametersUpdated . "'
                WHERE id = " . $id;
                \Wildix\Databases\WMSDB::getInstance()->exec($query);
                $confIsDirty = true;
            }
        }
    }

    if ($confIsDirty){
        $dialplan = $GLOBALS['diContainer']->get(IncomingCalls::class);
        $dialplan->set_extensions_incomingcalls();
    }
}

function changeSendSmsThroughPbxSettings() {
    $companyGlobalConfig = new \Wildix\CompanyGlobalConfig();
    $gsmspbx = $companyGlobalConfig->getVariable('GSMSPBX');

    if ($gsmspbx) {
        $dn = 'pbxid='.$gsmspbx.',dc=wildix';
        $pbx = \Wildix\PBXes\PBXes::getInstance()->getPBXByDN($dn);

        if ($pbx !== null) {
            $companyGlobalConfig->setVariable('GSMSPBX', $dn);
        }
    }
}

function update_ctidb(){
    $cti_path = '/mnt/cticonnect/cticonnectdb';
    if(file_exists($cti_path)){
        $phDB = new DB_SQLite3($cti_path);

        $newTable   = false;
        $newTable2  = false;
        $newTable3  = false;
        $colRington = false;
        $colOwnerId = false;

        $res = $phDB->query('PRAGMA table_info (cti_contacts);');
        while($row = $res->fetchRow($res)){
            if($row[1] == 'source_id'){
                $newTable = true;
            }elseif($row[1] == 'group_id'){
                $newTable2 = true;
                if($row[4] == "''"){
                    $newTable3 = true;
                }
            }elseif($row[1] == 'ringtone'){
                $colRington = true;
            } elseif($row[1] == 'owner_id'){
                $colOwnerId = true;
            }
        }

        if(!$colRington){
            $query[] = 'ALTER TABLE `cti_contacts` ADD `ringtone` varchar(255) default \'\' not null;';
        }

        if(!$colOwnerId){
            $query[] = 'ALTER TABLE `cti_contacts` ADD `owner_id` varchar(255) default \'\' not null;';
        }

        if(! $newTable2){
            $query[] = 'ALTER TABLE cti_contacts ADD group_id varchar(255);';
            if( ! $newTable){
                $query[] = 'ALTER TABLE cti_contacts ADD extension varchar(255);';
                $query[] = 'ALTER TABLE cti_contacts ADD home varchar(255);';
                $query[] = 'ALTER TABLE cti_contacts ADD home_mobile varchar(255);';
                $query[] = 'ALTER TABLE cti_contacts ADD source_id varchar(255);';
                $query[] = 'ALTER TABLE cti_contacts ADD office varchar(255);';
                $query[] = "UPDATE cti_contacts SET `extension`=`phone`, `phone`=''  WHERE organization='LDAP' AND extension IS NULL;";
            }

            sqlite3FastManip($query, $phDB);
            $query = array();
        }

        if(! $newTable3){
            if(disk_free_space('/mnt/cdr/') > (filesize($cti_path)/2)){
                $res = $phDB->query('PRAGMA index_list(`cti_contacts`);');
                while($row = $res->fetchRow(DB_FETCHMODE_ASSOC)){
                    $query[] = 'DROP INDEX '.$row['name'].';';
                }
                $res = $phDB->query("SELECT name FROM sqlite_master where type = 'trigger' AND tbl_name='cti_contacts'");
                while($row = $res->fetchRow(DB_FETCHMODE_ASSOC)){
                    $query[] = 'DROP TRIGGER '.$row['name'].';';
                }
                $query[] = 'ALTER TABLE `cti_contacts` RENAME TO `cti_contacts_bkp`;';
                sqlite3FastManip($query, $phDB);
                $phDB->query('VACUUM;');

                $query = array();

                preg_match_all ("/CREATE\s*(((INDEX|TABLE)[^;]*;)|((TRIGGER)(?:(?!END).)*END;))/si", file_get_contents('/var/www/dbsetup/cticonnectdb.sql'), $var);

                $restoreSQL = array('TABLE'=>array(), 'INDEX'=>array(), 'TRIGGER'=>array());
                foreach($var[0] as $i=>$val){
                    $restoreSQL[$var[3][$i]?$var[3][$i]:$var[5][$i]][] = $val;
                }

                $query = $restoreSQL['TABLE'];

                $query[] = "INSERT INTO `cti_contacts`
                              SELECT `rid`,ifnull(`source_id`,''),ifnull(`username`,''),ifnull(`email`,''),ifnull(`extension`,''),
                                       ifnull(`phone`,''),ifnull(`office`,''),ifnull(`home`,''),ifnull(`home_mobile`,''),
                                       ifnull(`fax`,''),ifnull(`mobile`,''),ifnull(`organization`,''),ifnull(`image_url`,''),
                                       ifnull(`shortcut`,''),`phonebook_id`,ifnull(`group_id`,''),ifnull(`user_class`,''),
                                       ifnull(`ringtone`,''),`note`,ifnull(`address`,''),ifnull(`vat_id`,''),ifnull(`name_prefix`,''),
                                       ifnull(`user_passport_type`,''),ifnull(`user_passport_id`,''),`pin`,`credit`,
                                       ifnull(`hash`,''),ifnull(`country`,''),`date_birth`,ifnull(`born_in`,''),`postal_code`,
                                       ifnull(`city`,''),ifnull(`province`,''),ifnull(`license_plate`,''),`document_released_on`,
                                       ifnull(`document_from`,''),`last_update`,ifnull(`owner_id`,'')
                              FROM `cti_contacts_bkp`;";

                sqlite3FastManip($query, $phDB);
                $phDB->disconnect();
                $phDB = new DB_SQLite3($cti_path);
                $phDB->query('DROP TABLE `cti_contacts_bkp`; VACUUM;');

                $query = array_merge($restoreSQL['INDEX'], $restoreSQL['TRIGGER']);
            }
        }

        /*
         * add table fulltext
         * ;
         * */
        $check_fts4 = "SELECT count(*) as count FROM sqlite_master WHERE type='table' AND name IN ('cti_contacts_fts4', 'cti_contacts_fts4_docsize', 'cti_contacts_fts4_segdir', 'cti_contacts_fts4_segments', 'cti_contacts_fts4_stat')";
        $res = $phDB->query($check_fts4);
        if($row = $res->fetchRow(DB_FETCHMODE_ASSOC)){
            if($row['count'] == 0){
                $query[] = "DROP INDEX `idx_cti_contacts_phonebook_id`;";
                $query[] = 'CREATE VIRTUAL TABLE  IF NOT EXISTS cti_contacts_fts4 USING fts4(content="cti_contacts", username, email, organization);';
                $query[] = "CREATE TRIGGER  IF NOT EXISTS cti_contacts_fts4_bu BEFORE UPDATE ON cti_contacts BEGIN
  DELETE FROM cti_contacts_fts4 WHERE docid=old.rowid;
END;
CREATE TRIGGER IF NOT EXISTS cti_contacts_fts4_bd BEFORE DELETE ON cti_contacts BEGIN
  DELETE FROM cti_contacts_fts4 WHERE docid=old.rowid;
END;

CREATE TRIGGER IF NOT EXISTS cti_contacts_fts4_au AFTER UPDATE ON cti_contacts BEGIN
  INSERT INTO cti_contacts_fts4(docid, username, email, organization) VALUES(new.rowid, new.username, new.email, new.organization);
END;
CREATE TRIGGER IF NOT EXISTS cti_contacts_fts4_ai AFTER INSERT ON cti_contacts BEGIN
  INSERT INTO cti_contacts_fts4(docid, username, email, organization) VALUES(new.rowid, new.username, new.email, new.organization);
END;";
            }elseif($row['count'] < 5){
                $query[] = "DROP TABLE cti_contacts_fts4;";
                sqlite3FastManip($query, $phDB);
                $query = array();
                $query[] = 'CREATE VIRTUAL TABLE  IF NOT EXISTS cti_contacts_fts4 USING fts4(content="cti_contacts", username, email, organization);';
            }
        }

        // check create fts4, there are occasions when there is created the first time, but not reproduce
        // we try to create a second time
        sqlite3FastManip($query, $phDB);
        $query = array();
        $phDB->disconnect();
        $phDB = new DB_SQLite3($cti_path);

        $res = $phDB->query($check_fts4);
        if($row = $res->fetchRow(DB_FETCHMODE_ASSOC)){
            if($row['count'] == 0){
                $query[] = 'CREATE VIRTUAL TABLE  IF NOT EXISTS cti_contacts_fts4 USING fts4(content="cti_contacts", username, email, organization);';
            }elseif($row['count'] < 5){
                $phDB->exec("DROP TABLE cti_contacts_fts4;");
                $query[] = 'CREATE VIRTUAL TABLE  IF NOT EXISTS cti_contacts_fts4 USING fts4(content="cti_contacts", username, email, organization);';
            }
        }


        $query[] = 'CREATE TABLE IF NOT EXISTS `cdr_periods` (
    `id` INTEGER PRIMARY KEY AUTOINCREMENT,
    `uid` INTEGER NOT NULL,
    `value` VARCHAR(255) NOT NULL,
    `sla_value` INTEGER DEFAULT 0 NOT NULL,
    `miss_call_sec_value` INTEGER DEFAULT 0 NOT NULL
);';

        $query[] = 'CREATE TABLE IF NOT EXISTS `cdr_filters` (
    `id` INTEGER PRIMARY KEY AUTOINCREMENT,
    `uid` INTEGER NOT NULL,
    `name` VARCHAR(64) NOT NULL,
    `description` VARCHAR(255),
    `filter` TEXT,
    `shared` CHAR(1)
);';
        sqlite3FastManip($query, $phDB);


        $tableInfo = array();
        if($res = $phDB->query('PRAGMA table_info(`cdr_periods`);')){
            while($row = $res->fetchRow($res)){
                $tableInfo[$row[1]] = $row;
            }
        }

        $query = array();
        if(!isset($tableInfo['sla_value'])){
            $query[] = 'ALTER TABLE `cdr_periods` ADD COLUMN `sla_value` INTEGER DEFAULT 0 NOT NULL;';
        }
        if(!isset($tableInfo['miss_call_sec_value'])){
            $query[] = 'ALTER TABLE `cdr_periods` ADD COLUMN `miss_call_sec_value` INTEGER DEFAULT 0 NOT NULL;';
        }
        $query[] = "INSERT INTO cti_contacts_fts4(cti_contacts_fts4) VALUES('rebuild');";

        sqlite3FastManip($query, $phDB);

    }
}

function update_queuedb() {
    $queueDb = \Wildix\Databases\QueueDB::getInstance();
    $queueDb->createDb();
}

function update_calendardb(){
    if(\Models\PBX::getInstance()->isCustomShareMounted('/mnt/cticonnect')){
        $calendarDb = \Wildix\Databases\CalendarDB::getInstance();
        $calendarDb->createDb();
        $eventInfo = $calendarDb->getTableInfo('events');
        if($eventInfo && !isset($eventInfo['app'])){
            $calendarDb->exec('ALTER TABLE `events` ADD COLUMN `app` INTEGER NOT NULL default 1;');
        }
    }
}

function update_wmsdb(){

    $queries = array();
    $queries[] = 'CREATE TABLE IF NOT EXISTS `paging` (
    `id` INTEGER PRIMARY KEY AUTOINCREMENT,
    `name` varchar(40) UNIQUE)';
    $queries[] = 'CREATE INDEX IF NOT EXISTS `idx__paging_name` on `paging`(`name`)';
    $queries[] = 'CREATE TABLE IF NOT EXISTS `paging_members` (
    `id` INTEGER PRIMARY KEY AUTOINCREMENT,
    `paging_id` int(11),
    `group_member` varchar(20))';
    $queries[] = 'CREATE INDEX IF NOT EXISTS `idx__paging_members_paging_id` on `paging_members`(`paging_id`)';

    $uniqUsername = false;

    if ($rows = \Wildix\Databases\WMSDB::getInstance()->query('PRAGMA index_list(`trunks`);')) {
        while($row = $rows->fetchArray(SQLITE3_ASSOC)){
            if($row["unique"] == 1){
                if ($rows2 = \Wildix\Databases\WMSDB::getInstance()->query('PRAGMA index_info('.$row['name'].');')) {
                    while($row2 = $rows2->fetchArray(SQLITE3_ASSOC)){
                        if($row2['name'] == 'username'){
                            $uniqUsername = true;
                            break(2);
                        }
                    }
                    $rows2->finalize();
                }
            }
        }
        $rows->finalize();
    }

    if($uniqUsername){
        $queries[] = 'ALTER TABLE `trunks` RENAME TO `trunks_bkp`;';
        $queries[] = "CREATE TABLE `trunks` (
`id` INTEGER PRIMARY KEY AUTOINCREMENT,
`username` varchar(20),
`title` varchar(40) NOT NULL default '',
`register` varchar(255),
`settings_pbx` text,
`settings_wms` text);";
        $queries[] = 'INSERT INTO `trunks` SELECT `id`, `username`, `title`, `register`, `settings_pbx`, `settings_wms` FROM `trunks_bkp`;';
        foreach ($queries as $query){
            \Wildix\Databases\WMSDB::getInstance()->exec($query);
        }

        $queries = array();
        $queries[] = 'DROP TABLE `trunks_bkp`;';
        $queries[] = 'CREATE INDEX `idx_trunks_username` on `trunks`(`username`);';
    }

    foreach ($queries as $query){
        \Wildix\Databases\WMSDB::getInstance()->exec($query);
    }
}

function delete_old_backup_wmsdb(){
    $oldWmsdbPath = '/var/www/wmsdb';
    foreach (glob($oldWmsdbPath.'*') as $filename) {
        if($filename != $oldWmsdbPath.'.dmp.gz' && $filename != $oldWmsdbPath){
            unlink($filename);
        }
    }
    foreach (glob(\Wildix\Databases\Database::WILDIX_WMSDB.'*') as $filename) {
        if($filename != \Wildix\Databases\Database::WILDIX_WMSDB.'.dmp.gz' && $filename != \Wildix\Databases\Database::WILDIX_WMSDB){
            unlink($filename);
        }
    }
}

// ----------------- / functions to upgrade structure and others from WMS2 to WMS3 ---------------------

/* Update dialplan for any rules and links which content in parameters 'briX_X_1'*/
function update_dialplan_wms30(){

    $sql_rules = "SELECT id, parameters FROM dialplan_rules WHERE parameters LIKE '%%bri_\__\_1%%' ESCAPE '\'";
    $update_rules = "UPDATE dialplan_rules SET parameters = '%s' WHERE id = %d";
    $sql_links = "SELECT id, object_to_id FROM ".IncomingCalls::RULES_LINKS_TABLE." WHERE object_to_id LIKE 'bri_\__\_1' ESCAPE '\'";
    $update_links = "UPDATE ".IncomingCalls::RULES_LINKS_TABLE." SET object_to_id = '%s' WHERE id = %d";
    $queries = array();
    // update table dialplan_rules
    if ($rows = \Wildix\Databases\WMSDB::getInstance()->query($sql_rules)) {
        while($row = $rows->fetchArray(SQLITE3_ASSOC)){
            $row['parameters'] = preg_replace('/(bri\d_\d_)1/', '${1}0', $row['parameters']);
            $queries[] = sprintf($update_rules, $row['parameters'], $row['id']);
        }
        $rows->finalize();
    }

    // update table dialplan_links
    if ($rows = \Wildix\Databases\WMSDB::getInstance()->query($sql_links)) {
        while($row = $rows->fetchArray(SQLITE3_ASSOC)){
            $row['object_to_id'] = preg_replace('/(bri\d_\d_)1/', '${1}0', $row['object_to_id']);
            $queries[] = sprintf($update_rules, $row['object_to_id'], $row['id']);
        }
        $rows->finalize();
    }

    if(count($queries)){
        foreach ($queries as $query){
            \Wildix\Databases\WMSDB::getInstance()->exec($query);
        }
        $dialplan_class = $GLOBALS['diContainer']->get(IncomingCalls::class);
        $dialplan_class->set_extensions_incomingcalls();
    }
}


/* Update users features which which content in parameters 'briX_X_1' at line 'FKEYS'*/
function update_users_features_call_type_wms30(){

    _log("pre update phonebook", LOG_ERR);
    if(file_exists('/mnt/cticonnect/cticonnectdb')){
        $phonebookDB = new DB_SQLite3('/mnt/cticonnect/cticonnectdb');
        sqlite3FastManip(array('UPDATE cti_contacts SET user_class="whitelist" WHERE user_class="friends";'), $phonebookDB);
    }


    $queries = array();
    $update_rules = "UPDATE dialplan_rules SET parameters = '%s' WHERE id = %d";
    if ($rows = \Wildix\Databases\WMSDB::getInstance()->query("SELECT id, parameters FROM dialplan_rules WHERE parameters LIKE '%\"friends\"%';")) {
        while($row = $rows->fetchArray(SQLITE3_ASSOC)){
            $row['parameters'] = str_replace('"friends"', '"whitelist"', $row['parameters']);
            $queries[] = sprintf($update_rules, $row['parameters'], $row['id']);
        }
        $rows->finalize();
    }

    if(count($queries)){
        foreach ($queries as $query){
            \Wildix\Databases\WMSDB::getInstance()->exec($query);
        }
        $dialplan_class = $GLOBALS['diContainer']->get(IncomingCalls::class);
        $dialplan_class->set_extensions_incomingcalls();
    }
}


function remove_norewrite_networks(){
    $res = array();
    if ($rows = \Wildix\Databases\WMSDB::getInstance()->query('SELECT count(variable) as cnt FROM `system` WHERE `variable` = "NOREWRITE_NETWORKS"')) {
        $res = $rows->fetchArray(SQLITE3_ASSOC);
        $rows->finalize();
    }

    if ($res['cnt'] != 0) {
        \Wildix\Databases\WMSDB::getInstance()->exec('DELETE FROM `system` WHERE  `variable` = "NOREWRITE_NETWORKS"');
    }
}

function update_mail_options() {
    $companies_directory = '/etc/companies.d/';
    $def_muttrc = $companies_directory.'0/Muttrc';
    $is_update = true;

    if (is_writeable($def_muttrc)) {
        foreach ( file($def_muttrc) as $line ) {
            $a2file[] = $line;
            if(strpos($line,'set charset=') !== false)
                $is_update = false;
        }

        if ($is_update) {
            $a2file[] = "set charset=\"utf-8\"\n";
            if($fp = fopen($def_muttrc,'w')){
                fputs($fp,implode('',$a2file));
                fclose($fp);
            }
        }
    }
    if (is_writeable($def_muttrc)) {
        foreach ( file($def_muttrc) as $line ) {
            $a2file[] = $line;
            if(strpos($line,'set send_charset=') !== false)
                $is_update = false;
        }

        if ($is_update) {
            $a2file[] = "set send_charset=\"utf-8\"\n";
            if($fp = fopen($def_muttrc,'w')){
                fputs($fp,implode('',$a2file));
                fclose($fp);
            }
        }
    }
}

function update_proxy_dependency()
{
    $httpProxy = new \Wildix\System\HttpProxy();
    $httpProxy->generateDependency();
}

function set_chown_file_dialplan(){
    exec('sudo chown wms:wms /etc/callweaver/extensions-incomingcalls.lua');

}

function savePorts ($ports) {
    $callweaverConfigFile = PATH_TO_CW_CONF . 'rtp-wms.conf';
    $rtpEngineConfigFile = PATH_TO_RTP_ENGINE_CONF . 'rtp-wms.cfg';
    $wudpechoConfigFile = PATH_TO_WUDPECHO_CONF . 'wudpecho.conf';

    exec('sudo chown wms:wms ' . $wudpechoConfigFile);

    file_put_contents($callweaverConfigFile, "rtpstart=" . $ports['callweaverPortStart'] . "\nrtpend=" . $ports['callweaverPortEnd'] . "\n\n");
    exec('callweaver -rx "sip reload"');
    exec('callweaver -rx "reload res_rtp_asterisk.so"');

    file_put_contents($rtpEngineConfigFile, "PORT_MIN=" . $ports['rtpEnginePortStart'] . "\nPORT_MAX=" . $ports['rtpEnginePortEnd'] . "\n\n");
    exec('sudo systemctl restart rtpengine');

    /* @var $turnServer \Wildix\Settings\TurnServer */
    $turnServer = $GLOBALS['diContainer']->get(\Wildix\Settings\TurnServer::class);

    $turnServer->setParam(\Wildix\Settings\TurnServer::MIN_PORT, $ports['turnServerPortStart']);
    $turnServer->setParam(\Wildix\Settings\TurnServer::MAX_PORT, $ports['turnServerPortEnd']);

    $turnServer->saveConfig();

    file_put_contents($wudpechoConfigFile, "START=" . $ports['wudpEchoPortStart'] . "\nEND=" . $ports['wudpEchoPortEnd'] . "\n\n");
    exec('sudo systemctl restart wudpecho@START wudpecho@END');
}

function update_rtp_ports() {
    $callweaverConfigPath = PATH_TO_CW_CONF . 'rtp-wms.conf';
    $сallweaverPortsStart = null;
    $сallweaverPortsEnd = null;

    $rtpengineConfigPath = PATH_TO_RTP_ENGINE_CONF . 'rtp-wms.cfg';
    $rtpenginePortsEnd = null;

    $wudpechoConfigPath = PATH_TO_WUDPECHO_CONF . 'wudpecho.conf';
    $wudpechoPortsStart = 10000;
    $wudpechoPortsEnd = 59999;

    $reconfigure = false;

    $sipRedirectPort = Wildix\Databases\DEVDB::getInstance()->getSystemVariable('SIP_REDIRECT_PORT', null);

    $iptablesPort = array();
    exec('iptables -nL -t nat 2>/dev/null | grep "ports 5060" | grep "REDIRECT" | awk \'{print $7}\' | awk -F \':\' \'{print $2}\'', $iptablesPort);

    $newRule = isset($iptablesPort[0]) ? false : true;

    $iptablesPort = isset($iptablesPort[0]) ? $iptablesPort[0] : null;

    if ($sipRedirectPort === null || $iptablesPort === null || $iptablesPort !== $sipRedirectPort) {
        $reconfigure = true;
    }

    /* @var $turnServer \Wildix\Settings\TurnServer */
    $turnServer = $GLOBALS['diContainer']->get(\Wildix\Settings\TurnServer::class);

    $turnServerPortsEnd = $turnServer->getParam(\Wildix\Settings\TurnServer::MAX_PORT);

    $wUdpEchoSettingsPortEnd = null;
    $wrongTurnServerPorts    = false;

    if (file_exists($wudpechoConfigPath)) {
        $wudpechoSettings = parse_ini_file($wudpechoConfigPath, true, INI_SCANNER_RAW);

        if (!empty($wudpechoSettings) && !empty($wudpechoSettings['START']) && !empty($wudpechoSettings['END'])) {
            $wUdpEchoSettingsPortEnd = $wudpechoSettings['END'];
            $wrongCloudWudpechoPorts = $wudpechoSettings['START'] != $wudpechoPortsStart || $wUdpEchoSettingsPortEnd != $wudpechoPortsEnd;
            $wrongTurnServerPorts    = $turnServerPortsEnd !== ($wUdpEchoSettingsPortEnd - 1);
            if (\Wildix\License::getInstance()->isCloud() && ($wrongCloudWudpechoPorts || $wrongTurnServerPorts)) {
                $reconfigure = true;
            }

            if (!\Wildix\License::getInstance()->isCloud()) {
                $minCountRtpPorts = getMinCountRtpPorts();

                if ((($wUdpEchoSettingsPortEnd - $wudpechoSettings['START']) < $minCountRtpPorts) || $wrongTurnServerPorts) {
                    $reconfigure = true;
                }
            }
        }
    } else {
        $reconfigure          = true;
        $wrongTurnServerPorts = true;

        touch($wudpechoConfigPath);
        chmod($wudpechoConfigPath, 0775);
    }

    if ($reconfigure === true) {
        if (\Wildix\License::getInstance()->isCloud()) {
            $ports = calculatePorts(10000, 59999);
        } else {
            if (file_exists($rtpengineConfigPath)) {
                // read config
                $rtpengineSettings = parse_ini_file($rtpengineConfigPath, true, INI_SCANNER_RAW);

                if (!empty($rtpengineSettings) && !empty($rtpengineSettings['PORT_MIN']) && !empty($rtpengineSettings['PORT_MAX'])) {
                    $rtpenginePortsEnd = $rtpengineSettings['PORT_MAX'];
                }

                if (!$wUdpEchoSettingsPortEnd) {
                    $wrongTurnServerPorts = $turnServerPortsEnd > $rtpenginePortsEnd;
                }
            }

            if (file_exists($callweaverConfigPath)) {
                // read config
                $сallweaverSettings = parse_ini_file($callweaverConfigPath, true, INI_SCANNER_RAW);

                if (!empty($сallweaverSettings)) {
                    $сallweaverPortsStart = $сallweaverSettings['rtpstart'];
                    $сallweaverPortsEnd = $сallweaverSettings['rtpend'];
                }
            }

            if ($сallweaverPortsStart && ($rtpenginePortsEnd || $сallweaverPortsEnd || ($turnServerPortsEnd && !$wrongTurnServerPorts))) {
                $wudpechoPortsStart = $сallweaverPortsStart - 2;

                if ($turnServerPortsEnd && !$wrongTurnServerPorts) {
                    $wudpechoPortsEnd = $turnServerPortsEnd + 1;
                } else if ($rtpenginePortsEnd) {
                    $wudpechoPortsEnd = $rtpenginePortsEnd + 1;
                } else {
                    $wudpechoPortsEnd = $сallweaverPortsEnd + 1;
                }
            }

            if ($wudpechoPortsEnd < $wUdpEchoSettingsPortEnd) {
                // set port end from config
                $wudpechoPortsEnd = $wUdpEchoSettingsPortEnd;
            }
            $ports = calculatePorts($wudpechoPortsStart, $wudpechoPortsEnd);
        }

        savePorts($ports);
        forward_5060_port($ports['callweaverPortStart'], $newRule);
    }
}

function forward_5060_port($callweaverPort, $new) {
    $needForwardPort5060 = false;
    $port5060 = $callweaverPort - 1;

    // getSystemVariable
    $sipRedirectPort = Wildix\Databases\DEVDB::getInstance()->getSystemVariable('SIP_REDIRECT_PORT', null);
    if ($sipRedirectPort === null || $sipRedirectPort != $port5060) {
        $needForwardPort5060 = true;
    }

    if ($needForwardPort5060) {
        require_once "classes/network/network.class.php";
        $network_class = new network();

        $network_class->forward_5060_port($port5060, $new);
        exec("sudo /sbin/iptables -t nat -A PREROUTING -p udp -j UDP-SIP");
    }
}

/** Update udptl.conf ports (should be the same as in callweaver rtp-wms.conf)
*   In WMS2.0 udptl.conf had the following format:
*
*   [general]
*   T38FaxMaxDatagram=400
*   T38FaxMaxBuffer=400
*
*   should be changed to WMS3.0 format
*/
function update_udptl_conf(){
    $path_udptl = PATH_TO_CW_CONF . 'udptl.conf';
    $path_rtp = PATH_TO_CW_CONF . 'rtp-wms.conf';

    // default configuration
    $udptl_settings['general']['udptlstart'] = 10000;
    $udptl_settings['general']['udptlend'] = 15000;
    $udptl_settings['general']['udptlfecentries'] = 3;
    $udptl_settings['general']['udptlfecspan'] = 3;
    $udptl_settings['general']['use_even_ports'] = 'no';


    if(file_exists($path_rtp)) {
        // read callweaver config
        $rtp_settings = parse_ini_file($path_rtp, true, INI_SCANNER_RAW);
        if (!empty($rtp_settings['rtpstart']) && !empty($rtp_settings['rtpend'])) {
            $udptl_settings['general']['udptlstart'] = $rtp_settings['rtpstart'];
            $udptl_settings['general']['udptlend'] = $rtp_settings['rtpend'];
        }
    }
    // write config
    write_ini_file($path_udptl, $udptl_settings, true);
    exec('sudo chown wms:wms ' . $path_udptl);
    exec('callweaver -rx "reload udptl"');
}

function update_domain_portal(){
    $network = new network();
    $serial = \Models\PBX::getInstance()->getSerial();
    if( ! $pbx = \Wildix\PBXes\PBXes::getInstance()->getPBXBySerial($serial)){
        return;
    }
    $new_domain = false;
    $_portalApiUrl = env('SERVICE_PORTAL_API_URI');
    $_portalUrl    = env('SERVICE_UPGRADE_PORTAL_URI');
    $portalService = new \Wildix\Services\Portal(\Logger\Log::ERROR, $_portalApiUrl, $_portalUrl);

    if($domain = $portalService->getDomain()){
        if($domain['alias']){
            if($domain['alias'] != $pbx->getDomain() || $network->systemname.'.wildixin.com' != $domain['alias']){
                $new_domain = $domain['alias'];
                [$new_domain,] = explode('.', $new_domain);
            }
        }elseif($serial.'.wildixin.com' != $pbx->getDomain()){
            $domain = str_replace('.wildixin.com', '', $pbx->getDomain());
            if($domain && preg_match('/^[a-zA-Z0-9\-]+$/', $domain) && $domain != $serial){
                $ch = $portalService->checkDomain($domain);
                if($ch['success'] === false && $ch['error']['code'] > 300 && $ch['error']['code'] < 400){
                    $domain .= $serial;
                    $ch = $portalService->checkDomain($domain);
                    $new_domain = $domain;
                }
                if($ch['success'] === true){
                    $portalService->setDomain($domain);
                }else{
                    $new_domain = $serial;
                }
            }else{
                $new_domain = $serial;
            }
        }
    }elseif( ! $pbx->getDomain()){
        $new_domain = $serial;
    }

    if( ! $new_domain && $network->systemname.'.wildixin.com' != $pbx->getDomain()){
        [$new_domain,] = explode('.', $pbx->getDomain());
    }

    if($new_domain){
        $network->set_sysname($new_domain, true);
    }
}

function upSyncLdapToActiveD(){
    $aclpbx_class = new aclpbx();

    $set = $aclpbx_class->get_sync_settings_n_map();
    $configFile = '/etc/ad_connect.conf';
    if($set['global']['backend'] == 'ldap' && file_exists($configFile)){

        $ad = parse_ini_file($configFile, false, INI_SCANNER_RAW);
        if( ! empty($ad['host']) && ! empty($ad['windomain'])){
            [$ad['host'],] = explode(':', $ad['host']);
            if( ! $set['settings']['activeD']['host'] && $set['settings']['ldap']['host'] == $ad['host']){

                $set['settings']['activeD'] = $set['settings']['ldap'];
                $set['map']['activeD'] = $set['map']['ldap'];
                $set['global']['backend'] = 'activeD';
                $set['settings']['ldap'] = $set['default']['settings']['ldap'];
                $set['map']['ldap'] = $set['default']['map']['ldap'];

                $save_settings = array();
                $save_settings['global'] = $set['global'];
                foreach ($set['settings'] as $backend => $settings) {
                    $save_settings[$backend]['settings'] = $settings;
                    $save_settings[$backend]['map'] = $set['map'][$backend];
                }
                $save_settings['recurrent_job'] = $set['recurrent_job'];

                $aclpbx_class->set_sync_settings_n_map($save_settings);
            }
        }
    }
    // Add 'type' if not exists
    if(file_exists($configFile)){
        $ad = parse_ini_file($configFile, false, INI_SCANNER_RAW);
        if( empty($ad['type']) && !empty($set['global']['backend']) ){
            $availableTypes = array('activeD', 'domino', 'office365', 'google');
            if ( in_array($set['global']['backend'], $availableTypes) ) {
                $ad = array('type'=>$set['global']['backend']) + $ad;
                write_ini_file($configFile, $ad, true);
            }
        }
    }
}

function upPathActiveDConfig(){
    /*
     * relocation config Active Derect
     * */

    $old = '/etc/ad_connect.conf';
    $new = '/rw2/etc/pbx/ad_connect.conf';

    if(!file_exists($old)){
        symlink($new, $old);
    }elseif(!is_link($old)){
        rename($old, $new);
        chown($new, 'wms');
        chgrp($new, 'wms');
        symlink($new, $old);
    }
}

function setConfigOpenvpn(){
    $conf = '/rw2/etc/pbx/remote_support.config';
    $monit = '/etc/monit/openvpn.conf';

    if(file_exists($conf) && file_exists($monit)){
        $array = @parse_ini_file($conf);
        $set = file($monit);
        if(isset($array['autostart']) && $array['autostart'] == 0){
            $set = preg_replace('/^#?(.*)$/', '#$1', $set);
        }else{
            $set = preg_replace('/^#?(.*)$/', '$1', $set);
        }
        @file_put_contents($monit, implode('', $set));
        chgrp($conf, 'wms');
        chown($conf, 'wms');
    }

    chgrp($monit, 'wms');
    chown($monit, 'wms');
}

function updateConfigWmsnet(){
    $multipbx_class = new multipbx();
    $wmsnet_info = $multipbx_class->get_pbx_net_conf();
    $current_mode = $multipbx_class->get_mode();
    if($current_mode == '1'){
        $multipbx_class->set_ldap_connect_conf(array('host_rw' => $wmsnet_info['SRV_IP']));
    }

    $multipbx_class->set_sip_wms_network_conf(
        array(
            'username' => \Models\PBX::getInstance()->getSerial(),
            'secret' => $wmsnet_info['NSECRET'],
        )
    );
}

function lowerPriorityH264(){
    // Enable encryption of calls via TLS / SRTP
    $conf = PATH_TO_CW_CONF.'sip-wms.conf';
    $temp = parse_ini_file($conf);
    if(!empty($temp) && !empty($temp['allow'])){
        //g722:20,alaw:20,ulaw:20,g729:20,h264,h263,h263p,vp8
        if(preg_match("/^(.*?)(,h264.*?)(,vp8)$/", $temp['allow'], $matches)){
            if(!empty($matches) && !empty($matches[3]) && $matches[3] == ',vp8'){
                //g722:20,alaw:20,ulaw:20,g729:20,vp8,h264,h263,h263p
                $temp['allow'] = $matches[1].$matches[3].$matches[2];
                write_ini_file($conf, $temp, true);
            }
        }
    }
}

function update_smtp_settings() {
    $smtpService = Container::get(\Wildix\Smtp::class);

    $value = Container::get(\Wildix\Databases\WMSDB::class)->getSystemVariable(\Wildix\Databases\WMSDB::SYSTEM_SMTP_SETTINGS);
    if (is_null($value)) {
        // Upgrade from prev settings from config file
        $options = $smtpService->getMailOptions();

        // This function will write to DB and config file
        // Also it will look for "is_default_settings" is enabled it will apply new default settings
        $smtpService->setMailOptions($options);
    } else {
        // In DB found value for settings
        // Compare with values in config file
        // rewrite if differs
        // (This can be useful after apply backup)
        if (!$smtpService->isConfigSynchronized()) {
            $smtpService->setMailOptions(json_decode($value, true));
        }
    }
}

function update_adSingleSignOn_settings() {
    $config = new \Wildix\Settings\ConfigFile(\Wildix\System\ADSingleSignOnService::CONFIG_FILE);
    $adSingleSignOn = new \Wildix\System\ADSingleSignOnService($config);
    $fromDB = \Wildix\Databases\WMSDB::getInstance()->getSystemVariable(\Wildix\System\ADSingleSignOnService::AD_SSO);

    if (empty($fromDB)) {
        $values = $adSingleSignOn->getSettings();
        $adSingleSignOn->setSettings($values);
    } else {
        if(!$adSingleSignOn->isConfigSynchronized()){
            $adSingleSignOn->setSettings(json_decode($fromDB, true));
        }
    }
}

function update_ntp_settings() {
    try {
        $ntp = new \Wildix\System\Ntp();
        $ntp->changeGroupAndOwner('wms', 'wms');
        $ntp->updateNtpConf();

    } catch (\Exception $e) {
        echo $e->getMessage();
    }

}

function update_snmp_settings(){
    $conf = '/rw2/etc/snmp/snmpd.conf';

    $toConf = array(
        'rocommunity public'.PHP_EOL,
        'pass .1.3.6.1.4.1.7777.1 /usr/bin/php /usr/sbin/snmp-trunks'.PHP_EOL
    );

    $fromConf = file($conf);
    $search = '1.3.6.1.4.1.7777.1';
    $matches = array_filter($fromConf, function($var) use ($search) {
        return preg_match("/$search/i", $var);
    });
    if ( empty($matches) ) {
        file_put_contents($conf, array_merge($fromConf, $toConf));
    }
}

function updateEnUsLanguage() {
    try {
        $sip = SipRtp::getInstance()->getGeneralSip();
        if ($sip['language'] == 'us') {
            $sip['language'] = 'en-us';
            SipRtp::getInstance()->setGeneralSip(
                $sip
            );
        }

        $langs = $GLOBALS['diContainer']->get(LanguageAndRegion::class)->getInstalledLanguages();

        $key = array_search('us', $langs);
        if ($key !== false) {
            $langs[$key] = 'en-us';
            $GLOBALS['diContainer']->get(LanguageAndRegion::class)->setLanguages($langs);
        }
    } catch (\Exception $e) {
        echo $e->getMessage();
    }
}

function configureEjabberdLuaWorkers() {
    $diContainer = new \Wildix\DependencyInjection\Container();

    $diContainer->get(\Wildix\EjabberdMod\Astman::class)->configureLuaWorkers();
}

function addDialplanRulenames() {
    $logger = $GLOBALS['diContainer']->get(Log::class);

    $query = "SELECT id FROM dialplan_rulenames WHERE rulename='classound';";
    $result = false;
    if ($rows = \Wildix\Databases\WMSDB::getInstance()->query($query)) {
        $result = $rows->fetchArray(SQLITE3_ASSOC);
        $rows->finalize();
    }

    if (!is_array($result) || empty($result['id'])) {
        $logger->info(__LINE__, 'Add dialplan rulename "classound" to table "dialplan_rulenames"');
        \Wildix\Databases\WMSDB::getInstance()->exec("INSERT INTO dialplan_rulenames(rulename,subrule_id) VALUES('classound','');");
    } else {
        $logger->info(__LINE__, 'Dialplan rulename "classound" exist in table "dialplan_rulenames"');
    }
}

function addPermanentCORSDomainsIfNeed() {
    $settings = $GLOBALS['diContainer']->get(Service::class);
    $settings->save($settings->getSettings()->toArray());
}

function turnOffWmsNetworkIfLowCredentials() {
    if (\Models\PBX::getInstance()->isEnabledWmsNetwork()) {
        $multiPbx = new multipbx();
        $netConf  = $multiPbx->get_pbx_net_conf();

        if (!$multiPbx->isCredentialsSecure(($netConf['NCOMMUNITY'] ?? ''), ($netConf['NSECRET'] ?? ''))) {
            $pbx = \Models\PBX::getInstance();

            $logger = $GLOBALS['diContainer']->get(Log::class);
            $logger->warning(
                __LINE__,
                \sprintf(
                    'WMS network disabled because of low security of credentials. Current role %s, Number of PBXs in WMS-network %d, Server serial %s',
                    ($pbx->isMaster() ? 'Server' : 'Client'),
                    count(multipbx::getAllPbxes()),
                    ($pbx->isMaster() ? $pbx->getSerial() : $multiPbx->getNetworkServerPbxSerial())
                )
            );

            $multiPbx->set_pbx_net_conf(['FORCE_DISABLED' => 1]);
            $networkServices = $GLOBALS['diContainer']->get(NetworkServices::class);

            if ($pbx->isMaster()) {
                $networkServices->stopServer();
            } else if ($pbx->isSlave()) {
                $networkServices->stopClient();
            }
        }
    }
}

function updateLdapProperty() {
    $PBX         = $GLOBALS['diContainer']->get(\Models\PBX::class);
    $ldapService = $GLOBALS['diContainer']->get(LdapService::class);

    $ldapService->init('update_credentials');
    $PBXes = $GLOBALS['diContainer']->get(Wildix\PBXes\PBXes::class);
    $entry = $PBXes->getPBXBySerial($PBX->getSerial());

    if(!$entry || !$PBX->isEnabledWmsNetwork()) {
        return;
    }

    if ($PBX->isSlave()) {
        $configs = getTProxyPortConfigs();
        $result  = [
            PBXModel::PUBLIC_PORT => $configs['external_https_port'],
            PBXModel::IS_MASTER   => false
        ];
    } else {
        $result  = [
            PBXModel::IS_MASTER => true
        ];
    }
    $PBXes->updatePBXProperty($result, $entry);
}

function clearUsersAvatarCache() {
    $avatarCacheDB = $GLOBALS['diContainer']->get(AvatarCache::class);
    $avatarCacheDB->clearAllCache();
}

function updateNtpConfig() {
    $PBX             = $GLOBALS['diContainer']->get(\Models\PBX::class);
    $networkServices = $GLOBALS['diContainer']->get(NetworkServices::class);
    $netRepository   = $GLOBALS['diContainer']->get(NetRepository::class);
    $client          = $GLOBALS['diContainer']->get(Client::class);

    if ($PBX->isSlave()) {
        $netConfigData = $netRepository->get();

        $requestParams = [
            'master_connect_login'    => $netConfigData['NCOMMUNITY'],
            'master_connect_password' => $netConfigData['NSECRET']
        ];

        $ntpData = $networkServices->requestToServer('POST', 'ntp', $netConfigData['SRV_IP'], $requestParams);

        $client->configuringNtpServer($ntpData['ntp']);
    }
}

function createCustomEnvFile() {
    $logger        = $GLOBALS['diContainer']->get(Log::class);
    $pathCustomEnv = '/rw2/etc/env.custom.ini';

    if (!file_exists($pathCustomEnv) && !touch($pathCustomEnv)) {
        $logger->error(__LINE__, sprintf('[CustomEnvFile]. Failed to create: %s', $pathCustomEnv));
    }
}

function createHeadersCustomFile() {
    $logger = $GLOBALS['diContainer']->get(Log::class);

    if (! \Wildix\Services\Header::getInstance()->createCustomFile()) {
        $logger->error(__LINE__, sprintf('[CustomEnvFile]. Failed to create: %s', \Wildix\Services\Header::CUSTOM_PATH));
    }
}

function restoreMinTlsVersion() {
    $tProxyRepository = $GLOBALS['diContainer']->get(TlsRepository::class);

    $tlsVersion = env(strtoupper(TlsModelSettings::SSL_VERSION_FIELD));

    $tProxyRepository->save(
        new TlsModelSettings(
            [TlsModelSettings::SSL_VERSION_FIELD => $tlsVersion]
        ),
        true
    );
}

function updateWmsVersion() {
    exec('sudo /etc/network/if-up.d/ldap update');
}

function enableSmsByDefault() {
    $countryCode = $GLOBALS['diContainer']->get(ExtensionsVariables::class)->get(ExtensionsVariables::COUNTRY_CODE);
    $envConfig   = $GLOBALS['diContainer']->get(EnvConfig::class);

    if (!$envConfig->get('SERVICE_SMS_ENABLED')
        && in_array($countryCode, SmsService::DEFAULT_SUPPORTED_COUNTRY_CODES, true)
        && $GLOBALS['diContainer']->get(License::class)->haveLicense(License::TYPE_CLASSOUND)
    ) {
        $envConfig->set('SERVICE_SMS_ENABLED', 'yes');
        $envConfig->save();
    }
}

function updatePbxIp() {
    exec('/usr/sbin/wms_network_update_ip');
}

function fillEmptyDepartmentField() {
    //phpcs:ignore
    /** @var \Api\Jobs\FillDepartmentField $job */
    $job = $GLOBALS['diContainer']->get(\Api\Jobs\FillDepartmentField::class);

    $job->run();
}

function updateTProxyProtocols() {
    $ldapRadiusService = $GLOBALS['diContainer']->get(\Wildix\System\LdapRadius::class);
    $tProxyService     = $GLOBALS['diContainer']->get(Services\TProxyService::class);
    $pbx               = $GLOBALS['diContainer']->get(\Models\PBX::class);

    if ($ldapRadiusService->isEnabled() || $pbx->isMaster()) {
        $tProxyService->addLdapProxying();
        $tProxyService->saveAndReload();
    }
}
