<?php

function saveFeaturesToUserFile($uid, $values) {
    static $lua;

    if (! is_object($lua)) {
        $lua = new Services\LuaService();
    }

    if (isset($values['POPUPURL']) && !empty($values['POPUPURL']['url'])) {
        $values['POPUPURL']['url'] = htmlspecialchars($values['POPUPURL']['url'], ENT_QUOTES);
    }

    return $lua->saveUserFeatures($uid, $values);
}

function getUserFeatures($userid, $wmsUsersList = null) {
    static $luaService;

    if (! is_object($luaService)) {
        $luaService = new Services\LuaService();
    }
    $userdata = array();

    $isChangedRoster = false;
    $isChangedACL    = false;

    // Get features by uid
    if ($userid != 'multiple') {
        $userdata = $luaService->getUserFeatures($userid);
        if ($wmsUsersList == null) {
            $wmsUsersList = get_WmsGroupsList($userid);
        }


        if (empty($userdata['ROSTER'])) {
            $userdata['ROSTER'] = fillRosterIfEmpty($userid, $userdata['ROSTER']);
            $isChangedRoster    = true;
        }


        if (!$isChangedRoster && $userdata['ROSTER'] && is_array($userdata['ROSTER'])) {
            foreach ($userdata['ROSTER'] as $group_name => $users) {
                $finded = false;
                foreach ($wmsUsersList as $group) {
                    if ($group_name == $group['title']) {
                        $finded = true;
                        break;
                    }
                }
                if (!$finded) {
                    unset($userdata['ROSTER'][$group_name]);
                    $isChangedACL = true;
                }
            }
        }
    } else {
        // Get default features for multiply users
        $userdata = $luaService->getUserDefaultFeatures($userid);
    }

    if (isset($userdata['POPUPURL']) && !empty($userdata['POPUPURL']['url'])) {
        $userdata['POPUPURL']['url'] = htmlspecialchars_decode($userdata['POPUPURL']['url'], ENT_QUOTES);
    }

    if ($userid != 'multiple' && ($isChangedACL || $isChangedRoster)) {
        saveFeaturesToUserFile($userid, $userdata);
    }

    return $userdata;
}

function get_WmsGroupsList($userId = null) {
    if (! class_exists('WMS_Ldap')) {
        include_once 'common/wms_ldap.php';
    }
    $res          = array();
    $userLdapData = array();
    if ($userId !== null) {
        $userLdapData = WMS_Ldap::getInstance()->getEntry(WMS_Ldap::PERSONS, '(uid=' . $userId . ')', array('cn', 'userPassword', 'owner', \Wildix\Colleagues\Colleague::LICENSE_TYPE));
    }

    if (empty($userLdapData)) {
        return $res;
    }

    $values = WMS_Ldap::getInstance()->getEntries(WMS_Ldap::GROUPS, '', array('dn', 'cn'));

    foreach ($values as $v) {
        if (is_acl_subject_allowed($userLdapData['owner'], 'yesno', 'SEE', $userLdapData[\Wildix\Colleagues\Colleague::LICENSE_TYPE] ?? '', $v['dn'])){
            $res[$v['dn']]['title'] = $v['cn'];
        }
    }

    return $res;
}

function search_WmsUsersListLimit($search, $skip_phones = array(), $userId = null, $limit = 20) {
    if (! class_exists('WMS_Ldap')) {
        include_once 'common/wms_ldap.php';
    }

    $res          = array();
    $userLdapData = array();
    if ($userId !== null) {
        $userLdapData  = WMS_Ldap::getInstance()->getEntry(WMS_Ldap::PERSONS, '(uid=' . $userId . ')', array('cn', 'userPassword', 'owner', LDAP_EXTEN_NUMBER, \Wildix\Colleagues\Colleague::LICENSE_TYPE));
        $skip_phones[] = $userLdapData[LDAP_EXTEN_NUMBER];
    }

    if (!empty($userLdapData)) {
        $values = WMS_Ldap::getInstance()->getEntries(WMS_Ldap::GROUPS, '', array('dn', 'cn'));
        foreach ($values as $v) {
            if (is_acl_subject_allowed($userLdapData['owner'], 'yesno', 'SEE', $userLdapData[\Wildix\Colleagues\Colleague::LICENSE_TYPE], $v['dn'])) {
                $res[$v['dn']]['title'] = $v['cn'];
            }
        }
    }

    $lens = strlen(trim($search));
    $cs   = count($skip_phones);

    if ($cs != 0 or $lens != 0) {
        $filter = '(&';
        if ($cs != 0) {
            for ($i = 0, $len = sizeof($skip_phones); $i < $len; ++$i) {
                $filter .= '(!(' . LDAP_EXTEN_NUMBER . '=' . $skip_phones[$i] . '))';
            }
        }

        if ($lens != 0) {
            $search  = htmlspecialchars(trim($search));
            $filter .= '(|(cn=*' . $search . '*)(' . LDAP_EXTEN_NUMBER . '=*' . $search . '*))';
        }

        $filter .= ')';
    }

    $values = WMS_Ldap::getInstance()->getEntriesSortLimit(WMS_Ldap::PERSONS, '(' . LDAP_EXTEN_NUMBER . '=*)' . $filter, array('cn', LDAP_EXTEN_NUMBER, 'owner'), 0, $limit);
    if (empty($values) || !is_array($values)) {
        return false;
    }

    foreach ($values as $v) {
        if (isset($res[$v['owner']])) {
            $res[$v['owner']]['users'][] = array(
                'name' => $v['cn'],
                'jid' => $v[LDAP_EXTEN_NUMBER] . '@wildix',
                'number' => $v[LDAP_EXTEN_NUMBER]
            );
        }
    }

    $return          = array();
    $return['count'] = $values['count'];
    foreach ($res as $key => $values) {
        $users = $values['users'] ?? [];
        if (count($users)) {
            $return[$key] = $values;
        }
    }

    return $return;
}

function get_params($owner_phonenumber, $owner_nickname, $owner_group = false, $roster=array()) {
    $param = array();
    foreach ($roster as $group => $users) {
        foreach ($users as $nickname => $ujid) {
            list($user_phonenumber, ) = explode('@', $ujid);

            if (preg_match('/(.*)\s\[.*/', $nickname, $matches)) {
                $nickname = $matches[1];
            }

            $tmp = array(
            'localuser'   => $owner_phonenumber,
                'localserver' => 'wildix',
            // by default always wildix
                'localnick'   => "$owner_nickname ($owner_phonenumber)",
                'user'        => $user_phonenumber,
                'server'      => 'wildix',
                'nick'        => "$nickname ($user_phonenumber)",
                'group'       => $group,
                'subs'        => 'both'
            );

            if ($owner_group) {
                $tmp['localgroup'] = $owner_group;
            }

            $param[] = $tmp;
        }
    }

    return $param;
}


function fillRosterIfEmpty($uid, $roster) {
    if (!empty($roster)) {
        return $roster;
    }

    $user       = \Wildix\Colleagues\Colleagues::getInstance()->getUserByID($uid);
    $pbxDn      = $user->getPBXDn();
    $colleagues = \Wildix\Colleagues\Colleagues::getInstance()->getUsersByDepartmentAndPbx(
        $user->getDepartment(),
        $pbxDn,
        $user,
        \Wildix\License::ROSTER_DEFAULT_SIZE
    );

    if (empty($colleagues) || count($colleagues) === 1) {
        $colleagues = \Wildix\Colleagues\Colleagues::getInstance()->getUsersByGroupAndPbx(
            \Wildix\Colleagues\Groups::getInstance()->getGroupByDn($user->getGroupDn()),
            $pbxDn,
            \Wildix\License::ROSTER_DEFAULT_SIZE
        );
    }

    return fillRoster($user, $colleagues);
}

function fillRoster($user, $colleagues) {
    $roster     = array();
    $colleagues = filterColleagues($user, $colleagues);

    if (empty($colleagues)) {
        return $roster;
    }

    $groups = array();
    $gr     = \Wildix\Colleagues\Groups::getInstance()->getGroups($user);

    if ($gr) {
        foreach ($gr as $group) {
            $groups[$group->getDn()] = $group->getName();
        }
    }

    foreach ($colleagues as $colleague) {
        if ($colleague && $groups[$colleague->getGroupDn()]) {
            $key = $colleague->getName() . ' [' . $colleague->getExtension() . ']';
            $roster[$groups[$colleague->getGroupDn()]][$key] = $colleague->getExtension();
        }
    }

    return $roster;
}

function filterColleagues($user, $colleagues) {
    if (empty($colleagues)) {
        return array();
    }

    $countUsers     = count($colleagues);
    $maxRosterUsers = \Wildix\License::getInstance()->getMaxRosterUsers();

    if ($countUsers > $maxRosterUsers) {
        $colleagues = array_slice($colleagues, 0, $maxRosterUsers);
    }

    // exclude himself
    foreach ($colleagues as $key => $colleague) {
        if ($colleague->getExtension() === $user->getExtension()) {
            array_splice($colleagues, $key, 1);
        }
    }

    return $colleagues;
}

// ----------------------------------------------------------------------
function getGlobalFeatures() {
    static $luaService;

    if (! is_object($luaService)) {
        $luaService = new Services\LuaService();
    }
    $result       = $luaService->getFeatures();
    $def_features = getGlobalDefaultFeatures();

    return array_merge($def_features, $result);
}
// }} ------------------------------------------------------------------------------------------
function getGlobalDefaultFeatures() {
    // default values
    $defaultFeatures = array(
        // features
        'STATUS' => array(
            'access' => '60',
            'direct' => '_60!',
            'change' => true
        ),

        'BCF' => array(
            'access' => '61',
            'direct' => '_61!'
        ),

        'UCF' => array(
            'access' => '62',
            'direct' => '_62!',
        ),

        'FCF' => array(
            'access' => '63',
            'direct' => '_63!',
        ),

        'CW' => array(
            'access' => '64',
            'direct' => '_64!',
            'change' => true
        ),

        'MEXT' => array(
            'access' => '75',
            'direct' => '_75*!',
        ),

        'TOUT' => array(
            'access' => '65',
            'direct' => '_65!',
        ),

        'CALLBLOCK' => array(
            'access' => '72',
            'direct' => '_72*!',
            'change' => true
        ),

        'ROAD' => array(
                'access' => '68',
                'direct' => '_68*!',
                'change' => true
        ),

        'MOBCONFIRMATION' => array(
            'access' => '69',
            'direct' => '_69*!',
            'change' => true
        ),

        'VMACCESS' => array(
            'access' => '81',
            'direct' => '_81!',
        ),

        'DIRECTORY' => array(
            'access' => '82',
            'direct' => '_82!',
        ),

        'LOGIN' => array(
            'access' => '99',
            'direct' => '_99!',
        ),

        'PERSONALRECORD' => array(
            'access' => '84',
            'direct' => '_84!',
        ),

        'PBXRECORD' => array(
            'access' => '74',
            'direct' => '_74!',
        ),

        'CBARGE' => array(
            'access' => '85',
            'direct' => '_85!',
        ),

        'SBARGE' => array(
            'access' => '86',
            'direct' => '_86!',
        ),

        'PBARGE' => array(
            'access' => '87',
            'direct' => '_87!',
        ),

        'SENDDOC' => array(
            'access' => '89',
            'direct' => '_89!',
        ),

        'FAXRELAY' => array(
            'access' => '90',
            'direct' => '_90!',
        ),

        'PAGING' => array(
            'access' => '91',
            'direct' => '_91!',
        ),

        'HIDECID' => array(
            'access' => '92',
            'direct' => '_92!',
        ),

        'SWITCH' => array(
            'access' => '93',
            'direct' => '_93!',
        ),

        '3SWITCH' => array(
            'access' => '94',
            'direct' => '_94!',
        ),

        'STIME' => array(
            'access' => '95',
            'direct' => '_95!',
        ),

        'PICKUP' => array(
            'access' => '88',
            'direct' => '_88!',
        ),

        'CONTINUITYCALL' => array(
                'access' => '*5',
                'direct' => '_5!',
        ),

        'QCALL' => array(
            'access' => '79',
            'direct' => '_79!',
        ),

        'CGMANAGER' => array(
                'access' => '97',
                'direct' => '_97!',
        ),

        'INTERCOM' => array(
            'access' => '96',
            'direct' => '_96!',
        ),

        'CONFERENCE' => array(
            'access' => '98',
            'direct' => '_98!',
        ),

        'ECHO' => array('access' => '76'),

        'SHORTNUM' => array(
            'access' => '80',
            'direct' => '_80!',
        ),

        'PREANSWER' => array(
            'gotovm' => '1',
            'gotoprivat' => '2',
            // 'gotoconference' => '3',
            'gotointercom' => 4,
            'gotocc' => '5',
        ),

        'PREFIX' => array(
            'access' => ''
        ),

        'IDENTITY' => ['access' => '78'],
    );

    if (Bticino::getInstance()->isInstalled()) {
        $defaultFeatures['WHOTELINSPECT'] = array(
                'access' => '774',
                'direct' => '_774!',
                'change' => '[01]'
        );
        $defaultFeatures['WHOTELBAR']     = array(
                'access' => '772',
                'direct' => '_772!'
        );
    }

    $defaultFeatures['WHOTELMUR']   = array(
            'access' => '771',
            'direct' => '_771!',
            'change' => '[01]'
    );
    $defaultFeatures['WHOTELALARM'] = array(
            'access' => '773',
            'direct' => '_773!',
    );

    return $defaultFeatures;
}


function saveGlobalFeatures($values) {
    $FEATURES = feature_names();
    $SERVICES = service_names();

    $pbxfeatures[] = 'extensions["pbxfeatures"] = {';
    $pbxservices[] = 'extensions["pbxservices"] = {';

    // {{ Sort to reverse mode
    $defaultFeatures = getGlobalDefaultFeatures();
    $orderedFeatures = array();
    foreach ($defaultFeatures as $key => $value) {
        // !! do not store empty value, take default !!
        $orderedFeatures[$key] = $values[$key] == '' ? $value['access'] : $values[$key];
    }

    $codePrefix = $orderedFeatures['PREFIX'];

    arsort($orderedFeatures, SORT_NUMERIC);
    // }}
    // dump to lua structure
    $output[] = 'gl_features = {';

    $pbxservices[] = '["story"] = function() return require_once"services":start_call("STORY"); end;' . PHP_EOL;
    $pbxservices[] = '["_briX!"] = function() return require_once"services":start_call("PSTN_TRUNK_OCCUPATION"); end;' . PHP_EOL;
    $pbxservices[] = '["_priX!"] = function() return require_once"services":start_call("PSTN_TRUNK_OCCUPATION"); end;' . PHP_EOL;
    $pbxservices[] = '["_gsmX!"] = function() return require_once"services":start_call("PSTN_TRUNK_OCCUPATION"); end;' . PHP_EOL;
    $pbxservices[] = '["_f[x]oX.X"] = function() return require_once"services":start_call("PSTN_TRUNK_OCCUPATION"); end;' . PHP_EOL;
    $pbxservices[] = '["_gpickup*!"] = function() return require_once"services":start_call("GPICKUP"); end;' . PHP_EOL;
    $pbxservices[] = '["_cg_."] = function() return require_once"services":start_call("QCALL",3); end;' . PHP_EOL;
    $pbxservices[] = '["_co[n]f*!"] = function() return require_once"services":start_call("CONFERENCE"); end;' . PHP_EOL;
    $pbxservices[] = '["_vm*."] = function() return require_once"services":start_call("VMTRANSFER"); end;' . PHP_EOL;
    $pbxservices[] = '["*wair*"] = function() return require_once"services":start_call("CONTINUITYCALL"); end;' . PHP_EOL;

    foreach ($orderedFeatures as $key => $value) {
        if (in_array($key, array('BTX', 'ATX', 'DIS', 'REC', 'PREANSWER'))) {
            continue;
        }

        $output[] = '["' . $key . '"] = {';
        $output[] = '["access"] = "' . $value . '",';

        if (isset($defaultFeatures[$key]['direct'])) {
            $output[] = '["direct"] = "_' . $value . '*!",';
        }

        $output[] = '},';

        $extension = str_replace(
            array('n', 'x', 'z'),
            array('[n]', '[x]', '[z]'),
            strtolower($key)
        );
        // x,n,z
        // gl_features holds clear values
        // extensions array can has a prefix for all codes
        if ($codePrefix != '' && (in_array($key, $FEATURES) || in_array($key, $SERVICES))) {
            $value = $codePrefix . $value;
        }

        if (in_array($key, $FEATURES)) {
            $pbxfeatures[] = '["' . strtolower($key) . '"] = function() return require_once"services":start_call("' . $key . '"); end;' . PHP_EOL;
            $pbxfeatures[] = '["' . $value . '"] = function() return require_once"services":start_call("' . $key . '"); end;' . PHP_EOL;

            if (isset($defaultFeatures[$key]['direct'])) {
                $pbxfeatures[] = '["_' . $extension . '*!"] = function() return require_once"services":start_call("' . $key . '"); end;' . PHP_EOL;
                $pbxfeatures[] = '["_' . $value . '*!"] = function() return require_once"services":start_call("' . $key . '"); end;' . PHP_EOL;
                if (empty($defaultFeatures[$key]['change'])) {
                    $pbxfeatures[] = '["_' . $value . '!"] = function() return require_once"services":start_call("' . $key . '",' . strlen($value) . '); end;' . PHP_EOL;
                } else if ($key == 'STATUS') {
                    // Change status to Online, Away, Dnd assumes 600,601,602 codes
                    $pbxfeatures[] = '["_' . $value . '[0-2]"] = function() return require_once"services":start_call("' . $key . '",' . strlen($value) . '); end;' . PHP_EOL;
                } else {
                    $pbxfeatures[] = '["_' . $value . '[013]"] = function() return require_once"services":start_call("' . $key . '",' . strlen($value) . '); end;' . PHP_EOL;
                }
            }
        } else if (in_array($key, $SERVICES)) {
            if (strtoupper($key) === 'IDENTITY') {
                $pbxservices[] = '["' . $value . '"] = function() return require_once"services":start_call("' . $key . '"); end;' . PHP_EOL;
                $pbxservices[] = '["_' . $value . '!"] = function() return require_once"services":start_call("' . $key . '",' . strlen($value) . '); end;' . PHP_EOL;
                continue;
            }

            $pbxservices[] = '["' . strtolower($key) . '"] = function() return require_once"services":start_call("' . $key . '"); end;' . PHP_EOL;
            $pbxservices[] = '["' . $value . '"] = function() return require_once"services":start_call("' . $key . '"); end;' . PHP_EOL;

            if (isset($defaultFeatures[$key]['direct'])) {
                $change = $defaultFeatures[$key]['change'];

                if (empty($change)) {
                    $pbxservices[] = '["_' . $extension . '*!"] = function() return require_once"services":start_call("' . $key . '"); end;' . PHP_EOL;
                    $pbxservices[] = '["_' . $value . '*!"] = function() return require_once"services":start_call("' . $key . '"); end;' . PHP_EOL;
                    $pbxservices[] = '["_' . $value . '!"] = function() return require_once"services":start_call("' . $key . '",' . strlen($value) . '); end;' . PHP_EOL;
                } else {
                    $pbxservices[] = '["_' . $extension . '*' . $change . '"] = function() return require_once"services":start_call("' . $key . '"); end;' . PHP_EOL;
                    $pbxservices[] = '["_' . $value . '*' . $change . '"] = function() return require_once"services":start_call("' . $key . '"); end;' . PHP_EOL;
                    $pbxservices[] = '["_' . $value . '' . $change . '"] = function() return require_once"services":start_call("' . $key . '",' . strlen($value) . '); end;' . PHP_EOL;
                }

                if ($key == 'QCALL' && $orderedFeatures['PICKUP']) {
                    $pbxservices[] = '["_' . $value . $orderedFeatures['PICKUP'] . '!"] = function() return require_once"services":start_call("QPICKUP",' . strlen($value . $orderedFeatures['PICKUP']) . '); end;' . PHP_EOL;
                    $pbxservices[] = '["_' . $value . '*' . $orderedFeatures['PICKUP'] . '!"] = function() return require_once"services":start_call("QPICKUP",' . strlen($value . '*' . $orderedFeatures['PICKUP']) . '); end;' . PHP_EOL;

                    $pbxservices[] = '["_' . $orderedFeatures['PICKUP'] . $value . '!"] = function() return require_once"services":start_call("QPICKUP",' . strlen($orderedFeatures['PICKUP'] . $value) . '); end;' . PHP_EOL;
                    $pbxservices[] = '["_' . $orderedFeatures['PICKUP'] . '*' . $value . '!"] = function() return require_once"services":start_call("QPICKUP",' . strlen($orderedFeatures['PICKUP'] . '*' . $value) . '); end;' . PHP_EOL;
                }
            }
        }
    }

    // {{ Preanswer service
    $preanswer_features = array(
        'gotovm' => 1,
        'gotoprivat' => 2,
        // 'gotoconference' => 3,
        'gotointercom' => 4,
        'gotocc' => 5,
    );

    $output[] = '["PREANSWER"] = {';
    foreach ($preanswer_features as $feature => $defvalue) {
        if ($values[$feature] == '') {
            $values[$feature] = $defvalue;
        }
        $output[] = '["' . $feature . '"] = "' . $values[$feature] . '",';
    }
    $output[] = '}';
    // }}
    $output[] = "}\n\n";

    $pbxfeatures[] = "}\n\n";

    $pbxservices[] = "}\n\n";

    $filename = '/etc/callweaver/res_features.lua';
    $content  = implode('', array_merge($output, $pbxfeatures, $pbxservices));

    $lockFile = '/tmp/extensions.lock';
    if ($ex = file_exists($lockFile)) {
        $handle = fopen($lockFile, 'r+');
        if (flock($handle, LOCK_EX)) {
            if (! file_put_contents($filename, $content)) {
                // can't to store features
                logger('Can not save features in ' . $filename, __FUNCTION__, __LINE__);
            }
            flock($handle, LOCK_UN);
        } else {
            logger('Error flock file ' . $lockFile, __FUNCTION__, __LINE__);
        }
        fclose($handle);
    } else {
        logger('Not file for lock ' . $lockFile, __FUNCTION__, __LINE__);
        if (! file_put_contents($filename, $content)) {
            // can't to store features
            logger('Can not save features in ' . $filename, __FUNCTION__, __LINE__);
        }
    }
}

// featuree names
function feature_names() {
    return array('STATUS', 'BCF', 'UCF', 'FCF', 'CW', 'MEXT', 'TOUT', 'CALLBLOCK', 'ROAD', 'MOBCONFIRMATION');
}

// services names
function service_names() {
    $services = array('VMACCESS', 'DIRECTORY', 'LOGIN', 'PERSONALRECORD', 'PBXRECORD', 'SBARGE', 'PBARGE', 'CBARGE', 'SENDDOC', 'FAXRELAY', 'PAGING', 'HIDECID', 'SWITCH', '3SWITCH', 'STIME', 'PICKUP', 'CONTINUITYCALL', 'QCALL', 'CGMANAGER', 'INTERCOM', 'SHORTNUM', 'CONFERENCE', 'ECHO', 'WHOTELALARM', 'WHOTELMUR', 'IDENTITY');
    if (Bticino::getInstance()->isInstalled()) {
        $services[] = 'WHOTELINSPECT';
        $services[] = 'WHOTELBAR';
    }
    return $services;
}

// preferences names
function preferences_names() {
    return array('PREFIX');
}

/**
 * Check feature permissions
 *
 * @param  $uid An user id from ldap
 * @param  $featurename A string with feature (DND, FCF ..)
 * @param  $license_type A string with user license type
 * @return boolean
 */
function is_feature_allowed($group_dn, $featname, $license_type) {
    if (isset($_REQUEST['admin'])) {
        return true;
    }
    return is_acl_subject_allowed($group_dn, 'canset', $featname, $license_type);
}

function is_acl_subject_allowed($group_dn, $can_type, $what, $license_type, $dest_group_dn = null) {
    static $lua;

    if (! is_object($lua)) {
        // get permissions
        $lua = new Services\LuaService();
    }

    return $lua->checkACL($group_dn, $can_type, $what, $dest_group_dn, $license_type);
}

function get_call_classes() {
    static $lua;

    if (! is_object($lua)) {
        // get permissions
        $lua = new Services\LuaService();
    }

    $return = array();

    foreach ($lua->getCallClasses() as $call_type) {
        $return[$call_type] = _t('callclass.' . $call_type);
    }

    return $return;
}

function get_call_classes_no_assoc() {
    static $lua;

    if (! is_object($lua)) {
        // get permissions
        $lua = new Services\LuaService();
    }

    $return = array();
    $cnt    = 1;
    foreach ($lua->getCallClasses() as $call_type) {
        $return[$cnt] = _t('callclass.' . $call_type);
        $cnt++;
    }

    return $return;
}

// ========================================
// ====== features.conf functions ======
// ========================================
function get_features_conf() {
    $file_conf        = PATH_TO_CW_CONF . 'features.conf';
    $file             = file($file_conf);
    $originalFeatures = array(
            'general' => array(),
            'featuremap' => array(),
            'applicationmap' => array()
    );

    $section = 'general';
    foreach ($file as $key => $value) {
        $value = trim($value);
        if (preg_match('/^\[([^\]]+)\].*/', $value, $matches)) {
            $section                    = $matches[1];
            $originalFeatures[$section] = array();
        }

        if (!empty($section)) {
            if (preg_match('/^([^=]+)(=>|=)+([^;]+)(.*)/', $value, $matches)) {
                $originalFeatures[$section][trim($matches[1])] = trim($matches[3]);
            }
        }
    }

    return $originalFeatures;
}

function set_features_conf($newFeatures) {
    $equalKey = array(
            'parkhints',
            'courtesytone',
            'xfersound',
            'xferfailsound',
            'adsipark',
            'pickupexten',
            'featuredigittimeout',
            'atxferdropcall',
            'atxfernoanswertimeout',
    );

    $newFileContent = '';
    foreach ($newFeatures as $sectionName => $section) {
        $newFileContent .= "\n[$sectionName]\n";
        foreach ($section as $key => $value) {
            if (in_array($key, $equalKey)) {
                $newFileContent .= "$key = $value\n";
            } else {
                $newFileContent .= "$key => $value\n";
            }
        }
    }
    file_put_contents(PATH_TO_CW_CONF . 'features.conf', $newFileContent);
}

function value($value) {
    return $value instanceof Closure ? $value() : $value;
}

function arrayGet(array $array, $key, $default = null) {
    if (is_null($key)) {
        return $default;
    }
    if (array_key_exists($key, $array)) {
        return !empty($array[$key]) ? $array[$key] : $default;
    }

    return $default;
}
