importScripts('js/firebase/firebase-app-messaging.packed.js');

firebase.initializeApp({
    'messagingSenderId': '563951675713'
});

self.addEventListener('push', function(event) {
    var payload = event.data.json();

    if (!payload.data) {
        return true;
    }

    var data = {};
    try {
        data = payload.data;
    } catch (e) {
        data = {
            title: 'Received a push message',
            body: payload.data.body,
            number: 'unknown',
            name: 'unknown',
            event: 'test'
        }
    }

    console.log('Received a push message', data);

    // send postMessage if tab is opened
    var groupChatPayloadData = {
        options: data
    };

    var title = data.title;
    var tag = data.event + '-' + data.number;
    var icon = 'collaboration/lua/avatar.lua?' + data.number + '&' + data.name;
    if (data.event === 'group-chat') {
        icon = 'collaboration/data/images/roster/conference.png';
        title = data.roomName;
    }
    var options = {
        body: data.body,
        icon: icon,
        tag: tag,
        badge: 'collaboration/data/images/info_48.png', // img
        lang: 'en',
        requireInteraction: true,
        data: data,
        vibrate: [200, 100, 200, 100, 200, 100, 400]
    };

    // check if Collaboration tab is opened
    event.waitUntil(
        clients.matchAll({
            type: "window",
            includeUncontrolled: true
        })
        .then(function (clientsList) {
            for (var i = 0; i < clientsList.length; i++) {
                var client = clientsList[i];
                if (client.url.indexOf('collaboration') >= 0 && 'focus' in client) {
                    // do not show push notification at the same time with the html5
                    if (data.event === 'group-chat'){
                        // send data to the browser
                        client.postMessage(groupChatPayloadData);
                        // firebase waiting for Promise as return value
                        return Promise.resolve();
                    }
                }
            }
            // show other notifications
            return self.registration.showNotification(title, options)
                .then(function () {
                    return self.registration.getNotifications();
                })
                .then(function (notifications) {
                    notifications = notifications || [];
                    for (var i = 0; i < notifications.length; i++) {
                        if ( tag !== notifications[i].tag && (
                            notifications[i].data.event !== 'call' ||
                            (notifications[i].data.number === data.number && data.event === 'missed-call'))) {
                            notifications[i].close();
                        }
                    }

                    return new Promise(function (resolve, reject) {
                        if (data.event === 'call') {
                            setTimeout(resolve, 35 * 1000);
                        }else {
                            reject();
                        }
                    });
                })
                .then(function () {
                    return self.registration.getNotifications();
                })
                .then(function (notifications) {
                    notifications = notifications || [];
                    // close incoming call by timeout
                    for (var i = 0; i < notifications.length; i++) {
                        if (notifications[i].tag === tag && notifications[i].data.event === 'call') {
                            notifications[i].close();
                        }
                    }
                })
                .catch(function () {
                });
        })
    );
});

self.addEventListener('notificationclick', function (event) {
    // Android doesn't close the notification when you click on it
    // See: http://crbug.com/463146
    event.notification.close();

    if (event.action && (event.action === 'cancel')) {
        return;
    }

    // This looks to see if the current is already open and
    // focuses if it is
    event.waitUntil(
        clients.matchAll({
            type: "window",
            includeUncontrolled: true
        })
        .then(function (clientsList) {
            var payload = {
                channel: event.notification.data.tag,
                action: event.action
            };
            if (event.notification.data.event === 'group-chat'){
                payload = {
                    options: event.notification.data
                }
            }

            for (var i = 0; i < clientsList.length; i++) {
                var client = clientsList[i];
                if (client.url.indexOf('collaboration') >= 0 && 'focus' in client) {
                    client.postMessage(payload);

                    if (event.action !== 'reject') {
                        return client.focus();
                    }

                    return;
                }
            }
            if (clients.openWindow) {
                var window = clients.openWindow('/collaboration/');
                window.then(function (client) {
                    client.postMessage(payload);
                });

                return window;
            }
        })
    );
});