<?php

use Api\Translation\Enums\LanguagesEnum;
use Api\Translation\Interfaces\TranslationStrategyInterface;
use Session\Session;

require_once('auth.php');

if (!($diContainer instanceof \Wildix\DependencyInjection\Container)) {
    $diContainer = new \Wildix\DependencyInjection\Container();
}

function getPBX($mac){
    $search = WMS_Ldap::getInstance()->getEntry(WMS_Ldap::PBX, '(pbxSerial=' . $mac . ')', array('pbxSerial', 'dn', 'pbxDomain', 'pbxIp'));
    $pbx = is_array($search) ? $search : false;
    if($pbx){
        $result = $mac;
        if(!empty($pbx['pbxDomain'])){
            $result = $pbx['pbxDomain'];
        }
        if(!empty($pbx['pbxIp'])){
            $result.=' ('.$pbx['pbxIp'].')';
        }
        return $result;
    }
    return $mac;
}
function get_mode() {
    $filename = '/rw2/etc/pbx/net.conf';
    $vals = parse_ini_file($filename, false, INI_SCANNER_RAW);

    $mode = $vals['STARTUP'];

    // New LDAP doesn't have shared modules
    exec('sudo /bin/cat /etc/ldap/slapd.d/cn\=config/cn\=module\{0\}.ldif', $out);
    if (count($out) > 0) {
        if ($mode == '2') {
            $syncprov_present = exec('sudo /bin/cat /etc/ldap/slapd.d/cn\=config/cn\=module\{0\}.ldif | grep syncprov | wc -l', $out);
            if ($syncprov_present == '0')
                $mode = '0';

            $syncprov_present = exec('sudo /bin/cat /etc/ldap/slapd.d/cn\=config/olcDatabase\=\{1\}hdb/olcOverlay\=\{0\}syncprov.ldif 2>/dev/null | wc -l', $out);
            if ($syncprov_present == '0')
                $mode = '0';
        }
    }

    return $mode;
}
$mac = \Models\PBX::getInstance()->getSerial();

$currentPBX =  getPBX($mac);

$cust_logo_filename = BASEPATH . 'images/' . md5($mac.substr($mac,5,4)) . '.png';
$contexts_select_options = '';
foreach (get_contextnames() As $contextname => $context_descr) {
    $selected = '';
    if ($contextname == 'users')
        $selected = 'selected="selected"';
    $contexts_select_options .= '<option value="' . htmlspecialchars($contextname) . '" ' . $selected . '>' . htmlspecialchars($context_descr) . '</option>';
}

$isRootPermissions = User::getInstance()->isRoot();
$top_controls_perms = array(
    'generate_call' => WMS_Permissions::getInstance()->is_allowed('page','top_control__generate_call'),
    'sounds' => WMS_Permissions::getInstance()->is_allowed('page','top_control__sounds'),
    'debug' => WMS_Permissions::getInstance()->is_allowed('page','top_control__debug'),
    'halt' => WMS_Permissions::getInstance()->is_allowed('page','top_control__halt'),
    'terminal' => $isRootPermissions,
    'monit' => $isRootPermissions,
);

/** @var \Wildix\License $license */
$license = $diContainer->get(\Wildix\License::class);

$exceededLicensesErrorMessage = null;

if ($license->isLicenseLimitExceeded()) {
    $exceededLicensesErrorMessage = $license->getLimitExceededMessage();
}

$licenseUpdateHasFailedMessage = null;

if ($license->isActivated() && $license->isLicenseUpdateHasFailed()) {
    $licenseUpdateHasFailedMessage = $license->getUpdateHasFailedMessage();
}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en">
<head><title><?=$title;?></title>
    <meta http-equiv="Content-type" content="text/html;charset=UTF-8" />
    <meta http-equiv="X-UA-Compatible" content="IE=EmulateIE9" />
    <meta http-equiv="X-UA-Compatible" content="chrome=1">
    <meta name="<?= Session::CSRF_TOKEN_HEADER?>" content="<?= Session::getCsrfToken();?>">

    <?php if ($wmsSpa) {?>
    <meta name="viewport" content="width=device-width,initial-scale=1.0">
    <?}?>
    <!-- // css includes // -->
    <script type="text/javascript">
        var env = {
            serviceBacktraceUri : '<?php echo env('SERVICE_BACKTRACE_URI')?>',
            serviceTextToSpeechUri : '<?php echo env('SERVICE_TEXT_TO_SPEECH_URI')?>',
            serviceAuthUri:  '<?php echo env('SERVICE_AUTH_URI')?>',
            serviceGeoLocationUri:  '<?php echo env('SERVICE_GEO_URI')?>',
            serviceWebinarUri:  '<?php echo env('SERVICE_WEBINAR_URI')?>',
            serviceUrlPreviewUri:  '<?php echo env('SERVICE_URL_PREVIEW_URI')?>',
            serviceFsUri:  '<?php echo env('SERVICE_FS_URI')?>',
        }
    </script>
    <link href="collaboration/dist/wms.css<?=((! strstr($_SERVER['HTTP_USER_AGENT'], 'Chrome') && strstr($_SERVER['HTTP_USER_AGENT'], 'Safari'))?'?'.rand(1000, 9999):'') /*fix cashe Safari*/?>" rel="stylesheet" type="text/css">
    <link href="css/window.css?<?=WMS_VERSION;?>" rel="stylesheet" type="text/css">
    <link href="css/yahoo.packed.css?<?=WMS_VERSION;?>" rel="stylesheet" type="text/css">
    <link href="css/mainstyle.css?<?=WMS_VERSION;?>" rel="stylesheet" type="text/css">


    <link rel="shortcut icon" href="<?=\Wildix\WhiteLabel::getInstance()->getFavicon();?>" type="image/x-icon">
    <!--  // js scripts // -->
    <?php if (!$wmsSpa && array_search($_SESSION["Menuid"], array(65,10,78,66)) == false){ ?>

    <script src="js/yass.packed.js?<?=WMS_VERSION;?>" type="text/javascript"></script>
    <script src="js/yahoo.packed.js?<?=WMS_VERSION;?>" type="text/javascript"></script>
    <script src="js/dragdrop.packed.js?<?=WMS_VERSION;?>" type="text/javascript"></script>

    <?php }else if (!$wmsSpa && array_search($_SESSION["Menuid"], array(65,66)) == false){?>

    <link href="css/datatable.css?<?=WMS_VERSION;?>" rel="stylesheet" type="text/css">

    <script src="js/yui_2.9.0/yahoo-dom-event.js?<?=WMS_VERSION;?>" type="text/javascript"></script>
    <script src="js/yui_2.9.0/connection.js?<?=WMS_VERSION;?>" type="text/javascript"></script>
    <script src="js/yui_2.9.0/element.js?<?=WMS_VERSION;?>" type="text/javascript"></script>
    <script src="js/yui_2.9.0/dragdrop.js?<?=WMS_VERSION;?>" type="text/javascript"></script>
    <script src="js/yui_2.9.0/tabview.js?<?=WMS_VERSION;?>" type="text/javascript"></script>
    <script src="js/yui_2.9.0/paginator.js?<?=WMS_VERSION;?>" type="text/javascript"></script>
    <script src="js/yui_2.9.0/datasource.js?<?=WMS_VERSION;?>" type="text/javascript"></script>
    <script src="js/yui_2.9.0/event-delegate.js?<?=WMS_VERSION;?>" type="text/javascript"></script>
    <script src="js/yui_2.9.0/datatable.js?<?=WMS_VERSION;?>" type="text/javascript"></script>

    <script type='text/javascript'>
        YAHOO.widget.DataTable.MSG_EMPTY = "<?=_t('strings.NoData');?>";
    </script>

    <?php }?>

    <script src="js/prototype.js?<?=WMS_VERSION;?>" type="text/javascript"></script>
    <script src="js/effects.js?<?=WMS_VERSION;?>" type="text/javascript"></script>
    <script src="js/window.js?<?=WMS_VERSION;?>" type="text/javascript"></script>
    <script src="js/topmenu.js?<?=WMS_VERSION;?>" type="text/javascript"></script>
    <script src="js/wms.js?<?=WMS_VERSION;?>" type="text/javascript"></script>
    <script src="js/_patches.js?<?=WMS_VERSION;?>" type="text/javascript"></script>
    <script src="js/rsv.js?<?=WMS_VERSION;?>" type="text/javascript"></script>

    <?php if (!$wmsSpa && array_search($_SESSION["Menuid"], array(65,10,78,66)) == false){ ?>

    <script src="js/_patches_DT.js?<?=WMS_VERSION;?>" type="text/javascript"> </script>

    <?php }else if(array_search($_SESSION["Menuid"], array(65,66)) == false){?>

    <script src="js/wmstables.js?<?=WMS_VERSION;?>" type="text/javascript"></script>
    <script src="js/wms.dt.js?<?=WMS_VERSION;?>" type="text/javascript"></script>

    <?php }?>
	<script src="collaboration/dist/common.js?<?=WMS_VERSION;?>" type="text/javascript"></script>
	<script src="collaboration/dist/wms.js?<?=WMS_VERSION;?>" type="text/javascript"></script>

	<script src="js/errors.js?<?=WMS_VERSION;?>" type="text/javascript"></script>

    <?php if ($wmsSpa || $_SESSION['Menuid'] == 10) {?>
        <script type="application/javascript">

            var wmsConfig = JSON.parse('<?=addslashes(json_encode($wmsConfig))?>');

            wmsConfig.networkInterfaces = JSON.parse('<?= json_encode( Wildix\System\Network::getInstance()->getActiveNetworkInterfaces())?>');
        </script>

        <link href=collaboration/dist/wms-spa.css?<?=WMS_VERSION;?> rel=stylesheet>
    <?php }?>

    <script type="text/javascript">

    Object.assign(WMS, {_translation: <?= json_encode($diContainer->get(TranslationStrategyInterface::class)->getDictionary());?>});

    var pbxDomain = '<? echo \Models\PBX::getInstance()->getDomain();?>';
    jQuery(document).ready(function() {
        jQuery.ajaxSetup({
            statusCode: {
                200: function(jqXHR, textStatus, errorThrown) {
                    if(jqXHR.responseText == 'Cannot authorize the user'){
                        window.location = 'logout/';
                    }
                },
                401: function(jqXHR, textStatus, errorThrown) {
                    if(this.remoteService!==true){
                        var location = jQuery.trim(jqXHR.getResponseHeader('Location'));
                        if(location && location!=''){
                            window.location = location;
                        }else{
                            window.location = 'logout/';
                        }
                    }
                }
              }
        });
        jQuery.ajaxPrefilter(function(options, originalOptions, jqXHR ) {
            if(options.url.indexOf('/') === 0){
                options.url = options.url.replace(/^\//, '');
            }
            if(options.url.indexOf('api/v1/') >= 0){
                options.url += (options.url.indexOf('?') !==-1?'&':'?') + 'skip-basic-auth-header=true';
            }
            jqXHR.setRequestHeader('<?=Session::CSRF_TOKEN_HEADER?>', jQuery("meta[name='<?=Session::CSRF_TOKEN_HEADER?>']").attr('content'));
        });
    });

    window.localStorage.setItem("auth", 1);
    //if we lose the authorization site close all browser tabs
    if (window.addEventListener) {
        window.addEventListener("storage", checkAuthTab, false);
    } else {
        window.attachEvent("onstorage", checkAuthTab);
    }

    function checkAuthTab(e){
        if(window.localStorage.getItem('auth') == 0){
            window.location = 'authorization/';
        }
    }
    </script>

    <script type='text/javascript'>/* #start min */
    var win, err_stack = [], msgChan = "<?=_t('header.ActiveChannels');?>";
    var comboSelects = {};
    if(typeof YAHOO!='undefined') {
        var _t = {
            'buttons.Cancel': "<?=_t('buttons.Cancel');?>",
            'buttons.Ok': "<?=_t('buttons.Ok');?>"
        };
    }
    document.observe('WMS:load', function(event) {
        jQuery('#top_port_blocks_alert').portsStatus({
            host: pbxDomain
        });

        top_monit.init();
        top_sip_blocks.init();
        if (!$('wmsApp')) {
            $('loading').hide();
        }
        <?php if (\Wildix\Certificate\SSLCertificate::isFailedToRenew()):?>
        setError('error', '<?=_t('certificate.expire', \Wildix\Certificate\SSLCertificate::getRemainingDaysCount());?>');
        <?php endif; ?>
        <?php if (!empty($exceededLicensesErrorMessage)):?>
        setError('error', '<?= $exceededLicensesErrorMessage; ?>');
        <?php endif; ?>
        <?php if (!empty($licenseUpdateHasFailedMessage)) : ?>
        setError('error', '<?= $licenseUpdateHasFailedMessage; ?>');
        <?php endif; ?>
    });
    var astman;
    var gl_translation = {
        'is': '<?= _t('strings.is'); ?>',
        'usageof': '<?= _t('devices.usageOf'); ?>',
        'root': '<?= _t('devices./'); ?>',
        'rewritable': '<?= _t('devices./rw2'); ?>',
        'shmem': '<?= _t('devices./dev/shm'); ?>',
        'memory': 'Memory',
        'cpu': 'CPU',
        'mounted_cdr': '<?= _t('devices./mnt/cdr'); ?>',
        'mounted_voicemail': '<?= _t('devices./var/spool/callweaver/voicemail'); ?>',
        'not_mounted': '<?= _t('devices.isNotMounted'); ?>',
        'has_write_problem': '<?= _t('devices.hasWriteProblem'); ?>',
        'confirm_perform_halt_reboot': '<?= _t('strings.JS.DoYouWantToReformTheOperation'); ?>',
        'noMonitProc': '<?= _t('strings.noMonitProc'); ?>',
        'banned': '<?= _t('strings.isBanned'); ?>',
        'unbanned': '<?= _t('strings.isUnBanned'); ?>',

        'succeeded': '<?= _t('strings.isReachable'); ?>',
        'failed': '<?= _t('strings.isUnReachable'); ?>',

        'from': '<?= _t('phones.madd.1.From'); ?>',
        'to': '<?= _t('phones.madd.1.To'); ?>',

        'banned_for': '<?= _t('strings.isBannedFor'); ?>',
        'banned_forever': '<?= _t('strings.isBannedForever'); ?>',

        'minutes': '<?= _t('strings.minutes'); ?>',

        'strings.Info': '<?= _t('strings.Info'); ?>',
        'button.Ok': '<?= _t('buttons.Ok'); ?>',
        'button.Save': '<?= _t('buttons.Save'); ?>',
        'button.Cancel': '<?= _t('buttons.Cancel'); ?>',
        'button.Upload': '<?= _t('buttons.Upload'); ?>',
        'button.Close': '<?= _t('buttons.Close'); ?>',
        'strings.Name': '<?= _t('strings.Name'); ?>',
        'strings.Size': '<?= _t('backup.FileSize'); ?>',
        'strings.Modified': '<?= _t('strings.Modified'); ?>',
        'MusicOnHold': '<?= _t('strings.MusicOnHold'); ?>',
        'RingTones': '<?= _t('strings.RingTones'); ?>',
        'phoneNumber': '<?= _t('aclpbx.extenNumber'); ?>',
        'ConfirmDelete': '<?= addslashes(_t('JS.ConfirmDelete')); ?>',
        'addDirectory': '<?= _t('strings.Directory'); ?>',
        'send_problem': '<?= _t('strings.SmtpSendProblem'); ?>',
        'authentication_failed': '<?= _t('strings.SmtpAuthenticationFailed'); ?>',
        'no_space': '<?= _t('strings.NoSpaceLeft'); ?>',
        'errors.fileIsNotUploadedNotEnoughSpace': '<?= _t('errors.fileIsNotUploadedNotEnoughSpace'); ?>',
        'errors.selectedFileMustBeLessThan': '<?= _t('errors.selectedFileMustBeLessThan', (min(let_to_num(ini_get('post_max_size')), let_to_num(ini_get('upload_max_filesize'))))/1024/1024)?>',
        'wms_fax': '<?= _t('strings.FaxServerService'); ?>',
        'wms_msmtp': '<?= _t('strings.SmtpService'); ?>',

        'aclpbx.userName': '<?= _t('aclpbx.userName'); ?>',
        'aclpbx.userPrincipalName': '<?= _t('aclpbx.userPrincipalName'); ?>',
        'aclpbx.extenNumber': '<?= _t('aclpbx.extenNumber'); ?>',
        'aclpbx.facsimileTelephoneNumber': '<?= _t('aclpbx.facsimileTelephoneNumber'); ?>',
        'aclpbx.officeNumber': '<?= _t('aclpbx.officeNumber'); ?>',
        'aclpbx.Email': '<?= _t('aclpbx.Email'); ?>',
        'aclpbx.MobileNumber': '<?= _t('aclpbx.MobileNumber'); ?>',
        'aclpbx.userDialplan': '<?= _t('aclpbx.userDialplan'); ?>',
        'aclpbx.userFaxDialplan': '<?= _t('aclpbx.userFaxDialplan'); ?>',
        'aclpbx.Group': '<?= _t('aclpbx.Group'); ?>',
        'aclpbx.preferredLanguage': '<?= _t('aclpbx.preferredLanguage'); ?>',
        'aclpbx.owner': '<?= _t('aclpbx.owner'); ?>',
        'aclpbx.wuserPasswordSip': '<?= _t('aclpbx.wuserPasswordSip'); ?>',
        'aclpbx.userPassword': '<?= _t('aclpbx.userPassword'); ?>',
        'aclpbx.userPasswordWeak': '<?= _t('aclpbx.userPasswordWeak'); ?>',
        'aclpbx.sipPasswordWeak': '<?= _t('aclpbx.sipPasswordWeak'); ?>',
        'aclpbx.userCurrPassword': '<?= _t('aclpbx.userCurrPassword'); ?>',
        'aclpbx.userNewPassword': '<?= _t('aclpbx.userNewPassword'); ?>',
        'aclpbx.userConfirmNewPassword': '<?= _t('aclpbx.userConfirmNewPassword'); ?>',
        'aclpbx.usersImport': '<?= _t('aclpbx.usersImport'); ?>',
        'aclpbx.NoPermissionForUsers': '<?= _t('aclpbx.NoPermissionForUsers'); ?>',
        'aclpbx.impossibleToEditPrefsForRemoteUsers': '<?= _t('aclpbx.impossibleToEditPrefsForRemoteUsers'); ?>',
        'aclpbx.NoEmailError': '<?= _t('aclpbx.NoEmailError'); ?>',
        'aclpbx.BodyIsTooBig': '<?= json_encode(_t('aclpbx.BodyIsTooBig',3000)); ?>',
        'aclpbx.editEmailBody': '<?= json_encode(_t('aclpbx.editEmailBody')); ?>',
        'aclpbx.emailBody': <?= json_encode( _t('aclpbx.emailBody')); ?>,
        'aclpbx.ou': '<?= _t('aclpbx.ou'); ?>',
        'aclpbx.wcgrp': '<?= _t('aclpbx.wcgrp'); ?>',
        'aclpbx.avaliablefields': '<?=_t('aclpbx.avaliablefields');?>',
        'aclpbx.uniontwofields': '<?=_t('aclpbx.uniontwofields');?>',
        'acl.SeeFullNumber': '<?= _t('acl.SeeFullNumber'); ?>',
        'aclpbx.InheritsFrom': '<?= _t('aclpbx.InheritsFrom'); ?>',
        'aclpbx.CountOfContacts': '<?= _t('aclpbx.CountOfContacts'); ?>',
        'aclpbx.RecurrentJob': '<?= _t('aclpbx.RecurrentJob'); ?>',
        'aclpbx.RecurrentSyncIsSet': '<?= _t('aclpbx.RecurrentSyncIsSet'); ?>',
        'aclpbx.SetPasswords': '<?= _t('aclpbx.SetPasswords'); ?>',
        'aclpbx.EditPreferences': '<?= _t('aclpbx.EditPreferences'); ?>',
        'aclpbx.SendWelcome': '<?= _t('aclpbx.SendWelcome'); ?>',
        'aclpbx.InviteXbees': '<?= _t('aclpbx.InviteXbees'); ?>',
        'aclpbx.PBXes': '<?= _t('aclpbx.PBXes'); ?>',
        'aclpbx.noRecurrentSyncForCsv': '<?= _t('aclpbx.noRecurrentSyncForCsv'); ?>',
        'acl.canManagePbx': '<?= _t('acl.canManagePbx'); ?>',
        'acl.canNotManagePbx': '<?= _t('acl.canNotManagePbx'); ?>',
        'acl.canManageGroup': '<?= _t('acl.canManageGroup'); ?>',
        'acl.canNotManageGroup': '<?= _t('acl.canNotManageGroup'); ?>',
        'acl.canViewPage': '<?= _t('acl.canViewPage'); ?>',
        'acl.canNotViewPage': '<?= _t('acl.canNotViewPage'); ?>',
        'acl.all': '<?= _t('acl.all'); ?>',
        'acl.allgroups': '<?= _t('acl.allgroups'); ?>',
        'acl.CALL': '<?= _t('acl.CALL'); ?>',
        'acl.IM_FAX': '<?= _t('acl.IM_FAX'); ?>',
        'acl.CHANGE_PRESENCE': '<?= _t('acl.CHANGE_PRESENCE'); ?>',
        'acl.INTERCOM': '<?= _t('acl.INTERCOM'); ?>',
        'acl.SUPERVISION': '<?= _t('acl.SUPERVISION'); ?>',
        'acl.PICKUP': '<?= _t('acl.PICKUP'); ?>',
        'acl.EDIT_PP': '<?= _t('acl.EDIT_PP'); ?>',
        'acl.ADVANCED_STATUS': '<?= _t('acl.ADVANCED_STATUS'); ?>',
        'acl.SEE': '<?= _t('acl.SEE'); ?>',
        'acl.SEE_CALLS': '<?= _t('acl.SEE_CALLS'); ?>',
        'acl.DELETE_CALLS': '<?= _t('acl.DELETE_CALLS'); ?>',
        'acl.SHARE_STATUS_VIA_KITE': '<?= _t('acl.SHARE_STATUS_VIA_KITE'); ?>',
        'acl.SHARE_STATUS_MESS_VIA_KITE': '<?= _t('acl.SHARE_STATUS_MESS_VIA_KITE'); ?>',
        'acl.SHARE_GEO_VIA_KITE': '<?= _t('acl.SHARE_GEO_VIA_KITE'); ?>',
        'acl.VIEW_GEO': '<?= _t('acl.VIEW_GEO'); ?>',
        'acl.CONTACT_CENTER': '<?= _t('acl.CONTACT_CENTER'); ?>',
        'acl.MANAGE_CALLCENTER': '<?= _t('acl.MANAGE_CALLCENTER'); ?>',
        'acl.DIRECTORY_LOOKUP': '<?= _t('acl.DIRECTORY_LOOKUP'); ?>',
        'acl.ACCESS_ALARM_CALL_OF': '<?= _t('acl.ACCESS_ALARM_CALL_OF'); ?>',
        'acl.HOTEL_ADMIN': '<?= _t('acl.HOTEL_ADMIN'); ?>',
        'acl.HOTEL_EVENTS': '<?= _t('acl.HOTEL_EVENTS'); ?>',
        'acl.CREATE_CONFERENCE': '<?= _t('acl.CREATE_CONFERENCE'); ?>',
        'acl.CTI_PRO': '<?= _t('acl.CTI_PRO'); ?>',
        'acl.CTI_PO': '<?= _t('acl.CTI_PO'); ?>',
        'acl.CTI_CDR': '<?= _t('acl.CTI_CDR'); ?>',
        'acl.CTI_CDR_VIEW': '<?= _t('acl.CTI_CDR_VIEW'); ?>',
        'acl.PBXRECORD': '<?= _t('acl.PBXRECORD'); ?>',
        'acl.PERSONALRECORD': '<?= _t('acl.PERSONALRECORD'); ?>',
        'acl.SMS': '<?= _t('acl.SMS'); ?>',
        'acl.FAX': '<?= _t('acl.FAX'); ?>',
        'acl.PAGING': '<?= _t('acl.PAGING'); ?>',
        'acl.PRE_ANSWER_SERVICES': '<?= _t('acl.PRE_ANSWER_SERVICES'); ?>',
        'acl.PRE_ANSWER_SERVICES_FULL': '<?= _t('acl.PRE_ANSWER_SERVICES_FULL'); ?>',
        'acl.SEE_EXTENSIONS': '<?= _t('acl.SEE_EXTENSIONS'); ?>',
        'acl.PHONE_SETTING_MENU': '<?= _t('acl.PHONE_SETTING_MENU'); ?>',
        'acl.VOICEMAIL': '<?= _t('acl.VOICEMAIL'); ?>',
        'acl.VOICEMAIL_WITHOUT_PIN': '<?= _t('acl.VOICEMAIL_WITHOUT_PIN'); ?>',
        'acl.BROWSER_PHONE': '<?= _t('acl.BROWSER_PHONE'); ?>',
        'acl.P_INFO': '<?= _t('acl.P_INFO'); ?>',
        'services.SHORTNUM': '<?= _t('services.SHORTNUM'); ?>',
        'multipbx.SelectNewOwnerTitle': '<?= _t('multipbx.SelectNewOwnerTitle'); ?>',
        'multipbx.SelectNewOwner': '<?= _t('multipbx.SelectNewOwner'); ?>',
        'multipbx.WarningMovingSettings': '<?= _t('multipbx.WarningMovingSettings'); ?>',
        'multipbx.ip_address': '<?= _t('multipbx.ip_address'); ?>',
        'multipbx.serial': '<?= _t('multipbx.serial'); ?>',
        'multipbx.model': '<?= _t('multipbx.model'); ?>',
        'multipbx.domain': '<?= _t('multipbx.domain'); ?>',
        'multipbx.removePBX': '<?= _t('multipbx.removePBX'); ?>',
        'multipbx.MoveUser': '<?= _t('multipbx.MoveUser'); ?>',
        'multipbx.cantRemoveMaster': '<?= _t('multipbx.cantRemoveMaster'); ?>',
        'strings.notAllowedCharsPresent': "<?= _t('strings.notAllowedCharsPresent'); ?>",
        'strings.notSecure': '<?= _t('strings.notSecure'); ?>',
        'strings.mediumSecure': '<?= _t('strings.mediumSecure'); ?>',
        'strings.secure': '<?= _t('strings.secure'); ?>',
        'strings.hour': '<?= _t('strings.hour'); ?>',
        'strings.Proceeding': '<?= _t('strings.Proceeding'); ?>',
        'strings.can': '<?= _t('strings.can'); ?>',
        'strings.canNot': '<?= _t('strings.canNot'); ?>',
        'strings.canSet': '<?= _t('strings.canSet'); ?>',
        'strings.canNotSet': '<?= _t('strings.canNotSet'); ?>',
        'strings.canUse': '<?= _t('strings.canUse'); ?>',
        'strings.canNotUse': '<?= _t('strings.canNotUse'); ?>',
        'strings.canCall': '<?= _t('strings.canCall'); ?>',
        'strings.canNotCall': '<?= _t('strings.canNotCall'); ?>',
        'strings.Add': '<?= _t('strings.Add'); ?>',
        'strings.Edit': '<?= _t('strings.Edit'); ?>',
        'strings.Show': '<?= _t('strings.Show'); ?>',
        'strings.Hide': '<?= _t('strings.Hide'); ?>',
        'strings.Interval': '<?= _t('strings.Interval'); ?>',
        'strings.downloadLog': '<?= _t('strings.downloadLog'); ?>',
        'strings.genSecurePass': '<?= _t('strings.genSecurePass'); ?>',
        'strings.genSecurePassShort': '<?= _t('strings.genSecurePassShort'); ?>',
        'strings.Generate': '<?= _t('strings.Generate'); ?>',
        'strings.CtiIsNotMounted': '<?= _t('strings.CtiIsNotMounted'); ?>',
        'strings.EditPermissions': '<?= _t('strings.EditPermissions'); ?>',
        'strings.EditAdminPermissions': '<?= _t('strings.EditAdminPermissions'); ?>',
        'strings.EnterFilename': '<?= _t('strings.EnterFilename'); ?>',
        'strings.EnterDirectoryname': '<?= _t('strings.EnterDirectoryname'); ?>',
        'strings.PlayViaPhone': '<?= _t('strings.PlayViaPhone'); ?>',
        'strings.StartRecordViaPhone': '<?= _t('strings.StartRecordViaPhone'); ?>',
        'rules.wrongCurrentPassword': '<?= _t('rules.wrongCurrentPassword'); ?>',
        'rules.passwordsAreNotTheSame': '<?= _t('rules.passwordsAreNotTheSame'); ?>',
        'rules.enterStrongPassword': '<?= _t('rules.enterStrongPassword'); ?>',
        'rules.CannotBeEmpty': '<?= _t('rules.CannotBeEmpty'); ?>',
        'rules.enterValidValue': '<?= _t('rules.enterValidValue'); ?>',
        'rules.enterNumber': '<?= _t('rules.enterNumber'); ?>',
        'services.STIME': '<?= _t('services.STIME'); ?>',
        'services.3SWITCH': '<?= _t('services.3SWITCH'); ?>',
        'services.SWITCH': '<?= _t('services.SWITCH'); ?>',
        'features.PHONEBOOK': '<?= _t('features.PHONEBOOK'); ?>',
        'features.FKEYS': '<?= _t('features.FKEYS'); ?>',
        'features.DEFSTATUS': '<?= _t('features.DEFSTATUS'); ?>',
        'features.all': '<?= _t('features.all'); ?>',
        'phonebooks.Export': '<?= _t('phonebooks.Export'); ?>',
        'import.phonebooksImportIsInProgress': '<?= _t('import.phonebooksImportIsInProgress'); ?>',
        'buttons.ImportDryRun': '<?= _t('buttons.ImportDryRun'); ?>',
        'buttons.ImportDryRunVerbose': '<?= _t('buttons.ImportDryRunVerbose'); ?>',
        'buttons.Import': '<?= _t('buttons.Import'); ?>',
        'buttons.Export': '<?= _t('buttons.Export'); ?>',
        'buttons.SaveAndImport': '<?= _t('buttons.SaveAndImport'); ?>',
        'buttons.Save': '<?= _t('buttons.Save'); ?>',
        'buttons.Back': '<?= _t('buttons.Back'); ?>',
        'buttons.Ok': '<?= _t('buttons.Ok'); ?>',
        'buttons.Cancel': '<?= _t('buttons.Cancel'); ?>',
        'buttons.Apply': '<?= _t('buttons.Apply'); ?>',
        'buttons.Clear': '<?= _t('buttons.Clear'); ?>',
        'datatable.oPaginate.sFirst': '<?= _t('datatable.oPaginate.sFirst'); ?>',
        'datatable.oPaginate.sLast': '<?= _t('datatable.oPaginate.sLast'); ?>',
        'datatable.oPaginate.sNext': '<?= _t('datatable.oPaginate.sNext'); ?>',
        'datatable.oPaginate.sPrevious': '<?= _t('datatable.oPaginate.sPrevious'); ?>',
        'datatable.sZeroRecords': '<?= _t('datatable.sZeroRecords'); ?>',
        'datatable.sInfo': '<?= _t('datatable.sInfo'); ?>',
        'datatable.sInfoFiltered': '<?= _t('datatable.sInfoFiltered'); ?>',
        'datatable.sSearch': '<?= _t('datatable.sSearch'); ?>'

    };

        var lang = 'en';
        <?php if(User::getInstance()->hasSessionCache()) : ?>
            lang = '<?= User::getInstance()->getLanguage() ?>';
        <?php endif; ?>
        var showHideTopSoundsEdit = function(){
            WMS.SoundsDialog.init(false,false,{showTextToSpeechButton: <?= ($license->isPremium() && $license->isSubscription()) ? 'true' : 'false' ?>},lang);

            jQuery('#dialog-sounds-form').dialog('open');
        };

/* #end min */
    </script>
    <?php
        $custom_css = \Wildix\WhiteLabel::getInstance()->getCss();
        if(!empty($custom_css)){
            echo '<link href="../'.$custom_css.'" rel="stylesheet" type="text/css">'.PHP_EOL;
        }
    ?>
</head>
<body class="yui-skin-sam" >
    <div id="information_div" style="z-index:9999;font-size: 14px; font-weight:bold; display:none; background: #ffffbb;position:absolute; top: 40%;  border-bottom: 1px solid #446fd7; border-top: 1px solid #446fd7;height: auto; padding: 10px;width: 100%;text-align: center;"></div>
    <div id="loading">
        <div class="bluelighting_overlay"></div>
        <div class="loading-indicator"><i class="fa fa-refresh fa-spin"></i><br /><span id="loading-msg"></span></div>
    </div>
<!--admin panel header-->
<?php if(User::getInstance()->isLogged()) {?>
    <div id="Wrapper">
        <div id="Header">
            <div id="Logo">
                <a href="./"><img src="<?=\Wildix\WhiteLabel::getInstance()->getSmallLogo();?>"></a>
            </div>
            <div id="menu">
                <?=$acl_class->menu_html;?>
            </div>
            <?php if (file_exists($cust_logo_filename)){?>
                <div id="CustLogo"><img src="<?=str_replace(BASEPATH,'',$cust_logo_filename);?>" title="<?= _t('strings.providedBy'); ?>"></div>
            <?php } ?>
            <div style="float:right;">
            <div id="TopLinks">
                <div id="top_sip_blocks_win" class="block_window_top_links">
                    <div class="bluelighting_overlay"></div>
                    <div id="top_sip_blocks_content" class="top_blocks_win_content"></div>
                    <div id="top_sip_blocks_content_buttons" class="top_blocks_win_content_buttons">
                        <input type="button" onclick="top_sip_blocks.diasble_blocks();" value="<?=_t('buttons.resetBlacklist');?>" />
                        <input type="button" onclick="top_sip_blocks.win_hide();" value="<?=_t('buttons.Close');?>" />
                    </div>
                </div>
                <div id="top_monit_win" class="block_window_top_links">
                    <div class="bluelighting_overlay"></div>
                    <div id="top_monit_content" class="top_blocks_win_content"></div>
                    <div id="top_monit_content_buttons" class="top_blocks_win_content_buttons">
                        <input type="button" onclick="top_monit.show_monit_page();" value="<?=_t('buttons.More');?>" />
                        <input type="button" onclick="top_monit.remove_file();" value="<?=_t('buttons.Clear');?>" />
                        <input type="button" onclick="top_monit.win_show_hide();" value="<?=_t('buttons.Close');?>" />
                    </div>
                </div>
                <div id="top_reboot_win" class="block_window_top_links">
                    <div class="bluelighting_overlay"></div>
                    <div id="top_reboot_content_buttons" style="text-align:right;width:250px; z-index:1;position:relative;">
                        <input type="button" onclick="top_reboot.reboot('');" value="<?=_t('buttons.Reboot');?>" />
                        <?php if(!\Wildix\License::getInstance()->isCloud()): ?>
                        <input type="button" onclick="top_reboot.reboot('poweroff');" value="<?=_t('buttons.PowerOff');?>" />
                        <?php endif; ?>
                        <input type="button" onclick="top_reboot.win_hide();" value="<?=_t('buttons.Close');?>" />
                    </div>
                </div>
                <div id="top_test_call_win" class="block_window_top_links">
                    <div class="bluelighting_overlay"></div>
                    <div id="top_test_call_content" style="text-align:right;z-index:1;position:relative;" >
                        <table align="right" cellpadding="0" cellspacing="5" style="background-color:#fff;"><tr><td>
                            <?=_t('strings.Generate');?> <select id="top_test_call_method" onchange="top_test_call.method_change(this.value);"><option value="echo" selected="selected"><?=_t('strings.Echo');?></option><option value="call"><?=_t('strings.Call');?></option></select>
                            <span id="top_test_call_method_echo_to"><?=_t('phones.madd.1.To');?></span>
                            <input type="text" id="top_test_call_number_1">@<select id="top_test_call_context_1" style="width:150px;"><?=$contexts_select_options;?></select>
                        </td></tr>
                        <tr><td>
                            <span id="top_test_call_method_call" style="display:none;">
                                <?=_t('phones.madd.1.To');?>
                                <input type="text" id="top_test_call_number_2">@<select id="top_test_call_context_2" style="width:150px;"><?=$contexts_select_options;?></select>
                            </span>
                        </td></tr>
                        <tr><td>
                            <input type="button" onclick="top_test_call.perform_call();" value="<?=_t('buttons.Call');?>" />
                            <input type="button" onclick="top_test_call.win_hide();" value="<?=_t('buttons.Close');?>" />
                        </td></tr></table>
                    </div>
                </div>
                <input type="hidden" id="top_sip_blocks_show_val" value="0" />
                <input type="hidden" id="top_monit_show_val" value="0" />
                <input type="hidden" id="gl_sounds_ed_id" />
                <input type="hidden" id="top_test_call_show_val" value="0" />
                <input type="hidden" id="top_soundsEd_show_val" value="0" />
                <input type="hidden" id="top_reboot_show_val" value="0" />

                <a id="top_port_blocks_alert" title="<?=_t('strings.PortBlocks');?>">
                    <i class="fa fa-firewall"></i>
                </a>
                <a id="top_sip_blocks_alert" onclick="top_sip_blocks.win_show_hide();" title="<?=_t('strings.SipBlocks');?>" style="display: none;">
                    <i class="fa fa-ban"></i>
                </a>
<?php if ($top_controls_perms['monit']) { ?>
                <a id="top_monit_alert" onclick="top_monit.show_monit_page();" title="<?=_t('strings.Info');?>" style="display: none;">
                    <i class="fa fa-info-circle"></i>
                </a>
<?php } else { ?>
                <a class="hover_not_color" title="<?=_t('strings.Info');?> <?=_t('strings.permissionsDenied');?>">
                    <i class="fa fa-info-circle"></i>
                </a>
<?php } ?>
<?php if ($top_controls_perms['generate_call']) { ?>
                <a onclick="top_test_call.win_show_hide()" href="javascript:void(0);" title="<?=_t('strings.GenerateCall');?>" >
                    <i class="fa fa-phone"></i>
                </a>
<?php } else { ?>
                <a class="hover_not_color" href="javascript:void(0);" title="<?=_t('strings.GenerateCall');?>  <?=_t('strings.permissionsDenied');?>">
                    <i class="fa fa-phone"></i>
                </a>
<?php }?>
<?php if ($top_controls_perms['sounds']) { ?>
               <a onclick="showHideTopSoundsEdit()" href="javascript:void(0);" title="<?=_t('strings.Sounds');?>" ><i class="fa fa-file-audio-o"></i></a>
<?php } else { ?>
               <a class="hover_not_color" href="javascript:void(0);" title="<?=_t('strings.Sounds');?>  <?=_t('strings.permissionsDenied');?>"><i class="fa fa-file-audio-o"></i></a>
<?php } ?>
<?php if ($top_controls_perms['terminal']) { ?>
                <a class="fa-stack fa-lg" id="aTerminal" onclick="if( ! Prototype.Browser.IE){ window.open('terminal/','terminal_win')} else {return false;}" href="javascript:void(0);" title="">
                <script type='text/javascript'>
                    if( ! Prototype.Browser.IE){
                        jQuery('#aTerminal').attr('title','<?=_t('strings.Terminal');?>');
                    }else{
                        jQuery('#aTerminal').attr('title','<?=_t('strings.Terminal_does_not_support_browser');?>');
                    }
                </script>
<?php } else { ?>
                <a class="hover_not_color fa-stack fa-lg" href="javascript:void(0);" title="<?=_t('strings.Terminal');?>  <?=_t('strings.permissionsDenied');?>">
<?php } ?>
                    <i class="fa fa-square-o fa-stack-2x"></i>
                    <i class="fa fa-terminal fa-stack-1x"></i>
                </a>
<?php if ($top_controls_perms['debug']) { ?>
                <a onclick="window.open('?Menuid=95','debug_win');" href="javascript:void(0);" title="<?=_t('strings.Debug');?>" ><i class="fa fa-cog"></i></a>
<?php } else { ?>
                <a class="hover_not_color" href="javascript:void(0);" title="<?=_t('strings.Debug');?> <?=_t('strings.permissionsDenied');?>"><i class="fa fa-cog"></i></a>
<?php } ?>
<?php if ($top_controls_perms['halt']) {?>
                <a onclick="top_reboot.win_show_hide()" href="javascript:void(0);" title="<?=_t((\Wildix\License::getInstance()->isCloud())?'buttons.Reboot':'strings.Reboot_Halt');?>"><i class="fa fa-refresh"></i></a>
<?php } else { ?>
                <a class="hover_not_color" href="javascript:void(0);" title="<?=_t('strings.Reboot_Halt');?>  <?=_t('strings.permissionsDenied');?>"><i class="fa fa-refresh"></i></a>
<?php } ?>
                <a id="Logout" href="logout/" title="<?=_t('menu.logout');?>" onclick="$.jStorage.flush();"><i class="fa fa-sign-out"></i></a>
            </div>
            <div style="clear:right;"></div>
            <div id="version">
                <small style="color:#999;">
                    <b style="font-weight:bold;color:#446fd7">
                        WMS <?php if (\Wildix\License::getInstance()->haveLicense('hotel')) echo ' HOTEL';?> at <?=$hostname[0]; ?>
                    </b>
                </small>
                <small>
                    <?=WMS_VERSION_FULL;?>
                </small>
                <?php if(get_mode()){?>
                <small>
                    <?=$currentPBX;?>
                </small>
                <?php }?>
            </div>
            </div>
            <div style="clear:both;"></div>
        </div> <!-- Header -->

        <?php require('pbx_settings/SoundsDialog.php');?>

        <?php if(!$wmsSpa) {?>
        <div id="Main" class="clearfix">
            <table id="Area" border="0">
                <tr>
                    <td class="main-content">
        <?php } ?>
<? } ?>
