(function ($) {
	'use strict';

	var hotelCommonareas = function(el, options){

		var table,
			modwin,
			init = function(){

				table = new WMS.DataTables({
					ajaxDataUrl: options.url + '?action=getCommonAreas',
					$table: $('#' + options.table),
					columns: [ // column header
					    {"data":"rn", "title":"FIAS RN", "width": "60px", "orderable": true},
			    		{"data":"extension", "title":"Extension", "width": "70px", "orderable": true},
			    		{"data":"descr", "title":"Description", "width": "150px", "orderable": true},
			    		{"data":"building", "title":"Building", "width": "50px", "orderable": true},
			    		{"data":"floor", "title":"Floor", "width": "40px", "orderable": true},
			    		{"data":"id", "title":"ID", "width": "250px", "orderable": true}
			    	],
					options:{
						searching: true,
				    	processing: true,
				        serverSide: true,
				        order: [[ 1, "asc" ]]
				    }
				});

				$('#commonAreasApply').on('click', _onClickApply);
	            $('#commonAreasClear').on('click', _onClickClear);

				setEvent();
			},

			setEvent = function(){
				$(document).on('HotelIntegration:XMLFile:loaded', function() {
					table.reload();
				});

				table.on('dblclick', 'tr', editItem);
			},

			_onClickApply = function(){
				ap_showWaitMessage('waitDiv', 1);
				$.ajax({
		            url: options.url ,
		            type: "POST",
		            data: {action: 'reloadXml'},
		            success: function (data) {
		            	ap_showWaitMessage('waitDiv', 0);
		            	setError('success', 'Apply successfully', 3000)
	                },
	                error: function(){
	                	ap_showWaitMessage('waitDiv', 0);
	                	setError('error', 'Unknown error');
	                }
		    	});
			},

			_onClickClear = function(){

				var yes = confirm("Are you sure you want to clear the hotel configuration file?");
				if(yes){

					ap_showWaitMessage('waitDiv', 1);

					$.ajax({
			            url: options.url ,
			            type: "POST",
			            data: {action: 'removeHotelConfigurationFile'},
			            success: function (data) {
			            	ap_showWaitMessage('waitDiv', 0);
		            		if(typeof data === 'object'){
		            			if(data.result == 'success'){
		            				$(document).trigger('HotelIntegration:XMLFile:loaded');
		            				setError('success', 'Successfully cleaned hotel configuration file', 3000);
		                		}else if(data.result == 'error'){
		                			//error
		                			setError('error', data.reason)
		                		}
		            		}else{
		            			setError('error', 'Unknown error');
		            		}
		                },
		                error: function(){
		                	ap_showWaitMessage('waitDiv', 0);
		                	setError('error', 'Unknown error');
		                }
			    	});
				}
			},

			editItem = function(){

				var pObj = table.getTrData(this);

			    if (pObj && 'id' in pObj) {

			        showFormEdit().setHeader(gl_translation['strings.Edit']);

			        $('#edit_id').html(pObj['id'] || '');
			        $('#__edit_id').val(pObj['id'] || '');

			        $('#edit_extension').val(pObj['extension'] || '');
			        $('#__edit_extension').val(pObj['extension'] || '');

			        $('#edit_rn').val(pObj['rn'] || '');
			        $('#__edit_rn').val(pObj['rn'] || '');

			        $('#edit_description').html(pObj['descr'] || '');
			        $('#edit_building').html(pObj['building'] || '');
			        $('#edit_floor').html(pObj['floor'] || '');
			        $('#edit_payment').html(pObj['payment'] || '');
			    }
			},

			showFormEdit = function(){

				return showDialog(300, 200, $('#edCommonAreas_tmpl').html(), function(){

					var opt = {
				        rules: [ // rule, element_id, message
				            "digits_only,edit_extension," + gl_translation['rules.enterNumber'],
				            "digits_only,edit_rn," + gl_translation['rules.enterNumber'] + ' (1-20)'
				        ],
				        customErrorHandler: function(f, errorInfo){
				        	for(var i = 0; i < errorInfo.length; i++){
				        		$(errorInfo[i][0]).after('<span class="err_span" style="color:#ff0000;padding-left:10px;">' + errorInfo[i][1] + '<br></span>');
				        	}
				        	return errorInfo.length == 0;
				        }
				    };

				    if (!WMS.validate('edCommonAreas', opt) ) {
				        return false;
				    }

				    if($('#edit_rn').val() && ($('#edit_rn').val() < 1 || $('#edit_rn').val() > 20)){
						$('#edit_rn').after('<span class="err_span" style="color:#ff0000;padding-left:10px;">'+gl_translation['rules.enterNumber'] + ' (1-20)<br></span>');
						return false;
				    }

					var dataSave = {
							id: $('#__edit_id').val(),
			                extension: $('#edit_extension').val(),
			                extension_old: $('#__edit_extension').val(),
			                rn: $('#edit_rn').val(),
			                rn_old: $('#__edit_rn').val()
			        };

					if(dataSave.extension != dataSave.extension_old || dataSave.rn != dataSave.rn_old){
						ap_showWaitMessage('waitDiv', 1);
						$.ajax({
				            url: options.url ,
				            type: "POST",
				            data: {
				            	action: 'setCommonAreas',
				            	data: JSON.stringify(dataSave)
				            },
				            timeout: 10000,
				            success: function (data) {
				            	ap_showWaitMessage('waitDiv', 0);
			            		if(typeof data === 'object'){
			            			if(data.result == 'success'){
			            				modwin.close();
			        					modwin = null;
			            				table.reload();
			                		}else if(data.result == 'error'){
			                			//error
			                			setError('error', data.reason)
			                		}
			            		}else{
			            			setError('error', 'Unknown error');
			            		}
			                },
			                error: function(){
			                	ap_showWaitMessage('waitDiv', 0);
			                	setError('error', 'Unknown error');
			                }
				    	});
					}else{
						if(modwin){
							modwin.close();
			            	modwin = null;
						}
						return true;
					}

				});
			},

			showDialog = function(width, height, content, functionOk, buttons){
				modwin = new UI.Window({
					width: width,
					draggable:true,
					resizable:false,
					height: height,
					shadow: false,
					superflousEffects : false,
					theme: 'bluelighting'
				})
				.setContent(content)
				.center({ auto: true });

				if( ! buttons){
					modwin.prefoot.innerHTML = '<input id="saveButOk" type="button" value="'+(gl_translation['button.Ok'] || 'Ok')+'" class="but20" />\
					<input id="saveButCancel" type="button" value="'+(gl_translation['button.Cancel'] || 'Cancel')+'" class="but20" />';
				}else{
					modwin.prefoot.innerHTML = buttons;
				}

				modwin.show(true).focus();

				if(functionOk){
					$('#saveButOk').on('click', functionOk);
				}

				$('#saveButCancel').on('click', function(){
					modwin.close();
					modwin = null;
				});

				$('#edit_extension').focus();

				return modwin;
			}


		return {
			init: init,
			table: table
		}
	}

	$.fn.hotelCommonareas = function (opt) {

        return this.each(function () {
            var app;
            if (!$(this).data('hotelCommonareas')) {
                app = new hotelCommonareas(this, $.extend(true, {}, opt));
                app.init();
                $(this).data('hotelCommonareas', app);
            }
        });
    };
}(jQuery));