(function ($) {
	'use strict';

	var hotelGeneral = function(el, options){

		var generalConf,
			init = function(){

	            loadGeneralConf();

	            $(document).on('HotelIntegration:GeneralConf:chenged', _onChangedGeneralConf);
	            $(document).trigger('HotelIntegration:getGeneral');

	            $('#enableXOpenIntegration').on('click', _onClickEnableXOpenIntegration);
	            $('#disableXOpenIntegration').on('click', _onClickDisableXOpenIntegration);
	            $('#uninstallWhotelIntegration').on('click', _onClickUninstallWhotelIntegration);
	            $('#installWhotelIntegration').on('click', _onClickInstallWhotelIntegration);
	            $('#clearUserDefinedData').on('click', _onClickClearUserDefinedData);
	            $('#restartService').on('click', _onClickRestartService);

			},
		    loadGeneralConf = function (checkInstalationResult) {

				ap_showWaitMessage('waitDiv', 1);
				$.ajax({
		            url: options.url ,
		            type: "GET",
		            data: {action: 'getGeneral'},
		            timeout: 10000,
		            success: function (data) {

		            	if ( typeof data === 'object'){
		            		$(document).trigger('HotelIntegration:GeneralConf:chenged', data);

		            		if (data.InstalationProgress === true) {
	                            return setTimeout(loadGeneralConf.bind(this, checkInstalationResult), 2000);
	                        }

	                        if (checkInstalationResult && data.InstalationResult !== true) {
		                        setError('error', data.InstalationResult);
		                    }

	                    } else {
	                        setError('error', 'Unknown error');
	                    }
		            	ap_showWaitMessage('waitDiv', 0);
	                },
	                error: function(){
	                	ap_showWaitMessage('waitDiv', 0);
	                	setError('error', 'Unknown error');
	                }

		    	});
	        },
	        saveGeneralConf = function (conf) {
	        	ap_showWaitMessage('waitDiv', 1);

	        	$.ajax({
		            url: options.url ,
		            type: "GET",
		            data: {
		            	action: 'setGeneral',
		            	data: JSON.stringify(conf)
		            },
		            timeout: 10000,
		            success: function (data) {

		            	if(typeof data === 'object'){
	            			if(data.result == 'success'){
	            				return loadGeneralConf(true);

	                		}else if(data.result == 'error'){
	                			//error
	                			setError('error', data.reason)
	                		}
	            		}else{
	            			setError('error', 'Unknown error');
	            		}
		            	ap_showWaitMessage('waitDiv', 0);
	                },
	                error: function(){
	                	ap_showWaitMessage('waitDiv', 0);
	                	setError('error', 'Unknown error');
	                }
		    	});
	        },
	        _onClickEnableXOpenIntegration = function (event) {
	            saveGeneralConf(Object.extend(generalConf, {EnableAutomation: true}));
	        },
	        _onClickDisableXOpenIntegration = function (event) {
	            saveGeneralConf(Object.extend(generalConf, {EnableAutomation: false}));
	        },
	        _onClickUninstallWhotelIntegration = function (event) {
	            var yes = confirm("Are you sure you want to uninstall the wildix hotel integration?");
	            if (yes) {
	                saveGeneralConf(Object.extend(generalConf, {installed: false}));
	            }
	        },
	        _onClickInstallWhotelIntegration = function (event) {
	            saveGeneralConf(Object.extend(generalConf, {installed: true}));
	        },
	        _onClickClearUserDefinedData = function (event) {
	            var yes = confirm("Are you sure you want to clear the workstations mapping and the hotel configuration files?");
	            if (yes) {
	            	ap_showWaitMessage('waitDiv', 1);
	            	$.ajax({
			            url: options.url ,
			            type: "POST",
			            data: {
			            	action: 'removeAllFile'
			            },
			            timeout: 10000,
			            success: function (data) {
			            	ap_showWaitMessage('waitDiv', 0);
	                        if(typeof data === 'object'){
		            			if(data.result == 'success'){
		                			loadConf();
		                			setError('success', 'Successfully cleaned files', 3000)

		                		}else if(data.result == 'error'){
		                			//error
		                			setError('error', data.reason)
		                		}
		            		}else{
		            			setError('error', 'Unknown error');
		            		}

	                        $(document).trigger('HotelIntegration:XMLFile:loaded');
		                },
		                error: function(){
		                	ap_showWaitMessage('waitDiv', 0);
		                	setError('error', 'Unknown error');
		                }
			    	});

	            }
	        },
	        _onClickRestartService = function (event) {
	        	ap_showWaitMessage('waitDiv', 1);
	        	$.ajax({
		            url: options.url ,
		            type: "POST",
		            data: {
		            	action: 'reloadXml'
		            },
		            timeout: 10000,
		            success: function (data) {
		            	ap_showWaitMessage('waitDiv', 0);
	                    setError('success', 'Service restarted successfully', 3000)
	                },
	                error: function(){
	                	ap_showWaitMessage('waitDiv', 0);
	                	setError('error', 'Unknown error');
	                }
		    	});
	        },
	        _onChangedGeneralConf = function (event, data) {

	            generalConf = data;

	            if (generalConf.EnableAutomation) {
	                $('#enableXOpenIntegration').hide();
	                $('#disableXOpenIntegration').show();
	                $('#roomsGenerate').hide();
	            } else {
	                $('#enableXOpenIntegration').show();
	                $('#disableXOpenIntegration').hide();
	                $('#roomsGenerate').show();
	            }

	            if (generalConf.installed) {
	                $('#uninstallWhotelIntegration').show();
	                $('#installWhotelIntegration').hide();
	                $('#enableXOpenIntegration').attr('disabled', false);
	                $('#disableXOpenIntegration').attr('disabled', false);
	                $('#clearUserDefinedData').attr('disabled', false);
	                $('#restartService').attr('disabled', false);
	            } else {
	                $('#uninstallWhotelIntegration').hide();
	                $('#installWhotelIntegration').show();
	                $('#enableXOpenIntegration').attr('disabled', true);
	                $('#disableXOpenIntegration').attr('disabled', true);
	                $('#clearUserDefinedData').attr('disabled', true);
	                $('#restartService').attr('disabled', true);
	            }
	        };

		return {
			init: init
		}
	}

	$.fn.hotelGeneral = function (opt) {

        return this.each(function () {
            var app;
            if (!$(this).data('hotelGeneral')) {
                app = new hotelGeneral(this, $.extend(true, {}, opt));
                app.init();
                $(this).data('hotelGeneral', app);
            }
        });
    };
}(jQuery));