(function ($) {
	'use strict';

	var hotelPbxServices = function(el, options){

		var init = function(){

				$('#WakeUpService_save').on('click', saveConf);
				$('#WakeUpService_clean').on('click', cleanConf);

                jQuery("body").on("click", '#WakeUpService_soundEdit', function () {
                    WMS.SoundsDialog.init(true,'WakeUpService_sound',options);
                    jQuery('#dialog-sounds-form').dialog('open');
                });

				loadConf();
			},

			loadConf = function(){
				ap_showWaitMessage('waitDiv', 1);
	        	$.ajax({
		            url: options.url ,
		            type: "GET",
		            data: {
		            	action: 'getPbxServices'
		            },
		            timeout: 10000,
		            success: function (data) {
		            	ap_showWaitMessage('waitDiv', 0);
	            		if(typeof data === 'object'){
	            			parseConf(data);
	            		}else{
	            			setError('error', 'Unknown error');
	            		}
	                },
	                error: function(){
	                	ap_showWaitMessage('waitDiv', 0);
	                	setError('error', 'Unknown error');
	                }
		    	});
			},

			parseConf = function(conf){

				if(conf && conf.WakeUpService){
					$('#WakeUpService_timeout').val(conf.WakeUpService.timeout);
					$('#WakeUpService_tries').val(conf.WakeUpService.tries);
					$('#WakeUpService_sound').val(conf.WakeUpService.sound);
				}else{
					$('#WakeUpService_timeout').val('300');
					$('#WakeUpService_tries').val('3');
					$('#WakeUpService_sound').val('');
				}
			},

			cleanConf = function(){
				var yes = confirm("Are you sure you want to clear the PBX Services settings?");
				if(yes){
					ap_showWaitMessage('waitDiv', 1);
					$.ajax({
			            url: options.url ,
			            type: "GET",
			            data: {
			            	action: 'cleanPbxServices'
			            },
			            timeout: 10000,
			            success: function (data) {
			            	ap_showWaitMessage('waitDiv', 0);
		            		if(typeof data === 'object'){
		            			if(data.result == 'success'){
		            				loadConf();
			                		setError('success', 'Settings cleared successfully', 3000)
		            			}else if(data.result == 'error'){
			                		setError('error', data.reason)
			                	}else{
			                		setError('error', data);
			                	}
		            		}else{
		            			setError('error', 'Unknown error');
		            		}
		                },
		                error: function(){
		                	ap_showWaitMessage('waitDiv', 0);
		                	setError('error', 'Unknown error');
		                }
			    	});

				}
			},

			saveConf = function(){

				var opt = {
				        rules: [ // rule, element_id, message
				                 "required,WakeUpService_timeout," + gl_translation['rules.CannotBeEmpty'],
				                 "digits_only,WakeUpService_timeout," + gl_translation['rules.enterNumber'],

				                 "required,WakeUpService_tries," + gl_translation['rules.CannotBeEmpty'],
				                 "digits_only,WakeUpService_tries," + gl_translation['rules.enterNumber'],

				                 "required,WakeUpService_tries," + gl_translation['rules.CannotBeEmpty']
				        ],
				        customErrorHandler: function(f, errorInfo){
				        	for(var i = 0; i < errorInfo.length; i++){
				        		$(errorInfo[i][0]).after('<span class="err_span" style="color:#ff0000;padding-left:10px;">' + errorInfo[i][1] + '<br></span>');
				        	}
				        	return errorInfo.length == 0;
				        }
				    };

			    if (!WMS.validate('WakeUpService_settings_form', opt) ) {
			        return false;
			    }


				var dataSave = {
						WakeUpService: {
							timeout: $('#WakeUpService_timeout').val(),
							tries: $('#WakeUpService_tries').val(),
							sound: $('#WakeUpService_sound').val()
						}
				}
				ap_showWaitMessage('waitDiv', 1);
				$.ajax({
		            url: options.url ,
		            type: "POST",
		            data: {
		            	action: 'setPbxServices',
		            	data: JSON.stringify(dataSave)
		            },
		            timeout: 10000,
		            success: function (data) {

		            	ap_showWaitMessage('waitDiv', 0);
	            		if(typeof data === 'object'){
	            			if(data.result == 'success'){
	                			loadConf();
	                			setError('success', 'Settings saved successfully', 3000)

	                		}else if(data.result == 'error'){
	                			//error
	                			setError('error', data.reason)
	                		}
	            		}else{
	            			setError('error', 'Unknown error');
	            		}
	                },
	                error: function(){
	                	ap_showWaitMessage('waitDiv', 0);
	                	setError('error', 'Unknown error');
	                }
		    	});
			}

		return {
			init: init
		}
	}

	$.fn.hotelPbxServices = function (opt) {

        return this.each(function () {
            var app;
            if (!$(this).data('hotelPbxServices')) {
                app = new hotelPbxServices(this, $.extend(true, {}, opt));
                app.init();
                $(this).data('hotelPbxServices', app);
            }
        });
    };
}(jQuery));