(function ($) {
	'use strict';

	var hotelRooms = function(el, options){

		var table,
			modwin,
			init = function(){

				table = new WMS.DataTables({
					ajaxDataUrl: options.url + '?action=getRooms',
					$table: $('#' + options.table),
					columns: [ // column header
					    {"data":"rn", "title":"FIAS RN", "width": "60px", "orderable": true},
			    		{"data":"extension", "title":"Extension", "width": "70px", "orderable": true},
			    		{"data":"descr", "title":"Description", "width": "150px", "orderable": true},
			    		{"data":"building", "title":"Building", "width": "50px", "orderable": true},
			    		{"data":"floor", "title":"Floor", "width": "40px", "orderable": true},
			    		{"data":"category", "title":"Category", "width": "90px", "orderable": true, "render": categoryFormatter},
			    		{"data":"id", "title":"ID", "width": "250px", "orderable": true}
			    	],
					options:{
				    	searching: true,
				    	processing: true,
				        serverSide: true,
				        order: [[ 1, "asc" ]]
				    }
				});

				$('#roomsGenerate').on('click', _onClickGenerate);
	            $('#XMLFile').on('change', changeXML);
	            $('#uploadXMLForm').on('submit', uploadXML);
	            $('#roomsApply').on('click', _onClickApply);
	            $('#roomsClear').on('click', _onClickClear);

				setEvent();
			},
			categoryFormatter = function(data, type, full, meta){
	        	//<!-- Room category: 1=Single room, 2=Twin room, 3=Double room, 4=Triple room, 5=Quadruple room, 6=Suite. Empty if type=2 or 3. -->
	        	var text = '';
	            switch (data) {
					case '1': text='Single room';
						break;
					case '2': text='Twin room';
						break;
					case '3': text='Double room';
						break;
					case '4': text='Triple room';
						break;
					case '5': text='Quadruple room';
						break;
					case '6': text='Suite';
						break;
					default: text = data;
						break;
				}
	            return text;
	        },

	        setEvent = function(){
	        	$(document).on('HotelIntegration:XMLFile:loaded', function() {

					table.reload();
				});

				$(document).on('HotelIntegration:GeneralConf:chenged', _onChangedGeneralConf);
				$(document).trigger('HotelIntegration:getGeneral');

				// table

				table.on('dblclick', 'tr', editItem);

	        },

	        _onChangedGeneralConf = function (event, data) {

		    	if(!data.EnableAutomation){
	    			$('#uploadXMLForm').hide();
		        }else{
		        	$('#uploadXMLForm').show();
		        }
			},

			_onClickGenerate = function(){

				ap_showWaitMessage('waitDiv', 1);
				$.ajax({
		            url: options.url ,
		            type: "POST",
		            data: {action: 'generateHotelConfigurationFile'},
		            success: function (data) {
		            	ap_showWaitMessage('waitDiv', 0);
	            		if(typeof data === 'object'){
	            			if(data.result == 'success'){
	            				$(document).trigger('HotelIntegration:XMLFile:loaded');
	                			setError('success', 'Successfully generated hotel configuration file', 3000)

	                		}else if(data.result == 'error'){
	                			//error
	                			setError('error', data.reason)
	                		}
	            		}else{
	            			setError('error', 'Unknown error');
	            		}
	                },
	                error: function(){
	                	ap_showWaitMessage('waitDiv', 0);
	                	setError('error', 'Unknown error');
	                }
		    	});

			},
			_onClickClear = function(){

				var yes = confirm("Are you sure you want to clear the hotel configuration file?");
				if(yes){

					ap_showWaitMessage('waitDiv', 1);

					$.ajax({
			            url: options.url ,
			            type: "POST",
			            data: {action: 'removeHotelConfigurationFile'},
			            success: function (data) {
			            	ap_showWaitMessage('waitDiv', 0);
		            		if(typeof data === 'object'){
		            			if(data.result == 'success'){
		            				$(document).trigger('HotelIntegration:XMLFile:loaded');
		                			setError('success', 'Successfully cleaned hotel configuration file', 3000)

		                		}else if(data.result == 'error'){
		                			//error
		                			setError('error', data.reason)
		                		}
		            		}else{
		            			setError('error', 'Unknown error');
		            		}
		                },
		                error: function(){
		                	ap_showWaitMessage('waitDiv', 0);
		                	setError('error', 'Unknown error');
		                }
			    	});
				}
			},

			_onClickApply = function(){
				ap_showWaitMessage('waitDiv', 1);

				$.ajax({
		            url: options.url ,
		            type: "POST",
		            data: {action: 'reloadXml'},
		            success: function (data) {
		            	ap_showWaitMessage('waitDiv', 0);
		            	setError('success', 'Apply successfully', 3000)
	                },
	                error: function(){
	                	ap_showWaitMessage('waitDiv', 0);
	                	setError('error', 'Unknown error');
	                }
		    	});
			},

			changeXML = function(){
				if($('#XMLFile').val() != ''){
					$('#uploadXMLForm').submit();
				}
			},

			uploadXML = function() {

				table.unselectAllRows();

				if($('#XMLFile').val() != ''){
					return AIM.submit($('#uploadXMLForm')[0], {
						'onStart' : function(){
							ap_showWaitMessage('waitDiv', 1);
						},
						'onComplete' : function(data){
							data = jQuery.parseJSON(data);
							ap_showWaitMessage('waitDiv', 0);
							$('#XMLFile').val('');

							if(typeof data === 'object'){
		            			if(data.result == 'success'){
		            				$(document).trigger('HotelIntegration:XMLFile:loaded');
		        					setError('success', 'File uploaded successfully', 3000)
		        				}else if(data.result == 'error'){
		        					if(typeof data.reason == 'string'){
		        						setError('error', data.reason)
		        					}else if(data.reason && data.reason.message && data.reason.data){
		        						setError('error', data.reason.message+':</br>'+data.reason.data.join('</br>'))
		        					}

		        				}else if(data.result == 'warning'){
		        					if(data.reason && data.reason.duplicatedRoom){
		        						setError('warning', 'Duplicated FIAS RN in rooms:</br>'+data.reason.duplicatedRoom.join('</br>'))
		        					}else{
		        						setError('warning', data.reason)
		        					}
		        					$(document).fire('HotelIntegration:XMLFile:loaded');
		        				}
							}
						}
					});
				}else{
					return false;
				}
			},

			editItem = function(){

			    var pObj = table.getTrData(this);

			    if (pObj && 'id' in pObj) {

			        showFormEdit().setHeader(gl_translation['strings.Edit']);

			        $('#edit_category').lightCombobox([{
		        											label:'Single room',
		        											value:'1'
		                                                },{
		                                                	label:'Twin room',
		        											value:'2'
		                                                },{
		                                                	label:'Double room',
		        											value:'3'
		                                                },{
		                                                	label:'Triple room',
		        											value:'4'
		                                                },{
		                                                	label:'Quadruple room',
		        											value:'5'
		                                                },{
		                                                	label:'Suite',
		        											value:'6'
		                                                }
		                                               ]);


			        $('#edit_id').html(pObj['id'] || '');
			        $('#__edit_id').val(pObj['id'] || '');

			        $('#edit_extension').val(pObj['extension'] || '');
			        $('#__edit_extension').val(pObj['extension'] || '');

			        $('#edit_rn').val(pObj['rn'] || '');
			        $('#__edit_rn').val(pObj['rn'] || '');

			        $('#edit_description').val(pObj['descr'] || '');
			        $('#__edit_description').val(pObj['descr'] || '');

			        $('#edit_building').val(pObj['building'] || '');
			        $('#__edit_building').val(pObj['building'] || '');

			        $('#edit_floor').val(pObj['floor'] || '');
			        $('#__edit_floor').val(pObj['floor'] || '');

			        $('#edit_category').val(pObj['category'] || '');
			        $('#__edit_category').val(pObj['category'] || '');

			    }
			},

			showFormEdit = function(){

				return showDialog(500, 220, $('#edRoom_tmpl').html(), function(){

					var opt = {
				        rules: [ // rule, element_id, message
				            "digits_only,edit_extension," + gl_translation['rules.enterNumber']
				        ],
				        customErrorHandler: function(f, errorInfo){
				        	for(var i = 0; i < errorInfo.length; i++){
				        		$(errorInfo[i][0]).after('<span class="err_span" style="color:#ff0000;padding-left:10px;">' + errorInfo[i][1] + '<br></span>');
				        	}
				        	return errorInfo.length == 0;
				        }
				    };

				    if (!WMS.validate('edRoom', opt) ) {
				        return false;
				    }

					var dataSave = {
			                id: $('#__edit_id').val(),
			                extension: $('#edit_extension').val(),
			                extension_old: $('#__edit_extension').val(),
			                rn: $('#edit_rn').val(),
			                rn_old: $('#__edit_rn').val(),
			                descr: $('#edit_description').val(),
			                descr_old: $('#__edit_description').val(),
			                building: $('#edit_building').val(),
			                building_old: $('#__edit_building').val(),
			                floor: $('#edit_floor').val(),
			                floor_old: $('#__edit_floor').val(),
			                category: $('#edit_category').val(),
			                category_old: $('#__edit_category').val()

			            };

					if(dataSave.extension != dataSave.extension_old ||
							dataSave.rn != dataSave.rn_old ||
							dataSave.descr != dataSave.descr_old||
							dataSave.building != dataSave.building_old||
							dataSave.floor != dataSave.floor_old ||
							dataSave.category != dataSave.category_old){

						ap_showWaitMessage('waitDiv', 1);

						$.ajax({
				            url: options.url ,
				            type: "POST",
				            data: {
				            	action: 'setRoom',
				            	data: JSON.stringify(dataSave)
				            },
				            timeout: 10000,
				            success: function (data) {
				            	ap_showWaitMessage('waitDiv', 0);
			            		if(typeof data === 'object'){
			            			if(data.result == 'success'){
			            				table.reload();
			            				modwin.close();
			        					modwin = null;
			                		}else if(data.result == 'error'){
			                			//error
			                			setError('error', data.reason)
			                		}
			            		}else{
			            			setError('error', 'Unknown error');
			            		}
			                },
			                error: function(){
			                	ap_showWaitMessage('waitDiv', 0);
			                	setError('error', 'Unknown error');
			                }
				    	});
					}else{
						if(modwin){
							modwin.close();
			            	modwin = null;
			            	$('#edit_category').lightCombobox('destroy');
						}
						return true;
					}
				});
			},

			showDialog = function(width, height, content, functionOk, buttons){
				modwin = new UI.Window({
					width: width,
					draggable:true,
					resizable:false,
					height: height,
					shadow: false,
					superflousEffects : false,
					theme: 'bluelighting'
				})
				.setContent(content)
				.center({ auto: true });

				if( ! buttons){
					modwin.prefoot.innerHTML = '<input id="saveButOk" type="button" value="'+(gl_translation['button.Ok'] || 'Ok')+'" class="but20" />\
					<input id="saveButCancel" type="button" value="'+(gl_translation['button.Cancel'] || 'Cancel')+'" class="but20" />';
				}else{
					modwin.prefoot.innerHTML = buttons;
				}

				modwin.show(true).focus();

				if(functionOk){
					$('#saveButOk').on('click', functionOk);
				}

				$('#saveButCancel').on('click', function(){
					modwin.close();
					modwin = null;
					$('#edit_category').lightCombobox('destroy');
				});

				$('#edit_extension').focus();

				return modwin;
			}


		return {
			init: init,
			table: table
		}
	}

	$.fn.hotelRooms = function (opt) {

        return this.each(function () {
            var app;
            if (!$(this).data('hotelRooms')) {
                app = new hotelRooms(this, $.extend(true, {}, opt));
                app.init();
                $(this).data('hotelRooms', app);
            }
        });
    };
}(jQuery));