(function ($) {
	'use strict';

	var hotelWorkstations = function(el, options){

		var table,
			modwin,
			init = function(){

				table = new WMS.DataTables({
					ajaxDataUrl: options.url + '?action=getWorkstations',
					$table: $('#' + options.table),
					columns: [ // column header
			       		{"data":"ws", "title":"FIAS WS", "width": "15%", "orderable": true},
			    		{"data":"description", "title":"Description", "width": "30%", "orderable": true},
			    		{"data":"fc", "title":"Client FC", "width": "15%", "orderable": true},
			    		{"data":"uc", "title":"Client UC", "width": "15%", "orderable": true},
			    		{"data":"ip", "title":"Client IP", "width": "25%", "orderable": true}
					],
					options:{
						searching: true,
				    	processing: true,
				        serverSide: true
				    }
				});

				$('#wsNewLine').on('click', addLine);
				$('#wsEditLine').on('click', editLine);
				$('#wsDeleteLine').on('click', deleteLine);
				$('#wsSave').on('click', _onClickApply);
				$('#wsClear').on('click', _onClickClear);

				setEvent();
			},

			setEvent = function(){
				table.on( 'select', function ( e, dt, type, indexes ) {
						if(type == "row"){
							if(indexes.length == 1){
								$('#wsEditLine').attr('disabled', false);
								$('#wsDeleteLine').attr('disabled', false);
							}else{
								$('#wsEditLine').attr('disabled', true);
								$('#wsDeleteLine').attr('disabled', false);
							}
						}
					}).on( 'deselect', function ( e, dt, type, indexes ) {
					    if(table.getSelectedCount() == 0){
					    	$('#wsEditLine').attr('disabled', true);
							$('#wsDeleteLine').attr('disabled', true);
						}
					});

				table.on('dblclick', 'tr', editLine);
			},

			_onClickApply = function(){
				ap_showWaitMessage('waitDiv', 1);
				$.ajax({
		            url: options.url ,
		            type: "POST",
		            data: {action: 'reloadXml'},
		            timeout: 10000,
		            success: function (data) {
		            	ap_showWaitMessage('waitDiv', 0);
		            	setError('success', 'Apply successfully', 3000)
	                },
	                error: function(){
	                	ap_showWaitMessage('waitDiv', 0);
	                	setError('error', 'Unknown error');
	                }
		    	});
			},

			_onClickClear = function(){

				var yes = confirm("Are you sure you want to clear the workstations mapping file?");
				if(yes){

					ap_showWaitMessage('waitDiv', 1);

					$.ajax({
			            url: options.url ,
			            type: "POST",
			            data: {action: 'removeWorkstationsMappingFile'},
			            timeout: 10000,
			            success: function (data) {
			            	ap_showWaitMessage('waitDiv', 0);
		            		if(typeof data === 'object'){
		            			if(data.result == 'success'){
		            				table.reload();
		            				$('#wsEditLine').attr('disabled', true);
									$('#wsDeleteLine').attr('disabled', true);
		            				setError('success', 'Successfully cleaned workstations mapping file', 3000);
		                		}else if(data.result == 'error'){
		                			//error
		                			setError('error', data.reason)
		                		}
		            		}else{
		            			setError('error', 'Unknown error');
		            		}
		                },
		                error: function(){
		                	ap_showWaitMessage('waitDiv', 0);
		                	setError('error', 'Unknown error');
		                }
			    	});
				}
			},

			deleteLine = function(){
				if (table.getSelectedCount() == 0) {
			        return;
			    }

				if (!confirm(gl_translation['ConfirmDelete'])) return false;

				ap_showWaitMessage('waitDiv', 1);

				var data = [];
				var selected = table.getSelectedData()
				for(var i = 0; i < selected.length; i ++){
					data.push(selected[i]['ws']);
				}

				$.ajax({
		            url: options.url ,
		            type: "POST",
		            data: {
		            	action: 'delWorkstation',
		            	data: JSON.stringify(data)
		            },
		            timeout: 10000,
		            success: function (data) {
		            	ap_showWaitMessage('waitDiv', 0);
	            		table.reload(true);
	                },
	                error: function(){
	                	ap_showWaitMessage('waitDiv', 0);
	                	setError('error', 'Unknown error');
	                }
		    	});

			},

			addLine = function(){
				showFormEdit().setHeader(gl_translation['strings.Add']);
				$('#edit_ws').val('');
		        $('#__edit_ws').val('');
			},

			editLine = function(){

			    var pObj;
			    if($(this).is('tr')){
			    	pObj = table.getTrData(this);

			    }else{
			    	pObj = table.getSelectedData()[0];
			    }

			    if (pObj && 'ws' in pObj) {

			        showFormEdit().setHeader(gl_translation['strings.Edit']);

			        $('#edit_ws').val(pObj['ws'] || '');
			        $('#__edit_ws').val(pObj['ws'] || '');
			        $('#edit_description').val(pObj['description'] || '');
			        $('#edit_uc').val(pObj['uc'] || '');
			        $('#edit_ip').val(pObj['ip'] || '');
			    }
			},

			showFormEdit = function(){
				var opt = {
				        rules: [
				                "required,edit_ws," + gl_translation['rules.CannotBeEmpty'],
				                "reg_exp,edit_ws,[0-9A-Za-z\-]+$," + gl_translation['rules.enterValidValue']+' 0-9 A-Z a-z -',
				                "invert_reg_exp,edit_ws,^[0-9]+$," + 'Can not consist only of digits',

				                "required,edit_uc," + gl_translation['rules.CannotBeEmpty'],
				                "digits_only,edit_uc," + gl_translation['rules.enterValidValue'] +' 0-9',

				                "valid_ipaddr,edit_ip," + gl_translation['rules.enterValidValue']+" IP"

				        ],
				        customErrorHandler: function(f, errorInfo){
				        	for(var i = 0; i < errorInfo.length; i++){
				        		$(errorInfo[i][0]).after('<span class="err_span" style="color:#ff0000;padding-left:10px;">' + errorInfo[i][1] + '<br></span>');
				        	}
				        	return errorInfo.length == 0;
				        }
				};


				return showDialog(300, 180, $('#edWorkstations_tmpl').html(), function(){

					if (!WMS.validate('edWorkstations', opt) ) {
				    	return false;
				    }
					var dataSave = {
			                ws: $('#edit_ws').val(),
			                ws_old: $('#__edit_ws').val(),
			                description: $('#edit_description').val(),
			                uc: $('#edit_uc').val(),
			                ip: $('#edit_ip').val()
			        };
					ap_showWaitMessage('waitDiv', 1);
					$.ajax({
			            url: options.url ,
			            type: "POST",
			            data: {
			            	action: 'setWorkstation',
			            	data: JSON.stringify(dataSave)
			            },
			            timeout: 10000,
			            success: function (data) {
			            	ap_showWaitMessage('waitDiv', 0);
		            		if(typeof data === 'object'){
		            			if(data.result == 'success'){
		            				table.reload();
		            				modwin.close();
		        					modwin = null;
		                		}else if(data.result == 'error'){
		                			//error
		                			setError('error', data.reason)
		                		}
		            		}else{
		            			setError('error', 'Unknown error');
		            		}
		                },
		                error: function(){
		                	ap_showWaitMessage('waitDiv', 0);
		                	setError('error', 'Unknown error');
		                }
			    	});

				});
			},

			showDialog = function(width, height, content, functionOk, buttons){
				modwin = new UI.Window({
					width: width,
					draggable:true,
					resizable:false,
					height: height,
					shadow: false,
					superflousEffects : false,
					theme: 'bluelighting'
				})
				.setContent(content)
				.center({ auto: true });

				if( ! buttons){
					modwin.prefoot.innerHTML = '<input id="saveButOk" type="button" value="'+(gl_translation['button.Ok'] || 'Ok')+'" class="but20" />\
					<input id="saveButCancel" type="button" value="'+(gl_translation['button.Cancel'] || 'Cancel')+'" class="but20" />';
				}else{
					modwin.prefoot.innerHTML = buttons;
				}

				modwin.show(true).focus();

				if(functionOk){
					$('#saveButOk').on('click', functionOk);
				}

				$('#saveButCancel').on('click', function(){
					modwin.close();
					modwin = null;
				});

				$('#edit_ws').focus();

				return modwin;
			}


		return {
			init: init,
			table: table
		}
	}

	$.fn.hotelWorkstations = function (opt) {

        return this.each(function () {
            var app;
            if (!$(this).data('hotelWorkstations')) {
                app = new hotelWorkstations(this, $.extend(true, {}, opt));
                app.init();
                $(this).data('hotelWorkstations', app);
            }
        });
    };
}(jQuery));