(function ($) {
	'use strict';

	var hotelXOpen = function(el, options){

		var init = function(){

				$(document).on('HotelIntegration:status:chenged', _onChangedStatus);

				$('#XOpen_save').on('click',saveConf);
				loadConf();
			},

			loadConf = function(){
				ap_showWaitMessage('waitDiv', 1);
	        	$.ajax({
		            url: options.url ,
		            type: "GET",
		            data: {
		            	action: 'getXOpen'
		            },
		            timeout: 10000,
		            success: function (data) {
		            	ap_showWaitMessage('waitDiv', 0);
	            		if(typeof data === 'object'){
	            			parseConf(data);
	            		}else{
	            			setError('error', 'Unknown error');
	            		}
	                },
	                error: function(){
	                	ap_showWaitMessage('waitDiv', 0);
	                	setError('error', 'Unknown error');
	                }
		    	});
			},

			parseConf = function(conf){

				if(conf){
					$('#XOpen_host').val(conf.host);
					$('#XOpen_port').val(conf.port);
					$('#XOpen_fcode').val(conf.fcode);
					$('#XOpen_ucode').val(conf.ucode);
					$('#XOpen_secret').val(conf.secret);
					$('#BadgeController').prop('checked', conf.BadgeController == 'yes');
				}else{
					$('#XOpen_host').val('');
					$('#XOpen_port').val('');
					$('#XOpen_fcode').val('');
					$('#XOpen_ucode').val('');
					$('#XOpen_secret').val('');
					$('#BadgeController').prop('checked', true);
				}
				$(document).trigger('HotelIntegration:BadgeController:chenged', {BadgeController: conf.BadgeController == 'yes'});

			},

			saveConf = function(){

				var opt = {
			        rules: [ // rule, element_id, message
			            "required,XOpen_host," + gl_translation['rules.CannotBeEmpty'],
			            "valid_host_or_ip,XOpen_host," + gl_translation['rules.enterValidValue']+" IP or host",
			            "digits_only,XOpen_port," + gl_translation['rules.enterNumber'],
			            "range=1-65535,XOpen_port," + gl_translation['rules.enterValidValue']+" 1-65535",
			            "digits_only,XOpen_fcode," + gl_translation['rules.enterNumber'],
			            "digits_only,XOpen_ucode," + gl_translation['rules.enterNumber'],
			            "digits_only,XOpen_secret," + gl_translation['rules.enterNumber']
			        ],
			        customErrorHandler: function(f, errorInfo){
			        	for(var i = 0; i < errorInfo.length; i++){
			        		$(errorInfo[i][0]).after('<span class="err_span" style="color:#ff0000;padding-left:10px;">' + errorInfo[i][1] + '<br></span>');
			        	}
			        	return errorInfo.length == 0;
			        }
			    };

			    if (!WMS.validate('XOpen_settings_form', opt) ) {
			        return false;
			    }

			    if ($('#BadgeController').is(':checked')) {
			        $('#fias_fidelio_automation_title').parents('tr').eq(0).show();
			        $('#fias_fidelio_automation_host').parents('tr').eq(0).show();
			        $('#fias_fidelio_automation_port').parents('tr').eq(0).show();
			        $('#fias_fidelio_automation_delimiter').parents('tr').eq(0).show();
			    } else {
			        $('#fias_fidelio_automation_title').parents('tr').eq(0).hide();
			        $('#fias_fidelio_automation_host').parents('tr').eq(0).hide();
			        $('#fias_fidelio_automation_port').parents('tr').eq(0).hide();
			        $('#fias_fidelio_automation_delimiter').parents('tr').eq(0).hide()
			    }

				var dataSave = {
						host: $('#XOpen_host').val(),
						port: $('#XOpen_port').val(),
						fcode: $('#XOpen_fcode').val(),
						ucode: $('#XOpen_ucode').val(),
						secret: $('#XOpen_secret').val(),
						BadgeController: $('#BadgeController').is(':checked') ? 'yes' : 'no'
				}
				ap_showWaitMessage('waitDiv', 1);
				$.ajax({
		            url: options.url ,
		            type: "POST",
		            data: {
		            	action: 'setXOpen',
		            	data: JSON.stringify(dataSave)
		            },
		            timeout: 10000,
		            success: function (data) {

		            	ap_showWaitMessage('waitDiv', 0);
	            		if(typeof data === 'object'){
	            			if(data.result == 'success'){
	                			loadConf();
	                			setError('success', 'Settings saved successfully', 3000)

	                		}else if(data.result == 'error'){
	                			//error
	                			setError('error', data.reason)
	                		}
	            		}else{
	            			setError('error', 'Unknown error');
	            		}
	                },
	                error: function(){
	                	ap_showWaitMessage('waitDiv', 0);
	                	setError('error', 'Unknown error');
	                }
		    	});
			},

			_onChangedStatus = function(event, data){

				if(data.XOPEN == 0){
					$('#status_XOpen').attr('title', 'connected');
					$('#status_XOpen').removeClass('red gray').addClass('green');
				}else if(data.XOPEN > 0){
					$('#status_XOpen').attr('title', 'connected but HSE status fails');
					$('#status_XOpen').removeClass('green gray').addClass('red');
				}else{
					$('status_XOpen').attr('title', 'no connection');
					$('status_XOpen').removeClass('red green').addClass('gray');
				}
			};

		return {
			init: init
		}
	}

	$.fn.hotelXOpen = function (opt) {

        return this.each(function () {
            var app;
            if (!$(this).data('hotelXOpen')) {
                app = new hotelXOpen(this, $.extend(true, {}, opt));
                app.init();
                $(this).data('hotelXOpen', app);
            }
        });
    };
}(jQuery));