<?php

use Session\Session;
use Wildix\License;
use Wildix\PBXes\Network\NetworkServices;
use Wildix\PBXes\Network\Server;

require_once('auth.php');

error_reporting(E_ALL ^ E_NOTICE ^ E_WARNING);
ini_set('display_errors', 'on');

if (!defined('WMS_ENV')) {
    define('WMS_ENV', 1);
}

@exec('hostname', $hostname);

$title = 'WMS @ <'.$hostname[0].'>';

$diContainer = new \Wildix\DependencyInjection\Container();

// WMSProxy redirect
if(!empty($_GET['class'])) {
    if(\Wildix\HttpSecurity\Service::isCsrf([
        'method' => $_SERVER["REQUEST_METHOD"],
        'host' => $_SERVER["HTTP_HOST"],
        'origin' => $_SERVER["HTTP_ORIGIN"],
        'referer' => $_SERVER["HTTP_REFERER"]
    ])){
        if ($_SERVER['REQUEST_METHOD'] === 'GET' || Session::isValidCsrfToken()) {
            ini_set("include_path", BASEPATH . ':' . ini_get("include_path"));

            $classesWhiteList = array(
                'classes/aclpbx/aclpbx.class.php',
                'classes/backuper/backuper.class.php',
                'classes/network/network.class.php',
            );
            if(in_array($_GET['class'], $classesWhiteList)){
                require_once($_GET['class']);
            }
        }
    }
    die('Cannot redirect to class file');
}

if (!isset($_SESSION["login"])) {
    header("Pragma: Pragma: must-revalidate, private, max-age=86400");
    header("Cache-Control: must-revalidate");
}

require_once('common/wms_ldap.php');
$got_userPasswordIsDefault = false;
$got_adminMailEmpty = false;
$entry = WMS_Ldap::getInstance()->getEntry(WMS_Ldap::PERSONS, '(cn=admin)', array('userPassword', 'userKind', 'mail'));
if (!empty($entry)){
    if($entry['userPassword'] == 'wildix' || \User::getInstance()->isEqualPasswords($entry['userPassword'], 'wildix')) {
        $got_userPasswordIsDefault = true;
    }
    if($entry['mail'] == ''){
        $got_adminMailEmpty = true;
    }
}
$GLOBALS['got_userPasswordIsDefault'] = $got_userPasswordIsDefault;

require_once('common/errors.php');
if (empty($wmsErr) || !is_object($wmsErr)) {
    $wmsErr = new WMSErrors();
}

$licenseNotActivated = !License::getInstance()->isActivated();

// Connect to database

$_SESSION["Menuid"] = isset($_REQUEST["Menuid"]) ? $_REQUEST["Menuid"] : '10';

ob_start();

$wmsSpa = ($_SERVER['REQUEST_URI'] === '/wms');

$acl_class = new ACL();

// Check for password is default
$GLOBALS['disabledMenuIds'] = array('20','30','40','62','64','65','66','68','82','80','75','72','79','81','94','96');
$GLOBALS['hideMenuIds'] = array();

if (($got_userPasswordIsDefault || $licenseNotActivated) && in_array($_SESSION["Menuid"], $GLOBALS['disabledMenuIds'])){
    $_SESSION['Menuid'] = '10';
}else if(in_array($_SESSION["Menuid"], $GLOBALS['hideMenuIds'])){
    $_SESSION['Menuid'] = '10';
}


$acl_class->init_menu($_SESSION['Menuid'], '?Menuid=');

// redirect to new SPA page
if (!$wmsSpa && isset($acl_class->menu_includes[$_SESSION["Menuid"]]['route'])) {
    header('HTTP/1.1 301 Moved Permanently');
    header('Location: wms#/' . $acl_class->menu_includes[$_SESSION["Menuid"]]['route']);
    die;
}

$title .= ' ' . $acl_class->menu_includes[$_SESSION["Menuid"]]['title'];

preg_match("/cpu ([MG]Hz)\s*:\s*(\d*)/i", \Models\PBX::getInstance()->getCpuInfo(), $matched);
if($matched[1] == "GHz"){
    $matched[2] *= 1024;
}
if(!$matched[2] || $matched[2] > 700){
    $powerCPU = true;
}else{
    $powerCPU = false;
}
$acl = new stdClass();
if ($wmsSpa) {
    $acl = [];
    $aclKeys = [
        'dialplan__dialplan',
        'dialplan__call_groups',
        'dialplan__paging_groups',
        'dialplan__timetables',
        'dialplan__ivr',
        'dialplan__feature_code',
        'dialplan__general_settings',
        'users__users',
        'users__groups',
        'users__pbxs',
        'users__phonebooks3',
        'trunks__trunks',
        'trunks__hunt_groups',
        'trunks__pricelists',
        'devices',
        'settings__pbx',
        'settings__system',
        'settings__utilites__remote_support',
        'settings__utilites__backup',
        'settings__utilites__upgrade',
        'settings__utilites__activation',
        'settings__utilites__generate_trace',
        'top_control__generate_call',
        'top_control__sounds',
        'top_control__debug',
        'top_control__halt'
    ];
    $permissionKeys = [
        'add_remove_users'
    ];
    foreach ($aclKeys as $value) {
        $acl[$value] = WMS_Permissions::getInstance()->is_allowed('page', $value);
    }
    foreach ($permissionKeys as $value) {
        $acl[$value] = WMS_Permissions::getInstance()->is_allowed('permissions', $value);
    }
}

require_once './aclpbx/aclpbx.inc.php';

$wmsConfig = [
    'title' => $title,
    'license' => (License::getInstance()->haveLicense('hotel')) ? 'WMS HOTEL' : 'WMS ' . $hostname[0],
    'version' => WMS_VERSION_FULL,
    'languages' => isset($_SESSION['language']) ? $_SESSION['language'] : 'english',
    'menu' => $acl_class->menu_includes,
    'pbxName' => $diContainer->get(\Wildix\WhiteLabel::class)->getPbxName(),
    'isCloud' => License::getInstance()->isCloud(),
    'isSlave' => \Models\PBX::getInstance()->isSlave(),
    'isPremium' => License::getInstance()->isPremium(),
    'isSubscription' => License::getInstance()->isSubscription(),
    'cpuInfo' => [
        'isPower' => $powerCPU
    ],
    'isBackupsMounted' => \Models\PBX::getInstance()->isCustomShareMounted(\Models\PBX::BACKUPS_SHARE_PATH),
    'user' => [
        'name' => $currentUser->getName(),
        'email' => $currentUser->getEmail(),
        'extension' => $currentUser->getExtension(),
        'isRoot' => $currentUser->isRoot(),
    ],
    'userSyncSettings' => $aclpbx_class->get_sync_settings_n_map(),
    'acl' => $acl,
    'integrations' => [
        'bTicino' => [
            'installed' => \Bticino::getInstance()->isInstalled()
        ]
    ],
    'isXBeesEnable' => License::getInstance()->haveLicense(License::TYPE_XBEES)
        && in_array(License::getInstance()->getMaximumAvailableLicenseType(), [License::TYPE_PREMIUM, License::TYPE_BUSINESS], true)
];


include 'header.php';


    echo <<<JS
<script language="javascript">/* #start min */
    document.observe('WMS:load', function() {
        new WMSTopMenu('mmenu-1');
    });
</script>
JS;

    if($acl_class->menu_includes[$_SESSION["Menuid"]]['include'] != "activation/index.php"){
        $expired = array();

        $license_list = array(
            'cti_connect_pro',
            'cti_cdr_view',
            'support',
            'tapi'
        );


        foreach ($license_list as $service) {
            $range = License::getInstance()->getActiveDay($service);
            if($range <= 7 && $range >= -30){
                $expired[$range][] = _t('license.service.'.$service);
            }
        }


        if(count($expired)){
            foreach ($expired as $daysCount => $lc) {
                $lics = implode(', ', $lc);
                if($daysCount >= 0){
                    $err = _t('license.WmsErrorWorkDay',$lics, $daysCount);
                }else{
                       $err = _t('license.WmsErrorStoppedDay',$lics, abs($daysCount));
                }
                if (is_object($wmsErr)) {
                    $wmsErr->_set("", "error", $err);
                }
            }
        }elseif($licenseNotActivated) {
            if (is_object($wmsErr)) {
                $wmsErr->_set("", "error", _t('license.WmsIsNotActivatedPlaeseActivate'));
            }
        }
    }


    // Check for password is default
    if ($got_userPasswordIsDefault) {
        if (is_object($wmsErr)) {
             $wmsErr->_set("", "error", _t('strings.passwordsError'));
        }
    }

    if (isset($acl_class->menu_includes[$_SESSION["Menuid"]])) {
        //Check if user has permission fo curent page
        $permission = $acl_class->menu_includes[$_SESSION["Menuid"]]['permission'];
        if (!empty($permission)){
           if (!WMS_Permissions::getInstance()->is_allowed('page',$permission)) {
                die(_t('strings.permissionsDenied'));
            }
        }

        include($acl_class->menu_includes[$_SESSION["Menuid"]]['include']);
    } else if (!$wmsSpa) {
        include($acl_class->menu_includes[10]['include']);
    }

if (!\Models\PBX::getInstance()->isEnabledWmsNetwork()) {
    require_once('classes/multipbx.class.php');

    $multiPbx = new multipbx();
    $netConf  = $multiPbx->get_pbx_net_conf();

    if (isset($netConf['FORCE_DISABLED']) && \Wildix\Validator::isTrue($netConf['FORCE_DISABLED']) && is_object($wmsErr)) {
        $wmsErr->_set('', 'error', _t('strings.wmsNetworkDisabledBecauseOfLowCredentials'));
    }
}

$networkServices = $diContainer->get(NetworkServices::class);
$server          = $diContainer->get(Server::class);

if (\Models\PBX::getInstance()->isEnabledWmsNetwork() && $networkServices->isVersionDiffers()) {
    $wmsErr->_set('', 'error', _t('strings.wmsNetworkUpgradeAllPbxes', $server->getVersion()));
}

    // Check if /dev/shm is full (at least 3M is available)
    if (($current = is_tmp_full()) !== false) {
        if (is_object($wmsErr)) {
            $wmsErr->_set('','error',_t('strings.TempIsFull', $current));
        }
    }

    // Check if we have errors from CTIconnect
    $err_file = '/tmp/cticonnect.errs';
    if(is_object($wmsErr) && is_file($err_file)){
        $errs = file($err_file, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
        foreach($errs as $err){
            $wmsErr->_set('','error', $err);
        }
        unlink($err_file);
    }

    // Redundancy: check if secondary host has unmounted partitions
    check_mpoints_on_mirrored_box();

$pbxSerial = \Models\PBX::getInstance()->getSerial();
$pbxDomain = \Models\PBX::getInstance()->getDomain();

$isUseSerialInDomain  = strripos($_SERVER['SERVER_NAME'], $pbxSerial) !== false;
$isUseSerialInPbxName = strripos($pbxDomain, $pbxSerial) !== false;

if ($isUseSerialInDomain && !$isUseSerialInPbxName) {
    $wmsErr->_set('', 'error', _t('strings.accessToPBXWithSerialNumber', $pbxDomain));
}

include 'footer.php';
