/* DebugDialplan module */
(function universalModuleDefinition(root, factory) {
    if (typeof exports === 'object') {
        // CommonJS
        module.exports = factory(require('jquery'));
    } else if (typeof define === 'function' && define.amd) {
        // AMD
        define(['jquery'], factory);
    } else {
        // Browser
        root.DebugDialplan = factory(root.jQuery);
    }
}(this, function ($) {
    'use strict';

    function DebugDialplan(data) {
        this.constructor(data);
    }

    $.extend(DebugDialplan.prototype, {
        authorized: false,

        constructor: function (data) {
            this._data = data.callLogs;
            this._enabled = data.isEnabled;
            this.timer = 10 * 1000; // 10 seconds
            this.timerId = null;
        },

        load: function () {
            if (this._data) {
                this.initTable(this._data);
            }

            $('.call_log_container_column').show();
            $('#searchAll').show();

            this.periodicalUpdate(true);

            // global search
            $('#searchAll').keyup(function () {
                $('#active_calls').DataTable().search(this.value).draw();
                $('#terminated_calls').DataTable().search(this.value).draw();
            });
            // draw calls details
            this.drawDetails('#active_calls');
            this.drawDetails('#terminated_calls');

            return this;
        },

        drawDetails: function (id) {
            var table = $(id).DataTable().on('click', 'tr', function () {
                if ($(this).hasClass('selected')) {
                    $(this).removeClass('selected');
                    $('#call_log_output_div').html(''); // clear details when unselect
                } else {
                    $('tr.selected').removeClass('selected');
                    $(this).addClass('selected');

                    $('#call_log_output_div').html('');
                    if (table.row(this).data() !== undefined) {
                        $('#call_log_output_div').append(table.row(this).data().content);
                    }
                }
            });
        },

        initTable: function (data) {
            var types = ['active', 'terminated'];

            for (var i = 0; i < types.length; i++) {
                var id = '#' + types[i] + '_calls';
                var type = types[i];
                var dataSet = data[type] !== undefined ? data[type] : {};
                $(id).DataTable({
                    data: dataSet,
                    columns: [
                        {data: 'date', title: WMS._t('debug.dialplan.Date')},
                        {data: 'from', title: WMS._t('debug.dialplan.From')},
                        {data: 'to', title: WMS._t('debug.dialplan.To')},
                        {data: 'content'}
                    ],

                    columnDefs: [
                        {
                            targets: [3],
                            visible: false,
                            orderable: true,
                            searchable: true
                        }
                    ],
                    scrollY: '275px',
                    scrollCollapse: true,
                    retrieve: true,
                    paging: false,
                    dom: '<"' + type + '_table_title">rtip<"bottom">'
                });

                // title
                var title = (type === 'active') ? WMS._translation['debug.dialplan.Calls'] : WMS._translation['debug.dialplan.History'];
                $('div.' + type + '_table_title').html('<b>' + title + '</b>');
            }
        },

        periodicalUpdate: function loop(isRun) {
            var update = function () {
                $.ajax({
                    url: 'api/v1/Dialplan/Debug/CallLogs',
                    type: 'GET',
                    success: function (response) {
                        if (response.result) {
                            var types = ['active', 'terminated'];
                            for (var i = 0; i < types.length; i++) {
                                var oldScrollPosition = $('.dataTables_scrollBody').eq(i).scrollTop();
                                var id = '#' + types[i] + '_calls';
                                var type = types[i];
                                var dataSet = response.result[type] !== undefined ? response.result[type] : {};
                                var table = $(id).DataTable();
                                var selectedRow = table.rows('.selected').data();
                                // reinit table
                                table.clear();
                                table.rows.add(
                                    dataSet
                                ).draw();
                                var parentWidth = $('.call_log_container_column').width();
                                $('.dataTables_scrollHeadInner').css('width', parentWidth - 20);
                                // restore selection on row
                                if (selectedRow.length > 0) {
                                    table.rows(function (index, row, node) {
                                        if (row.content) {
                                            var result = $.grep(selectedRow, function (val) {
                                                return row.content === val.content;
                                            });
                                            return result.length > 0;
                                        }
                                        return false;
                                    }).select();
                                }
                                if (oldScrollPosition) {
                                    $('.dataTables_scrollBody').scrollTop(oldScrollPosition);
                                }
                            }
                        }
                    },
                    error: function (XMLHttpRequest, textStatus, errorThrown) {
                        console.error(errorThrown);
                    },
                    complete: function () {
                        if (isRun) {
                            this.timerId = setTimeout(update, this.timer); // recursion
                        }
                    }.bind(this)
                });
            }.bind(this);
            if (isRun) {
                update();
            } else {
                clearTimeout(this.timerId);
            }
        }
    });
    return DebugDialplan;
}));
