(function universalModuleDefinition(root, factory){
    if (typeof exports === 'object'){
        // CommonJS
        module.exports = factory(require('jquery'));
    } else if (typeof define === 'function' && define.amd){
        // AMD
        define(['jquery'], factory);
    } else {
        // Browser
        root.QMetricsSettings = factory(root.jQuery);
    }
}(this, function ($) {
    var QMetricsSettings = function () {
        this.constructor();
    };

    QMetricsSettings.prototype = {
        constructor: function () {
            this.mainForm = $('#q_metrics_settings_form');

            this.mainForm.checkForm({
                rules: [ // rule, element_id, message
                    'required,q_metrics_host,' + WMS._t('rules.CannotBeEmpty'),
                    'required,q_metrics_login,' + WMS._t('rules.CannotBeEmpty'),
                    'required,q_metrics_password,' + WMS._t('rules.CannotBeEmpty'),
                    'required,q_metrics_database,' + WMS._t('rules.CannotBeEmpty')
                ]
            });
        },

        load: function () {
            $('#saveSettings').on('click', jQuery.proxy(this._save, this));

            this.mainForm.apiForm({
                load: 'api/v1/PBX/settings/qMetrics/',
                submit: 'api/v1/PBX/settings/qMetrics/',

                beforeSubmit: function () {
                    ap_showWaitMessage('waitDiv', 1);
                },

                error: function (ajaxData) {
                    setError('error', ajaxData.reason, 5000);
                },

                afterSubmit: function () {
                    ap_showWaitMessage('waitDiv', 0);

                    var params = this.mainForm.apiForm('option', 'loadData');

                    for (var key in params) {
                        var input = this.mainForm.find('#q_metrics_' + key);

                        if (input.attr('type') === 'checkbox') {
                            this.mainForm.find('#q_metrics_' + key).prop('checked', params[key]);
                        } else {
                            this.mainForm.find('#q_metrics_' + key).attr('value', params[key]);
                        }
                    }
                }.bind(this)
            });

            this.mainForm.apiForm('load');
        },

        validate: function () {
            return this.mainForm.checkForm('validate');
        },

        _save: function () {
            if (!this.validate()) {
                return false;
            }

            this.mainForm.apiForm('submit');

            return false;
        }
    };

    return QMetricsSettings;
}));
