(function universalModuleDefinition(root, factory) {
    if (typeof exports === 'object'){
        // CommonJS
        module.exports = factory(require('jquery'));
    } else if (typeof define === 'function' && define.amd){
        // AMD
        define(['jquery'], factory);
    } else {
        // Browser
        root.RemoteSupport = factory(root.jQuery);
    }
}(this, function ($) {
    'use strict';

    function RemoteSupport(data) {
        this.constructor(data);
    }

    $.extend(RemoteSupport.prototype = {

        vtunServiceDoStartAjaxURL: 'api/v1/PBX/settings/remoteSupport',
        geoLocationPostAjaxURL: 'api/v1/PBX/settings/remoteSupport/location',
        geoSettingsSaveAjaxURL: 'api/v1/PBX/settings/remoteSupport/location',
        vtunPeriodicCheckStateAjaxURL: 'api/v1/PBX/settings/remoteSupport',

        constructor: function(data) {
            this.vtunInitServStat = data.vtunInitServStat;
            this.geoLocationIsChecked = data.geoLocationIsChecked;
            this._bindEvents();
            this._showVtunServiceValues(this.vtunInitServStat);
            $('#geo_post_location_on').prop('checked', this.geoLocationIsChecked);
        },

        _showVtunServiceValues: function(status) {
            this.vtunInitServStat = status;
            ap_showWaitMessage('waitDiv', 0);
            var fontColor, fontMessage;

            if (status == '0') {
                fontColor = 'orange';
                fontMessage = WMS._t('state.ServerStarted');
                $('#vtun_service_reload').show();
                $('#vtun_service_stop').show();
                $('#vtun_service_start').hide();
            } else {
                fontColor = 'gray';
                fontMessage = WMS._t('state.ServerStopped');
                $('#vtun_service_reload').hide();
                $('#vtun_service_stop').hide();
                $('#vtun_service_start').show();
            }

            $('#vtun_service_status').html('<font color="' + fontColor + '">' + fontMessage + '</font>');
            $('#geo_location_post').removeAttr('disabled');
            $('#geo_location_post').attr('class', 'but20');
            $('#geo_settings_save_btn').removeAttr('disabled');
            $('#geo_settings_save_btn').attr('class', 'but20');
        },

        _bindEvents: function() {
            $('#vtun_service_reload').on('click', $.proxy(this._vtunServiceDoStart, this, 'restart'));
            $('#vtun_service_stop').on('click', $.proxy(this._vtunServiceDoStart, this, 'stop'));
            $('#vtun_service_start').on('click', $.proxy(this._vtunServiceDoStart, this, 'start'));

            $('#geo_location_post').on('click', $.proxy(this._geoLocationPost, this));
            $('#geo_settings_save_btn').on('click', $.proxy(this._geoSettingsSave, this));
        },

        _vtunServiceDoStart: function(type) {
            this._disableButtons();
            this.checkCnt = 10;
            ap_showWaitMessage('waitDiv', 1);
            var errorFlag = false;

            var statusText = (type == 'restart') ? WMS._t('vtun.JS.Restarting') : WMS._t('vtun.JS.Starting');
            $('#vtun_status_block').text(statusText);

            if (type == undefined || type == '') {
                type = 'start';
            }

            $.ajax({
                url: this.vtunServiceDoStartAjaxURL,
                type: 'PUT',
                dataType: 'json',
                data: {
                    type: type
                },
                success: function(data, textStatus, transport) {
                    if (transport.status == 200 && transport.responseText != '') {
                        if (data.result.error != '') {
                            setError('error', data.result.error);
                            ap_showWaitMessage('waitDiv', 0);
                            $('#vtun_status_block').text(WMS._t('vtun.JS.ConnectionError'));
                            this._showVtunServiceValues('1');
                            errorFlag = true;
                        }
                    } else {
                        $('#vtun_status_block').text('HTTP transport problem.');
                        errorFlag = true;
                    }

                    if (!errorFlag) {
                        setTimeout(function() {
                            this._vtunPeriodicCheckState();
                        }.bind(this), 1500);
                    }
                }.bind(this),
                error: function(jqXHR, textStatus) {
                    console.error(textStatus);
                }
            });
        },

        _geoLocationPost: function() {
            this._disableButtons();
            ap_showWaitMessage('waitDiv', 1);

            $.ajax({
                type: 'POST',
                url: this.geoLocationPostAjaxURL,
                dataType: 'json',
                success: function(data, textStatus, transport) {
                    if (transport.status == 200 && transport.responseText != '') {
                        $('#geo_settings_updater_info').text(data.result.location_update);
                        $('#geo_settings_latitude').text(data.result.latitude);
                        $('#geo_settings_longitude').text(data.result.longitude);
                        $('#geo_settings_address').text(data.result.address);
                        $('#geo_settings_updated').text(data.result.updated);
                    } else {
                        $('#geo_settings_updater_info').text('HTTP transport problem.');
                    }
                    this._showVtunServiceValues(this.vtunInitServStat);
                }.bind(this),
                error: function(jqXHR, textStatus) {
                    console.error(textStatus);
                }
            });
        },

        _geoSettingsSave: function() {
            this._disableButtons();
            ap_showWaitMessage('waitDiv', 1);

            $.ajax({
                type: 'PUT',
                url: this.geoSettingsSaveAjaxURL,
                dataType: 'json',
                data: {
                    geoLocation: $('#geo_post_location_on').prop('checked') ? 'yes' : 'no'
                },
                success: function (data, textStatus, transport) {
                    if (transport.status == 200 && transport.responseText != '') {
                        $('#geo_post_location_on').prop('checked', data.result.post_geo_location == 'yes');
                    } else {
                        $('#geo_settings_updater_info').text('HTTP transport problem.');
                    }
                    this._showVtunServiceValues(this.vtunInitServStat);
                }.bind(this),
                error: function (jqXHR, textStatus) {
                    console.error(textStatus);
                }
            });
        },

        _vtunPeriodicCheckState: function() {
            var started = false;
            $('#vtun_status_block').text(WMS._t('vtun.JS.Connecting'));

            $.ajax({
                type: 'POST',
                url: this.vtunPeriodicCheckStateAjaxURL,
                dataType: 'json',
                success: function(data, textStatus, transport) {
                    if (transport.status == 200 && transport.responseText != '') {
                        if (data.result.state == '0') {
                            $('#vtun_status_block').text('IP: ' + data.result.vtun_ip);
                            this._showVtunServiceValues(data.result.state);
                            started = true;
                            this.checkCnt = 0;
                        }
                    }

                    if (this.checkCnt > 0) {
                        this.checkCnt--;
                        setTimeout(function() {
                            this._vtunPeriodicCheckState();
                        }.bind(this), 3000);
                    } else {
                        if (!started) {
                            $('#vtun_status_block').text(WMS._t('vtun.JS.ConnectionTimeout'));
                            this._showVtunServiceValues('1');
                        }
                    }
                }.bind(this),
                error: function(jqXHR, textStatus) {
                    console.error(textStatus);
                }
            });
        },

        _disableButtons: function() {
            $('#geo_location_post').attr('disabled', 'disabled');
            $('#geo_location_post').attr('class', 'but20_dis');
            $('#geo_settings_save_btn').attr('disabled', 'disabled');
            $('#geo_settings_save_btn').attr('class', 'but20_dis');
        }
    });

    return RemoteSupport;
}));
