<?php

function get_page_settings() {
	$return = array(
		'externip' => '',
		'dyndnsaddr' => 'http://checkip.wildix.com/',
		'autoipdiscover' => 'on',
		'rtpstart' => '',
		'defaultexpiry' => '600',
		'rtpend' => '',
		'tos' => '184',
		'tos_sip' => '184',
		'language' => 'it',
		'prov_trust_local_device' => 'no',
		'https_only' => ''
	);

	$rtp_filename = PATH_TO_CW_CONF . 'rtp-wms.conf';
	$rtp_engine_filename = PATH_TO_RTP_ENGINE_CONF . 'rtp-wms.cfg';
	$wudpecho_filename = PATH_TO_WUDPECHO_CONF . 'wudpecho.conf';
	$sip_general_filename = PATH_TO_CW_CONF . 'sip-wms.conf';
	$prov_filename = '/rw2/etc/provision.conf';
	$httpsOnlyConf = '/rw2/etc/pbx/https-only.conf';
	$mohConf = PATH_TO_CW_CONF . 'musiconhold-wms.conf';

	if (!check_read_file($rtp_filename) ||
		!check_read_file($rtp_engine_filename) ||
		!check_read_file($wudpecho_filename) ||
		!check_read_file($sip_general_filename) ||
		!check_read_file('/rw2/etc/kamailio/host_specific.cfg') ||
		!check_read_file($prov_filename) ||
		!check_read_file($httpsOnlyConf) ||
        !check_read_file($mohConf)
	)
		return $return;

	// get https-only.conf data
	$httpsOnly = parse_ini_file($httpsOnlyConf);
	$return['https_only'] = $httpsOnly['https_only'];

	// get musiconhold-wms.conf data
	$moh = parse_ini_file($mohConf);
    $return['random_moh'] = $moh['sort'] === 'random' ? 'yes' : 'no';

	// get kamailio parameters
	$kamparams = get_kamailio_config();

	$extern_host_port = explode(':', $kamparams['via_tool']['externip']);

	$return['externip'] = $extern_host_port[0];
	if ($return['externip'] == 'empty')
		$return['externip'] = '';

	// get auto ip discover parameter
	$is_autoipdiscover = (int) $kamparams['via_tool']['enable_ip_check'] == 1;
	$return['autoipdiscover'] = $is_autoipdiscover ? 'on' : 'off';

	// get dydns addr
	//$dyndnsaddr = $kamparams['via_tool']['ipcheck_url'];
	//$return['dyndnsaddr'] = $dyndnsaddr;

	if ($is_autoipdiscover && $return['dyndnsaddr'] != '') {
		$content = file_get_contents('/tmp/provisioning_externip');
		if (preg_match('/^[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}$/', $content, $matches)) {
			$return['externip'] = $matches[0];
		}
	}

	// sip general
	$sip_opts = parse_ini_file($sip_general_filename, true, INI_SCANNER_RAW);
	if (is_array($sip_opts) && isset($rtp_opts['general']))
		$sip_opts = $sip_opts['general'];

	if (is_array($sip_opts)) {
		foreach (array('defaultexpiry', 'tos', 'tos_sip', 'musicclass') as $val) {
			if (isset($sip_opts[$val]))
				$return[$val] = $sip_opts[$val];
		}
		/* WMS-2139 hide
		if($sip_opts['disallow'] && $sip_opts['allow']){
			$return['widebandcodecg722'] = 'on';
		}*/
	}

	// rtp settings
        $wudpecho_opts = parse_ini_file($wudpecho_filename, true, INI_SCANNER_RAW);
	if (is_array($wudpecho_opts) && $wudpecho_opts['START'] && $wudpecho_opts['END']) {
            $return['rtpstart'] = $wudpecho_opts['START'];
            $return['rtpend'] = $wudpecho_opts['END'];
	} else {
            $rtp_opts = parse_ini_file($rtp_filename, true, INI_SCANNER_RAW);
            if (is_array($rtp_opts)) {
                    foreach (array('rtpstart', 'rtpend') As $val) {
                            if (isset($rtp_opts[$val]))
                                    $return[$val] = $rtp_opts[$val];
                    }
            }

            if($return['rtpstart'] != $return['rtpend']){
                    $rtpengine_opts = parse_ini_file($rtp_engine_filename, true, INI_SCANNER_RAW);
                    if (is_array($rtpengine_opts) && count($rtpengine_opts) > 0 && $rtpengine_opts['PORT_MIN'] != '' && $rtpengine_opts['PORT_MAX'] != '' ) {
                            $return['rtpend'] = $rtpengine_opts['PORT_MAX'];
                    }
            }
        }

	// norewritenetworks
	$return['norewritenetworks'] = implode(PHP_EOL, get_norewrite_networks());

	// jitter buffer
	$jb_settins = get_jitter_buffer();
	$return['jb_min'] = $jb_settins['min'];
	$return['jb_nom'] = $jb_settins['nom'];
	$return['jb_max'] = $jb_settins['max'];

	// prov settings
	$prov_opts = parse_ini_file($prov_filename, true, INI_SCANNER_RAW);
	if (is_array($prov_opts) && is_array($prov_opts['general'])) {
		if(isset($prov_opts['general']['TrustLocalDevice']) && $prov_opts['general']['TrustLocalDevice'] == 'no'){
			$return['prov_trust_local_device'] = 'no';
		}
	}


	return $return;
}

function set_settings($values) {
    $settings = get_page_settings();
    $messages = array();

    $needUploadPorts = false;

    $rtp_filename = PATH_TO_CW_CONF . 'rtp-wms.conf';
    $rtp_engine_filename = PATH_TO_RTP_ENGINE_CONF . 'rtp-wms.cfg';
    $wudpecho_filename = PATH_TO_WUDPECHO_CONF . 'wudpecho.conf';
    $sip_general_filename = PATH_TO_CW_CONF . 'sip-wms.conf';
    $prov_filename = '/rw2/etc/provision.conf';
    $udptl_filename = PATH_TO_CW_CONF . 'udptl.conf';
    $rtpEngineTos = PATH_TO_RTP_ENGINE_CONF . 'rtp-tos.cfg';
    $httpsOnlyConf = '/rw2/etc/pbx/https-only.conf';
    $mohConf = PATH_TO_CW_CONF . 'musiconhold-wms.conf';
    $turnServerConfFilePath = \Wildix\Settings\TurnServer::TURN_SERVER_CONF;

    $diContainer = new \Wildix\DependencyInjection\Container();

    if (!check_write_file($rtp_filename) ||
        !check_write_file($rtp_engine_filename) ||
        !check_write_file($wudpecho_filename) ||
        !check_write_file($sip_general_filename) ||
        !check_write_file('/rw2/etc/kamailio/host_specific.cfg') ||
        !check_write_file($prov_filename) ||
        !check_write_file($udptl_filename) ||
        !check_write_file($rtpEngineTos) ||
        !check_write_file($httpsOnlyConf) ||
        !check_read_file($mohConf) ||
        !check_read_file($turnServerConfFilePath)
    ) {
        return false;
    }

    // set https-only.conf
    write_ini_file($httpsOnlyConf, array('https_only' => $values['https_only']));

    // set musiconhold-wms.conf
    set_random_moh($values['random_moh'], $mohConf);

    // {{ set host_specific.cfg
    $is_autoipdiscover = $values['autoipdiscover'] == 'on';

    $kamparams['enable_ip_check'] = $is_autoipdiscover ? 1 : 0;
    $kamparams['ipcheck_url'] = $settings['dyndnsaddr'];
    $kamparams['externip'] = ($is_autoipdiscover || $values['externip'] == '') ? 'empty' : $values['externip'];
    $kamvarset['trunk_language'] = 's:' . $values['language'] ?? 'en';
    // }}

    // {{ LDAP_EXTEN_NUMBER
    $extenNumber_str = trim(exec('sed -ne "s/^LDAP_EXTEN_NUMBER=\(.*\)/\1/p" /etc/callweaver/extensions-variables.conf'));
    if ($extenNumber_str == '') {
        $extenNumber_str = 'telephoneNumber';
    }
    $kamvarset['telephoneNumberAttr'] = 's:' . $extenNumber_str;
    // }}

    // hardcode failcounter
    $kamvarset['failscount'] = 'i:25';

    if(!empty($values['external_https_port'])){
        $kamvarset['external_secure_port'] = 'i:'.$values['external_https_port'];
    }else{
        $kamvarset['external_secure_port'] = 'i:443';
    }

    // generate localnet pattern
    require_once"classes/network/network.class.php";
    $network_class = new network();

    // norewritenetworks
    $norewritenetworks = array();
    foreach (explode(PHP_EOL, $values['norewritenetworks']) as $network) {
        list($address, $netmask) = explode('/', trim($network));

        if ($address == '' || !is_ip($address)) {
            continue;
        }

        if ($netmask == '') {
            $netmask = 32;
        }

        if (!is_ip_mask($netmask)) {
            $cidr = $netmask;
            $netmask = $network_class->cidr2netmask($netmask);
        } else {
            $cidr = $network_class->netmask2cidr($netmask);
        }

        $norewritenetworks[] = $address . '/' . $cidr;
    }

    array_unique($norewritenetworks);

    set_norewrite_networks($norewritenetworks);

    set_kamailio_config(
        array(
            'via_tool' => $kamparams,
            'pv' => array('varset' => $kamvarset)
        )
    );


    if($values['rtpstart'] != $settings['rtpstart'] || $values['rtpend'] != $settings['rtpend']){
        $needUploadPorts = true;
    }

    $portList = calculatePorts((int)$values['rtpstart'], (int)$values['rtpend']);

    //callweaver, rtpengine, turnserver and wudpecho config
    $wudpecho_ports_start   = $portList['wudpEchoPortStart'];
    $wudpecho_ports_end     = $portList['wudpEchoPortEnd'];
    $сallweaver_ports_start = $portList['callweaverPortStart'];
    $сallweaver_ports_end   = $portList['callweaverPortEnd'];
    $rtpengine_ports_start  = $portList['rtpEnginePortStart'];
    $rtpengine_ports_end    = $portList['rtpEnginePortEnd'];
    $turnServerPortsStart   = $portList['turnServerPortStart'];
    $turnServerPortsEnd     = $portList['turnServerPortEnd'];

    $fp = fopen($rtp_filename, 'w');
    fputs($fp, "rtpstart=" . $сallweaver_ports_start . "\nrtpend=" . $сallweaver_ports_end . "\n\n");
    fclose($fp);

    $udptl_settings = parse_ini_file($udptl_filename, true, INI_SCANNER_RAW);
    $udptl_settings['general']['udptlstart'] = $сallweaver_ports_start;
    $udptl_settings['general']['udptlend'] = $сallweaver_ports_end;
    write_ini_file($udptl_filename, $udptl_settings, true);

    $reloadRtpEngine = false;
    $current_rtp_config = parse_ini_file($rtp_engine_filename);
    if (($current_rtp_config['PORT_MIN'] != $rtpengine_ports_start) or ($current_rtp_config['PORT_MAX'] != $rtpengine_ports_end)) {
        $fp = fopen($rtp_engine_filename, 'w');
        fputs($fp, "PORT_MIN=" . $rtpengine_ports_start . "\nPORT_MAX=" . $rtpengine_ports_end . "\n\n");
        fclose($fp);
        $reloadRtpEngine = true;
    }

    /* @var $turnServer \Wildix\Settings\TurnServer */
    $turnServer = $diContainer->get(\Wildix\Settings\TurnServer::class);

    $currentTurnServerMinPort = (int)$turnServer->getParam(\Wildix\Settings\TurnServer::MIN_PORT);
    $currentTurnServerMaxPort = (int)$turnServer->getParam(\Wildix\Settings\TurnServer::MAX_PORT);

    if (($currentTurnServerMinPort !== $turnServerPortsStart)
        || ($currentTurnServerMaxPort !== $turnServerPortsEnd)
    ) {
        $turnServer->setParam(\Wildix\Settings\TurnServer::MIN_PORT, $turnServerPortsStart);
        $turnServer->setParam(\Wildix\Settings\TurnServer::MAX_PORT, $turnServerPortsEnd);

        $turnServer->saveConfig();
    }

    $currentRtpTos = parse_ini_file($rtpEngineTos);
    $tos = $values['tos'] . PHP_EOL;

    if (!isset($currentRtpTos['TOS']) || $currentRtpTos['TOS'] != $tos) {
        $fpTos = fopen($rtpEngineTos, 'w');
        fputs($fpTos, 'TOS=' . $tos);
        fclose($fpTos);
        $reloadRtpEngine = true;
    }

    if ($reloadRtpEngine) {
        exec('sudo systemctl restart rtpengine');
    }

    $fp = fopen($wudpecho_filename, 'w');
    fputs($fp, "START=" . $wudpecho_ports_start . "\nEND=" . $wudpecho_ports_end . "\n\n");
    fclose($fp);

    // {{ set sip general options
    $flines = file($sip_general_filename);
    $endlines = array();
    for ($i = 0, $cnt = sizeof($flines); $i < $cnt; $i++) {
        $line = trim($flines[$i]);
        if (substr($line, 0, 13) != 'defaultexpiry' &&
            substr($line, 0, 3) != 'tos' &&
            substr($line, 0, 14) != 'progressinband' &&
            substr($line, 0, 7) != 'tos_sip' &&
            substr($line, 0, 10) != 'musicclass' &&
            // erase not used option from the sip config / could be removed in future or during refactoring / see WMS-12049
            substr($line, 0, 13) != 'prov_tls_srtp' &&
            substr($line, 0, 8) != 'disallow' &&
            substr($line, 0, 5) != 'allow' &&
            $line !== '')
        {
            $endlines[] = $flines[$i];
        }
    }

    $endlines[] = 'defaultexpiry=' . $values['defaultexpiry'] . PHP_EOL;
    $endlines[] = 'tos=' . $values['tos'] . PHP_EOL;
    $endlines[] = 'tos_sip=' . $values['tos_sip'] . PHP_EOL;
    $endlines[] = 'musicclass=' . $values['musicclass'] . PHP_EOL;
    /* WMS-2139 hide
    if($values['widebandcodecg722'] == 'on'){
        $endlines[] = 'disallow=all' . PHP_EOL;
        $endlines[] = 'allow=g722:20,alaw:20,ulaw:20,g729:20,vp8,h264,h263,h263p' . PHP_EOL;
    }*/

    $fp = fopen($sip_general_filename, 'w');
    fputs($fp, implode('', $endlines));
    fclose($fp);
    // }}

    exec('callweaver -rx "sip reload"');
    exec('callweaver -rx "reload res_rtp_asterisk.so"');
    exec('callweaver -rx "reload udptl"');
    exec('sudo systemctl restart wudpecho@START wudpecho@END');

    touch('/dev/shm/.magnet_up_wideband');

    // {{ jitter buffer
    $jb_settings = array(
        'min' => $values['jb_min'],
        'nom' => $values['jb_nom'],
        'max' => $values['jb_max'],
    );

    set_jitter_buffer($jb_settings);
    // }}

    $prov_conf = parse_ini_file($prov_filename, true, INI_SCANNER_RAW);
    if($prov_conf){
        if(!isset($prov_conf['general'])){
            $prov_conf['general'] = array();
        }
        $prov_conf['general']['TrustLocalDevice'] = $values['prov_trust_local_device'];
        write_ini_file($prov_filename, $prov_conf, true);
    }

    // set external ip and custom secure port in ldap
    require_once('common/wms_ldap.php');

    $serial = \Models\PBX::getInstance()->getSerial();
    $dn = \Wildix\PBXes\PBXes::getInstance()->getPBXBySerial($serial)->getDn();

    $_pbxPublicPort = '';
    $_pbxPublicIp = '';
    if(!empty($values['external_https_port'])){
        $_pbxPublicPort = $values['external_https_port'];
    }
    if(!empty($values['externip'])){
        $_pbxPublicIp = $values['externip'];
    }
    WMS_Ldap::getInstance()->update($dn, array('pbxPublicIp' => $_pbxPublicIp, 'pbxPublicPort' => $_pbxPublicPort));

    $dirtyTproxyPortConfigs = false;
    $tproxyPortConfigs = getTProxyPortConfigs();
    if(isset($values['external_https_port'])){
        $external_https_port = trim($values['external_https_port']);

        if(!empty($external_https_port) && preg_match('/\d+/', $external_https_port)  && $tproxyPortConfigs['external_https_port'] != $external_https_port){
            $tproxyPortConfigs['external_https_port'] = $external_https_port;
            $dirtyTproxyPortConfigs = true;

        }else if(!empty($tproxyPortConfigs['external_https_port']) && empty($external_https_port)){
            $tproxyPortConfigs['external_https_port'] = '';
            $dirtyTproxyPortConfigs = true;
        }
    }
    if($dirtyTproxyPortConfigs){
        $result = saveTProxyPortConfigs($tproxyPortConfigs);
        if($result === false) {
            $messages[] = 'Error save "External https port"';
        }else{
            $needUploadPorts = true;
        }
    }

    $network_class->forward_5060_port($wudpecho_ports_start + 1);
    if ($needUploadPorts){
        $task = new \BackgroundTask('\Controllers\PBX:progressUploadPbxPorts', false);
        if($task->getStatus() != \BackgroundTask::LAUNCHED){
            $task->runAsync();
        }
    }

    return $messages;
}

function set_random_moh($status, $confFile){
    if (empty($status)) { return; }
    $status = $status === 'yes' ? 'random' : 'alpha';
    $data = parse_ini_file($confFile);
    if($data['sort'] != $status){
        $data['sort'] = $status;
        write_ini_file($confFile, $data, true);
        PBX::getInstance()->put_cli_reload('moh');
    }
}

function get_jitter_buffer() {
	$jb_settings = array(
		'min' => \Wildix\Databases\DEVDB::getInstance()->getSystemVariable(\Wildix\Databases\DEVDB::SYSTEM_JITTER_MIN, '50'),
		'nom' => \Wildix\Databases\DEVDB::getInstance()->getSystemVariable(\Wildix\Databases\DEVDB::SYSTEM_JITTER_NOM, '100'),
		'max' => \Wildix\Databases\DEVDB::getInstance()->getSystemVariable(\Wildix\Databases\DEVDB::SYSTEM_JITTER_MAX, '200'),
	);
	return $jb_settings;
}

function set_jitter_buffer($jb_settings) {
	$variables = array(
			\Wildix\Databases\DEVDB::SYSTEM_JITTER_MIN => $jb_settings['min'],
			\Wildix\Databases\DEVDB::SYSTEM_JITTER_NOM => $jb_settings['nom'],
			\Wildix\Databases\DEVDB::SYSTEM_JITTER_MAX => $jb_settings['max']
	);
	\Wildix\Databases\DEVDB::getInstance()->setSystemVariables($variables);
}

function get_norewrite_networks() {
	$result = array();

	$aclParams = file(PATH_TO_CW_CONF.'acl-directrtp.conf');
	if ($aclParams === false) {
		logger('Can\'t read from acl-directrtp.conf' , __FUNCTION__, __LINE__);
		return;
	}

	foreach ($aclParams as $value) {
		$value = trim($value);
		$value = explode('=', $value);
		$value[0] = trim($value[0]);
		$value[1] = trim($value[1]);
		if ($value[0] == 'permit' && !empty($value[1])) {
			$result[] = $value[1];
		}
	}

	return $result;
}

function set_norewrite_networks($networks) {

	$filename = PATH_TO_CW_CONF.'acl-directrtp.conf';

	if (!is_array($networks)) {
		$tmp[] = $networks;
		$networks = $tmp;
		unset($tmp);
	}

	$file = array();
	foreach($networks as $value){
		$file[] = 'permit='.trim($value);
	}
	$newParams = join("\n", $file);
	$currentParams = file_get_contents($filename);

	if ($currentParams !== $newParams) {
		if(file_put_contents($filename, $newParams) !== false){
			exec("callweaver -rx 'reload acl'");
		}else{
			logger('Can\'t write to acl-directrtp.conf' , __FUNCTION__, __LINE__);
		}
	}
}

function set_kamailio_config($params) {
	$filename = '/rw2/etc/kamailio/host_specific.cfg';

	$kamparams = get_kamailio_config();

	$needUpdateExternalIP = false;
	if($params['via_tool']
			&& $params['via_tool']['enable_ip_check']
			&& $kamparams['via_tool']
			&& !$kamparams['via_tool']['enable_ip_check']
			){
		$needUpdateExternalIP = true;
	}

	$restart_kamailio = false;
	foreach ($params as $modname => $values) {
		if (isset($kamparams[$modname])) {
			foreach ($values as $param => $value) {
				if (is_array($value)) {
					foreach ($value as $p => $v) {
						if($kamparams[$modname][$param][$p] != $v){
							$restart_kamailio = true;
						}
						$kamparams[$modname][$param][$p] = $v;
					}
				} else {
					if($kamparams[$modname][$param] != $value){
						$restart_kamailio = true;
					}
					$kamparams[$modname][$param] = $value;
				}
			}
		}
	}

	$tofile = array();

	foreach ($kamparams as $param => $conf) {
		foreach ($conf as $p => $v) {

			if (is_array($v)) {
				foreach ($v as $p1 => $v1) {
					$value = '"' . $p1 . '=' . $v1 . '"';
					$tofile[] = 'modparam("' . $param . '", "' . $p . '", ' . $value . ')';
				}
			} else {
				$value = '"' . $v . '"';
				if (in_array($p, array('enable_ip_check'))) {
					// without quotes int value
					$value = $v;
				}

				$tofile[] = 'modparam("' . $param . '", "' . $p . '", ' . $value . ')';
			}
		}
	}

	$pbxserial = \Models\PBX::getInstance()->getSerial();
	$dn = \Wildix\PBXes\PBXes::getInstance()->getPBXBySerial($pbxserial)->getDn();

	if (!file_put_contents($filename, implode(PHP_EOL, $tofile) . PHP_EOL)) {
		logger('Can\'t write to ' . $filename, __FUNCTION__, __LINE__);
		return false;
	}

    exec('sudo /usr/sbin/update_kamailio_cfg.sh localnets');

	// restart kamailio
	if ($restart_kamailio) {
		if($needUpdateExternalIP){
			try {
				$checkIpService = new \Wildix\Services\CheckIP();
				$newExtIp = $checkIpService->getIp($params['via_tool']['ipcheck_url']);
				if($newExtIp){
					file_put_contents('/tmp/provisioning_externip', $newExtIp);
				}
			} catch (\Exception $e) {
				logger($e->getMessage(), __FUNCTION__, __LINE__);
			}
		}
		exec('nohup sudo /etc/init.d/kamailio restart > /dev/null &');
	}
}

function get_kamailio_config() {
	$filename = '/rw2/etc/kamailio/host_specific.cfg';

	$params = array(
		'presence' => array(
			'server_address' => 'sip:127.0.0.1:5060',
		),
		'via_tool' => array(
			'media_gateway_ip' => '127.0.0.1',
			'externip' => '',
			'localip' => '127.0.0.1',
			'localnet' => '(^10\.[0-9]*\.[0-9]*\.[0-9]*.*)|(172\.[0-9]*\.[0-9]*\.[0-9]*.*)|(192\.168\.*)|(127\.0\.0\.*)',
			'enable_ip_check' => '0',
			'ipcheck_url' => 'http://checkip.wildix.com/',
		),
		'pv' => array(
			'varset' => array(
				'trunk_language' => 's:it',
				'block_disable' => 's:no',
				'enable_ban' => 's:yes',
				'failscount' => 'i:25',
				'telephoneNumberAttr' => 's:telephoneNumber',
				'external_secure_port'=> 'i:443'
			)
		)/*,
		'tls' => array(
			'certificate' => '/etc/kamailio/wildix.pem',
			'private_key' => '/etc/kamailio/privkey.pem'
		)*/
	);

	if (!check_read_file($filename))
		return $params;

	$content = file_get_contents($filename);

	$params_skip = array(
		'pv' => array(
			'varset' => array('disable_yealink_ua', 'ua_block_rx')
		)
	);

	if (preg_match_all('/modparam\("(.*)",\s"(.*)",\s(.*)\)/', $content, $matches)) {
		foreach ($matches[1] as $index => $modname) {

			if (!isset($params[$modname])) { // do not allow unknown module name
				continue;
			}

			$param = $matches[2][$index];
			$value = str_replace('"', '', $matches[3][$index]);

			if (!isset($params[$modname][$param])) { // do not allow unknown param
				continue;
			}

			if (!isset($params[$modname])) {
				$params[$modname] = array();
			}

			if (isset($params[$modname][$param]) &&
				is_array($params[$modname][$param])) {

				list ($p, $v) = explode('=', $value);

				if (isset($params_skip[$modname][$param]) &&
					in_array($p, $params_skip[$modname][$param])) { // skip unnecessry param
					continue;
				}

				$params[$modname][$param][$p] = $v;
			} else {
				$params[$modname][$param] = $value;
			}
		}
	}

	return $params;
}

function saveTProxyPortConfigs($newData){
    $patch = '/rw2/etc/pbx/wildix/tproxy_wms_include.conf';
    $content = array();
    $port = '443';
    foreach ($newData as $key=>$value){
        $value = trim($value);
        if(!empty($value)){
            $content[] = '{ host="0.0.0.0";port='.$value.'; }';
            $port = $value;
        }
    }

    if(!empty($content)){
        $content = join(",\n",$content);
    }else{
        $content = '';
    }

    if(file_put_contents($patch, $content) !==false){
        exec('sudo /etc/init.d/tproxyd reload');
        $_portalApiUrl = env('SERVICE_PORTAL_API_URI');
        $_portalUrl    = env('SERVICE_UPGRADE_PORTAL_URI');
        $portalService = new \Wildix\Services\Portal(\Logger\Log::ERROR, $_portalApiUrl, $_portalUrl);
        $portalService->setPort($port);
        return true;
    }

    return false;
}

function getMinCountRtpPorts(){
	/**
	 * Min rtp ports calculated according to
	 *   3 ports (rtp/rtcp/internal) in cw for each call leg for audio call
	 *   4 port (rtp/rtcp/rtp_2_cw/rtcp_2_cw) in engine for each call leg for audio call
	 *   2 ports (vrtp/vrtcp) in cw for each call leg
	 *   4 ports (vrtp/vrtcp/vrtp_2_cw/vrtcp_2_cw) in engine for each call leg
	 *   2 ports in turnserver for each call leg
	 *   + 10 %
	 */
	$calls = (int)\Wildix\License::getInstance()->getLimitations('calls');

	if($calls > 400){
		$calls = 400;
	}
	$minPorts = ceil( $calls * (3*2 + 4*2 + 2*2 + 4*2 + 2*2) * 1.1 );

	if($calls < 8){
		$minPorts = $minPorts * 5;
    }else if($calls < 24){
		$minPorts = $minPorts * 3;
    }else if($calls <= 45){
		$minPorts = $minPorts * 2;
    }

	$minPorts = round(($minPorts/10) + 0.5, 0, PHP_ROUND_HALF_DOWN) * 10;
	if($minPorts > 57000){
		$minPorts = 57000;
	}
	return $minPorts;

}

function calculatePorts(int $startPort, int $endPort): array {
    $wudpEchoPortStart   = $startPort;
    $wudpEchoPortEnd     = $endPort;
    $callweaverPortStart = $wudpEchoPortStart < $wudpEchoPortEnd ? $wudpEchoPortStart + 1 + 1 : $wudpEchoPortStart; // added +1 for 5060 port forwarding;
    $callweaverPortEnd   = $callweaverPortStart < $wudpEchoPortEnd ? $wudpEchoPortEnd - 1 : $wudpEchoPortEnd;
    $rtpEnginePortStart  = '';
    $rtpEnginePortEnd    = '';
    $turnServerPortStart = '';
    $turnServerPortEnd   = '';

    if ($callweaverPortStart < $callweaverPortEnd) {
        $rtpEnginePortEnd   = $callweaverPortEnd;
        $callweaverPortEnd  = floor(($callweaverPortEnd - $callweaverPortStart) * 0.50) + $callweaverPortStart;
        $rtpEnginePortStart = $callweaverPortEnd + 1;
    }

    if ($rtpEnginePortStart < $rtpEnginePortEnd) {
        $turnServerPortEnd   = $rtpEnginePortEnd;
        $rtpEnginePortEnd    = floor(($rtpEnginePortEnd - $rtpEnginePortStart) * 0.80) + $rtpEnginePortStart;
        $turnServerPortStart = $rtpEnginePortEnd + 1;
    }

    return array(
        'wudpEchoPortStart' => $wudpEchoPortStart,
        'wudpEchoPortEnd' => $wudpEchoPortEnd,
        'callweaverPortStart' => $callweaverPortStart,
        'callweaverPortEnd' => $callweaverPortEnd,
        'rtpEnginePortStart' => $rtpEnginePortStart,
        'rtpEnginePortEnd' => $rtpEnginePortEnd,
        'turnServerPortStart' => $turnServerPortStart,
        'turnServerPortEnd' => $turnServerPortEnd,
    );
}
