import {DEVICE_MAX_PORTS} from '@/configuration/constants';

export default class Device {

    constructor(data) {
        this.id = data.id;
        this.ready = data.ready;
        this.model = data.model;
        this.registrar = data.registrar;
        this.vendor = data.vendor;
        this.address = data.address;
        this.alternatePort = data.alternatePort;
        this.description = data.description;
        this.firmware = data.firmware;
        this.mac = data.mac;
        this.multipleUsers = data.multipleUsers;
        this.qtyPorts = data.qtyPorts;
        this.registrar = data.registrar;
        this.settings = data.settings;
        this.timezone = this.prepareTimezone(data.settings.ntp);
        this.ssl = data.ssl;
        this.token = data.token;
        this.user = data.user;
        this.vendor = data.vendor;
        this.allowMultipleUsers = Boolean(data.qtyPorts > 1);
        this.ports = this.allowMultipleUsers ? this.createPorts(this.multipleUsers) : [];
        this.provision = Boolean(data.provision);
        this.received = data.received;
        this.VLan = this.prepareVLan(data.settings);
        this.connect = data.connect;
        this.allowAssign = data.allowAssign;
        this.isOnline = data.isOnline;
        this.allowConnect = this.allowConnectUrl(data.connect);
        this.isLocal = data.isLocal;
    }
    createPorts(data) {
        let ports = {};
        for (let i = 0; i < DEVICE_MAX_PORTS; i++) {
            let userLabel = String(data[i]).includes('unknown') ? '' : data[i];
            let userName = String(data[i]).includes('unknown') ? 'unknown' : data[i];
            ports[`port${i}`] = {
                port: i + 1,
                user: userName || '',
                userLabel: userLabel || '',
                active: Boolean(data[i] !== void 0)
            };
        }

        return ports;
    }
    prepareVLan(data) {
        let res = '';
        if (data.voiceVLAN.voice) {
            res += `v:${data.voiceVLAN.voice}/${data.voiceVLAN.data}; `;
        }
        if (data.dataVLAN.voice) {
            res += `d:${data.dataVLAN.voice}/${data.dataVLAN.data};`;
        }
        return res;
    }
    prepareTimezone(data) {
        let res = '';
        if (data.server) {
            res = data.server;
        }else if (data.timezone) {
            res = data.timezone;
        }
        return res;
    }
    setConnectUrl(url = '') {
        this.connect = String(url);
    }
    isWizyconf() {
        return this.model.toLowerCase() === 'wizyconf';
    }
    isProvision() {
        return Boolean(this.provision);
    }
    allowConnectUrl() {
        return Boolean(window.location.href.includes('wildixin.com')) || Boolean(window.location.href.includes('wildix.com'));
    }
    isAllowBind() {
        return Boolean(this.mac) && Boolean(this.address);
    }
    isAllowAssign() {
        return this.allowAssign;
    }

}
