import {
    BOOL_LICENSE_USAGE,
    QUANTITY_LICENSE_USAGE
} from '@/helpers/constants/license';

export default class License {

    constructor(data) {
        this._rawData = data;

        // System state
        this.domain = String(data.domain);
        this.hwserial = String(data.hwserial);
        this.swserial = String(data.swserial);
        this.processor = String(data.processor);
        this.memory = Math.ceil(data.memory / 1024 / 1024) + ' Mb';

        this.rooms = Number(data.limitations.rooms);
        this.phones = Number(data.limitations.phones);
        this.calls = Number(data.limitations.calls);

        this.boolUsageLimitation = {};
        BOOL_LICENSE_USAGE.forEach((licenseName) => {
            if(['x-bees', 'networkLicense'].includes(licenseName)) {
                this.boolUsageLimitation[licenseName] = Boolean(data.limitations[licenseName]);
            } else {
                this.boolUsageLimitation[licenseName] = Boolean(data.limitations.licenseTypes[licenseName]);
            }
        });

        this.quantityUsageLimitation = {};
        QUANTITY_LICENSE_USAGE.forEach((licenseName) => {
            this.quantityUsageLimitation[licenseName] = {
                usage: Number(data.licenseUsage[licenseName]),
                purchased: Number(data.limitations.licenseTypes[licenseName])
            };
        });

        this.logoExist = Boolean(data.logoExist);
        this.isActive = Boolean(data.activated);
        this.isVirtualPBX = !data.limitations.cloud.state;
        this.expireDate = '';

        if (data.limitations['license_update']['state'] === true) {
            if (data.limitations['license_update']['until'] !== '*') {
                const date = new Date(data.limitations['license_update']['until'] * 1000);
                this.expireDate = date.format('yyyy-mm-dd');
            }
        }
    }

    canBeDeactivated() {
        return this.isActive && this.isVirtualPBX;
    }

}
