import AbstractTrunk from '../AbstractTrunk';
import {DEVICE_MODEL_FXOR3} from '@/helpers/constants/trunksList/fxo';

export default class FxoTrunk extends AbstractTrunk {

    constructor(data) {
        super();

        this.setData(data);

        this.setCountryCode(this.settingsMgw.countryCode);
    }

    setData(data) {
        this.id = data.id;
        this.username = data.username;
        this.title = data.title;
        this.technology = data.technology;
        this.address = data.address;
        this.model = data.model;

        this.status = {
            active: data.status.active,
            title: data.status.title
        };

        this.settingsMgw = {
            toneZone: data.settingsMgw.toneZone,
            countryCode: data.settingsMgw.countryCode,
            impedance: Number(data.settingsMgw.impedance) || 1,
            dcImpedance: data.settingsMgw.dcImpedance,
            fskCidField: Number(data.settingsMgw.fskCidField) || 0,
            busyToneDetected: data.settingsMgw.busyToneDetected,
            polarityNormalDetected: data.settingsMgw.polarityNormalDetected,
            currentDetected: data.settingsMgw.currentDetected,
            currentDisconnectThreshold: Number(data.settingsMgw.currentDisconnectThreshold) || 200,
            silenceDetectionEnabled: data.settingsMgw.silenceDetectionEnabled,
            silenceDetection: Number(data.settingsMgw.silenceDetection) || 60,
            ports: this.preparePorts(data.settingsMgw.ports)
        };
    }

    preparePorts(data) {
        return data.map(item => ({
            port: Number(item.port),
            priceList: Number(item.priceList) || 0,
            destinationCode: String(item.destinationCode) || '',
            context: String(item.context) || 'main',
            hotlineNumber: String(item.hotlineNumber) || '',
            pstnRingCount: Boolean(item.pstnRingCount),
            cidType: Number(item.cidType) || 1,
            flashTime: Number(item.flashTime) || 300,
            answerTime: Number(item.answerTime) || 1,
            faxType: Number(item.faxType) || 2,
            faxSpeed: Number(item.faxSpeed) || 14400,
            codecInputGain: Number(item.codecInputGain) || (this.model === DEVICE_MODEL_FXOR3 ? 0 : 32),
            codecOutputGain: Number(item.codecOutputGain) || (this.model === DEVICE_MODEL_FXOR3 ? 0 : 32),
            preversalDetection: item.preversalDetection
        }));
    }

    prepareDataToSave() {
        this.settingsMgw.countryCode = this.getCountryCode();
        this.removeTmpCountryCodes();
    }

}
