import AbstractTrunk from '../AbstractTrunk';

export default class IsdnTrunk extends AbstractTrunk {

    constructor(data) {
        super();

        this.setData(data);

        this.setCountryCode(this.settingsMgw.countryCode);
    }

    setData(data) {
        this.id = data.id;
        this.name = data.name;
        this.title = data.title;
        this.technology = data.technology.toLowerCase();
        this.ports = data.ports;
        this.address = data.address;
        this.status = {
            active: data.status.active,
            title: data.status.title
        };
        this.settingsPbx = {
            username: data.settingsPbx.username,
            type: data.settingsPbx.type,
            secret: data.settingsPbx.secret,
            insecure: data.settingsPbx.insecure,
            fromUser: data.settingsPbx.fromUser,
            dtmfMode: data.settingsPbx.dtmfMode,
            context: data.settingsPbx.context,
            host: data.settingsPbx.host,
            port: data.settingsPbx.port
        };
        this.settingsMgw = {
            currentDetected: data.settingsMgw.currentDetected,
            polarityNormalDetected: data.settingsMgw.polarityNormalDetected,
            busyToneDetected: data.settingsMgw.busyToneDetected,
            currentDisconnectThreshold: data.settingsMgw.currentDisconnectThreshold,
            fskCidField: data.settingsMgw.fskCidField,
            toneZone: data.settingsMgw.toneZone,
            dcImpedance: data.settingsMgw.dcImpedance,
            impedance: data.settingsMgw.impedance,
            lineType: data.settingsMgw.lineType,
            silenceDetection: data.settingsMgw.silenceDetection,
            silenceDetectionEnabled: data.settingsMgw.silenceDetectionEnabled,
            voipOutputGain: data.settingsMgw.voipOutputGain,
            voipInputGain: data.settingsMgw.voipInputGain,
            bearerCapG729: data.settingsMgw.bearerCapG729 || 200,
            bearerCapG711: data.settingsMgw.bearerCapG711 || 200,
            priceList: data.settingsMgw.priceList,
            dtmfDebounce: data.settingsMgw.dtmfDebounce,
            smsDeliveryTries: data.settingsMgw.smsDeliveryTries,
            busyResponse: data.settingsMgw.busyResponse,
            language: data.settingsMgw.language,
            countryCode: data.settingsMgw.countryCode,
            dialTone: data.settingsMgw.dialTone,
            preserveOrigCid: data.settingsMgw.preserveOrigCid,
            poundSupport: data.settingsMgw.poundSupport,
            clockReferencePort: data.settingsMgw.clockReferencePort || 100,
            ports: this.preparePorts(data.settingsMgw.ports)
        };
    }

    preparePorts(data) {
        return data.map(item => ({
            port: item.port,
            priceList: Number(item.priceList) || 0,
            destinationCode: item.destinationCode,
            endpointType: item.endpointType,
            context: item.context,
            clock: item.clock,
            pinOut: item.pinOut,
            lineFraming: item.lineFraming,
            lineCoding: item.lineCoding,
            networkType: item.networkType,
            connectionType: item.connectionType,
            linkEstablishment: item.linkEstablishment,
            signalProtocol: item.signalProtocol,
            facilityServices: item.facilityServices,
            overlap: item.overlap,
            inbandDtmfDialing: item.inbandDtmfDialing,
            sendRestartOnStartup: item.sendRestartOnStartup,
            callingNameMaxLength: item.callingNameMaxLength,
            channelAllocationStrategy: item.channelAllocationStrategy,
            sendingComplete: item.sendingComplete,
            progressIndicatorInSetup: item.progressIndicatorInSetup,
            progressIndicatorInSetupAck: item.progressIndicatorInSetupAck,
            progressIndicatorInCallProgressForSetup: item.progressIndicatorInCallProgressForSetup,
            progressIndicatorInProgress: item.progressIndicatorInProgress,
            progressIndicatorInAlerting: item.progressIndicatorInAlerting,
            progressIndicatorInConnect: item.progressIndicatorInConnect,
            maximumFacilityWaitingDelay: item.maximumFacilityWaitingDelay,
            useImplicitInbandInfo: item.useImplicitInbandInfo,
            correctIncomingCallingNumbers: item.correctIncomingCallingNumbers,
            signalInformationElement: item.signalInformationElement,
            cngToneDetection: item.cngToneDetection,
            cedToneDetection: item.cedToneDetection,
            detectionThreshold: item.detectionThreshold,
            status: {
                physical: {
                    title: item.status.physical.title,
                    state: item.status.physical.state
                },
                logic: {
                    title: item.status.logic.title,
                    state: item.status.logic.state
                }
            }
        }));
    }

    prepareDataToSave() {
        this.settingsMgw.countryCode = this.getCountryCode();
        this.removeTmpCountryCodes();
    }

}
