import objectToFormData from 'object-to-formdata';
import applications from './manuals/applications';
import additionalDialplans from './manuals/additional_dialplans';
import jsonExtens from './manuals/json_extens.json';
import appsList from './manuals/appsList';

function DialplanRules(core) {
    this.client = core.client;
}

const path = '/v1/PBX/Dialplans';

Object.assign(DialplanRules.prototype, {
    namespace: 'PBX.dialplans.rules',
    oldPath: '/v1/Dialplan/Rules',
    getList() {
        return this.client.send('GET', `${path}/?`);
    },
    getItem(params) {
        return this.client.send('GET', `${path}/${params.id}/`);
    },
    create(params) {
        return this.client.send('POST', `${path}/?`, params);
    },
    update(params) {
        return this.client.send('PUT', `${path}/${params.id}/`, params);
    },
    remove({id}) {
        return this.client.send('DELETE', `${path}/${id}/`);
    },
    export(params) {
        return this.client.send('POST', `${this.oldPath}/export`, params);
    },
    exportPing(params) {
        return this.client.send('GET', `${this.oldPath}/pingExport`, params);
    },
    import(data) {
        return this.client.send('POST', `${this.oldPath}/import/`, objectToFormData(data));
    },
    importConfirm(params) {
        return this.client.send('GET', `${this.oldPath}/restoreBackup/`, params);
    },
    getAdditionalRules() {
        return new Promise((resolve, reject) => {
            resolve({
                type: 'result',
                result: {
                    records: additionalDialplans
                }
            });
        });
    },
    getExtens() {
        return new Promise((resolve, reject) => {
            resolve({type: 'result', result: {extens: jsonExtens}});
        });
    },
    getAppsList() {
        return new Promise((resolve, reject) => {
            resolve({type: 'result', result: {appsList: appsList}});
        });
    },
    getScheme() {
        return new Promise((resolve, reject) => {
            resolve({
                type: 'result',
                result: {records: Object.entries(applications).map((item) => item[1])}
            });
        });
    }
});

export default DialplanRules;
