/* eslint-disable no-template-curly-in-string */
import translate from '@/modules/translate/translate';
import {StatusIncomingCell, StatusOutgoingCell} from '@/pages/trunks/trunkLists/sip/_chunks/tableCells';
import {CountryCodeCell} from '@/pages/trunks/trunkLists/_chunks/tableCells';

export const MAIN_TABLE_COLS = [
    {
        key: 'id',
        label: translate('strings.ID'),
        sortable: true,
        thStyle: {
            width: '35px'
        }
    },
    {
        key: 'title',
        label: 'SIP',
        sortable: true
    },
    {
        key: 'name',
        label: translate('services.LOGIN'),
        sortable: true,
        thStyle: {
            width: '100px'
        },
        tdClass: 'text-center'
    },
    {
        key: 'settingsPbx.context',
        label: translate('trunks.Context'),
        sortable: true,
        thStyle: {
            width: '85px'
        },
        tdClass: 'text-center'
    },
    {
        key: 'settingsPbx.host',
        label: translate('strings.Host'),
        sortable: true,
        thStyle: {
            width: '105px'
        },
        tdClass: 'text-center'
    },
    {
        key: 'settingsPbx.port',
        label: translate('trunks.Port'),
        thStyle: {
            width: '30px'
        },
        tdClass: 'text-center'
    },
    {
        key: 'settingsPbx.countryCode',
        label: translate('prefs.GCOUNTRY_CODE'),
        sortable: true,
        thStyle: {
            width: '50px'
        },
        renderComponent: () => (CountryCodeCell)
    },
    {
        key: 'status.outgoing',
        label: `${translate('trunks.Status')} ${translate('trunks.outgoing')}`,
        thStyle: {
            width: '55px'
        },
        renderComponent: () => (StatusOutgoingCell)
    },
    {
        key: 'status.incoming',
        label: `${translate('trunks.Status')} ${translate('trunks.incoming')}`,
        thStyle: {
            width: '55px'
        },
        renderComponent: () => (StatusIncomingCell)
    }
];

export const TRUNK_ITEM_INITIAL = {
    title: '',
    name: '',
    settingsPbx: {
        priceList: 0,
        peername: '',
        username: '',
        fromUser: '',
        fromDomain: '',
        host: 'dynamic',
        port: '',
        secret: '',
        context: 'main',
        toneZone: '',
        countryCode: 0,
        qualify: true,
        audioCodecs: [
            {
                key: 'g729',
                value: 20,
                enable: true
            },
            {
                key: 'alaw',
                value: 20,
                enable: true
            },
            {
                key: 'ulaw',
                value: 20,
                enable: true
            }
        ],
        videoCodecs: false,
        thirtyEightPtUdptl: true,
        thirtyEightPtErrorCorrection: 'redundancy',
        thirtyEightPtMaxDatagram: 400,
        fromNumber: '',
        fromName: '',
        cidHeader: '',
        cidBody: '',
        trustRpid: true,
        privacyHeader: '',
        diversionHeader: '',
        historyInfoHeader: '',
        contactNumber: '',
        preserveOrigCid: true,
        allowTransfer: false,
        sessionTimer: true,
        sessionMinse: 90,
        sessionExpires: 600,
        playRemoteMoh: false,
        ssrcChange: false,
        rport: 'invite',
        forceSrtp: false,
        transportWildix: 'udp',
        dtmfMode: 'rfc2833',
        rfcPayload: 101
    },
    settingsWms: {
        enableReg: true,
        overwriteReg: false,
        regHost: '',
        regPort: '',
        expiry: '',
        natIp: '',
        dnsServer: '',
        outboundProxy: '',
        outboundProxyPort: '',
        regUsername: '',
        regSecret: '',
        regFromUser: ''
    },
    status: {
        outgoing: false,
        incoming: false
    }
};

export const TRUNK_ITEM_FIELDS_ERRORS = {
    title: null,
    name: null,
    settingsPbx: {
        userName: null,
        peername: null,
        host: null,
        port: null,
        secret: null,
        context: null,
        toneZone: null,
        countryCode: null,
        audioCodecs: null,
        thirtyEightPtUdptl: null,
        thirtyEightPtErrorCorrection: null,
        thirtyEightPtMaxDatagram: null,
        sessionMinse: null,
        sessionExpires: null,
        rfcPayload: null
    },
    settingsWms: {
        expiry: null,
        dnsServer: null,
        outboundProxy: null,
        outboundProxyPort: null,
        natIp: null,
        regHost: null,
        regPort: null,
        regUsername: null,
        regSecret: null,
        regFromUser: null
    }
};

export const TRUNK_ITEM_HOSTS = [
    {value: 'dynamic', text: 'dynamic'}
];

export const AUDIO_CODEC_TIMES = [
    {value: 20, text: '20ms'},
    {value: 40, text: '40ms'},
    {value: 60, text: '60ms'}
];

export const T38_ERROR_CORRECTIONS = [
    {value: 'redundancy', text: 'redundancy'},
    {value: 'fec', text: 'fec'},
    {value: 'off', text: 'off'}
];

export const FROM_NUMBER_OPTIONS = [
    {value: '${num}', text: '${num}'}
];

export const FROM_NAME_OPTIONS = [
    {value: '${name}', text: '${name}'}
];

export const CID_HEADERS = [
    {value: 'P-Asserted-Identity', text: 'P-Asserted-Identity'},
    {value: 'P-Preferred-Identity', text: 'P-Preferred-Identity'},
    {value: 'Remote-Party-ID', text: 'Remote-Party-ID'}
];

export const CID_BODIES = [
    {value: '"${name}" <sip:${num}@${sipdomain}>', text: '"${name}" <sip:${num}@${sipdomain}>'}
];

export const TRUST_RPID = [
    {value: true, text: 'p-asserted-identity,from'},
    {value: false, text: 'from'}
];

export const PRIVACY_HEADER = [
    {value: 'id,user', text: 'id,user'}
];

export const DIVERSION_HEADER = [
    {
        value: '"${div_name}" <sip:${div_num}@${sipdomain}>;reason=follow-me;privacy=off',
        text: '"${div_name}" <sip:${div_num}@${sipdomain}>;reason=follow-me;privacy=off'
    }
];

export const HISTORY_INFO_HEADER = [
    {
        value: '"${div_name}" <sip:${div_num}@${sipdomain}?Reason=${histinfo_reason}>;index=1.1',
        text: '"${div_name}" <sip:${div_num}@${sipdomain}?Reason=${histinfo_reason}>;index=1.1'
    }
];

export const R_PORT_OPTIONS = [
    {value: 'invite', text: 'INVITE'},
    {value: 'all', text: 'REGISTER,INVITE'},
    {value: 'off', text: 'off'}
];

export const TRANSPORT_WILDIX = [
    {value: 'udp', text: 'UDP'},
    {value: 'tcp', text: 'TCP'},
    {value: 'tls', text: 'TLS'},
    {value: 'dns-srv', text: 'auto (dns ptr-srv)'}
];

export const DTMF_MODE = [
    {value: 'info', text: 'info'},
    {value: 'rfc2833', text: 'rfc2833'},
    {value: 'inband', text: 'inband'}
];
