import clone from '@/modules/clone-object';
import isEqual from '@/modules/is-equal';

export default {
    data() {
        return {
            dirtyData: null
        };
    },
    methods: {
        setDirtyBefore(data) {
            this.dirtyData = clone(data);
        },
        isDirty() {
            let isDirty = false;
            if (typeof this.getDataToSave === 'function') {
                let toSave = this.getDataToSave();
                let before = this.dirtyData;
                for (let prop in before) {
                    if (before.hasOwnProperty(prop)) {
                        let old = before[prop];
                        let current = toSave[prop];
                        if (!isEqual(old, current)) {
                            isDirty = true;
                        }
                    }
                }
            }
            return isDirty;
        },
        beforeUnloadMethod(e) {
            if (this.isDirty()) {
                e.returnValue = this.$t('prefs.are_you_sure_want_to_exit_without_save');
                return this.$t('prefs.are_you_sure_want_to_exit_without_save');
            }
            return undefined;
        }
    },
    mounted() {
        window.addEventListener('beforeunload', this.beforeUnloadMethod);
    },
    beforeDestroy() {
        window.removeEventListener('beforeunload', this.beforeUnloadMethod);
    },
    beforeRouteLeave(to, from, next) {
        if (!this.isDirty()) {
            next();
        } else if (confirm(this.$t('prefs.are_you_sure_want_to_exit_without_save'))) {
            next();
        }
    }
};
