const CLEAR = (data) => {
    if (!data) {
        return;
    }

    Object.keys(data)
        .forEach(key => {
            if (Array.isArray(data[key])) {
                data[key].forEach(item => CLEAR(item));
            } else if (!data[key] || (data[key].hasOwnProperty('code') && data[key].hasOwnProperty('reason'))) {
                data[key] = null;
            } else if (typeof data[key] === 'object'){
                CLEAR(data[key]);
            } else {
                data[key] = null;
            }
        });
};

export default {
    methods: {
        clearErrors() {
            CLEAR(this.fieldErrors);
        },
        showErrors(e) {
            if (e && e.data && typeof e.data !== 'undefined') {
                if (typeof e.data.reason === 'string' && e.data.reason !== '') {
                    this.$toast('error', e.data.reason);
                } else if (e.status === 504) {
                    console.warn('504 Gateway Timeout');
                    this.$toast('error', '504 Gateway Timeout');
                }

                if(Array.isArray(e.data.errors)) {
                    let errs = {};
                    e.data.errors.forEach((item, index) => {
                        errs[index] = item;
                    });
                    e.data.errors = errs;
                }

                if (typeof e.data.errors === 'object') {
                    let fieldErrors = e.data.errors;
                    let notFieldErrors = [];
                    let errors = {};
                    for (let param in fieldErrors) {
                        if (fieldErrors.hasOwnProperty(param)) {
                            if (typeof this.fieldErrors[param] !== 'undefined') {
                                if (typeof fieldErrors[param]['code'] !== 'undefined' && typeof fieldErrors[param]['reason'] !== 'undefined') {
                                    errors[param] = fieldErrors[param];
                                } else {
                                    // support multi level errors
                                    if (Array.isArray(this.fieldErrors[param])) {
                                        errors[param] = fieldErrors[param];
                                    }

                                    for (let param2 in this.fieldErrors[param]) {
                                        if (typeof errors[param] === 'undefined') {
                                            errors[param] = {};
                                        }
                                        errors[param][param2] = (fieldErrors[param] && fieldErrors[param][param2]) ? fieldErrors[param][param2] : null;
                                    }
                                }
                            } else {
                                notFieldErrors.push(fieldErrors[param].reason);
                            }
                        }
                    }
                    Object.assign(this.fieldErrors, errors);
                    if (notFieldErrors.length) {
                        this.$toast('error', notFieldErrors.concat('<br />'));
                    }
                }
            }
        },
        getErrorReason(data) {
            return (data && data.reason !== 'undefined') ? data.reason : null;
        },
        setErrors(e) {
            if (!e.data) {
                if (typeof e === 'string') {
                    this.$toast('error', e);
                }
                return;
            }
            const {errors} = e.data;
            if (Array.isArray(errors)) {
                let str = errors.reduce((acc, item) => {
                    if (typeof item === 'string') {
                        return acc + item + '<br/>';
                    }
                    return acc;
                }, '');
                if (str) {
                    this.$toast('error', str);
                    return;
                }
            }
            if (typeof errors === 'object' && errors.constructor === Object) {
                let obj = Object.entries(errors).reduce((accumulate, item) => {
                    if (typeof item[1] === 'string') return {...accumulate, [item[0]]: item[1]};
                    return {...accumulate, [item[0]]: item[1]['reason']};
                }, {});
                if (this.fieldErrors) {
                    Object.assign(this.fieldErrors, obj);
                }
                return;
            }
            if (typeof e.data.reason === 'string') this.$toast('error', e.data.reason, 10000);
        }
    }
};
