import errorsMixin from '@/modules/errors-mixin';
import confirmation from '@/components/confirmation/modal.vue';
import {mapActions} from 'vuex';

export default {
    mixins: [errorsMixin],
    inheritAttrs: false,
    data() {
        return {
            items: [],
            tableColumns: [],
            selectedItems: [],
            fieldErrors: {}
        };
    },
    methods: {
        ...mapActions({
            showLoader: 'showLoader',
            hideLoader: 'hideLoader'
        }),
        setTableColumns(items) {
            this.tableColumns = items;

            return this;
        },
        getItems() {
            return Array.from(this.items);
        },
        setItems(items) {
            this.items = items;
        },
        dblClick(val) {
            this.edit(val);
        },
        showDeleteConfirmation() {
            this.$modal.open({
                component: confirmation,
                title: this.$t('buttons.Delete'),
                props: {
                    text: this.$t('JS.ConfirmDelete'),
                    callback: this.remove,
                    btnOk: this.$t('buttons.Delete')
                }
            });
        },
        isEditDisabled() {
            return this.selectedItems.length !== 1;
        },
        isDeleteDisabled() {
            return !this.selectedItems.length;
        },
        isCreateDisabled() {
            return false;
        }
    }
};
