export default {
    namespaced: true,
    state: {
        rules: [],
        additionalRules: [],
        extens: [],
        appsList: [],
        schemes: {},
        optionsLists: {},
        valCompareErrs: {}
    },
    actions: {
        fetchRules({commit}) {
            return this._vm.$api.PBX.dialplans.rules.getList().then(({result}) => {
                commit('setRules', result.records);
                return {result};
            });
        },
        fetchAdditionalRules({commit}) {
            return this._vm.$api.PBX.dialplans.rules
                .getAdditionalRules()
                .then(({result}) => {
                    commit('setAdditionalRules', result.records);
                    return {result};
                });
        },
        fetchExtens({commit}) {
            return this._vm.$api.PBX.dialplans.rules.getExtens().then(({result}) => {
                commit('setExtens', result.extens);
                return {result};
            });
        },
        fetchAppsList({commit}) {
            return this._vm.$api.PBX.dialplans.rules.getAppsList().then(({result}) => {
                commit('setAppsList', result.appsList);
                return {result};
            });
        },
        fetchScheme({commit}) {
            return this._vm.$api.PBX.dialplans.rules
                .getScheme()
                .then(({result}) => {
                    commit('setScheme', result.records);
                    return {result};
                });
        }
    },
    mutations: {
        setRules(state, data) {
            state.rules = data;
        },
        setAdditionalRules(state, data) {
            state.additionalRules = data;
        },
        setExtens(state, data) {
            state.extens = Object.entries(data).map(item => {
                return {
                    value: item[0],
                    label: item[1]
                };
            });
        },
        setAppsList(state, data) {
            state.appsList = Object.entries(data).map((item, index) => {
                return {
                    label: this._vm.$t(`inccalls.${item[0]}`),
                    options: Object.entries(item[1]).map((inner, idx) => {
                        return {
                            value: inner[0],
                            text: this._vm.$t(`inccalls.${inner[0]}`)
                        };
                    })
                };
            });
        },
        setScheme(state, data) {
            state.schemes = data.reduce((acc, item) => {
                return {...acc, [item.name]: item};
            }, {});
        },
        setValCompareError(state, obj) {
            state.valCompareErrs[obj.key] = obj.data;
        },
        removeValCompareError(state, key) {
            delete state.valCompareErrs[key];
        },
        clearValCompareErrs(state) {
            state.valCompareErrs = {};
        }
    },
    getters: {
        getRules: state => state.rules,
        getAdditionalRules: state => state.additionalRules,
        getExtens: state => state.extens,
        getAppsList: state => state.appsList,
        getScheme: state => key => state.schemes[key],
        getSchemes: state => state.schemes,
        getReqStatus: state => key => state.reqStatus[key],
        getValCompareError: state => key => state.valCompareErrs[key],
        getValCompareErrors: state => state.valCompareErrs
    }
};
